/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ArgumentCoders.h"
#include "Connection.h"
#include "IdentifierTypes.h"
#include "MessageNames.h"
#include <WebCore/LayerHostingContextIdentifier.h>
#include <wtf/Forward.h>
#include <wtf/ThreadSafeRefCounted.h>

namespace WebKit {
struct FrameInfoData;
}

namespace Messages {
namespace WebFrame {

static inline IPC::ReceiverName messageReceiverName()
{
    return IPC::ReceiverName::WebFrame;
}

class GetFrameInfo {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFrame_GetFrameInfo; }
    static constexpr bool isSync = false;

    static IPC::MessageName asyncMessageReplyName() { return IPC::MessageName::WebFrame_GetFrameInfoReply; }
    static constexpr auto callbackThread = WTF::CompletionHandlerCallThread::ConstructionThread;
    using ReplyArguments = std::tuple<WebKit::FrameInfoData>;
    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

class ContinueWillSubmitForm {
public:
    using Arguments = std::tuple<WebKit::FormSubmitListenerIdentifier>;

    static IPC::MessageName name() { return IPC::MessageName::WebFrame_ContinueWillSubmitForm; }
    static constexpr bool isSync = false;

    explicit ContinueWillSubmitForm(const WebKit::FormSubmitListenerIdentifier& listenerID)
        : m_arguments(listenerID)
    {
    }

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const WebKit::FormSubmitListenerIdentifier&> m_arguments;
};

class DidCommitLoadInAnotherProcess {
public:
    using Arguments = std::tuple<WebCore::LayerHostingContextIdentifier>;

    static IPC::MessageName name() { return IPC::MessageName::WebFrame_DidCommitLoadInAnotherProcess; }
    static constexpr bool isSync = false;

    explicit DidCommitLoadInAnotherProcess(const WebCore::LayerHostingContextIdentifier& layerHostingContextIdentifier)
        : m_arguments(layerHostingContextIdentifier)
    {
    }

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const WebCore::LayerHostingContextIdentifier&> m_arguments;
};

class DidFinishLoadInAnotherProcess {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFrame_DidFinishLoadInAnotherProcess; }
    static constexpr bool isSync = false;

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

} // namespace WebFrame
} // namespace Messages
