/*
 * Copyright (C) 2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(FULLSCREEN_API)

#include "ArgumentCoders.h"
#include "Connection.h"
#include "MessageNames.h"
#include <WebCore/RectEdges.h>
#include <wtf/Forward.h>
#include <wtf/ThreadSafeRefCounted.h>


namespace Messages {
namespace WebFullScreenManager {

static inline IPC::ReceiverName messageReceiverName()
{
    return IPC::ReceiverName::WebFullScreenManager;
}

class RequestRestoreFullScreen {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_RequestRestoreFullScreen; }
    static constexpr bool isSync = false;

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

class RequestExitFullScreen {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_RequestExitFullScreen; }
    static constexpr bool isSync = false;

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

class WillEnterFullScreen {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_WillEnterFullScreen; }
    static constexpr bool isSync = false;

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

class DidEnterFullScreen {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_DidEnterFullScreen; }
    static constexpr bool isSync = false;

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

class WillExitFullScreen {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_WillExitFullScreen; }
    static constexpr bool isSync = false;

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

class DidExitFullScreen {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_DidExitFullScreen; }
    static constexpr bool isSync = false;

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

class SetAnimatingFullScreen {
public:
    using Arguments = std::tuple<bool>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_SetAnimatingFullScreen; }
    static constexpr bool isSync = false;

    explicit SetAnimatingFullScreen(bool animating)
        : m_arguments(animating)
    {
    }

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<bool> m_arguments;
};

class SaveScrollPosition {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_SaveScrollPosition; }
    static constexpr bool isSync = false;

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

class RestoreScrollPosition {
public:
    using Arguments = std::tuple<>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_RestoreScrollPosition; }
    static constexpr bool isSync = false;

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<> m_arguments;
};

class SetFullscreenInsets {
public:
    using Arguments = std::tuple<WebCore::RectEdges<float>>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_SetFullscreenInsets; }
    static constexpr bool isSync = false;

    explicit SetFullscreenInsets(const WebCore::RectEdges<float>& insets)
        : m_arguments(insets)
    {
    }

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const WebCore::RectEdges<float>&> m_arguments;
};

class SetFullscreenAutoHideDuration {
public:
    using Arguments = std::tuple<Seconds>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_SetFullscreenAutoHideDuration; }
    static constexpr bool isSync = false;

    explicit SetFullscreenAutoHideDuration(const Seconds& duration)
        : m_arguments(duration)
    {
    }

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const Seconds&> m_arguments;
};

class SetFullscreenControlsHidden {
public:
    using Arguments = std::tuple<bool>;

    static IPC::MessageName name() { return IPC::MessageName::WebFullScreenManager_SetFullscreenControlsHidden; }
    static constexpr bool isSync = false;

    explicit SetFullscreenControlsHidden(bool hidden)
        : m_arguments(hidden)
    {
    }

    const auto& arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<bool> m_arguments;
};

} // namespace WebFullScreenManager
} // namespace Messages

#endif // ENABLE(FULLSCREEN_API)
