/*
 * Copyright (C) 2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "GeneratedSerializers.h"

template<size_t...> struct MembersInCorrectOrder;
template<size_t onlyOffset> struct MembersInCorrectOrder<onlyOffset> { static constexpr bool value = true; };
template<size_t firstOffset, size_t secondOffset, size_t... remainingOffsets> struct MembersInCorrectOrder<firstOffset, secondOffset, remainingOffsets...> {
    static constexpr bool value = firstOffset > secondOffset ? false : MembersInCorrectOrder<secondOffset, remainingOffsets...>::value;
};

#if COMPILER(GCC)
IGNORE_WARNINGS_BEGIN("invalid-offsetof")
#endif
#include "APIError.h"
#include "APIFrameHandle.h"
#include "APIGeometry.h"
#include "APIPageHandle.h"
#include "APIURL.h"
#include "APIURLRequest.h"
#include "APIURLResponse.h"
#include "ArgumentCoders.h"
#if USE(SOUP)
#include "ArgumentCodersGLib.h"
#endif
#include "AuxiliaryProcessCreationParameters.h"
#include "CacheModel.h"
#include "EditorState.h"
#include "FocusedElementInformation.h"
#include "FrameInfoData.h"
#include "FrameInfoData.h"
#include "FrameTreeNodeData.h"
#if ENABLE(GPU_PROCESS)
#include "GPUProcessSessionParameters.h"
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
#include "InitializationSegmentInfo.h"
#endif
#include "LayerTreeContext.h"
#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
#include "MediaDescriptionInfo.h"
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW)
#include "ModelIdentifier.h"
#endif
#include "NetworkLoadParameters.h"
#include "NetworkProcessCreationParameters.h"
#include "NetworkProcessCreationParameters.h"
#include "NetworkResourceLoadParameters.h"
#include "NetworkResourceLoadParameters.h"
#if PLATFORM(COCOA)
#include "RemoteLayerTreeTransaction.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "RemoteMediaPlayerConfiguration.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "RemoteMediaPlayerProxyConfiguration.h"
#endif
#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#include "RemoteMediaPlayerState.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "RemoteRenderingBackendCreationParameters.h"
#endif
#include "RemoteScrollingUIState.h"
#include "SameDocumentNavigationType.h"
#include "SessionState.h"
#include "ShareableBitmap.h"
#include "ShareableBitmap.h"
#include "StreamConnectionEncoder.h"
#include "SwapBuffersDisplayRequirement.h"
#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)
#include "TextTrackPrivateRemoteConfiguration.h"
#endif
#include "WebCoreArgumentCoders.h"
#include "WebCoreArgumentCoders.h"
#include "WebEvent.h"
#if ENABLE(GPU_PROCESS)
#include "WebGPUBindGroupDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUBindGroupEntry.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUBindGroupLayoutDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUBindGroupLayoutEntry.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUBlendComponent.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUBlendState.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUBufferBinding.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUBufferBindingLayout.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUBufferDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUCanvasConfiguration.h"
#endif
#include "WebGPUColor.h"
#if ENABLE(GPU_PROCESS)
#include "WebGPUColorTargetState.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUCommandBufferDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUCommandEncoderDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUCompilationMessage.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUComputePassDescriptor.h"
#endif
#include "WebGPUComputePassTimestampWrites.h"
#if ENABLE(GPU_PROCESS)
#include "WebGPUComputePipelineDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUDepthStencilState.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUDeviceDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUExtent3D.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUExternalTextureBindingLayout.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUExternalTextureDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUFragmentState.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUImageCopyBuffer.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUImageCopyExternalImage.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUImageCopyTexture.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUImageCopyTextureTagged.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUImageDataLayout.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUMultisampleState.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUObjectDescriptorBase.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUOrigin2D.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUOrigin3D.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUOutOfMemoryError.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUPipelineDescriptorBase.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUPipelineLayoutDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUPresentationContextDescriptor.h"
#endif
#include "WebGPUPrimitiveState.h"
#if ENABLE(GPU_PROCESS)
#include "WebGPUPrimitiveState.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUProgrammableStage.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUQuerySetDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPURenderBundleDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPURenderBundleEncoderDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPURenderPassColorAttachment.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPURenderPassDepthStencilAttachment.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPURenderPassDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPURenderPassLayout.h"
#endif
#include "WebGPURenderPassTimestampWrites.h"
#if ENABLE(GPU_PROCESS)
#include "WebGPURenderPipelineDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPURequestAdapterOptions.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUSamplerBindingLayout.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUSamplerDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUShaderModuleCompilationHint.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUShaderModuleDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUStencilFaceState.h"
#endif
#include "WebGPUStorageTextureBindingLayout.h"
#if ENABLE(GPU_PROCESS)
#include "WebGPUStorageTextureBindingLayout.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUSupportedFeatures.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUSupportedLimits.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUTextureBindingLayout.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUTextureDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUTextureViewDescriptor.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUValidationError.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUVertexAttribute.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUVertexBufferLayout.h"
#endif
#if ENABLE(GPU_PROCESS)
#include "WebGPUVertexState.h"
#endif
#if ENABLE(MAC_GESTURE_EVENTS)
#include "WebGestureEvent.h"
#endif
#include "WebHitTestResultData.h"
#include "WebIDBResult.h"
#include "WebKeyboardEvent.h"
#include "WebMouseEvent.h"
#include "WebPopupItem.h"
#include "WebPushDaemonConnectionConfiguration.h"
#include "WebPushMessage.h"
#if ENABLE(TOUCH_EVENTS)
#include "WebTouchEvent.h"
#endif
#include "WebWheelEvent.h"
#include "WebsiteDataFetchOption.h"
#include "WebsiteDataStoreParameters.h"
#include "WebsiteDataStoreParameters.h"
#if USE(CG)
#include <CoreGraphics/CGAffineTransform.h>
#endif
#if USE(CG)
#include <CoreGraphics/CGGeometry.h>
#endif
#if USE(SYSTEM_PREVIEW)
#include <WebCore/ARKitBadgeSystemImage.h>
#endif
#include <WebCore/AffineTransform.h>
#if ENABLE(APP_HIGHLIGHTS)
#include <WebCore/AppHighlight.h>
#endif
#if ENABLE(APPLE_PAY_AMS_UI) && ENABLE(PAYMENT_REQUEST)
#include <WebCore/ApplePayAMSUIRequest.h>
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
#include <WebCore/ApplePayAutomaticReloadPaymentRequest.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayButtonPart.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayButtonPart.h>
#endif
#if ENABLE(APPLE_PAY_COUPON_CODE)
#include <WebCore/ApplePayCouponCodeUpdate.h>
#endif
#if ENABLE(APPLE_PAY_SHIPPING_METHOD_DATE_COMPONENTS_RANGE)
#include <WebCore/ApplePayDateComponents.h>
#endif
#if ENABLE(APPLE_PAY_SHIPPING_METHOD_DATE_COMPONENTS_RANGE)
#include <WebCore/ApplePayDateComponentsRange.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayDetailsUpdateBase.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayError.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayLineItem.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayLogoSystemImage.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayPaymentAuthorizationResult.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayPaymentMethodUpdate.h>
#endif
#if ENABLE(APPLE_PAY_PAYMENT_ORDER_DETAILS)
#include <WebCore/ApplePayPaymentOrderDetails.h>
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
#include <WebCore/ApplePayPaymentTokenContext.h>
#endif
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
#include <WebCore/ApplePayRecurringPaymentRequest.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayShippingContactUpdate.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayShippingMethod.h>
#endif
#if ENABLE(APPLE_PAY)
#include <WebCore/ApplePayShippingMethodUpdate.h>
#endif
#if ENABLE(APPLICATION_MANIFEST)
#include <WebCore/ApplicationManifest.h>
#endif
#include <WebCore/AttributionSecondsUntilSendData.h>
#include <WebCore/AudioConfiguration.h>
#include <WebCore/AudioIOCallback.h>
#if USE(AUDIO_SESSION)
#include <WebCore/AudioSession.h>
#endif
#include <WebCore/AuthenticationChallenge.h>
#if ENABLE(WEB_AUTHN)
#include <WebCore/AuthenticationExtensionsClientInputs.h>
#endif
#if ENABLE(WEB_AUTHN)
#include <WebCore/AuthenticationExtensionsClientOutputs.h>
#endif
#include <WebCore/AutocapitalizeTypes.h>
#include <WebCore/BasicShapes.h>
#include <WebCore/BufferSource.h>
#if ENABLE(ENCRYPTED_MEDIA)
#include <WebCore/CDMKeySystemConfiguration.h>
#endif
#if ENABLE(ENCRYPTED_MEDIA)
#include <WebCore/CDMMediaCapability.h>
#endif
#include <WebCore/CSPViolationReportBody.h>
#include <WebCore/CacheQueryOptions.h>
#include <WebCore/CanvasActivityRecord.h>
#include <WebCore/CertificateInfo.h>
#include <WebCore/CharacterRange.h>
#include <WebCore/ClientOrigin.h>
#include <WebCore/ColorInterpolationMethod.h>
#include <WebCore/CompositionHighlight.h>
#include <WebCore/CompositionUnderline.h>
#include <WebCore/ContactInfo.h>
#include <WebCore/ContactsRequestData.h>
#include <WebCore/ContentType.h>
#include <WebCore/ControlStyle.h>
#include <WebCore/Cookie.h>
#include <WebCore/CookieRequestHeaderFieldProxy.h>
#include <WebCore/CrossOriginEmbedderPolicy.h>
#include <WebCore/CrossOriginOpenerPolicy.h>
#include <WebCore/CustomHeaderFields.h>
#include <WebCore/DOMCacheEngine.h>
#include <WebCore/DOMPasteAccess.h>
#if ENABLE(DATA_DETECTION)
#include <WebCore/DataDetectorType.h>
#endif
#if ENABLE(DATALIST_ELEMENT)
#include <WebCore/DataListSuggestionInformation.h>
#endif
#if ENABLE(DATALIST_ELEMENT)
#include <WebCore/DataListSuggestionInformation.h>
#endif
#if ENABLE(DATALIST_ELEMENT)
#include <WebCore/DataListSuggestionInformation.h>
#endif
#include <WebCore/DatabaseDetails.h>
#if ENABLE(DATE_AND_TIME_INPUT_TYPES)
#include <WebCore/DateTimeChooserParameters.h>
#endif
#include <WebCore/DecomposedGlyphs.h>
#include <WebCore/DeprecationReportBody.h>
#include <WebCore/DestinationColorSpace.h>
#if ENABLE(WEB_RTC)
#include <WebCore/DetachedRTCDataChannel.h>
#endif
#include <WebCore/DeviceOrientationOrMotionPermissionState.h>
#include <WebCore/DictationAlternative.h>
#include <WebCore/DictionaryPopupInfo.h>
#include <WebCore/DisplayListItems.h>
#include <WebCore/DisplayListItems.h>
#include <WebCore/DistantLightSource.h>
#include <WebCore/DocumentStorageAccess.h>
#if ENABLE(DRAG_SUPPORT)
#include <WebCore/DragData.h>
#endif
#include <WebCore/DragData.h>
#include <WebCore/ElementContext.h>
#include <WebCore/EventInit.h>
#include <WebCore/EventTrackingRegions.h>
#include <WebCore/Exception.h>
#include <WebCore/ExceptionData.h>
#include <WebCore/ExceptionDetails.h>
#include <WebCore/ExceptionDetails.h>
#include <WebCore/FEBlend.h>
#include <WebCore/FEColorMatrix.h>
#include <WebCore/FEComponentTransfer.h>
#include <WebCore/FEComponentTransfer.h>
#include <WebCore/FEComposite.h>
#include <WebCore/FEConvolveMatrix.h>
#include <WebCore/FEDiffuseLighting.h>
#include <WebCore/FEDisplacementMap.h>
#include <WebCore/FEDropShadow.h>
#include <WebCore/FEFlood.h>
#include <WebCore/FEGaussianBlur.h>
#include <WebCore/FEImage.h>
#include <WebCore/FEMerge.h>
#include <WebCore/FEMorphology.h>
#include <WebCore/FEOffset.h>
#include <WebCore/FESpecularLighting.h>
#include <WebCore/FETurbulence.h>
#include <WebCore/FetchOptions.h>
#include <WebCore/FileChooser.h>
#include <WebCore/FloatPoint.h>
#include <WebCore/FloatPoint3D.h>
#include <WebCore/FloatQuad.h>
#include <WebCore/FloatRect.h>
#include <WebCore/FloatRoundedRect.h>
#include <WebCore/FloatSize.h>
#include <WebCore/FocusDirection.h>
#include <WebCore/FontAttributeChanges.h>
#include <WebCore/FontAttributeChanges.h>
#include <WebCore/FontAttributeChanges.h>
#include <WebCore/FontAttributes.h>
#include <WebCore/FontShadow.h>
#include <WebCore/FormData.h>
#include <WebCore/FormData.h>
#include <WebCore/FourCC.h>
#include <WebCore/FrameLoaderTypes.h>
#if ENABLE(GAMEPAD)
#include <WebCore/GamepadEffectParameters.h>
#endif
#if ENABLE(GAMEPAD)
#include <WebCore/GamepadHapticEffectType.h>
#endif
#include <WebCore/GeolocationPositionData.h>
#include <WebCore/Gradient.h>
#include <WebCore/GradientColorStop.h>
#include <WebCore/GradientColorStops.h>
#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)
#include <WebCore/GraphicsContextGLActiveInfo.h>
#endif
#if ENABLE(GPU_PROCESS)
#include <WebCore/GraphicsContextGLAttributes.h>
#endif
#if ENABLE(GPU_PROCESS)
#include <WebCore/GraphicsContextGLAttributes.h>
#endif
#if ENABLE(GPU_PROCESS)
#include <WebCore/GraphicsContextGLAttributes.h>
#endif
#include <WebCore/GraphicsTypes.h>
#include <WebCore/GraphicsTypes.h>
#include <WebCore/GraphicsTypes.h>
#include <WebCore/HTMLModelElementCamera.h>
#include <WebCore/HTTPCookieAcceptPolicy.h>
#include <WebCore/HTTPHeaderField.h>
#include <WebCore/HTTPHeaderMap.h>
#include <WebCore/HTTPHeaderMap.h>
#include <WebCore/HTTPHeaderMap.h>
#include <WebCore/IDBCursorInfo.h>
#include <WebCore/IDBCursorRecord.h>
#include <WebCore/IDBDatabaseIdentifier.h>
#include <WebCore/IDBDatabaseInfo.h>
#include <WebCore/IDBDatabaseNameAndVersion.h>
#include <WebCore/IDBError.h>
#include <WebCore/IDBGetAllRecordsData.h>
#include <WebCore/IDBGetAllResult.h>
#include <WebCore/IDBGetRecordData.h>
#include <WebCore/IDBGetResult.h>
#include <WebCore/IDBIndexInfo.h>
#include <WebCore/IDBIterateCursorData.h>
#include <WebCore/IDBKeyData.h>
#include <WebCore/IDBKeyRangeData.h>
#include <WebCore/IDBObjectStoreInfo.h>
#include <WebCore/IDBRequestData.h>
#include <WebCore/IDBResourceIdentifier.h>
#include <WebCore/IDBResultData.h>
#include <WebCore/IDBTransactionInfo.h>
#include <WebCore/IDBValue.h>
#include <WebCore/IdentityTransformOperation.h>
#include <WebCore/ImageBufferBackendParameters.h>
#include <WebCore/ImageDecoder.h>
#include <WebCore/ImageOrientation.h>
#include <WebCore/ImagePaintingOptions.h>
#if ENABLE(VIDEO)
#include <WebCore/InbandGenericCue.h>
#endif
#if ENABLE(INLINE_PATH_DATA)
#include <WebCore/InlinePathData.h>
#endif
#if ENABLE(INLINE_PATH_DATA)
#include <WebCore/InlinePathData.h>
#endif
#if ENABLE(INLINE_PATH_DATA)
#include <WebCore/InlinePathData.h>
#endif
#if ENABLE(INLINE_PATH_DATA)
#include <WebCore/InlinePathData.h>
#endif
#if ENABLE(INLINE_PATH_DATA)
#include <WebCore/InlinePathData.h>
#endif
#if ENABLE(INLINE_PATH_DATA)
#include <WebCore/InlinePathData.h>
#endif
#include <WebCore/IntPoint.h>
#include <WebCore/IntRect.h>
#include <WebCore/IntSize.h>
#include <WebCore/KeyboardScroll.h>
#include <WebCore/LayoutPoint.h>
#include <WebCore/LayoutRect.h>
#include <WebCore/LayoutSize.h>
#include <WebCore/LayoutUnit.h>
#include <WebCore/LengthSize.h>
#include <WebCore/Matrix3DTransformOperation.h>
#include <WebCore/MatrixTransformOperation.h>
#include <WebCore/MediaCapabilitiesDecodingInfo.h>
#include <WebCore/MediaCapabilitiesEncodingInfo.h>
#include <WebCore/MediaCapabilitiesInfo.h>
#include <WebCore/MediaConfiguration.h>
#if ENABLE(MEDIA_STREAM)
#include <WebCore/MediaConstraints.h>
#endif
#include <WebCore/MediaDecodingConfiguration.h>
#include <WebCore/MediaDeviceHashSalts.h>
#include <WebCore/MediaEncodingConfiguration.h>
#if ENABLE(VIDEO)
#include <WebCore/MediaPlayer.h>
#endif
#if ENABLE(MEDIA_SESSION)
#include <WebCore/MediaPositionState.h>
#endif
#include <WebCore/MediaSelectionOption.h>
#include <WebCore/MediaStreamRequest.h>
#if ENABLE(MEDIA_STREAM)
#include <WebCore/MediaStreamRequest.h>
#endif
#if ! ENABLE(MEDIA_STREAM)
#include <WebCore/MediaStreamRequest.h>
#endif
#include <WebCore/MessagePortIdentifier.h>
#include <WebCore/MessageWithMessagePorts.h>
#include <WebCore/MeterPart.h>
#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
#include <WebCore/MockContentFilterSettings.h>
#endif
#include <WebCore/ModalContainerTypes.h>
#if ENABLE(SERVICE_WORKER)
#include <WebCore/NavigationPreloadState.h>
#endif
#include <WebCore/NavigationRequester.h>
#include <WebCore/NetworkLoadInformation.h>
#include <WebCore/NotificationData.h>
#include <WebCore/NotificationResources.h>
#include <WebCore/Pasteboard.h>
#include <WebCore/Pasteboard.h>
#include <WebCore/Pasteboard.h>
#include <WebCore/Pasteboard.h>
#include <WebCore/Pasteboard.h>
#include <WebCore/PasteboardCustomData.h>
#include <WebCore/Path.h>
#include <WebCore/PathOperation.h>
#include <WebCore/PathOperation.h>
#include <WebCore/Pattern.h>
#include <WebCore/PermissionDescriptor.h>
#include <WebCore/PerspectiveTransformOperation.h>
#include <WebCore/PixelBufferFormat.h>
#if !USE(CG)
#include <WebCore/PlatformColorSpace.h>
#endif
#include <WebCore/PlatformTimeRanges.h>
#include <WebCore/PluginData.h>
#include <WebCore/PointLightSource.h>
#include <WebCore/PolicyContainer.h>
#include <WebCore/PrivateClickMeasurement.h>
#include <WebCore/ProcessIdentity.h>
#include <WebCore/ProgressBarPart.h>
#include <WebCore/PromisedAttachmentInfo.h>
#include <WebCore/PublicKeyCredentialCreationOptions.h>
#if ENABLE(WEB_AUTHN)
#include <WebCore/PublicKeyCredentialDescriptor.h>
#endif
#include <WebCore/PublicKeyCredentialRequestOptions.h>
#if ENABLE(SERVICE_WORKER)
#include <WebCore/PushSubscriptionData.h>
#endif
#include <WebCore/RectEdges.h>
#include <WebCore/RegistrableDomain.h>
#include <WebCore/RenderStyleConstants.h>
#include <WebCore/Report.h>
#include <WebCore/ResourceLoadStatistics.h>
#include <WebCore/ResourceRequest.h>
#if USE(SOUP)
#include <WebCore/ResourceRequest.h>
#endif
#if PLATFORM(COCOA) && USE(SYSTEM_PREVIEW)
#include <WebCore/ResourceRequest.h>
#endif
#if PLATFORM(COCOA) && !USE(SYSTEM_PREVIEW)
#include <WebCore/ResourceRequest.h>
#endif
#if USE(CURL)
#include <WebCore/ResourceRequest.h>
#endif
#if !USE(CURL) && !PLATFORM(COCOA)
#include <WebCore/ResourceRequest.h>
#endif
#if !USE(CURL) && !PLATFORM(COCOA)
#include <WebCore/ResourceRequest.h>
#endif
#include <WebCore/ResourceResponse.h>
#include <WebCore/ResourceResponseBase.h>
#include <WebCore/RetrieveRecordsOptions.h>
#include <WebCore/RotateTransformOperation.h>
#include <WebCore/SVGPathByteStream.h>
#include <WebCore/SameSiteInfo.h>
#include <WebCore/ScaleTransformOperation.h>
#include <WebCore/ScreenProperties.h>
#include <WebCore/ScreenProperties.h>
#include <WebCore/ScrollTypes.h>
#include <WebCore/ScrollTypes.h>
#include <WebCore/ScrollTypes.h>
#include <WebCore/ScrollingConstraints.h>
#include <WebCore/ScrollingCoordinatorTypes.h>
#include <WebCore/ScrollingCoordinatorTypes.h>
#if ENABLE(ASYNC_SCROLLING)
#include <WebCore/ScrollingStateNode.h>
#endif
#include <WebCore/SearchPopupMenu.h>
#include <WebCore/SecurityOrigin.h>
#include <WebCore/SecurityOriginData.h>
#include <WebCore/SecurityPolicyViolationEvent.h>
#include <WebCore/SecurityPolicyViolationEventDisposition.h>
#if PLATFORM(IOS_FAMILY)
#include <WebCore/SelectionGeometry.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ServiceWorkerClientData.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ServiceWorkerClientQueryOptions.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ServiceWorkerData.h>
#endif
#if ENABLE(SERVICE_WORKER)
#include <WebCore/ServiceWorkerJobData.h>
#endif
#include <WebCore/ShareData.h>
#include <WebCore/ShareData.h>
#include <WebCore/SkewTransformOperation.h>
#include <WebCore/SliderTrackPart.h>
#include <WebCore/SourceBrush.h>
#include <WebCore/SpeechRecognitionError.h>
#include <WebCore/SpeechRecognitionRequestInfo.h>
#include <WebCore/SpeechRecognitionResultData.h>
#include <WebCore/SpeechRecognitionUpdate.h>
#include <WebCore/SpotLightSource.h>
#include <WebCore/StorageEstimate.h>
#include <WebCore/StorageEstimate.h>
#include <WebCore/SubstituteData.h>
#include <WebCore/TestReportBody.h>
#include <WebCore/TextChecking.h>
#include <WebCore/TextChecking.h>
#include <WebCore/TextChecking.h>
#include <WebCore/TextChecking.h>
#include <WebCore/TextGranularity.h>
#include <WebCore/TextIndicator.h>
#include <WebCore/TextIndicator.h>
#include <WebCore/TextManipulationController.h>
#include <WebCore/TextManipulationController.h>
#include <WebCore/TextManipulationController.h>
#include <WebCore/TextManipulationController.h>
#include <WebCore/TextManipulationController.h>
#include <WebCore/TextManipulationController.h>
#include <WebCore/TextManipulationController.h>
#include <WebCore/TextManipulationItem.h>
#include <WebCore/TextManipulationToken.h>
#include <WebCore/TextManipulationToken.h>
#if ENABLE(IMAGE_ANALYSIS)
#include <WebCore/TextRecognitionResult.h>
#endif
#if ENABLE(IMAGE_ANALYSIS)
#include <WebCore/TextRecognitionResult.h>
#endif
#if ENABLE(IMAGE_ANALYSIS)
#include <WebCore/TextRecognitionResult.h>
#endif
#if ENABLE(IMAGE_ANALYSIS)
#include <WebCore/TextRecognitionResult.h>
#endif
#include <WebCore/TimingFunction.h>
#include <WebCore/TransformOperation.h>
#include <WebCore/TransformOperations.h>
#include <WebCore/TransformationMatrix.h>
#include <WebCore/TranslateTransformOperation.h>
#include <WebCore/UserStyleSheet.h>
#include <WebCore/VP9Utilities.h>
#include <WebCore/VelocityData.h>
#if ENABLE(VIDEO)
#include <WebCore/VideoFrame.h>
#endif
#if ENABLE(VIDEO) && USE(AVFOUNDATION)
#include <WebCore/VideoFrameCV.h>
#endif
#if ENABLE(VIDEO)
#include <WebCore/VideoFrameMetadata.h>
#endif
#if ENABLE(VIDEO)
#include <WebCore/VideoPlaybackQualityMetrics.h>
#endif
#include <WebCore/ViewportArguments.h>
#include <WebCore/VisibleSelection.h>
#include <WebCore/WebCodecsEncodedVideoChunk.h>
#if ENABLE(WEB_CODECS)
#include <WebCore/WebCodecsEncodedVideoChunkData.h>
#endif
#include <WebCore/WebLockManagerSnapshot.h>
#include <WebCore/WindowFeatures.h>
#include <WebCore/WritingDirection.h>
#if ENABLE(WK_WEB_EXTENSIONS)
#include <WebKit/WebExtensionEventListenerType.h>
#endif
#include <pal/graphics/WebGPU/WebGPUPredefinedColorSpace.h>
#include <pal/graphics/WebGPU/WebGPUTextureAspect.h>
#include <pal/graphics/WebGPU/WebGPUTextureFormat.h>
#include <wtf/MediaTime.h>
#include <wtf/MonotonicTime.h>
#include <wtf/Seconds.h>
#include <wtf/URL.h>
#include <wtf/WallTime.h>
#include <wtf/text/AtomString.h>

namespace IPC {


#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)
template<> struct ArgumentCoder<WebKit::InitializationSegmentInfo::TrackInformation> {
    static void encode(Encoder&, const WebKit::InitializationSegmentInfo::TrackInformation&);
    static std::optional<WebKit::InitializationSegmentInfo::TrackInformation> decode(Decoder&);
};
#endif

template<> struct ArgumentCoder<WebKit::EditorState::PostLayoutData> {
    static void encode(Encoder&, const WebKit::EditorState::PostLayoutData&);
    static std::optional<WebKit::EditorState::PostLayoutData> decode(Decoder&);
};

template<> struct ArgumentCoder<WebKit::EditorState::VisualData> {
    static void encode(Encoder&, const WebKit::EditorState::VisualData&);
    static std::optional<WebKit::EditorState::VisualData> decode(Decoder&);
};

template<> struct ArgumentCoder<WebKit::HTTPBody::Element> {
    static void encode(Encoder&, const WebKit::HTTPBody::Element&);
    static std::optional<WebKit::HTTPBody::Element> decode(Decoder&);
};

template<> struct ArgumentCoder<WebKit::HTTPBody::Element::FileData> {
    static void encode(Encoder&, const WebKit::HTTPBody::Element::FileData&);
    static std::optional<WebKit::HTTPBody::Element::FileData> decode(Decoder&);
};

#if ENABLE(APPLICATION_MANIFEST)
template<> struct ArgumentCoder<WebCore::ApplicationManifest::Icon> {
    static void encode(Encoder&, const WebCore::ApplicationManifest::Icon&);
    static std::optional<WebCore::ApplicationManifest::Icon> decode(Decoder&);
};
#endif

template<> struct ArgumentCoder<WebCore::WebLockManagerSnapshot::Info> {
    static void encode(Encoder&, const WebCore::WebLockManagerSnapshot::Info&);
    static std::optional<WebCore::WebLockManagerSnapshot::Info> decode(Decoder&);
};

#if ENABLE(WEB_AUTHN)
template<> struct ArgumentCoder<WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput> {
    static void encode(Encoder&, const WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput&);
    static std::optional<WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput> decode(Decoder&);
};
#endif

#if ENABLE(WEB_AUTHN)
template<> struct ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::Parameters> {
    static void encode(Encoder&, const WebCore::PublicKeyCredentialCreationOptions::Parameters&);
    static std::optional<WebCore::PublicKeyCredentialCreationOptions::Parameters> decode(Decoder&);
};
#endif

#if ENABLE(WEB_AUTHN)
template<> struct ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria> {
    static void encode(Encoder&, const WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria&);
    static std::optional<WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria> decode(Decoder&);
};
#endif

#if ENABLE(WEB_AUTHN)
template<> struct ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::Entity> {
    static void encode(Encoder&, const WebCore::PublicKeyCredentialCreationOptions::Entity&);
    static std::optional<WebCore::PublicKeyCredentialCreationOptions::Entity> decode(Decoder&);
};
#endif

#if ENABLE(WEB_AUTHN)
template<> struct ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::RpEntity> {
    static void encode(Encoder&, const WebCore::PublicKeyCredentialCreationOptions::RpEntity&);
    static std::optional<WebCore::PublicKeyCredentialCreationOptions::RpEntity> decode(Decoder&);
};
#endif

#if ENABLE(WEB_AUTHN)
template<> struct ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::UserEntity> {
    static void encode(Encoder&, const WebCore::PublicKeyCredentialCreationOptions::UserEntity&);
    static std::optional<WebCore::PublicKeyCredentialCreationOptions::UserEntity> decode(Decoder&);
};
#endif

template<> struct ArgumentCoder<WebCore::HTTPHeaderMap::CommonHeader> {
    static void encode(Encoder&, const WebCore::HTTPHeaderMap::CommonHeader&);
    static std::optional<WebCore::HTTPHeaderMap::CommonHeader> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::HTTPHeaderMap::UncommonHeader> {
    static void encode(Encoder&, const WebCore::HTTPHeaderMap::UncommonHeader&);
    static std::optional<WebCore::HTTPHeaderMap::UncommonHeader> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ResourceRequest::RequestData> {
    static void encode(Encoder&, const WebCore::ResourceRequest::RequestData&);
    static std::optional<WebCore::ResourceRequest::RequestData> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::FormDataElement::EncodedFileData> {
    static void encode(Encoder&, const WebCore::FormDataElement::EncodedFileData&);
    static std::optional<WebCore::FormDataElement::EncodedFileData> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::FormDataElement::EncodedBlobData> {
    static void encode(Encoder&, const WebCore::FormDataElement::EncodedBlobData&);
    static std::optional<WebCore::FormDataElement::EncodedBlobData> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::PlatformTimeRanges::Range> {
    static void encode(Encoder&, const WebCore::PlatformTimeRanges::Range&);
    static std::optional<WebCore::PlatformTimeRanges::Range> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::PasteboardCustomData::Entry> {
    static void encode(Encoder&, const WebCore::PasteboardCustomData::Entry&);
    static std::optional<WebCore::PasteboardCustomData::Entry> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::Gradient::LinearData> {
    static void encode(Encoder&, const WebCore::Gradient::LinearData&);
    static void encode(StreamConnectionEncoder&, const WebCore::Gradient::LinearData&);
    static std::optional<WebCore::Gradient::LinearData> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::Gradient::RadialData> {
    static void encode(Encoder&, const WebCore::Gradient::RadialData&);
    static void encode(StreamConnectionEncoder&, const WebCore::Gradient::RadialData&);
    static std::optional<WebCore::Gradient::RadialData> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::Gradient::ConicData> {
    static void encode(Encoder&, const WebCore::Gradient::ConicData&);
    static void encode(StreamConnectionEncoder&, const WebCore::Gradient::ConicData&);
    static std::optional<WebCore::Gradient::ConicData> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::SourceBrush::Brush::LogicalGradient> {
    static void encode(Encoder&, const WebCore::SourceBrush::Brush::LogicalGradient&);
    static void encode(StreamConnectionEncoder&, const WebCore::SourceBrush::Brush::LogicalGradient&);
    static std::optional<WebCore::SourceBrush::Brush::LogicalGradient> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::Pattern::Parameters> {
    static void encode(Encoder&, const WebCore::Pattern::Parameters&);
    static void encode(StreamConnectionEncoder&, const WebCore::Pattern::Parameters&);
    static std::optional<WebCore::Pattern::Parameters> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::SourceBrush::Brush> {
    static void encode(Encoder&, const WebCore::SourceBrush::Brush&);
    static void encode(StreamConnectionEncoder&, const WebCore::SourceBrush::Brush&);
    static std::optional<WebCore::SourceBrush::Brush> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ResourceResponseBase::ResponseData> {
    static void encode(Encoder&, const WebCore::ResourceResponseBase::ResponseData&);
    static std::optional<WebCore::ResourceResponseBase::ResponseData> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::TextManipulationControllerExclusionRule::ElementRule> {
    static void encode(Encoder&, const WebCore::TextManipulationControllerExclusionRule::ElementRule&);
    static std::optional<WebCore::TextManipulationControllerExclusionRule::ElementRule> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::TextManipulationControllerExclusionRule::AttributeRule> {
    static void encode(Encoder&, const WebCore::TextManipulationControllerExclusionRule::AttributeRule&);
    static std::optional<WebCore::TextManipulationControllerExclusionRule::AttributeRule> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::TextManipulationControllerExclusionRule::ClassRule> {
    static void encode(Encoder&, const WebCore::TextManipulationControllerExclusionRule::ClassRule&);
    static std::optional<WebCore::TextManipulationControllerExclusionRule::ClassRule> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::HSL> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::HSL&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::HSL&);
    static std::optional<WebCore::ColorInterpolationMethod::HSL> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::HWB> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::HWB&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::HWB&);
    static std::optional<WebCore::ColorInterpolationMethod::HWB> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::LCH> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::LCH&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::LCH&);
    static std::optional<WebCore::ColorInterpolationMethod::LCH> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::Lab> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::Lab&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::Lab&);
    static std::optional<WebCore::ColorInterpolationMethod::Lab> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::OKLCH> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::OKLCH&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::OKLCH&);
    static std::optional<WebCore::ColorInterpolationMethod::OKLCH> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::OKLab> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::OKLab&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::OKLab&);
    static std::optional<WebCore::ColorInterpolationMethod::OKLab> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::SRGB> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::SRGB&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::SRGB&);
    static std::optional<WebCore::ColorInterpolationMethod::SRGB> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::SRGBLinear> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::SRGBLinear&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::SRGBLinear&);
    static std::optional<WebCore::ColorInterpolationMethod::SRGBLinear> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::XYZD50> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::XYZD50&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::XYZD50&);
    static std::optional<WebCore::ColorInterpolationMethod::XYZD50> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::ColorInterpolationMethod::XYZD65> {
    static void encode(Encoder&, const WebCore::ColorInterpolationMethod::XYZD65&);
    static void encode(StreamConnectionEncoder&, const WebCore::ColorInterpolationMethod::XYZD65&);
    static std::optional<WebCore::ColorInterpolationMethod::XYZD65> decode(Decoder&);
};

template<> struct ArgumentCoder<WebCore::SecurityOriginData::Tuple> {
    static void encode(Encoder&, const WebCore::SecurityOriginData::Tuple&);
    static std::optional<WebCore::SecurityOriginData::Tuple> decode(Decoder&);
};


#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::GPUProcessSessionParameters>::encode(Encoder& encoder, const WebKit::GPUProcessSessionParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mediaCacheDirectory)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mediaCacheDirectorySandboxExtensionHandle)>, WebKit::SandboxExtension::Handle>);
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mediaKeysStorageDirectory)>, String>);
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mediaKeysStorageDirectorySandboxExtensionHandle)>, WebKit::SandboxExtension::Handle>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::GPUProcessSessionParameters, mediaCacheDirectory)
        , offsetof(WebKit::GPUProcessSessionParameters, mediaCacheDirectorySandboxExtensionHandle)
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
        , offsetof(WebKit::GPUProcessSessionParameters, mediaKeysStorageDirectory)
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
        , offsetof(WebKit::GPUProcessSessionParameters, mediaKeysStorageDirectorySandboxExtensionHandle)
#endif
    >::value);
    encoder << instance.mediaCacheDirectory;
    encoder << instance.mediaCacheDirectorySandboxExtensionHandle;
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    encoder << instance.mediaKeysStorageDirectory;
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    encoder << instance.mediaKeysStorageDirectorySandboxExtensionHandle;
#endif
}

std::optional<WebKit::GPUProcessSessionParameters> ArgumentCoder<WebKit::GPUProcessSessionParameters>::decode(Decoder& decoder)
{
    auto mediaCacheDirectory = decoder.decode<String>();
    if (!mediaCacheDirectory)
        return std::nullopt;

    auto mediaCacheDirectorySandboxExtensionHandle = decoder.decode<WebKit::SandboxExtension::Handle>();
    if (!mediaCacheDirectorySandboxExtensionHandle)
        return std::nullopt;

#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    auto mediaKeysStorageDirectory = decoder.decode<String>();
    if (!mediaKeysStorageDirectory)
        return std::nullopt;
#endif

#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
    auto mediaKeysStorageDirectorySandboxExtensionHandle = decoder.decode<WebKit::SandboxExtension::Handle>();
    if (!mediaKeysStorageDirectorySandboxExtensionHandle)
        return std::nullopt;
#endif

    return {
        WebKit::GPUProcessSessionParameters {
            WTFMove(*mediaCacheDirectory),
            WTFMove(*mediaCacheDirectorySandboxExtensionHandle),
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
            WTFMove(*mediaKeysStorageDirectory),
#endif
#if ENABLE(LEGACY_ENCRYPTED_MEDIA)
            WTFMove(*mediaKeysStorageDirectorySandboxExtensionHandle)
#endif
        }
    };
}

#endif

#if ENABLE(INLINE_PATH_DATA)

void ArgumentCoder<WebCore::LineData>::encode(Encoder& encoder, const WebCore::LineData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.start)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.end)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::LineData, start)
        , offsetof(WebCore::LineData, end)
    >::value);
    encoder << instance.start;
    encoder << instance.end;
}

void ArgumentCoder<WebCore::LineData>::encode(StreamConnectionEncoder& encoder, const WebCore::LineData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.start)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.end)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::LineData, start)
        , offsetof(WebCore::LineData, end)
    >::value);
    encoder << instance.start;
    encoder << instance.end;
}

std::optional<WebCore::LineData> ArgumentCoder<WebCore::LineData>::decode(Decoder& decoder)
{
    auto start = decoder.decode<WebCore::FloatPoint>();
    if (!start)
        return std::nullopt;

    auto end = decoder.decode<WebCore::FloatPoint>();
    if (!end)
        return std::nullopt;

    return {
        WebCore::LineData {
            WTFMove(*start),
            WTFMove(*end)
        }
    };
}

#endif

#if ENABLE(INLINE_PATH_DATA)

void ArgumentCoder<WebCore::MoveData>::encode(Encoder& encoder, const WebCore::MoveData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MoveData, location)
    >::value);
    encoder << instance.location;
}

void ArgumentCoder<WebCore::MoveData>::encode(StreamConnectionEncoder& encoder, const WebCore::MoveData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MoveData, location)
    >::value);
    encoder << instance.location;
}

std::optional<WebCore::MoveData> ArgumentCoder<WebCore::MoveData>::decode(Decoder& decoder)
{
    auto location = decoder.decode<WebCore::FloatPoint>();
    if (!location)
        return std::nullopt;

    return {
        WebCore::MoveData {
            WTFMove(*location)
        }
    };
}

#endif

#if ENABLE(INLINE_PATH_DATA)

void ArgumentCoder<WebCore::QuadCurveData>::encode(Encoder& encoder, const WebCore::QuadCurveData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startPoint)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.controlPoint)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endPoint)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::QuadCurveData, startPoint)
        , offsetof(WebCore::QuadCurveData, controlPoint)
        , offsetof(WebCore::QuadCurveData, endPoint)
    >::value);
    encoder << instance.startPoint;
    encoder << instance.controlPoint;
    encoder << instance.endPoint;
}

void ArgumentCoder<WebCore::QuadCurveData>::encode(StreamConnectionEncoder& encoder, const WebCore::QuadCurveData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startPoint)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.controlPoint)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endPoint)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::QuadCurveData, startPoint)
        , offsetof(WebCore::QuadCurveData, controlPoint)
        , offsetof(WebCore::QuadCurveData, endPoint)
    >::value);
    encoder << instance.startPoint;
    encoder << instance.controlPoint;
    encoder << instance.endPoint;
}

std::optional<WebCore::QuadCurveData> ArgumentCoder<WebCore::QuadCurveData>::decode(Decoder& decoder)
{
    auto startPoint = decoder.decode<WebCore::FloatPoint>();
    if (!startPoint)
        return std::nullopt;

    auto controlPoint = decoder.decode<WebCore::FloatPoint>();
    if (!controlPoint)
        return std::nullopt;

    auto endPoint = decoder.decode<WebCore::FloatPoint>();
    if (!endPoint)
        return std::nullopt;

    return {
        WebCore::QuadCurveData {
            WTFMove(*startPoint),
            WTFMove(*controlPoint),
            WTFMove(*endPoint)
        }
    };
}

#endif

#if ENABLE(INLINE_PATH_DATA)

void ArgumentCoder<WebCore::BezierCurveData>::encode(Encoder& encoder, const WebCore::BezierCurveData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startPoint)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.controlPoint1)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.controlPoint2)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endPoint)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::BezierCurveData, startPoint)
        , offsetof(WebCore::BezierCurveData, controlPoint1)
        , offsetof(WebCore::BezierCurveData, controlPoint2)
        , offsetof(WebCore::BezierCurveData, endPoint)
    >::value);
    encoder << instance.startPoint;
    encoder << instance.controlPoint1;
    encoder << instance.controlPoint2;
    encoder << instance.endPoint;
}

void ArgumentCoder<WebCore::BezierCurveData>::encode(StreamConnectionEncoder& encoder, const WebCore::BezierCurveData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startPoint)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.controlPoint1)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.controlPoint2)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endPoint)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::BezierCurveData, startPoint)
        , offsetof(WebCore::BezierCurveData, controlPoint1)
        , offsetof(WebCore::BezierCurveData, controlPoint2)
        , offsetof(WebCore::BezierCurveData, endPoint)
    >::value);
    encoder << instance.startPoint;
    encoder << instance.controlPoint1;
    encoder << instance.controlPoint2;
    encoder << instance.endPoint;
}

std::optional<WebCore::BezierCurveData> ArgumentCoder<WebCore::BezierCurveData>::decode(Decoder& decoder)
{
    auto startPoint = decoder.decode<WebCore::FloatPoint>();
    if (!startPoint)
        return std::nullopt;

    auto controlPoint1 = decoder.decode<WebCore::FloatPoint>();
    if (!controlPoint1)
        return std::nullopt;

    auto controlPoint2 = decoder.decode<WebCore::FloatPoint>();
    if (!controlPoint2)
        return std::nullopt;

    auto endPoint = decoder.decode<WebCore::FloatPoint>();
    if (!endPoint)
        return std::nullopt;

    return {
        WebCore::BezierCurveData {
            WTFMove(*startPoint),
            WTFMove(*controlPoint1),
            WTFMove(*controlPoint2),
            WTFMove(*endPoint)
        }
    };
}

#endif

#if ENABLE(INLINE_PATH_DATA)

void ArgumentCoder<WebCore::ArcData>::encode(Encoder& encoder, const WebCore::ArcData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.start)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.center)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radius)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startAngle)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endAngle)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clockwise)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ArcData::Type>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ArcData, start)
        , offsetof(WebCore::ArcData, center)
        , offsetof(WebCore::ArcData, radius)
        , offsetof(WebCore::ArcData, startAngle)
        , offsetof(WebCore::ArcData, endAngle)
        , offsetof(WebCore::ArcData, clockwise)
        , offsetof(WebCore::ArcData, type)
    >::value);
    encoder << instance.start;
    encoder << instance.center;
    encoder << instance.radius;
    encoder << instance.startAngle;
    encoder << instance.endAngle;
    encoder << instance.clockwise;
    encoder << instance.type;
}

void ArgumentCoder<WebCore::ArcData>::encode(StreamConnectionEncoder& encoder, const WebCore::ArcData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.start)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.center)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radius)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startAngle)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endAngle)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clockwise)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ArcData::Type>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ArcData, start)
        , offsetof(WebCore::ArcData, center)
        , offsetof(WebCore::ArcData, radius)
        , offsetof(WebCore::ArcData, startAngle)
        , offsetof(WebCore::ArcData, endAngle)
        , offsetof(WebCore::ArcData, clockwise)
        , offsetof(WebCore::ArcData, type)
    >::value);
    encoder << instance.start;
    encoder << instance.center;
    encoder << instance.radius;
    encoder << instance.startAngle;
    encoder << instance.endAngle;
    encoder << instance.clockwise;
    encoder << instance.type;
}

std::optional<WebCore::ArcData> ArgumentCoder<WebCore::ArcData>::decode(Decoder& decoder)
{
    auto start = decoder.decode<WebCore::FloatPoint>();
    if (!start)
        return std::nullopt;

    auto center = decoder.decode<WebCore::FloatPoint>();
    if (!center)
        return std::nullopt;

    auto radius = decoder.decode<float>();
    if (!radius)
        return std::nullopt;

    auto startAngle = decoder.decode<float>();
    if (!startAngle)
        return std::nullopt;

    auto endAngle = decoder.decode<float>();
    if (!endAngle)
        return std::nullopt;

    auto clockwise = decoder.decode<bool>();
    if (!clockwise)
        return std::nullopt;

    auto type = decoder.decode<WebCore::ArcData::Type>();
    if (!type)
        return std::nullopt;

    return {
        WebCore::ArcData {
            WTFMove(*start),
            WTFMove(*center),
            WTFMove(*radius),
            WTFMove(*startAngle),
            WTFMove(*endAngle),
            WTFMove(*clockwise),
            WTFMove(*type)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::RemoteRenderingBackendCreationParameters>::encode(Encoder& encoder, const WebKit::RemoteRenderingBackendCreationParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebKit::RenderingBackendIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageProxyID)>, WebKit::WebPageProxyIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageID)>, WebCore::PageIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::RemoteRenderingBackendCreationParameters, identifier)
        , offsetof(WebKit::RemoteRenderingBackendCreationParameters, pageProxyID)
        , offsetof(WebKit::RemoteRenderingBackendCreationParameters, pageID)
    >::value);
    encoder << instance.identifier;
    encoder << instance.pageProxyID;
    encoder << instance.pageID;
}

std::optional<WebKit::RemoteRenderingBackendCreationParameters> ArgumentCoder<WebKit::RemoteRenderingBackendCreationParameters>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebKit::RenderingBackendIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto pageProxyID = decoder.decode<WebKit::WebPageProxyIdentifier>();
    if (!pageProxyID)
        return std::nullopt;

    auto pageID = decoder.decode<WebCore::PageIdentifier>();
    if (!pageID)
        return std::nullopt;

    return {
        WebKit::RemoteRenderingBackendCreationParameters {
            WTFMove(*identifier),
            WTFMove(*pageProxyID),
            WTFMove(*pageID)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)

void ArgumentCoder<WebKit::InitializationSegmentInfo>::encode(Encoder& encoder, const WebKit::InitializationSegmentInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.duration)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.audioTracks)>, Vector<WebKit::InitializationSegmentInfo::TrackInformation>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.videoTracks)>, Vector<WebKit::InitializationSegmentInfo::TrackInformation>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textTracks)>, Vector<WebKit::InitializationSegmentInfo::TrackInformation>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::InitializationSegmentInfo, duration)
        , offsetof(WebKit::InitializationSegmentInfo, audioTracks)
        , offsetof(WebKit::InitializationSegmentInfo, videoTracks)
        , offsetof(WebKit::InitializationSegmentInfo, textTracks)
    >::value);
    encoder << instance.duration;
    encoder << instance.audioTracks;
    encoder << instance.videoTracks;
    encoder << instance.textTracks;
}

std::optional<WebKit::InitializationSegmentInfo> ArgumentCoder<WebKit::InitializationSegmentInfo>::decode(Decoder& decoder)
{
    auto duration = decoder.decode<MediaTime>();
    if (!duration)
        return std::nullopt;

    auto audioTracks = decoder.decode<Vector<WebKit::InitializationSegmentInfo::TrackInformation>>();
    if (!audioTracks)
        return std::nullopt;

    auto videoTracks = decoder.decode<Vector<WebKit::InitializationSegmentInfo::TrackInformation>>();
    if (!videoTracks)
        return std::nullopt;

    auto textTracks = decoder.decode<Vector<WebKit::InitializationSegmentInfo::TrackInformation>>();
    if (!textTracks)
        return std::nullopt;

    return {
        WebKit::InitializationSegmentInfo {
            WTFMove(*duration),
            WTFMove(*audioTracks),
            WTFMove(*videoTracks),
            WTFMove(*textTracks)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)

void ArgumentCoder<WebKit::InitializationSegmentInfo::TrackInformation>::encode(Encoder& encoder, const WebKit::InitializationSegmentInfo::TrackInformation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.description)>, WebKit::MediaDescriptionInfo>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebKit::TrackPrivateRemoteIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::InitializationSegmentInfo::TrackInformation, description)
        , offsetof(WebKit::InitializationSegmentInfo::TrackInformation, identifier)
    >::value);
    encoder << instance.description;
    encoder << instance.identifier;
}

std::optional<WebKit::InitializationSegmentInfo::TrackInformation> ArgumentCoder<WebKit::InitializationSegmentInfo::TrackInformation>::decode(Decoder& decoder)
{
    auto description = decoder.decode<WebKit::MediaDescriptionInfo>();
    if (!description)
        return std::nullopt;

    auto identifier = decoder.decode<WebKit::TrackPrivateRemoteIdentifier>();
    if (!identifier)
        return std::nullopt;

    return {
        WebKit::InitializationSegmentInfo::TrackInformation {
            WTFMove(*description),
            WTFMove(*identifier)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS) && ENABLE(MEDIA_SOURCE)

void ArgumentCoder<WebKit::MediaDescriptionInfo>::encode(Encoder& encoder, const WebKit::MediaDescriptionInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_codec)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isVideo)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isAudio)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isText)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::MediaDescriptionInfo, m_codec)
        , offsetof(WebKit::MediaDescriptionInfo, m_isVideo)
        , offsetof(WebKit::MediaDescriptionInfo, m_isAudio)
        , offsetof(WebKit::MediaDescriptionInfo, m_isText)
    >::value);
    encoder << instance.m_codec;
    encoder << instance.m_isVideo;
    encoder << instance.m_isAudio;
    encoder << instance.m_isText;
}

std::optional<WebKit::MediaDescriptionInfo> ArgumentCoder<WebKit::MediaDescriptionInfo>::decode(Decoder& decoder)
{
    auto m_codec = decoder.decode<AtomString>();
    if (!m_codec)
        return std::nullopt;

    auto m_isVideo = decoder.decode<bool>();
    if (!m_isVideo)
        return std::nullopt;

    auto m_isAudio = decoder.decode<bool>();
    if (!m_isAudio)
        return std::nullopt;

    auto m_isText = decoder.decode<bool>();
    if (!m_isText)
        return std::nullopt;

    return {
        WebKit::MediaDescriptionInfo {
            WTFMove(*m_codec),
            WTFMove(*m_isVideo),
            WTFMove(*m_isAudio),
            WTFMove(*m_isText)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::RemoteMediaPlayerProxyConfiguration>::encode(Encoder& encoder, const WebKit::RemoteMediaPlayerProxyConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.referrer)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.userAgent)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceApplicationIdentifier)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.networkInterfaceName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mediaContentTypesRequiringHardwareSupport)>, Vector<WebCore::ContentType>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaContainerTypes)>, std::optional<Vector<String>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaCodecTypes)>, std::optional<Vector<String>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaVideoCodecIDs)>, std::optional<Vector<WebCore::FourCC>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaAudioCodecIDs)>, std::optional<Vector<WebCore::FourCC>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaCaptionFormatTypes)>, std::optional<Vector<WebCore::FourCC>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.playerContentBoxRect)>, WebCore::LayoutRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preferredAudioCharacteristics)>, Vector<String>>);
#if ENABLE(AVF_CAPTIONS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.outOfBandTrackData)>, Vector<WebCore::PlatformTextTrackData>>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.documentSecurityOrigin)>, WebCore::SecurityOriginData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.presentationSize)>, WebCore::IntSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.logIdentifier)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldUsePersistentCache)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isVideo)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.renderingCanBeAccelerated)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.prefersSandboxedParsing)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldDisableHDR)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, referrer)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, userAgent)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, sourceApplicationIdentifier)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, networkInterfaceName)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, mediaContentTypesRequiringHardwareSupport)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, allowedMediaContainerTypes)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, allowedMediaCodecTypes)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, allowedMediaVideoCodecIDs)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, allowedMediaAudioCodecIDs)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, allowedMediaCaptionFormatTypes)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, playerContentBoxRect)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, preferredAudioCharacteristics)
#if ENABLE(AVF_CAPTIONS)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, outOfBandTrackData)
#endif
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, documentSecurityOrigin)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, presentationSize)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, logIdentifier)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, shouldUsePersistentCache)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, isVideo)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, renderingCanBeAccelerated)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, prefersSandboxedParsing)
        , offsetof(WebKit::RemoteMediaPlayerProxyConfiguration, shouldDisableHDR)
    >::value);
    encoder << instance.referrer;
    encoder << instance.userAgent;
    encoder << instance.sourceApplicationIdentifier;
    encoder << instance.networkInterfaceName;
    encoder << instance.mediaContentTypesRequiringHardwareSupport;
    encoder << instance.allowedMediaContainerTypes;
    encoder << instance.allowedMediaCodecTypes;
    encoder << instance.allowedMediaVideoCodecIDs;
    encoder << instance.allowedMediaAudioCodecIDs;
    encoder << instance.allowedMediaCaptionFormatTypes;
    encoder << instance.playerContentBoxRect;
    encoder << instance.preferredAudioCharacteristics;
#if ENABLE(AVF_CAPTIONS)
    encoder << instance.outOfBandTrackData;
#endif
    encoder << instance.documentSecurityOrigin;
    encoder << instance.presentationSize;
    encoder << instance.logIdentifier;
    encoder << instance.shouldUsePersistentCache;
    encoder << instance.isVideo;
    encoder << instance.renderingCanBeAccelerated;
    encoder << instance.prefersSandboxedParsing;
    encoder << instance.shouldDisableHDR;
}

std::optional<WebKit::RemoteMediaPlayerProxyConfiguration> ArgumentCoder<WebKit::RemoteMediaPlayerProxyConfiguration>::decode(Decoder& decoder)
{
    auto referrer = decoder.decode<String>();
    if (!referrer)
        return std::nullopt;

    auto userAgent = decoder.decode<String>();
    if (!userAgent)
        return std::nullopt;

    auto sourceApplicationIdentifier = decoder.decode<String>();
    if (!sourceApplicationIdentifier)
        return std::nullopt;

    auto networkInterfaceName = decoder.decode<String>();
    if (!networkInterfaceName)
        return std::nullopt;

    auto mediaContentTypesRequiringHardwareSupport = decoder.decode<Vector<WebCore::ContentType>>();
    if (!mediaContentTypesRequiringHardwareSupport)
        return std::nullopt;

    auto allowedMediaContainerTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaContainerTypes)
        return std::nullopt;

    auto allowedMediaCodecTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaCodecTypes)
        return std::nullopt;

    auto allowedMediaVideoCodecIDs = decoder.decode<std::optional<Vector<WebCore::FourCC>>>();
    if (!allowedMediaVideoCodecIDs)
        return std::nullopt;

    auto allowedMediaAudioCodecIDs = decoder.decode<std::optional<Vector<WebCore::FourCC>>>();
    if (!allowedMediaAudioCodecIDs)
        return std::nullopt;

    auto allowedMediaCaptionFormatTypes = decoder.decode<std::optional<Vector<WebCore::FourCC>>>();
    if (!allowedMediaCaptionFormatTypes)
        return std::nullopt;

    auto playerContentBoxRect = decoder.decode<WebCore::LayoutRect>();
    if (!playerContentBoxRect)
        return std::nullopt;

    auto preferredAudioCharacteristics = decoder.decode<Vector<String>>();
    if (!preferredAudioCharacteristics)
        return std::nullopt;

#if ENABLE(AVF_CAPTIONS)
    auto outOfBandTrackData = decoder.decode<Vector<WebCore::PlatformTextTrackData>>();
    if (!outOfBandTrackData)
        return std::nullopt;
#endif

    auto documentSecurityOrigin = decoder.decode<WebCore::SecurityOriginData>();
    if (!documentSecurityOrigin)
        return std::nullopt;

    auto presentationSize = decoder.decode<WebCore::IntSize>();
    if (!presentationSize)
        return std::nullopt;

    auto logIdentifier = decoder.decode<uint64_t>();
    if (!logIdentifier)
        return std::nullopt;

    auto shouldUsePersistentCache = decoder.decode<bool>();
    if (!shouldUsePersistentCache)
        return std::nullopt;

    auto isVideo = decoder.decode<bool>();
    if (!isVideo)
        return std::nullopt;

    auto renderingCanBeAccelerated = decoder.decode<bool>();
    if (!renderingCanBeAccelerated)
        return std::nullopt;

    auto prefersSandboxedParsing = decoder.decode<bool>();
    if (!prefersSandboxedParsing)
        return std::nullopt;

    auto shouldDisableHDR = decoder.decode<bool>();
    if (!shouldDisableHDR)
        return std::nullopt;

    return {
        WebKit::RemoteMediaPlayerProxyConfiguration {
            WTFMove(*referrer),
            WTFMove(*userAgent),
            WTFMove(*sourceApplicationIdentifier),
            WTFMove(*networkInterfaceName),
            WTFMove(*mediaContentTypesRequiringHardwareSupport),
            WTFMove(*allowedMediaContainerTypes),
            WTFMove(*allowedMediaCodecTypes),
            WTFMove(*allowedMediaVideoCodecIDs),
            WTFMove(*allowedMediaAudioCodecIDs),
            WTFMove(*allowedMediaCaptionFormatTypes),
            WTFMove(*playerContentBoxRect),
            WTFMove(*preferredAudioCharacteristics),
#if ENABLE(AVF_CAPTIONS)
            WTFMove(*outOfBandTrackData),
#endif
            WTFMove(*documentSecurityOrigin),
            WTFMove(*presentationSize),
            WTFMove(*logIdentifier),
            WTFMove(*shouldUsePersistentCache),
            WTFMove(*isVideo),
            WTFMove(*renderingCanBeAccelerated),
            WTFMove(*prefersSandboxedParsing),
            WTFMove(*shouldDisableHDR)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)

void ArgumentCoder<WebKit::TextTrackPrivateRemoteConfiguration>::encode(Encoder& encoder, const WebKit::TextTrackPrivateRemoteConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.trackId)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.language)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.inBandMetadataTrackDispatchType)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startTimeVariance)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.trackIndex)>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cueFormat)>, WebCore::InbandTextTrackPrivate::CueFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kind)>, WebCore::InbandTextTrackPrivate::Kind>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isClosedCaptions)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isSDH)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.containsOnlyForcedSubtitles)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMainProgramContent)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isEasyToRead)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isDefault)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, trackId)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, label)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, language)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, inBandMetadataTrackDispatchType)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, startTimeVariance)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, trackIndex)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, cueFormat)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, kind)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, isClosedCaptions)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, isSDH)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, containsOnlyForcedSubtitles)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, isMainProgramContent)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, isEasyToRead)
        , offsetof(WebKit::TextTrackPrivateRemoteConfiguration, isDefault)
    >::value);
    encoder << instance.trackId;
    encoder << instance.label;
    encoder << instance.language;
    encoder << instance.inBandMetadataTrackDispatchType;
    encoder << instance.startTimeVariance;
    encoder << instance.trackIndex;
    encoder << instance.cueFormat;
    encoder << instance.kind;
    encoder << instance.isClosedCaptions;
    encoder << instance.isSDH;
    encoder << instance.containsOnlyForcedSubtitles;
    encoder << instance.isMainProgramContent;
    encoder << instance.isEasyToRead;
    encoder << instance.isDefault;
}

std::optional<WebKit::TextTrackPrivateRemoteConfiguration> ArgumentCoder<WebKit::TextTrackPrivateRemoteConfiguration>::decode(Decoder& decoder)
{
    auto trackId = decoder.decode<AtomString>();
    if (!trackId)
        return std::nullopt;

    auto label = decoder.decode<AtomString>();
    if (!label)
        return std::nullopt;

    auto language = decoder.decode<AtomString>();
    if (!language)
        return std::nullopt;

    auto inBandMetadataTrackDispatchType = decoder.decode<AtomString>();
    if (!inBandMetadataTrackDispatchType)
        return std::nullopt;

    auto startTimeVariance = decoder.decode<MediaTime>();
    if (!startTimeVariance)
        return std::nullopt;

    auto trackIndex = decoder.decode<int>();
    if (!trackIndex)
        return std::nullopt;

    auto cueFormat = decoder.decode<WebCore::InbandTextTrackPrivate::CueFormat>();
    if (!cueFormat)
        return std::nullopt;

    auto kind = decoder.decode<WebCore::InbandTextTrackPrivate::Kind>();
    if (!kind)
        return std::nullopt;

    auto isClosedCaptions = decoder.decode<bool>();
    if (!isClosedCaptions)
        return std::nullopt;

    auto isSDH = decoder.decode<bool>();
    if (!isSDH)
        return std::nullopt;

    auto containsOnlyForcedSubtitles = decoder.decode<bool>();
    if (!containsOnlyForcedSubtitles)
        return std::nullopt;

    auto isMainProgramContent = decoder.decode<bool>();
    if (!isMainProgramContent)
        return std::nullopt;

    auto isEasyToRead = decoder.decode<bool>();
    if (!isEasyToRead)
        return std::nullopt;

    auto isDefault = decoder.decode<bool>();
    if (!isDefault)
        return std::nullopt;

    return {
        WebKit::TextTrackPrivateRemoteConfiguration {
            WTFMove(*trackId),
            WTFMove(*label),
            WTFMove(*language),
            WTFMove(*inBandMetadataTrackDispatchType),
            WTFMove(*startTimeVariance),
            WTFMove(*trackIndex),
            WTFMove(*cueFormat),
            WTFMove(*kind),
            WTFMove(*isClosedCaptions),
            WTFMove(*isSDH),
            WTFMove(*containsOnlyForcedSubtitles),
            WTFMove(*isMainProgramContent),
            WTFMove(*isEasyToRead),
            WTFMove(*isDefault)
        }
    };
}

#endif


void ArgumentCoder<WebKit::NetworkProcessCreationParameters>::encode(Encoder& encoder, const WebKit::NetworkProcessCreationParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.auxiliaryProcessParameters)>, WebKit::AuxiliaryProcessCreationParameters>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cacheModel)>, WebKit::CacheModel>);
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.uiProcessCookieStorageIdentifier)>, Vector<uint8_t>>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldSuppressMemoryPressureHandler)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.urlSchemesRegisteredForCustomProtocols)>, Vector<String>>);
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.uiProcessBundleIdentifier)>, String>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.networkATSContext)>, RetainPtr<CFDataRef>>);
#endif
#if USE(SOUP)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cookieAcceptPolicy)>, WebCore::HTTPCookieAcceptPolicy>);
#endif
#if USE(SOUP)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.languages)>, Vector<String>>);
#endif
#if USE(SOUP)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.memoryPressureHandlerConfiguration)>, std::optional<MemoryPressureHandler::Configuration>>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.urlSchemesRegisteredAsSecure)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.urlSchemesRegisteredAsBypassingContentSecurityPolicy)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.urlSchemesRegisteredAsLocal)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.urlSchemesRegisteredAsNoAccess)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.enablePrivateClickMeasurement)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ftpEnabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.websiteDataStoreParameters)>, Vector<WebKit::WebsiteDataStoreParameters>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedFirstPartiesForCookies)>, Vector<std::pair<WebCore::ProcessIdentifier, WebCore::RegistrableDomain>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.localhostAliasesForTesting)>, HashSet<String>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::NetworkProcessCreationParameters, auxiliaryProcessParameters)
        , offsetof(WebKit::NetworkProcessCreationParameters, cacheModel)
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
        , offsetof(WebKit::NetworkProcessCreationParameters, uiProcessCookieStorageIdentifier)
#endif
        , offsetof(WebKit::NetworkProcessCreationParameters, shouldSuppressMemoryPressureHandler)
        , offsetof(WebKit::NetworkProcessCreationParameters, urlSchemesRegisteredForCustomProtocols)
#if PLATFORM(COCOA)
        , offsetof(WebKit::NetworkProcessCreationParameters, uiProcessBundleIdentifier)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebKit::NetworkProcessCreationParameters, networkATSContext)
#endif
#if USE(SOUP)
        , offsetof(WebKit::NetworkProcessCreationParameters, cookieAcceptPolicy)
#endif
#if USE(SOUP)
        , offsetof(WebKit::NetworkProcessCreationParameters, languages)
#endif
#if USE(SOUP)
        , offsetof(WebKit::NetworkProcessCreationParameters, memoryPressureHandlerConfiguration)
#endif
        , offsetof(WebKit::NetworkProcessCreationParameters, urlSchemesRegisteredAsSecure)
        , offsetof(WebKit::NetworkProcessCreationParameters, urlSchemesRegisteredAsBypassingContentSecurityPolicy)
        , offsetof(WebKit::NetworkProcessCreationParameters, urlSchemesRegisteredAsLocal)
        , offsetof(WebKit::NetworkProcessCreationParameters, urlSchemesRegisteredAsNoAccess)
        , offsetof(WebKit::NetworkProcessCreationParameters, enablePrivateClickMeasurement)
        , offsetof(WebKit::NetworkProcessCreationParameters, ftpEnabled)
        , offsetof(WebKit::NetworkProcessCreationParameters, websiteDataStoreParameters)
        , offsetof(WebKit::NetworkProcessCreationParameters, allowedFirstPartiesForCookies)
        , offsetof(WebKit::NetworkProcessCreationParameters, localhostAliasesForTesting)
    >::value);
    encoder << instance.auxiliaryProcessParameters;
    encoder << instance.cacheModel;
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
    encoder << instance.uiProcessCookieStorageIdentifier;
#endif
    encoder << instance.shouldSuppressMemoryPressureHandler;
    encoder << instance.urlSchemesRegisteredForCustomProtocols;
#if PLATFORM(COCOA)
    encoder << instance.uiProcessBundleIdentifier;
#endif
#if PLATFORM(COCOA)
    encoder << instance.networkATSContext;
#endif
#if USE(SOUP)
    encoder << instance.cookieAcceptPolicy;
#endif
#if USE(SOUP)
    encoder << instance.languages;
#endif
#if USE(SOUP)
    encoder << instance.memoryPressureHandlerConfiguration;
#endif
    encoder << instance.urlSchemesRegisteredAsSecure;
    encoder << instance.urlSchemesRegisteredAsBypassingContentSecurityPolicy;
    encoder << instance.urlSchemesRegisteredAsLocal;
    encoder << instance.urlSchemesRegisteredAsNoAccess;
    encoder << instance.enablePrivateClickMeasurement;
    encoder << instance.ftpEnabled;
    encoder << instance.websiteDataStoreParameters;
    encoder << instance.allowedFirstPartiesForCookies;
    encoder << instance.localhostAliasesForTesting;
}

std::optional<WebKit::NetworkProcessCreationParameters> ArgumentCoder<WebKit::NetworkProcessCreationParameters>::decode(Decoder& decoder)
{
    auto auxiliaryProcessParameters = decoder.decode<WebKit::AuxiliaryProcessCreationParameters>();
    if (!auxiliaryProcessParameters)
        return std::nullopt;

    auto cacheModel = decoder.decode<WebKit::CacheModel>();
    if (!cacheModel)
        return std::nullopt;

#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
    auto uiProcessCookieStorageIdentifier = decoder.decode<Vector<uint8_t>>();
    if (!uiProcessCookieStorageIdentifier)
        return std::nullopt;
#endif

    auto shouldSuppressMemoryPressureHandler = decoder.decode<bool>();
    if (!shouldSuppressMemoryPressureHandler)
        return std::nullopt;

    auto urlSchemesRegisteredForCustomProtocols = decoder.decode<Vector<String>>();
    if (!urlSchemesRegisteredForCustomProtocols)
        return std::nullopt;

#if PLATFORM(COCOA)
    auto uiProcessBundleIdentifier = decoder.decode<String>();
    if (!uiProcessBundleIdentifier)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto networkATSContext = decoder.decode<RetainPtr<CFDataRef>>();
    if (!networkATSContext)
        return std::nullopt;
#endif

#if USE(SOUP)
    auto cookieAcceptPolicy = decoder.decode<WebCore::HTTPCookieAcceptPolicy>();
    if (!cookieAcceptPolicy)
        return std::nullopt;
#endif

#if USE(SOUP)
    auto languages = decoder.decode<Vector<String>>();
    if (!languages)
        return std::nullopt;
#endif

#if USE(SOUP)
    auto memoryPressureHandlerConfiguration = decoder.decode<std::optional<MemoryPressureHandler::Configuration>>();
    if (!memoryPressureHandlerConfiguration)
        return std::nullopt;
#endif

    auto urlSchemesRegisteredAsSecure = decoder.decode<Vector<String>>();
    if (!urlSchemesRegisteredAsSecure)
        return std::nullopt;

    auto urlSchemesRegisteredAsBypassingContentSecurityPolicy = decoder.decode<Vector<String>>();
    if (!urlSchemesRegisteredAsBypassingContentSecurityPolicy)
        return std::nullopt;

    auto urlSchemesRegisteredAsLocal = decoder.decode<Vector<String>>();
    if (!urlSchemesRegisteredAsLocal)
        return std::nullopt;

    auto urlSchemesRegisteredAsNoAccess = decoder.decode<Vector<String>>();
    if (!urlSchemesRegisteredAsNoAccess)
        return std::nullopt;

    auto enablePrivateClickMeasurement = decoder.decode<bool>();
    if (!enablePrivateClickMeasurement)
        return std::nullopt;

    auto ftpEnabled = decoder.decode<bool>();
    if (!ftpEnabled)
        return std::nullopt;

    auto websiteDataStoreParameters = decoder.decode<Vector<WebKit::WebsiteDataStoreParameters>>();
    if (!websiteDataStoreParameters)
        return std::nullopt;

    auto allowedFirstPartiesForCookies = decoder.decode<Vector<std::pair<WebCore::ProcessIdentifier, WebCore::RegistrableDomain>>>();
    if (!allowedFirstPartiesForCookies)
        return std::nullopt;

    auto localhostAliasesForTesting = decoder.decode<HashSet<String>>();
    if (!localhostAliasesForTesting)
        return std::nullopt;

    return {
        WebKit::NetworkProcessCreationParameters {
            WTFMove(*auxiliaryProcessParameters),
            WTFMove(*cacheModel),
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
            WTFMove(*uiProcessCookieStorageIdentifier),
#endif
            WTFMove(*shouldSuppressMemoryPressureHandler),
            WTFMove(*urlSchemesRegisteredForCustomProtocols),
#if PLATFORM(COCOA)
            WTFMove(*uiProcessBundleIdentifier),
#endif
#if PLATFORM(COCOA)
            WTFMove(*networkATSContext),
#endif
#if USE(SOUP)
            WTFMove(*cookieAcceptPolicy),
#endif
#if USE(SOUP)
            WTFMove(*languages),
#endif
#if USE(SOUP)
            WTFMove(*memoryPressureHandlerConfiguration),
#endif
            WTFMove(*urlSchemesRegisteredAsSecure),
            WTFMove(*urlSchemesRegisteredAsBypassingContentSecurityPolicy),
            WTFMove(*urlSchemesRegisteredAsLocal),
            WTFMove(*urlSchemesRegisteredAsNoAccess),
            WTFMove(*enablePrivateClickMeasurement),
            WTFMove(*ftpEnabled),
            WTFMove(*websiteDataStoreParameters),
            WTFMove(*allowedFirstPartiesForCookies),
            WTFMove(*localhostAliasesForTesting)
        }
    };
}


void ArgumentCoder<WebKit::NetworkLoadParameters>::encode(Encoder& encoder, const WebKit::NetworkLoadParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webPageProxyID)>, WebKit::WebPageProxyIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webPageID)>, WebCore::PageIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webFrameID)>, WebCore::FrameIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topOrigin)>, RefPtr<WebCore::SecurityOrigin>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceOrigin)>, RefPtr<WebCore::SecurityOrigin>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parentPID)>, WTF::ProcessID>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.request)>, WebCore::ResourceRequest>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentSniffingPolicy)>, WebCore::ContentSniffingPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentEncodingSniffingPolicy)>, WebCore::ContentEncodingSniffingPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.storedCredentialsPolicy)>, WebCore::StoredCredentialsPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientCredentialPolicy)>, WebCore::ClientCredentialPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldClearReferrerOnHTTPSToHTTPRedirect)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.needsCertificateInfo)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMainFrameNavigation)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMainResourceNavigationForAnyFrame)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldRelaxThirdPartyCookieBlocking)>, WebCore::ShouldRelaxThirdPartyCookieBlocking>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldPreconnectOnly)>, WebKit::PreconnectOnly>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isNavigatingToAppBoundDomain)>, std::optional<WebKit::NavigatingToAppBoundDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hadMainFrameMainResourcePrivateRelayed)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowPrivacyProxy)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.networkConnectionIntegrityPolicy)>, OptionSet<WebCore::NetworkConnectionIntegrity>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::NetworkLoadParameters, webPageProxyID)
        , offsetof(WebKit::NetworkLoadParameters, webPageID)
        , offsetof(WebKit::NetworkLoadParameters, webFrameID)
        , offsetof(WebKit::NetworkLoadParameters, topOrigin)
        , offsetof(WebKit::NetworkLoadParameters, sourceOrigin)
        , offsetof(WebKit::NetworkLoadParameters, parentPID)
        , offsetof(WebKit::NetworkLoadParameters, request)
        , offsetof(WebKit::NetworkLoadParameters, contentSniffingPolicy)
        , offsetof(WebKit::NetworkLoadParameters, contentEncodingSniffingPolicy)
        , offsetof(WebKit::NetworkLoadParameters, storedCredentialsPolicy)
        , offsetof(WebKit::NetworkLoadParameters, clientCredentialPolicy)
        , offsetof(WebKit::NetworkLoadParameters, shouldClearReferrerOnHTTPSToHTTPRedirect)
        , offsetof(WebKit::NetworkLoadParameters, needsCertificateInfo)
        , offsetof(WebKit::NetworkLoadParameters, isMainFrameNavigation)
        , offsetof(WebKit::NetworkLoadParameters, isMainResourceNavigationForAnyFrame)
        , offsetof(WebKit::NetworkLoadParameters, shouldRelaxThirdPartyCookieBlocking)
        , offsetof(WebKit::NetworkLoadParameters, shouldPreconnectOnly)
        , offsetof(WebKit::NetworkLoadParameters, isNavigatingToAppBoundDomain)
        , offsetof(WebKit::NetworkLoadParameters, hadMainFrameMainResourcePrivateRelayed)
        , offsetof(WebKit::NetworkLoadParameters, allowPrivacyProxy)
        , offsetof(WebKit::NetworkLoadParameters, networkConnectionIntegrityPolicy)
    >::value);
    encoder << instance.webPageProxyID;
    encoder << instance.webPageID;
    encoder << instance.webFrameID;
    encoder << instance.topOrigin;
    encoder << instance.sourceOrigin;
    encoder << instance.parentPID;
    encoder << instance.request;
    encoder << instance.contentSniffingPolicy;
    encoder << instance.contentEncodingSniffingPolicy;
    encoder << instance.storedCredentialsPolicy;
    encoder << instance.clientCredentialPolicy;
    encoder << instance.shouldClearReferrerOnHTTPSToHTTPRedirect;
    encoder << instance.needsCertificateInfo;
    encoder << instance.isMainFrameNavigation;
    encoder << instance.isMainResourceNavigationForAnyFrame;
    encoder << instance.shouldRelaxThirdPartyCookieBlocking;
    encoder << instance.shouldPreconnectOnly;
    encoder << instance.isNavigatingToAppBoundDomain;
    encoder << instance.hadMainFrameMainResourcePrivateRelayed;
    encoder << instance.allowPrivacyProxy;
    encoder << instance.networkConnectionIntegrityPolicy;
}

std::optional<WebKit::NetworkLoadParameters> ArgumentCoder<WebKit::NetworkLoadParameters>::decode(Decoder& decoder)
{
    auto webPageProxyID = decoder.decode<WebKit::WebPageProxyIdentifier>();
    if (!webPageProxyID)
        return std::nullopt;

    auto webPageID = decoder.decode<WebCore::PageIdentifier>();
    if (!webPageID)
        return std::nullopt;

    auto webFrameID = decoder.decode<WebCore::FrameIdentifier>();
    if (!webFrameID)
        return std::nullopt;

    auto topOrigin = decoder.decode<RefPtr<WebCore::SecurityOrigin>>();
    if (!topOrigin)
        return std::nullopt;

    auto sourceOrigin = decoder.decode<RefPtr<WebCore::SecurityOrigin>>();
    if (!sourceOrigin)
        return std::nullopt;

    auto parentPID = decoder.decode<WTF::ProcessID>();
    if (!parentPID)
        return std::nullopt;

    auto request = decoder.decode<WebCore::ResourceRequest>();
    if (!request)
        return std::nullopt;

    auto contentSniffingPolicy = decoder.decode<WebCore::ContentSniffingPolicy>();
    if (!contentSniffingPolicy)
        return std::nullopt;

    auto contentEncodingSniffingPolicy = decoder.decode<WebCore::ContentEncodingSniffingPolicy>();
    if (!contentEncodingSniffingPolicy)
        return std::nullopt;

    auto storedCredentialsPolicy = decoder.decode<WebCore::StoredCredentialsPolicy>();
    if (!storedCredentialsPolicy)
        return std::nullopt;

    auto clientCredentialPolicy = decoder.decode<WebCore::ClientCredentialPolicy>();
    if (!clientCredentialPolicy)
        return std::nullopt;

    auto shouldClearReferrerOnHTTPSToHTTPRedirect = decoder.decode<bool>();
    if (!shouldClearReferrerOnHTTPSToHTTPRedirect)
        return std::nullopt;

    auto needsCertificateInfo = decoder.decode<bool>();
    if (!needsCertificateInfo)
        return std::nullopt;

    auto isMainFrameNavigation = decoder.decode<bool>();
    if (!isMainFrameNavigation)
        return std::nullopt;

    auto isMainResourceNavigationForAnyFrame = decoder.decode<bool>();
    if (!isMainResourceNavigationForAnyFrame)
        return std::nullopt;

    auto shouldRelaxThirdPartyCookieBlocking = decoder.decode<WebCore::ShouldRelaxThirdPartyCookieBlocking>();
    if (!shouldRelaxThirdPartyCookieBlocking)
        return std::nullopt;

    auto shouldPreconnectOnly = decoder.decode<WebKit::PreconnectOnly>();
    if (!shouldPreconnectOnly)
        return std::nullopt;

    auto isNavigatingToAppBoundDomain = decoder.decode<std::optional<WebKit::NavigatingToAppBoundDomain>>();
    if (!isNavigatingToAppBoundDomain)
        return std::nullopt;

    auto hadMainFrameMainResourcePrivateRelayed = decoder.decode<bool>();
    if (!hadMainFrameMainResourcePrivateRelayed)
        return std::nullopt;

    auto allowPrivacyProxy = decoder.decode<bool>();
    if (!allowPrivacyProxy)
        return std::nullopt;

    auto networkConnectionIntegrityPolicy = decoder.decode<OptionSet<WebCore::NetworkConnectionIntegrity>>();
    if (!networkConnectionIntegrityPolicy)
        return std::nullopt;

    return {
        WebKit::NetworkLoadParameters {
            WTFMove(*webPageProxyID),
            WTFMove(*webPageID),
            WTFMove(*webFrameID),
            WTFMove(*topOrigin),
            WTFMove(*sourceOrigin),
            WTFMove(*parentPID),
            WTFMove(*request),
            WTFMove(*contentSniffingPolicy),
            WTFMove(*contentEncodingSniffingPolicy),
            WTFMove(*storedCredentialsPolicy),
            WTFMove(*clientCredentialPolicy),
            WTFMove(*shouldClearReferrerOnHTTPSToHTTPRedirect),
            WTFMove(*needsCertificateInfo),
            WTFMove(*isMainFrameNavigation),
            WTFMove(*isMainResourceNavigationForAnyFrame),
            WTFMove(*shouldRelaxThirdPartyCookieBlocking),
            WTFMove(*shouldPreconnectOnly),
            WTFMove(*isNavigatingToAppBoundDomain),
            WTFMove(*hadMainFrameMainResourcePrivateRelayed),
            WTFMove(*allowPrivacyProxy),
            WTFMove(*networkConnectionIntegrityPolicy)
        }
    };
}


void ArgumentCoder<WebKit::NetworkResourceLoadParameters>::encode(Encoder& encoder, const WebKit::NetworkResourceLoadParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webPageProxyID)>, WebKit::WebPageProxyIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webPageID)>, WebCore::PageIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webFrameID)>, WebCore::FrameIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topOrigin)>, RefPtr<WebCore::SecurityOrigin>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceOrigin)>, RefPtr<WebCore::SecurityOrigin>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parentPID)>, WTF::ProcessID>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.request)>, WebCore::ResourceRequest>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentSniffingPolicy)>, WebCore::ContentSniffingPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentEncodingSniffingPolicy)>, WebCore::ContentEncodingSniffingPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.storedCredentialsPolicy)>, WebCore::StoredCredentialsPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientCredentialPolicy)>, WebCore::ClientCredentialPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldClearReferrerOnHTTPSToHTTPRedirect)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.needsCertificateInfo)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMainFrameNavigation)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMainResourceNavigationForAnyFrame)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldRelaxThirdPartyCookieBlocking)>, WebCore::ShouldRelaxThirdPartyCookieBlocking>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldPreconnectOnly)>, WebKit::PreconnectOnly>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isNavigatingToAppBoundDomain)>, std::optional<WebKit::NavigatingToAppBoundDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hadMainFrameMainResourcePrivateRelayed)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowPrivacyProxy)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.networkConnectionIntegrityPolicy)>, OptionSet<WebCore::NetworkConnectionIntegrity>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::NetworkLoadParameters, webPageProxyID)
        , offsetof(WebKit::NetworkLoadParameters, webPageID)
        , offsetof(WebKit::NetworkLoadParameters, webFrameID)
        , offsetof(WebKit::NetworkLoadParameters, topOrigin)
        , offsetof(WebKit::NetworkLoadParameters, sourceOrigin)
        , offsetof(WebKit::NetworkLoadParameters, parentPID)
        , offsetof(WebKit::NetworkLoadParameters, request)
        , offsetof(WebKit::NetworkLoadParameters, contentSniffingPolicy)
        , offsetof(WebKit::NetworkLoadParameters, contentEncodingSniffingPolicy)
        , offsetof(WebKit::NetworkLoadParameters, storedCredentialsPolicy)
        , offsetof(WebKit::NetworkLoadParameters, clientCredentialPolicy)
        , offsetof(WebKit::NetworkLoadParameters, shouldClearReferrerOnHTTPSToHTTPRedirect)
        , offsetof(WebKit::NetworkLoadParameters, needsCertificateInfo)
        , offsetof(WebKit::NetworkLoadParameters, isMainFrameNavigation)
        , offsetof(WebKit::NetworkLoadParameters, isMainResourceNavigationForAnyFrame)
        , offsetof(WebKit::NetworkLoadParameters, shouldRelaxThirdPartyCookieBlocking)
        , offsetof(WebKit::NetworkLoadParameters, shouldPreconnectOnly)
        , offsetof(WebKit::NetworkLoadParameters, isNavigatingToAppBoundDomain)
        , offsetof(WebKit::NetworkLoadParameters, hadMainFrameMainResourcePrivateRelayed)
        , offsetof(WebKit::NetworkLoadParameters, allowPrivacyProxy)
        , offsetof(WebKit::NetworkLoadParameters, networkConnectionIntegrityPolicy)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::ResourceLoaderIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.request.httpBody())>, RefPtr<WebCore::FormData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sandboxExtensionsIfHttpBody())>, std::optional<Vector<WebKit::SandboxExtension::Handle>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sandboxExtensionIflocalFile())>, std::optional<WebKit::SandboxExtension::Handle>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maximumBufferingTime)>, Seconds>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.options)>, WebCore::FetchOptions>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cspResponseHeaders)>, std::optional<WebCore::ContentSecurityPolicyResponseHeaders>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parentFrameURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parentCrossOriginEmbedderPolicy)>, WebCore::CrossOriginEmbedderPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.crossOriginEmbedderPolicy)>, WebCore::CrossOriginEmbedderPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.originalRequestHeaders)>, WebCore::HTTPHeaderMap>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldRestrictHTTPResponseAccess)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preflightPolicy)>, WebCore::PreflightPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldEnableCrossOriginResourcePolicy)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameAncestorOrigins)>, Vector<RefPtr<WebCore::SecurityOrigin>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageHasResourceLoadClient)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parentFrameID)>, std::optional<WebCore::FrameIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.crossOriginAccessControlCheckEnabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.documentURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isCrossOriginOpenerPolicyEnabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isClearSiteDataHeaderEnabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isDisplayingInitialEmptyDocument)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.effectiveSandboxFlags)>, WebCore::SandboxFlags>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.openerURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceCrossOriginOpenerPolicy)>, WebCore::CrossOriginOpenerPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.navigationID)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.navigationRequester)>, std::optional<WebCore::NavigationRequester>>);
#if ENABLE(SERVICE_WORKER)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.serviceWorkersMode)>, WebCore::ServiceWorkersMode>);
#endif
#if ENABLE(SERVICE_WORKER)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.serviceWorkerRegistrationIdentifier)>, std::optional<WebCore::ServiceWorkerRegistrationIdentifier>>);
#endif
#if ENABLE(SERVICE_WORKER)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.httpHeadersToKeep)>, OptionSet<WebCore::HTTPHeadersToKeepFromCleaning>>);
#endif
#if ENABLE(SERVICE_WORKER)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.navigationPreloadIdentifier)>, std::optional<WebCore::FetchIdentifier>>);
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mainDocumentURL)>, URL>);
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.userContentControllerIdentifier)>, std::optional<WebKit::UserContentControllerIdentifier>>);
#endif
    encoder << instance.webPageProxyID;
    encoder << instance.webPageID;
    encoder << instance.webFrameID;
    encoder << instance.topOrigin;
    encoder << instance.sourceOrigin;
    encoder << instance.parentPID;
    encoder << instance.request;
    encoder << instance.contentSniffingPolicy;
    encoder << instance.contentEncodingSniffingPolicy;
    encoder << instance.storedCredentialsPolicy;
    encoder << instance.clientCredentialPolicy;
    encoder << instance.shouldClearReferrerOnHTTPSToHTTPRedirect;
    encoder << instance.needsCertificateInfo;
    encoder << instance.isMainFrameNavigation;
    encoder << instance.isMainResourceNavigationForAnyFrame;
    encoder << instance.shouldRelaxThirdPartyCookieBlocking;
    encoder << instance.shouldPreconnectOnly;
    encoder << instance.isNavigatingToAppBoundDomain;
    encoder << instance.hadMainFrameMainResourcePrivateRelayed;
    encoder << instance.allowPrivacyProxy;
    encoder << instance.networkConnectionIntegrityPolicy;
    encoder << instance.identifier;
    encoder << instance.request.httpBody();
    encoder << instance.sandboxExtensionsIfHttpBody();
    encoder << instance.sandboxExtensionIflocalFile();
    encoder << instance.maximumBufferingTime;
    encoder << instance.options;
    encoder << instance.cspResponseHeaders;
    encoder << instance.parentFrameURL;
    encoder << instance.frameURL;
    encoder << instance.parentCrossOriginEmbedderPolicy;
    encoder << instance.crossOriginEmbedderPolicy;
    encoder << instance.originalRequestHeaders;
    encoder << instance.shouldRestrictHTTPResponseAccess;
    encoder << instance.preflightPolicy;
    encoder << instance.shouldEnableCrossOriginResourcePolicy;
    encoder << instance.frameAncestorOrigins;
    encoder << instance.pageHasResourceLoadClient;
    encoder << instance.parentFrameID;
    encoder << instance.crossOriginAccessControlCheckEnabled;
    encoder << instance.documentURL;
    encoder << instance.isCrossOriginOpenerPolicyEnabled;
    encoder << instance.isClearSiteDataHeaderEnabled;
    encoder << instance.isDisplayingInitialEmptyDocument;
    encoder << instance.effectiveSandboxFlags;
    encoder << instance.openerURL;
    encoder << instance.sourceCrossOriginOpenerPolicy;
    encoder << instance.navigationID;
    encoder << instance.navigationRequester;
#if ENABLE(SERVICE_WORKER)
    encoder << instance.serviceWorkersMode;
#endif
#if ENABLE(SERVICE_WORKER)
    encoder << instance.serviceWorkerRegistrationIdentifier;
#endif
#if ENABLE(SERVICE_WORKER)
    encoder << instance.httpHeadersToKeep;
#endif
#if ENABLE(SERVICE_WORKER)
    encoder << instance.navigationPreloadIdentifier;
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    encoder << instance.mainDocumentURL;
#endif
#if ENABLE(CONTENT_EXTENSIONS)
    encoder << instance.userContentControllerIdentifier;
#endif
}

std::optional<WebKit::NetworkResourceLoadParameters> ArgumentCoder<WebKit::NetworkResourceLoadParameters>::decode(Decoder& decoder)
{
    auto webPageProxyID = decoder.decode<WebKit::WebPageProxyIdentifier>();
    if (!webPageProxyID)
        return std::nullopt;

    auto webPageID = decoder.decode<WebCore::PageIdentifier>();
    if (!webPageID)
        return std::nullopt;

    auto webFrameID = decoder.decode<WebCore::FrameIdentifier>();
    if (!webFrameID)
        return std::nullopt;

    auto topOrigin = decoder.decode<RefPtr<WebCore::SecurityOrigin>>();
    if (!topOrigin)
        return std::nullopt;

    auto sourceOrigin = decoder.decode<RefPtr<WebCore::SecurityOrigin>>();
    if (!sourceOrigin)
        return std::nullopt;

    auto parentPID = decoder.decode<WTF::ProcessID>();
    if (!parentPID)
        return std::nullopt;

    auto request = decoder.decode<WebCore::ResourceRequest>();
    if (!request)
        return std::nullopt;

    auto contentSniffingPolicy = decoder.decode<WebCore::ContentSniffingPolicy>();
    if (!contentSniffingPolicy)
        return std::nullopt;

    auto contentEncodingSniffingPolicy = decoder.decode<WebCore::ContentEncodingSniffingPolicy>();
    if (!contentEncodingSniffingPolicy)
        return std::nullopt;

    auto storedCredentialsPolicy = decoder.decode<WebCore::StoredCredentialsPolicy>();
    if (!storedCredentialsPolicy)
        return std::nullopt;

    auto clientCredentialPolicy = decoder.decode<WebCore::ClientCredentialPolicy>();
    if (!clientCredentialPolicy)
        return std::nullopt;

    auto shouldClearReferrerOnHTTPSToHTTPRedirect = decoder.decode<bool>();
    if (!shouldClearReferrerOnHTTPSToHTTPRedirect)
        return std::nullopt;

    auto needsCertificateInfo = decoder.decode<bool>();
    if (!needsCertificateInfo)
        return std::nullopt;

    auto isMainFrameNavigation = decoder.decode<bool>();
    if (!isMainFrameNavigation)
        return std::nullopt;

    auto isMainResourceNavigationForAnyFrame = decoder.decode<bool>();
    if (!isMainResourceNavigationForAnyFrame)
        return std::nullopt;

    auto shouldRelaxThirdPartyCookieBlocking = decoder.decode<WebCore::ShouldRelaxThirdPartyCookieBlocking>();
    if (!shouldRelaxThirdPartyCookieBlocking)
        return std::nullopt;

    auto shouldPreconnectOnly = decoder.decode<WebKit::PreconnectOnly>();
    if (!shouldPreconnectOnly)
        return std::nullopt;

    auto isNavigatingToAppBoundDomain = decoder.decode<std::optional<WebKit::NavigatingToAppBoundDomain>>();
    if (!isNavigatingToAppBoundDomain)
        return std::nullopt;

    auto hadMainFrameMainResourcePrivateRelayed = decoder.decode<bool>();
    if (!hadMainFrameMainResourcePrivateRelayed)
        return std::nullopt;

    auto allowPrivacyProxy = decoder.decode<bool>();
    if (!allowPrivacyProxy)
        return std::nullopt;

    auto networkConnectionIntegrityPolicy = decoder.decode<OptionSet<WebCore::NetworkConnectionIntegrity>>();
    if (!networkConnectionIntegrityPolicy)
        return std::nullopt;

    auto identifier = decoder.decode<WebCore::ResourceLoaderIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto requesthttpBody = decoder.decode<RefPtr<WebCore::FormData>>();
    if (!requesthttpBody)
        return std::nullopt;

    auto sandboxExtensionsIfHttpBody = decoder.decode<std::optional<Vector<WebKit::SandboxExtension::Handle>>>();
    if (!sandboxExtensionsIfHttpBody)
        return std::nullopt;

    auto sandboxExtensionIflocalFile = decoder.decode<std::optional<WebKit::SandboxExtension::Handle>>();
    if (!sandboxExtensionIflocalFile)
        return std::nullopt;

    auto maximumBufferingTime = decoder.decode<Seconds>();
    if (!maximumBufferingTime)
        return std::nullopt;

    auto options = decoder.decode<WebCore::FetchOptions>();
    if (!options)
        return std::nullopt;

    auto cspResponseHeaders = decoder.decode<std::optional<WebCore::ContentSecurityPolicyResponseHeaders>>();
    if (!cspResponseHeaders)
        return std::nullopt;

    auto parentFrameURL = decoder.decode<URL>();
    if (!parentFrameURL)
        return std::nullopt;

    auto frameURL = decoder.decode<URL>();
    if (!frameURL)
        return std::nullopt;

    auto parentCrossOriginEmbedderPolicy = decoder.decode<WebCore::CrossOriginEmbedderPolicy>();
    if (!parentCrossOriginEmbedderPolicy)
        return std::nullopt;

    auto crossOriginEmbedderPolicy = decoder.decode<WebCore::CrossOriginEmbedderPolicy>();
    if (!crossOriginEmbedderPolicy)
        return std::nullopt;

    auto originalRequestHeaders = decoder.decode<WebCore::HTTPHeaderMap>();
    if (!originalRequestHeaders)
        return std::nullopt;

    auto shouldRestrictHTTPResponseAccess = decoder.decode<bool>();
    if (!shouldRestrictHTTPResponseAccess)
        return std::nullopt;

    auto preflightPolicy = decoder.decode<WebCore::PreflightPolicy>();
    if (!preflightPolicy)
        return std::nullopt;

    auto shouldEnableCrossOriginResourcePolicy = decoder.decode<bool>();
    if (!shouldEnableCrossOriginResourcePolicy)
        return std::nullopt;

    auto frameAncestorOrigins = decoder.decode<Vector<RefPtr<WebCore::SecurityOrigin>>>();
    if (!frameAncestorOrigins)
        return std::nullopt;

    auto pageHasResourceLoadClient = decoder.decode<bool>();
    if (!pageHasResourceLoadClient)
        return std::nullopt;

    auto parentFrameID = decoder.decode<std::optional<WebCore::FrameIdentifier>>();
    if (!parentFrameID)
        return std::nullopt;

    auto crossOriginAccessControlCheckEnabled = decoder.decode<bool>();
    if (!crossOriginAccessControlCheckEnabled)
        return std::nullopt;

    auto documentURL = decoder.decode<URL>();
    if (!documentURL)
        return std::nullopt;

    auto isCrossOriginOpenerPolicyEnabled = decoder.decode<bool>();
    if (!isCrossOriginOpenerPolicyEnabled)
        return std::nullopt;

    auto isClearSiteDataHeaderEnabled = decoder.decode<bool>();
    if (!isClearSiteDataHeaderEnabled)
        return std::nullopt;

    auto isDisplayingInitialEmptyDocument = decoder.decode<bool>();
    if (!isDisplayingInitialEmptyDocument)
        return std::nullopt;

    auto effectiveSandboxFlags = decoder.decode<WebCore::SandboxFlags>();
    if (!effectiveSandboxFlags)
        return std::nullopt;

    auto openerURL = decoder.decode<URL>();
    if (!openerURL)
        return std::nullopt;

    auto sourceCrossOriginOpenerPolicy = decoder.decode<WebCore::CrossOriginOpenerPolicy>();
    if (!sourceCrossOriginOpenerPolicy)
        return std::nullopt;

    auto navigationID = decoder.decode<uint64_t>();
    if (!navigationID)
        return std::nullopt;

    auto navigationRequester = decoder.decode<std::optional<WebCore::NavigationRequester>>();
    if (!navigationRequester)
        return std::nullopt;

#if ENABLE(SERVICE_WORKER)
    auto serviceWorkersMode = decoder.decode<WebCore::ServiceWorkersMode>();
    if (!serviceWorkersMode)
        return std::nullopt;
#endif

#if ENABLE(SERVICE_WORKER)
    auto serviceWorkerRegistrationIdentifier = decoder.decode<std::optional<WebCore::ServiceWorkerRegistrationIdentifier>>();
    if (!serviceWorkerRegistrationIdentifier)
        return std::nullopt;
#endif

#if ENABLE(SERVICE_WORKER)
    auto httpHeadersToKeep = decoder.decode<OptionSet<WebCore::HTTPHeadersToKeepFromCleaning>>();
    if (!httpHeadersToKeep)
        return std::nullopt;
#endif

#if ENABLE(SERVICE_WORKER)
    auto navigationPreloadIdentifier = decoder.decode<std::optional<WebCore::FetchIdentifier>>();
    if (!navigationPreloadIdentifier)
        return std::nullopt;
#endif

#if ENABLE(CONTENT_EXTENSIONS)
    auto mainDocumentURL = decoder.decode<URL>();
    if (!mainDocumentURL)
        return std::nullopt;
#endif

#if ENABLE(CONTENT_EXTENSIONS)
    auto userContentControllerIdentifier = decoder.decode<std::optional<WebKit::UserContentControllerIdentifier>>();
    if (!userContentControllerIdentifier)
        return std::nullopt;
#endif

    return {
        WebKit::NetworkResourceLoadParameters {
            WebKit::NetworkLoadParameters {
                WTFMove(*webPageProxyID),
                WTFMove(*webPageID),
                WTFMove(*webFrameID),
                WTFMove(*topOrigin),
                WTFMove(*sourceOrigin),
                WTFMove(*parentPID),
                WTFMove(*request),
                WTFMove(*contentSniffingPolicy),
                WTFMove(*contentEncodingSniffingPolicy),
                WTFMove(*storedCredentialsPolicy),
                WTFMove(*clientCredentialPolicy),
                WTFMove(*shouldClearReferrerOnHTTPSToHTTPRedirect),
                WTFMove(*needsCertificateInfo),
                WTFMove(*isMainFrameNavigation),
                WTFMove(*isMainResourceNavigationForAnyFrame),
                WTFMove(*shouldRelaxThirdPartyCookieBlocking),
                WTFMove(*shouldPreconnectOnly),
                WTFMove(*isNavigatingToAppBoundDomain),
                WTFMove(*hadMainFrameMainResourcePrivateRelayed),
                WTFMove(*allowPrivacyProxy),
                WTFMove(*networkConnectionIntegrityPolicy)
            },
            WTFMove(*identifier),
            WTFMove(*requesthttpBody),
            WTFMove(*sandboxExtensionsIfHttpBody),
            WTFMove(*sandboxExtensionIflocalFile),
            WTFMove(*maximumBufferingTime),
            WTFMove(*options),
            WTFMove(*cspResponseHeaders),
            WTFMove(*parentFrameURL),
            WTFMove(*frameURL),
            WTFMove(*parentCrossOriginEmbedderPolicy),
            WTFMove(*crossOriginEmbedderPolicy),
            WTFMove(*originalRequestHeaders),
            WTFMove(*shouldRestrictHTTPResponseAccess),
            WTFMove(*preflightPolicy),
            WTFMove(*shouldEnableCrossOriginResourcePolicy),
            WTFMove(*frameAncestorOrigins),
            WTFMove(*pageHasResourceLoadClient),
            WTFMove(*parentFrameID),
            WTFMove(*crossOriginAccessControlCheckEnabled),
            WTFMove(*documentURL),
            WTFMove(*isCrossOriginOpenerPolicyEnabled),
            WTFMove(*isClearSiteDataHeaderEnabled),
            WTFMove(*isDisplayingInitialEmptyDocument),
            WTFMove(*effectiveSandboxFlags),
            WTFMove(*openerURL),
            WTFMove(*sourceCrossOriginOpenerPolicy),
            WTFMove(*navigationID),
            WTFMove(*navigationRequester),
#if ENABLE(SERVICE_WORKER)
            WTFMove(*serviceWorkersMode),
#endif
#if ENABLE(SERVICE_WORKER)
            WTFMove(*serviceWorkerRegistrationIdentifier),
#endif
#if ENABLE(SERVICE_WORKER)
            WTFMove(*httpHeadersToKeep),
#endif
#if ENABLE(SERVICE_WORKER)
            WTFMove(*navigationPreloadIdentifier),
#endif
#if ENABLE(CONTENT_EXTENSIONS)
            WTFMove(*mainDocumentURL),
#endif
#if ENABLE(CONTENT_EXTENSIONS)
            WTFMove(*userContentControllerIdentifier)
#endif
        }
    };
}


void ArgumentCoder<WebKit::EditorState>::encode(Encoder& encoder, const WebKit::EditorState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebKit::EditorStateIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldIgnoreSelectionChanges)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionIsNone)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionIsRange)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionIsRangeInsideImageOverlay)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionIsRangeInAutoFilledAndViewableField)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isContentEditable)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isContentRichlyEditable)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isInPasswordField)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isInPlugin)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasComposition)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.triggeredByAccessibilitySelectionChange)>, bool>);
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canEnableAutomaticSpellingCorrection)>, bool>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.postLayoutData)>, std::optional<WebKit::EditorState::PostLayoutData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.visualData)>, std::optional<WebKit::EditorState::VisualData>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::EditorState, identifier)
        , offsetof(WebKit::EditorState, shouldIgnoreSelectionChanges)
        , offsetof(WebKit::EditorState, selectionIsNone)
        , offsetof(WebKit::EditorState, selectionIsRange)
        , offsetof(WebKit::EditorState, selectionIsRangeInsideImageOverlay)
        , offsetof(WebKit::EditorState, selectionIsRangeInAutoFilledAndViewableField)
        , offsetof(WebKit::EditorState, isContentEditable)
        , offsetof(WebKit::EditorState, isContentRichlyEditable)
        , offsetof(WebKit::EditorState, isInPasswordField)
        , offsetof(WebKit::EditorState, isInPlugin)
        , offsetof(WebKit::EditorState, hasComposition)
        , offsetof(WebKit::EditorState, triggeredByAccessibilitySelectionChange)
#if PLATFORM(MAC)
        , offsetof(WebKit::EditorState, canEnableAutomaticSpellingCorrection)
#endif
        , offsetof(WebKit::EditorState, postLayoutData)
        , offsetof(WebKit::EditorState, visualData)
    >::value);
    encoder << instance.identifier;
    encoder << instance.shouldIgnoreSelectionChanges;
    encoder << instance.selectionIsNone;
    encoder << instance.selectionIsRange;
    encoder << instance.selectionIsRangeInsideImageOverlay;
    encoder << instance.selectionIsRangeInAutoFilledAndViewableField;
    encoder << instance.isContentEditable;
    encoder << instance.isContentRichlyEditable;
    encoder << instance.isInPasswordField;
    encoder << instance.isInPlugin;
    encoder << instance.hasComposition;
    encoder << instance.triggeredByAccessibilitySelectionChange;
#if PLATFORM(MAC)
    encoder << instance.canEnableAutomaticSpellingCorrection;
#endif
    encoder << instance.postLayoutData;
    encoder << instance.visualData;
}

std::optional<WebKit::EditorState> ArgumentCoder<WebKit::EditorState>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebKit::EditorStateIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto shouldIgnoreSelectionChanges = decoder.decode<bool>();
    if (!shouldIgnoreSelectionChanges)
        return std::nullopt;

    auto selectionIsNone = decoder.decode<bool>();
    if (!selectionIsNone)
        return std::nullopt;

    auto selectionIsRange = decoder.decode<bool>();
    if (!selectionIsRange)
        return std::nullopt;

    auto selectionIsRangeInsideImageOverlay = decoder.decode<bool>();
    if (!selectionIsRangeInsideImageOverlay)
        return std::nullopt;

    auto selectionIsRangeInAutoFilledAndViewableField = decoder.decode<bool>();
    if (!selectionIsRangeInAutoFilledAndViewableField)
        return std::nullopt;

    auto isContentEditable = decoder.decode<bool>();
    if (!isContentEditable)
        return std::nullopt;

    auto isContentRichlyEditable = decoder.decode<bool>();
    if (!isContentRichlyEditable)
        return std::nullopt;

    auto isInPasswordField = decoder.decode<bool>();
    if (!isInPasswordField)
        return std::nullopt;

    auto isInPlugin = decoder.decode<bool>();
    if (!isInPlugin)
        return std::nullopt;

    auto hasComposition = decoder.decode<bool>();
    if (!hasComposition)
        return std::nullopt;

    auto triggeredByAccessibilitySelectionChange = decoder.decode<bool>();
    if (!triggeredByAccessibilitySelectionChange)
        return std::nullopt;

#if PLATFORM(MAC)
    auto canEnableAutomaticSpellingCorrection = decoder.decode<bool>();
    if (!canEnableAutomaticSpellingCorrection)
        return std::nullopt;
#endif

    auto postLayoutData = decoder.decode<std::optional<WebKit::EditorState::PostLayoutData>>();
    if (!postLayoutData)
        return std::nullopt;

    auto visualData = decoder.decode<std::optional<WebKit::EditorState::VisualData>>();
    if (!visualData)
        return std::nullopt;

    return {
        WebKit::EditorState {
            WTFMove(*identifier),
            WTFMove(*shouldIgnoreSelectionChanges),
            WTFMove(*selectionIsNone),
            WTFMove(*selectionIsRange),
            WTFMove(*selectionIsRangeInsideImageOverlay),
            WTFMove(*selectionIsRangeInAutoFilledAndViewableField),
            WTFMove(*isContentEditable),
            WTFMove(*isContentRichlyEditable),
            WTFMove(*isInPasswordField),
            WTFMove(*isInPlugin),
            WTFMove(*hasComposition),
            WTFMove(*triggeredByAccessibilitySelectionChange),
#if PLATFORM(MAC)
            WTFMove(*canEnableAutomaticSpellingCorrection),
#endif
            WTFMove(*postLayoutData),
            WTFMove(*visualData)
        }
    };
}


void ArgumentCoder<WebKit::EditorState::PostLayoutData>::encode(Encoder& encoder, const WebKit::EditorState::PostLayoutData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.typingAttributes)>, uint32_t>);
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectedTextLength)>, uint64_t>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textAlignment)>, uint32_t>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textColor)>, WebCore::Color>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.enclosingListType)>, uint32_t>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.baseWritingDirection)>, WebCore::WritingDirection>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.markedText)>, String>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.wordAtSelection)>, String>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.characterAfterSelection)>, UChar32>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.characterBeforeSelection)>, UChar32>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.twoCharacterBeforeSelection)>, UChar32>);
#endif
#if PLATFORM(IOS_FAMILY) && USE(DICTATION_ALTERNATIVES)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dictationContextsForSelection)>, Vector<WebCore::DictationContext>>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isReplaceAllowed)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasContent)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isStableStateUpdate)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.insideFixedPosition)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasPlainText)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.editableRootIsTransparentOrFullyClipped)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.caretColor)>, WebCore::Color>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.atStartOfSentence)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionStartIsAtParagraphBoundary)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionEndIsAtParagraphBoundary)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectedEditableImage)>, std::optional<WebCore::ElementContext>>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionBoundingRect)>, WebCore::IntRect>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.candidateRequestStartPosition)>, uint64_t>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.paragraphContextForCandidateRequest)>, String>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stringForCandidateRequest)>, String>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.evasionRectsAroundSelection)>, Vector<WebCore::FloatRect>>);
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.surroundingContext)>, String>);
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.surroundingContextCursorPosition)>, uint64_t>);
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.surroundingContextSelectionPosition)>, uint64_t>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fontAttributes)>, std::optional<WebCore::FontAttributes>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canCut)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canCopy)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canPaste)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::EditorState::PostLayoutData, typingAttributes)
#if PLATFORM(COCOA)
        , offsetof(WebKit::EditorState::PostLayoutData, selectedTextLength)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebKit::EditorState::PostLayoutData, textAlignment)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebKit::EditorState::PostLayoutData, textColor)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebKit::EditorState::PostLayoutData, enclosingListType)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebKit::EditorState::PostLayoutData, baseWritingDirection)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, markedText)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, wordAtSelection)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, characterAfterSelection)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, characterBeforeSelection)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, twoCharacterBeforeSelection)
#endif
#if PLATFORM(IOS_FAMILY) && USE(DICTATION_ALTERNATIVES)
        , offsetof(WebKit::EditorState::PostLayoutData, dictationContextsForSelection)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, isReplaceAllowed)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, hasContent)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, isStableStateUpdate)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, insideFixedPosition)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, hasPlainText)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, editableRootIsTransparentOrFullyClipped)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, caretColor)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, atStartOfSentence)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, selectionStartIsAtParagraphBoundary)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, selectionEndIsAtParagraphBoundary)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::PostLayoutData, selectedEditableImage)
#endif
#if PLATFORM(MAC)
        , offsetof(WebKit::EditorState::PostLayoutData, selectionBoundingRect)
#endif
#if PLATFORM(MAC)
        , offsetof(WebKit::EditorState::PostLayoutData, candidateRequestStartPosition)
#endif
#if PLATFORM(MAC)
        , offsetof(WebKit::EditorState::PostLayoutData, paragraphContextForCandidateRequest)
#endif
#if PLATFORM(MAC)
        , offsetof(WebKit::EditorState::PostLayoutData, stringForCandidateRequest)
#endif
#if PLATFORM(MAC)
        , offsetof(WebKit::EditorState::PostLayoutData, evasionRectsAroundSelection)
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
        , offsetof(WebKit::EditorState::PostLayoutData, surroundingContext)
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
        , offsetof(WebKit::EditorState::PostLayoutData, surroundingContextCursorPosition)
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
        , offsetof(WebKit::EditorState::PostLayoutData, surroundingContextSelectionPosition)
#endif
        , offsetof(WebKit::EditorState::PostLayoutData, fontAttributes)
        , offsetof(WebKit::EditorState::PostLayoutData, canCut)
        , offsetof(WebKit::EditorState::PostLayoutData, canCopy)
        , offsetof(WebKit::EditorState::PostLayoutData, canPaste)
    >::value);
    encoder << instance.typingAttributes;
#if PLATFORM(COCOA)
    encoder << instance.selectedTextLength;
#endif
#if PLATFORM(COCOA)
    encoder << instance.textAlignment;
#endif
#if PLATFORM(COCOA)
    encoder << instance.textColor;
#endif
#if PLATFORM(COCOA)
    encoder << instance.enclosingListType;
#endif
#if PLATFORM(COCOA)
    encoder << instance.baseWritingDirection;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.markedText;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.wordAtSelection;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.characterAfterSelection;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.characterBeforeSelection;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.twoCharacterBeforeSelection;
#endif
#if PLATFORM(IOS_FAMILY) && USE(DICTATION_ALTERNATIVES)
    encoder << instance.dictationContextsForSelection;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.isReplaceAllowed;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.hasContent;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.isStableStateUpdate;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.insideFixedPosition;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.hasPlainText;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.editableRootIsTransparentOrFullyClipped;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.caretColor;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.atStartOfSentence;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.selectionStartIsAtParagraphBoundary;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.selectionEndIsAtParagraphBoundary;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.selectedEditableImage;
#endif
#if PLATFORM(MAC)
    encoder << instance.selectionBoundingRect;
#endif
#if PLATFORM(MAC)
    encoder << instance.candidateRequestStartPosition;
#endif
#if PLATFORM(MAC)
    encoder << instance.paragraphContextForCandidateRequest;
#endif
#if PLATFORM(MAC)
    encoder << instance.stringForCandidateRequest;
#endif
#if PLATFORM(MAC)
    encoder << instance.evasionRectsAroundSelection;
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    encoder << instance.surroundingContext;
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    encoder << instance.surroundingContextCursorPosition;
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
    encoder << instance.surroundingContextSelectionPosition;
#endif
    encoder << instance.fontAttributes;
    encoder << instance.canCut;
    encoder << instance.canCopy;
    encoder << instance.canPaste;
}

std::optional<WebKit::EditorState::PostLayoutData> ArgumentCoder<WebKit::EditorState::PostLayoutData>::decode(Decoder& decoder)
{
    auto typingAttributes = decoder.decode<uint32_t>();
    if (!typingAttributes)
        return std::nullopt;

#if PLATFORM(COCOA)
    auto selectedTextLength = decoder.decode<uint64_t>();
    if (!selectedTextLength)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto textAlignment = decoder.decode<uint32_t>();
    if (!textAlignment)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto textColor = decoder.decode<WebCore::Color>();
    if (!textColor)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto enclosingListType = decoder.decode<uint32_t>();
    if (!enclosingListType)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto baseWritingDirection = decoder.decode<WebCore::WritingDirection>();
    if (!baseWritingDirection)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto markedText = decoder.decode<String>();
    if (!markedText)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto wordAtSelection = decoder.decode<String>();
    if (!wordAtSelection)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto characterAfterSelection = decoder.decode<UChar32>();
    if (!characterAfterSelection)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto characterBeforeSelection = decoder.decode<UChar32>();
    if (!characterBeforeSelection)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto twoCharacterBeforeSelection = decoder.decode<UChar32>();
    if (!twoCharacterBeforeSelection)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY) && USE(DICTATION_ALTERNATIVES)
    auto dictationContextsForSelection = decoder.decode<Vector<WebCore::DictationContext>>();
    if (!dictationContextsForSelection)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto isReplaceAllowed = decoder.decode<bool>();
    if (!isReplaceAllowed)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto hasContent = decoder.decode<bool>();
    if (!hasContent)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto isStableStateUpdate = decoder.decode<bool>();
    if (!isStableStateUpdate)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto insideFixedPosition = decoder.decode<bool>();
    if (!insideFixedPosition)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto hasPlainText = decoder.decode<bool>();
    if (!hasPlainText)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto editableRootIsTransparentOrFullyClipped = decoder.decode<bool>();
    if (!editableRootIsTransparentOrFullyClipped)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto caretColor = decoder.decode<WebCore::Color>();
    if (!caretColor)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto atStartOfSentence = decoder.decode<bool>();
    if (!atStartOfSentence)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto selectionStartIsAtParagraphBoundary = decoder.decode<bool>();
    if (!selectionStartIsAtParagraphBoundary)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto selectionEndIsAtParagraphBoundary = decoder.decode<bool>();
    if (!selectionEndIsAtParagraphBoundary)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto selectedEditableImage = decoder.decode<std::optional<WebCore::ElementContext>>();
    if (!selectedEditableImage)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto selectionBoundingRect = decoder.decode<WebCore::IntRect>();
    if (!selectionBoundingRect)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto candidateRequestStartPosition = decoder.decode<uint64_t>();
    if (!candidateRequestStartPosition)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto paragraphContextForCandidateRequest = decoder.decode<String>();
    if (!paragraphContextForCandidateRequest)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto stringForCandidateRequest = decoder.decode<String>();
    if (!stringForCandidateRequest)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto evasionRectsAroundSelection = decoder.decode<Vector<WebCore::FloatRect>>();
    if (!evasionRectsAroundSelection)
        return std::nullopt;
#endif

#if PLATFORM(GTK) || PLATFORM(WPE)
    auto surroundingContext = decoder.decode<String>();
    if (!surroundingContext)
        return std::nullopt;
#endif

#if PLATFORM(GTK) || PLATFORM(WPE)
    auto surroundingContextCursorPosition = decoder.decode<uint64_t>();
    if (!surroundingContextCursorPosition)
        return std::nullopt;
#endif

#if PLATFORM(GTK) || PLATFORM(WPE)
    auto surroundingContextSelectionPosition = decoder.decode<uint64_t>();
    if (!surroundingContextSelectionPosition)
        return std::nullopt;
#endif

    auto fontAttributes = decoder.decode<std::optional<WebCore::FontAttributes>>();
    if (!fontAttributes)
        return std::nullopt;

    auto canCut = decoder.decode<bool>();
    if (!canCut)
        return std::nullopt;

    auto canCopy = decoder.decode<bool>();
    if (!canCopy)
        return std::nullopt;

    auto canPaste = decoder.decode<bool>();
    if (!canPaste)
        return std::nullopt;

    return {
        WebKit::EditorState::PostLayoutData {
            WTFMove(*typingAttributes),
#if PLATFORM(COCOA)
            WTFMove(*selectedTextLength),
#endif
#if PLATFORM(COCOA)
            WTFMove(*textAlignment),
#endif
#if PLATFORM(COCOA)
            WTFMove(*textColor),
#endif
#if PLATFORM(COCOA)
            WTFMove(*enclosingListType),
#endif
#if PLATFORM(COCOA)
            WTFMove(*baseWritingDirection),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*markedText),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*wordAtSelection),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*characterAfterSelection),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*characterBeforeSelection),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*twoCharacterBeforeSelection),
#endif
#if PLATFORM(IOS_FAMILY) && USE(DICTATION_ALTERNATIVES)
            WTFMove(*dictationContextsForSelection),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*isReplaceAllowed),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*hasContent),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*isStableStateUpdate),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*insideFixedPosition),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*hasPlainText),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*editableRootIsTransparentOrFullyClipped),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*caretColor),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*atStartOfSentence),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*selectionStartIsAtParagraphBoundary),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*selectionEndIsAtParagraphBoundary),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*selectedEditableImage),
#endif
#if PLATFORM(MAC)
            WTFMove(*selectionBoundingRect),
#endif
#if PLATFORM(MAC)
            WTFMove(*candidateRequestStartPosition),
#endif
#if PLATFORM(MAC)
            WTFMove(*paragraphContextForCandidateRequest),
#endif
#if PLATFORM(MAC)
            WTFMove(*stringForCandidateRequest),
#endif
#if PLATFORM(MAC)
            WTFMove(*evasionRectsAroundSelection),
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
            WTFMove(*surroundingContext),
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
            WTFMove(*surroundingContextCursorPosition),
#endif
#if PLATFORM(GTK) || PLATFORM(WPE)
            WTFMove(*surroundingContextSelectionPosition),
#endif
            WTFMove(*fontAttributes),
            WTFMove(*canCut),
            WTFMove(*canCopy),
            WTFMove(*canPaste)
        }
    };
}


void ArgumentCoder<WebKit::EditorState::VisualData>::encode(Encoder& encoder, const WebKit::EditorState::VisualData& instance)
{
#if PLATFORM(IOS_FAMILY) || PLATFORM(GTK) || PLATFORM(WPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.caretRectAtStart)>, WebCore::IntRect>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionClipRect)>, WebCore::IntRect>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.caretRectAtEnd)>, WebCore::IntRect>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionGeometries)>, Vector<WebCore::SelectionGeometry>>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.markedTextRects)>, Vector<WebCore::SelectionGeometry>>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.markedTextCaretRectAtStart)>, WebCore::IntRect>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.markedTextCaretRectAtEnd)>, WebCore::IntRect>);
#endif
    static_assert(MembersInCorrectOrder<0
#if PLATFORM(IOS_FAMILY) || PLATFORM(GTK) || PLATFORM(WPE)
        , offsetof(WebKit::EditorState::VisualData, caretRectAtStart)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::VisualData, selectionClipRect)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::VisualData, caretRectAtEnd)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::VisualData, selectionGeometries)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::VisualData, markedTextRects)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::VisualData, markedTextCaretRectAtStart)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::EditorState::VisualData, markedTextCaretRectAtEnd)
#endif
    >::value);
#if PLATFORM(IOS_FAMILY) || PLATFORM(GTK) || PLATFORM(WPE)
    encoder << instance.caretRectAtStart;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.selectionClipRect;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.caretRectAtEnd;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.selectionGeometries;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.markedTextRects;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.markedTextCaretRectAtStart;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.markedTextCaretRectAtEnd;
#endif
}

std::optional<WebKit::EditorState::VisualData> ArgumentCoder<WebKit::EditorState::VisualData>::decode(Decoder& decoder)
{
#if PLATFORM(IOS_FAMILY) || PLATFORM(GTK) || PLATFORM(WPE)
    auto caretRectAtStart = decoder.decode<WebCore::IntRect>();
    if (!caretRectAtStart)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto selectionClipRect = decoder.decode<WebCore::IntRect>();
    if (!selectionClipRect)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto caretRectAtEnd = decoder.decode<WebCore::IntRect>();
    if (!caretRectAtEnd)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto selectionGeometries = decoder.decode<Vector<WebCore::SelectionGeometry>>();
    if (!selectionGeometries)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto markedTextRects = decoder.decode<Vector<WebCore::SelectionGeometry>>();
    if (!markedTextRects)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto markedTextCaretRectAtStart = decoder.decode<WebCore::IntRect>();
    if (!markedTextCaretRectAtStart)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto markedTextCaretRectAtEnd = decoder.decode<WebCore::IntRect>();
    if (!markedTextCaretRectAtEnd)
        return std::nullopt;
#endif

    return {
        WebKit::EditorState::VisualData {
#if PLATFORM(IOS_FAMILY) || PLATFORM(GTK) || PLATFORM(WPE)
            WTFMove(*caretRectAtStart),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*selectionClipRect),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*caretRectAtEnd),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*selectionGeometries),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*markedTextRects),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*markedTextCaretRectAtStart),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*markedTextCaretRectAtEnd)
#endif
        }
    };
}

#if PLATFORM(IOS_FAMILY)

void ArgumentCoder<WebKit::OptionItem>::encode(Encoder& encoder, const WebKit::OptionItem& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.text)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isGroup)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isSelected)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.disabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parentGroupID)>, int>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::OptionItem, text)
        , offsetof(WebKit::OptionItem, isGroup)
        , offsetof(WebKit::OptionItem, isSelected)
        , offsetof(WebKit::OptionItem, disabled)
        , offsetof(WebKit::OptionItem, parentGroupID)
    >::value);
    encoder << instance.text;
    encoder << instance.isGroup;
    encoder << instance.isSelected;
    encoder << instance.disabled;
    encoder << instance.parentGroupID;
}

std::optional<WebKit::OptionItem> ArgumentCoder<WebKit::OptionItem>::decode(Decoder& decoder)
{
    auto text = decoder.decode<String>();
    if (!text)
        return std::nullopt;

    auto isGroup = decoder.decode<bool>();
    if (!isGroup)
        return std::nullopt;

    auto isSelected = decoder.decode<bool>();
    if (!isSelected)
        return std::nullopt;

    auto disabled = decoder.decode<bool>();
    if (!disabled)
        return std::nullopt;

    auto parentGroupID = decoder.decode<int>();
    if (!parentGroupID)
        return std::nullopt;

    return {
        WebKit::OptionItem {
            WTFMove(*text),
            WTFMove(*isGroup),
            WTFMove(*isSelected),
            WTFMove(*disabled),
            WTFMove(*parentGroupID)
        }
    };
}

#endif

#if PLATFORM(IOS_FAMILY)

void ArgumentCoder<WebKit::FocusedElementInformation>::encode(Encoder& encoder, const WebKit::FocusedElementInformation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.interactionRect)>, WebCore::IntRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.elementContext)>, WebCore::ElementContext>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lastInteractionLocation)>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minimumScaleFactor)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maximumScaleFactor)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maximumScaleFactorIgnoringAlwaysScalable)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.nodeFontSize)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasNextNode)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.nextNodeRect)>, WebCore::IntRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasPreviousNode)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.previousNodeRect)>, WebCore::IntRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isAutocorrect)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isRTL)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMultiSelect)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isReadOnly)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowsUserScaling)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowsUserScalingIgnoringAlwaysScalable)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.insideFixedPosition)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.autocapitalizeType)>, WebCore::AutocapitalizeType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.elementType)>, WebKit::InputType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.inputMode)>, WebCore::InputMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.enterKeyHint)>, WebCore::EnterKeyHint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.formAction)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectOptions)>, Vector<WebKit::OptionItem>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectedIndex)>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.valueAsNumber)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.title)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.acceptsAutofilledLoginCredentials)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isAutofillableUsernameField)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.representingPageURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.autofillFieldName)>, WebCore::AutofillFieldName>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.nonAutofillCredentialType)>, WebCore::NonAutofillCredentialType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.placeholder)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ariaLabel)>, String>);
#if ENABLE(DATALIST_ELEMENT)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasSuggestions)>, bool>);
#endif
#if ENABLE(DATALIST_ELEMENT)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isFocusingWithDataListDropdown)>, bool>);
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorValue)>, WebCore::Color>);
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.suggestedColors)>, Vector<WebCore::Color>>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldSynthesizeKeyEventsForEditing)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isSpellCheckingEnabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldAvoidResizingWhenInputViewBoundsChange)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldAvoidScrollingWhenFocusedContentIsVisible)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldUseLegacySelectPopoverDismissalBehaviorInDataActivation)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isFocusingWithValidationMessage)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preventScroll)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebKit::FocusedElementInformationIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.containerScrollingNodeID)>, WebCore::ScrollingNodeID>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameID)>, WebCore::FrameIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::FocusedElementInformation, interactionRect)
        , offsetof(WebKit::FocusedElementInformation, elementContext)
        , offsetof(WebKit::FocusedElementInformation, lastInteractionLocation)
        , offsetof(WebKit::FocusedElementInformation, minimumScaleFactor)
        , offsetof(WebKit::FocusedElementInformation, maximumScaleFactor)
        , offsetof(WebKit::FocusedElementInformation, maximumScaleFactorIgnoringAlwaysScalable)
        , offsetof(WebKit::FocusedElementInformation, nodeFontSize)
        , offsetof(WebKit::FocusedElementInformation, hasNextNode)
        , offsetof(WebKit::FocusedElementInformation, nextNodeRect)
        , offsetof(WebKit::FocusedElementInformation, hasPreviousNode)
        , offsetof(WebKit::FocusedElementInformation, previousNodeRect)
        , offsetof(WebKit::FocusedElementInformation, isAutocorrect)
        , offsetof(WebKit::FocusedElementInformation, isRTL)
        , offsetof(WebKit::FocusedElementInformation, isMultiSelect)
        , offsetof(WebKit::FocusedElementInformation, isReadOnly)
        , offsetof(WebKit::FocusedElementInformation, allowsUserScaling)
        , offsetof(WebKit::FocusedElementInformation, allowsUserScalingIgnoringAlwaysScalable)
        , offsetof(WebKit::FocusedElementInformation, insideFixedPosition)
        , offsetof(WebKit::FocusedElementInformation, autocapitalizeType)
        , offsetof(WebKit::FocusedElementInformation, elementType)
        , offsetof(WebKit::FocusedElementInformation, inputMode)
        , offsetof(WebKit::FocusedElementInformation, enterKeyHint)
        , offsetof(WebKit::FocusedElementInformation, formAction)
        , offsetof(WebKit::FocusedElementInformation, selectOptions)
        , offsetof(WebKit::FocusedElementInformation, selectedIndex)
        , offsetof(WebKit::FocusedElementInformation, value)
        , offsetof(WebKit::FocusedElementInformation, valueAsNumber)
        , offsetof(WebKit::FocusedElementInformation, title)
        , offsetof(WebKit::FocusedElementInformation, acceptsAutofilledLoginCredentials)
        , offsetof(WebKit::FocusedElementInformation, isAutofillableUsernameField)
        , offsetof(WebKit::FocusedElementInformation, representingPageURL)
        , offsetof(WebKit::FocusedElementInformation, autofillFieldName)
        , offsetof(WebKit::FocusedElementInformation, nonAutofillCredentialType)
        , offsetof(WebKit::FocusedElementInformation, placeholder)
        , offsetof(WebKit::FocusedElementInformation, label)
        , offsetof(WebKit::FocusedElementInformation, ariaLabel)
#if ENABLE(DATALIST_ELEMENT)
        , offsetof(WebKit::FocusedElementInformation, hasSuggestions)
#endif
#if ENABLE(DATALIST_ELEMENT)
        , offsetof(WebKit::FocusedElementInformation, isFocusingWithDataListDropdown)
#endif
#if ENABLE(INPUT_TYPE_COLOR)
        , offsetof(WebKit::FocusedElementInformation, colorValue)
#endif
#if ENABLE(INPUT_TYPE_COLOR)
        , offsetof(WebKit::FocusedElementInformation, suggestedColors)
#endif
        , offsetof(WebKit::FocusedElementInformation, shouldSynthesizeKeyEventsForEditing)
        , offsetof(WebKit::FocusedElementInformation, isSpellCheckingEnabled)
        , offsetof(WebKit::FocusedElementInformation, shouldAvoidResizingWhenInputViewBoundsChange)
        , offsetof(WebKit::FocusedElementInformation, shouldAvoidScrollingWhenFocusedContentIsVisible)
        , offsetof(WebKit::FocusedElementInformation, shouldUseLegacySelectPopoverDismissalBehaviorInDataActivation)
        , offsetof(WebKit::FocusedElementInformation, isFocusingWithValidationMessage)
        , offsetof(WebKit::FocusedElementInformation, preventScroll)
        , offsetof(WebKit::FocusedElementInformation, identifier)
        , offsetof(WebKit::FocusedElementInformation, containerScrollingNodeID)
        , offsetof(WebKit::FocusedElementInformation, frameID)
    >::value);
    encoder << instance.interactionRect;
    encoder << instance.elementContext;
    encoder << instance.lastInteractionLocation;
    encoder << instance.minimumScaleFactor;
    encoder << instance.maximumScaleFactor;
    encoder << instance.maximumScaleFactorIgnoringAlwaysScalable;
    encoder << instance.nodeFontSize;
    encoder << instance.hasNextNode;
    encoder << instance.nextNodeRect;
    encoder << instance.hasPreviousNode;
    encoder << instance.previousNodeRect;
    encoder << instance.isAutocorrect;
    encoder << instance.isRTL;
    encoder << instance.isMultiSelect;
    encoder << instance.isReadOnly;
    encoder << instance.allowsUserScaling;
    encoder << instance.allowsUserScalingIgnoringAlwaysScalable;
    encoder << instance.insideFixedPosition;
    encoder << instance.autocapitalizeType;
    encoder << instance.elementType;
    encoder << instance.inputMode;
    encoder << instance.enterKeyHint;
    encoder << instance.formAction;
    encoder << instance.selectOptions;
    encoder << instance.selectedIndex;
    encoder << instance.value;
    encoder << instance.valueAsNumber;
    encoder << instance.title;
    encoder << instance.acceptsAutofilledLoginCredentials;
    encoder << instance.isAutofillableUsernameField;
    encoder << instance.representingPageURL;
    encoder << instance.autofillFieldName;
    encoder << instance.nonAutofillCredentialType;
    encoder << instance.placeholder;
    encoder << instance.label;
    encoder << instance.ariaLabel;
#if ENABLE(DATALIST_ELEMENT)
    encoder << instance.hasSuggestions;
#endif
#if ENABLE(DATALIST_ELEMENT)
    encoder << instance.isFocusingWithDataListDropdown;
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    encoder << instance.colorValue;
#endif
#if ENABLE(INPUT_TYPE_COLOR)
    encoder << instance.suggestedColors;
#endif
    encoder << instance.shouldSynthesizeKeyEventsForEditing;
    encoder << instance.isSpellCheckingEnabled;
    encoder << instance.shouldAvoidResizingWhenInputViewBoundsChange;
    encoder << instance.shouldAvoidScrollingWhenFocusedContentIsVisible;
    encoder << instance.shouldUseLegacySelectPopoverDismissalBehaviorInDataActivation;
    encoder << instance.isFocusingWithValidationMessage;
    encoder << instance.preventScroll;
    encoder << instance.identifier;
    encoder << instance.containerScrollingNodeID;
    encoder << instance.frameID;
}

std::optional<WebKit::FocusedElementInformation> ArgumentCoder<WebKit::FocusedElementInformation>::decode(Decoder& decoder)
{
    auto interactionRect = decoder.decode<WebCore::IntRect>();
    if (!interactionRect)
        return std::nullopt;

    auto elementContext = decoder.decode<WebCore::ElementContext>();
    if (!elementContext)
        return std::nullopt;

    auto lastInteractionLocation = decoder.decode<WebCore::IntPoint>();
    if (!lastInteractionLocation)
        return std::nullopt;

    auto minimumScaleFactor = decoder.decode<double>();
    if (!minimumScaleFactor)
        return std::nullopt;

    auto maximumScaleFactor = decoder.decode<double>();
    if (!maximumScaleFactor)
        return std::nullopt;

    auto maximumScaleFactorIgnoringAlwaysScalable = decoder.decode<double>();
    if (!maximumScaleFactorIgnoringAlwaysScalable)
        return std::nullopt;

    auto nodeFontSize = decoder.decode<double>();
    if (!nodeFontSize)
        return std::nullopt;

    auto hasNextNode = decoder.decode<bool>();
    if (!hasNextNode)
        return std::nullopt;

    auto nextNodeRect = decoder.decode<WebCore::IntRect>();
    if (!nextNodeRect)
        return std::nullopt;

    auto hasPreviousNode = decoder.decode<bool>();
    if (!hasPreviousNode)
        return std::nullopt;

    auto previousNodeRect = decoder.decode<WebCore::IntRect>();
    if (!previousNodeRect)
        return std::nullopt;

    auto isAutocorrect = decoder.decode<bool>();
    if (!isAutocorrect)
        return std::nullopt;

    auto isRTL = decoder.decode<bool>();
    if (!isRTL)
        return std::nullopt;

    auto isMultiSelect = decoder.decode<bool>();
    if (!isMultiSelect)
        return std::nullopt;

    auto isReadOnly = decoder.decode<bool>();
    if (!isReadOnly)
        return std::nullopt;

    auto allowsUserScaling = decoder.decode<bool>();
    if (!allowsUserScaling)
        return std::nullopt;

    auto allowsUserScalingIgnoringAlwaysScalable = decoder.decode<bool>();
    if (!allowsUserScalingIgnoringAlwaysScalable)
        return std::nullopt;

    auto insideFixedPosition = decoder.decode<bool>();
    if (!insideFixedPosition)
        return std::nullopt;

    auto autocapitalizeType = decoder.decode<WebCore::AutocapitalizeType>();
    if (!autocapitalizeType)
        return std::nullopt;

    auto elementType = decoder.decode<WebKit::InputType>();
    if (!elementType)
        return std::nullopt;

    auto inputMode = decoder.decode<WebCore::InputMode>();
    if (!inputMode)
        return std::nullopt;

    auto enterKeyHint = decoder.decode<WebCore::EnterKeyHint>();
    if (!enterKeyHint)
        return std::nullopt;

    auto formAction = decoder.decode<String>();
    if (!formAction)
        return std::nullopt;

    auto selectOptions = decoder.decode<Vector<WebKit::OptionItem>>();
    if (!selectOptions)
        return std::nullopt;

    auto selectedIndex = decoder.decode<int>();
    if (!selectedIndex)
        return std::nullopt;

    auto value = decoder.decode<String>();
    if (!value)
        return std::nullopt;

    auto valueAsNumber = decoder.decode<double>();
    if (!valueAsNumber)
        return std::nullopt;

    auto title = decoder.decode<String>();
    if (!title)
        return std::nullopt;

    auto acceptsAutofilledLoginCredentials = decoder.decode<bool>();
    if (!acceptsAutofilledLoginCredentials)
        return std::nullopt;

    auto isAutofillableUsernameField = decoder.decode<bool>();
    if (!isAutofillableUsernameField)
        return std::nullopt;

    auto representingPageURL = decoder.decode<URL>();
    if (!representingPageURL)
        return std::nullopt;

    auto autofillFieldName = decoder.decode<WebCore::AutofillFieldName>();
    if (!autofillFieldName)
        return std::nullopt;

    auto nonAutofillCredentialType = decoder.decode<WebCore::NonAutofillCredentialType>();
    if (!nonAutofillCredentialType)
        return std::nullopt;

    auto placeholder = decoder.decode<String>();
    if (!placeholder)
        return std::nullopt;

    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto ariaLabel = decoder.decode<String>();
    if (!ariaLabel)
        return std::nullopt;

#if ENABLE(DATALIST_ELEMENT)
    auto hasSuggestions = decoder.decode<bool>();
    if (!hasSuggestions)
        return std::nullopt;
#endif

#if ENABLE(DATALIST_ELEMENT)
    auto isFocusingWithDataListDropdown = decoder.decode<bool>();
    if (!isFocusingWithDataListDropdown)
        return std::nullopt;
#endif

#if ENABLE(INPUT_TYPE_COLOR)
    auto colorValue = decoder.decode<WebCore::Color>();
    if (!colorValue)
        return std::nullopt;
#endif

#if ENABLE(INPUT_TYPE_COLOR)
    auto suggestedColors = decoder.decode<Vector<WebCore::Color>>();
    if (!suggestedColors)
        return std::nullopt;
#endif

    auto shouldSynthesizeKeyEventsForEditing = decoder.decode<bool>();
    if (!shouldSynthesizeKeyEventsForEditing)
        return std::nullopt;

    auto isSpellCheckingEnabled = decoder.decode<bool>();
    if (!isSpellCheckingEnabled)
        return std::nullopt;

    auto shouldAvoidResizingWhenInputViewBoundsChange = decoder.decode<bool>();
    if (!shouldAvoidResizingWhenInputViewBoundsChange)
        return std::nullopt;

    auto shouldAvoidScrollingWhenFocusedContentIsVisible = decoder.decode<bool>();
    if (!shouldAvoidScrollingWhenFocusedContentIsVisible)
        return std::nullopt;

    auto shouldUseLegacySelectPopoverDismissalBehaviorInDataActivation = decoder.decode<bool>();
    if (!shouldUseLegacySelectPopoverDismissalBehaviorInDataActivation)
        return std::nullopt;

    auto isFocusingWithValidationMessage = decoder.decode<bool>();
    if (!isFocusingWithValidationMessage)
        return std::nullopt;

    auto preventScroll = decoder.decode<bool>();
    if (!preventScroll)
        return std::nullopt;

    auto identifier = decoder.decode<WebKit::FocusedElementInformationIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto containerScrollingNodeID = decoder.decode<WebCore::ScrollingNodeID>();
    if (!containerScrollingNodeID)
        return std::nullopt;

    auto frameID = decoder.decode<WebCore::FrameIdentifier>();
    if (!frameID)
        return std::nullopt;

    return {
        WebKit::FocusedElementInformation {
            WTFMove(*interactionRect),
            WTFMove(*elementContext),
            WTFMove(*lastInteractionLocation),
            WTFMove(*minimumScaleFactor),
            WTFMove(*maximumScaleFactor),
            WTFMove(*maximumScaleFactorIgnoringAlwaysScalable),
            WTFMove(*nodeFontSize),
            WTFMove(*hasNextNode),
            WTFMove(*nextNodeRect),
            WTFMove(*hasPreviousNode),
            WTFMove(*previousNodeRect),
            WTFMove(*isAutocorrect),
            WTFMove(*isRTL),
            WTFMove(*isMultiSelect),
            WTFMove(*isReadOnly),
            WTFMove(*allowsUserScaling),
            WTFMove(*allowsUserScalingIgnoringAlwaysScalable),
            WTFMove(*insideFixedPosition),
            WTFMove(*autocapitalizeType),
            WTFMove(*elementType),
            WTFMove(*inputMode),
            WTFMove(*enterKeyHint),
            WTFMove(*formAction),
            WTFMove(*selectOptions),
            WTFMove(*selectedIndex),
            WTFMove(*value),
            WTFMove(*valueAsNumber),
            WTFMove(*title),
            WTFMove(*acceptsAutofilledLoginCredentials),
            WTFMove(*isAutofillableUsernameField),
            WTFMove(*representingPageURL),
            WTFMove(*autofillFieldName),
            WTFMove(*nonAutofillCredentialType),
            WTFMove(*placeholder),
            WTFMove(*label),
            WTFMove(*ariaLabel),
#if ENABLE(DATALIST_ELEMENT)
            WTFMove(*hasSuggestions),
#endif
#if ENABLE(DATALIST_ELEMENT)
            WTFMove(*isFocusingWithDataListDropdown),
#endif
#if ENABLE(INPUT_TYPE_COLOR)
            WTFMove(*colorValue),
#endif
#if ENABLE(INPUT_TYPE_COLOR)
            WTFMove(*suggestedColors),
#endif
            WTFMove(*shouldSynthesizeKeyEventsForEditing),
            WTFMove(*isSpellCheckingEnabled),
            WTFMove(*shouldAvoidResizingWhenInputViewBoundsChange),
            WTFMove(*shouldAvoidScrollingWhenFocusedContentIsVisible),
            WTFMove(*shouldUseLegacySelectPopoverDismissalBehaviorInDataActivation),
            WTFMove(*isFocusingWithValidationMessage),
            WTFMove(*preventScroll),
            WTFMove(*identifier),
            WTFMove(*containerScrollingNodeID),
            WTFMove(*frameID)
        }
    };
}

#endif


void ArgumentCoder<WebKit::FrameInfoData>::encode(Encoder& encoder, const WebKit::FrameInfoData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMainFrame)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.request)>, WebCore::ResourceRequest>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.securityOrigin)>, WebCore::SecurityOriginData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameID)>, std::optional<WebCore::FrameIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parentFrameID)>, std::optional<WebCore::FrameIdentifier>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::FrameInfoData, isMainFrame)
        , offsetof(WebKit::FrameInfoData, request)
        , offsetof(WebKit::FrameInfoData, securityOrigin)
        , offsetof(WebKit::FrameInfoData, frameName)
        , offsetof(WebKit::FrameInfoData, frameID)
        , offsetof(WebKit::FrameInfoData, parentFrameID)
    >::value);
    encoder << instance.isMainFrame;
    encoder << instance.request;
    encoder << instance.securityOrigin;
    encoder << instance.frameName;
    encoder << instance.frameID;
    encoder << instance.parentFrameID;
}

std::optional<WebKit::FrameInfoData> ArgumentCoder<WebKit::FrameInfoData>::decode(Decoder& decoder)
{
    auto isMainFrame = decoder.decode<bool>();
    if (!isMainFrame)
        return std::nullopt;

    auto request = decoder.decode<WebCore::ResourceRequest>();
    if (!request)
        return std::nullopt;

    auto securityOrigin = decoder.decode<WebCore::SecurityOriginData>();
    if (!securityOrigin)
        return std::nullopt;

    auto frameName = decoder.decode<String>();
    if (!frameName)
        return std::nullopt;

    auto frameID = decoder.decode<std::optional<WebCore::FrameIdentifier>>();
    if (!frameID)
        return std::nullopt;

    auto parentFrameID = decoder.decode<std::optional<WebCore::FrameIdentifier>>();
    if (!parentFrameID)
        return std::nullopt;

    return {
        WebKit::FrameInfoData {
            WTFMove(*isMainFrame),
            WTFMove(*request),
            WTFMove(*securityOrigin),
            WTFMove(*frameName),
            WTFMove(*frameID),
            WTFMove(*parentFrameID)
        }
    };
}


void ArgumentCoder<WebKit::FrameTreeNodeData>::encode(Encoder& encoder, const WebKit::FrameTreeNodeData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.info)>, WebKit::FrameInfoData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.children)>, Vector<WebKit::FrameTreeNodeData>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::FrameTreeNodeData, info)
        , offsetof(WebKit::FrameTreeNodeData, children)
    >::value);
    encoder << instance.info;
    encoder << instance.children;
}

std::optional<WebKit::FrameTreeNodeData> ArgumentCoder<WebKit::FrameTreeNodeData>::decode(Decoder& decoder)
{
    auto info = decoder.decode<WebKit::FrameInfoData>();
    if (!info)
        return std::nullopt;

    auto children = decoder.decode<Vector<WebKit::FrameTreeNodeData>>();
    if (!children)
        return std::nullopt;

    return {
        WebKit::FrameTreeNodeData {
            WTFMove(*info),
            WTFMove(*children)
        }
    };
}


void ArgumentCoder<WebKit::LayerTreeContext>::encode(Encoder& encoder, const WebKit::LayerTreeContext& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contextID)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::LayerTreeContext, contextID)
    >::value);
    encoder << instance.contextID;
}

std::optional<WebKit::LayerTreeContext> ArgumentCoder<WebKit::LayerTreeContext>::decode(Decoder& decoder)
{
    auto contextID = decoder.decode<uint64_t>();
    if (!contextID)
        return std::nullopt;

    return {
        WebKit::LayerTreeContext {
            WTFMove(*contextID)
        }
    };
}

#if ENABLE(ARKIT_INLINE_PREVIEW)

void ArgumentCoder<WebKit::ModelIdentifier>::encode(Encoder& encoder, const WebKit::ModelIdentifier& instance)
{
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.uuid)>, String>);
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_IOS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.layerIdentifier)>, WebCore::GraphicsLayer::PlatformLayerID>);
#endif
    static_assert(MembersInCorrectOrder<0
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
        , offsetof(WebKit::ModelIdentifier, uuid)
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_IOS)
        , offsetof(WebKit::ModelIdentifier, layerIdentifier)
#endif
    >::value);
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
    encoder << instance.uuid;
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_IOS)
    encoder << instance.layerIdentifier;
#endif
}

std::optional<WebKit::ModelIdentifier> ArgumentCoder<WebKit::ModelIdentifier>::decode(Decoder& decoder)
{
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
    auto uuid = decoder.decode<String>();
    if (!uuid)
        return std::nullopt;
#endif

#if ENABLE(ARKIT_INLINE_PREVIEW_IOS)
    auto layerIdentifier = decoder.decode<WebCore::GraphicsLayer::PlatformLayerID>();
    if (!layerIdentifier)
        return std::nullopt;
#endif

    return {
        WebKit::ModelIdentifier {
#if ENABLE(ARKIT_INLINE_PREVIEW_MAC)
            WTFMove(*uuid),
#endif
#if ENABLE(ARKIT_INLINE_PREVIEW_IOS)
            WTFMove(*layerIdentifier)
#endif
        }
    };
}

#endif


void ArgumentCoder<WebCore::PasteboardImage>::encode(Encoder& encoder, const WebCore::PasteboardImage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.image)>, RefPtr<WebCore::Image>>);
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataInWebArchiveFormat)>, RefPtr<WebCore::SharedBuffer>>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataInHTMLFormat)>, String>);
#endif
#if !PLATFORM(WIN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, WebCore::PasteboardURL>);
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.resourceData)>, RefPtr<WebCore::SharedBuffer>>);
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.resourceMIMEType)>, String>);
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientTypes)>, Vector<String>>);
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientData)>, Vector<RefPtr<WebCore::SharedBuffer>>>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.suggestedName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.imageSize)>, WebCore::FloatSize>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PasteboardImage, image)
#if PLATFORM(MAC)
        , offsetof(WebCore::PasteboardImage, dataInWebArchiveFormat)
#endif
#if PLATFORM(MAC)
        , offsetof(WebCore::PasteboardImage, dataInHTMLFormat)
#endif
#if !PLATFORM(WIN)
        , offsetof(WebCore::PasteboardImage, url)
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
        , offsetof(WebCore::PasteboardImage, resourceData)
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
        , offsetof(WebCore::PasteboardImage, resourceMIMEType)
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
        , offsetof(WebCore::PasteboardImage, clientTypes)
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
        , offsetof(WebCore::PasteboardImage, clientData)
#endif
        , offsetof(WebCore::PasteboardImage, suggestedName)
        , offsetof(WebCore::PasteboardImage, imageSize)
    >::value);
    encoder << instance.image;
#if PLATFORM(MAC)
    encoder << instance.dataInWebArchiveFormat;
#endif
#if PLATFORM(MAC)
    encoder << instance.dataInHTMLFormat;
#endif
#if !PLATFORM(WIN)
    encoder << instance.url;
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
    encoder << instance.resourceData;
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
    encoder << instance.resourceMIMEType;
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
    encoder << instance.clientTypes;
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
    encoder << instance.clientData;
#endif
    encoder << instance.suggestedName;
    encoder << instance.imageSize;
}

std::optional<WebCore::PasteboardImage> ArgumentCoder<WebCore::PasteboardImage>::decode(Decoder& decoder)
{
    auto image = decoder.decode<RefPtr<WebCore::Image>>();
    if (!image)
        return std::nullopt;

#if PLATFORM(MAC)
    auto dataInWebArchiveFormat = decoder.decode<RefPtr<WebCore::SharedBuffer>>();
    if (!dataInWebArchiveFormat)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto dataInHTMLFormat = decoder.decode<String>();
    if (!dataInHTMLFormat)
        return std::nullopt;
#endif

#if !PLATFORM(WIN)
    auto url = decoder.decode<WebCore::PasteboardURL>();
    if (!url)
        return std::nullopt;
#endif

#if !(PLATFORM(GTK) || PLATFORM(WIN))
    auto resourceData = decoder.decode<RefPtr<WebCore::SharedBuffer>>();
    if (!resourceData)
        return std::nullopt;
#endif

#if !(PLATFORM(GTK) || PLATFORM(WIN))
    auto resourceMIMEType = decoder.decode<String>();
    if (!resourceMIMEType)
        return std::nullopt;
#endif

#if !(PLATFORM(GTK) || PLATFORM(WIN))
    auto clientTypes = decoder.decode<Vector<String>>();
    if (!clientTypes)
        return std::nullopt;
#endif

#if !(PLATFORM(GTK) || PLATFORM(WIN))
    auto clientData = decoder.decode<Vector<RefPtr<WebCore::SharedBuffer>>>();
    if (!clientData)
        return std::nullopt;
#endif

    auto suggestedName = decoder.decode<String>();
    if (!suggestedName)
        return std::nullopt;

    auto imageSize = decoder.decode<WebCore::FloatSize>();
    if (!imageSize)
        return std::nullopt;

    return {
        WebCore::PasteboardImage {
            WTFMove(*image),
#if PLATFORM(MAC)
            WTFMove(*dataInWebArchiveFormat),
#endif
#if PLATFORM(MAC)
            WTFMove(*dataInHTMLFormat),
#endif
#if !PLATFORM(WIN)
            WTFMove(*url),
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
            WTFMove(*resourceData),
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
            WTFMove(*resourceMIMEType),
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
            WTFMove(*clientTypes),
#endif
#if !(PLATFORM(GTK) || PLATFORM(WIN))
            WTFMove(*clientData),
#endif
            WTFMove(*suggestedName),
            WTFMove(*imageSize)
        }
    };
}


void ArgumentCoder<WebCore::PasteboardWebContent>::encode(Encoder& encoder, const WebCore::PasteboardWebContent& instance)
{
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentOrigin)>, String>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canSmartCopyOrDelete)>, bool>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataInWebArchiveFormat)>, RefPtr<WebCore::SharedBuffer>>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataInRTFDFormat)>, RefPtr<WebCore::SharedBuffer>>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataInRTFFormat)>, RefPtr<WebCore::SharedBuffer>>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataInAttributedStringFormat)>, RefPtr<WebCore::SharedBuffer>>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataInHTMLFormat)>, String>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataInStringFormat)>, String>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientTypes)>, Vector<String>>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientData)>, Vector<RefPtr<WebCore::SharedBuffer>>>);
#endif
#if PLATFORM(GTK)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentOrigin)>, String>);
#endif
#if PLATFORM(GTK)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canSmartCopyOrDelete)>, bool>);
#endif
#if PLATFORM(GTK)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.text)>, String>);
#endif
#if PLATFORM(GTK)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.markup)>, String>);
#endif
#if USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.text)>, String>);
#endif
#if USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.markup)>, String>);
#endif
    static_assert(MembersInCorrectOrder<0
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, contentOrigin)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, canSmartCopyOrDelete)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, dataInWebArchiveFormat)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, dataInRTFDFormat)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, dataInRTFFormat)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, dataInAttributedStringFormat)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, dataInHTMLFormat)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, dataInStringFormat)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, clientTypes)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardWebContent, clientData)
#endif
#if PLATFORM(GTK)
        , offsetof(WebCore::PasteboardWebContent, contentOrigin)
#endif
#if PLATFORM(GTK)
        , offsetof(WebCore::PasteboardWebContent, canSmartCopyOrDelete)
#endif
#if PLATFORM(GTK)
        , offsetof(WebCore::PasteboardWebContent, text)
#endif
#if PLATFORM(GTK)
        , offsetof(WebCore::PasteboardWebContent, markup)
#endif
#if USE(LIBWPE)
        , offsetof(WebCore::PasteboardWebContent, text)
#endif
#if USE(LIBWPE)
        , offsetof(WebCore::PasteboardWebContent, markup)
#endif
    >::value);
#if PLATFORM(COCOA)
    encoder << instance.contentOrigin;
#endif
#if PLATFORM(COCOA)
    encoder << instance.canSmartCopyOrDelete;
#endif
#if PLATFORM(COCOA)
    encoder << instance.dataInWebArchiveFormat;
#endif
#if PLATFORM(COCOA)
    encoder << instance.dataInRTFDFormat;
#endif
#if PLATFORM(COCOA)
    encoder << instance.dataInRTFFormat;
#endif
#if PLATFORM(COCOA)
    encoder << instance.dataInAttributedStringFormat;
#endif
#if PLATFORM(COCOA)
    encoder << instance.dataInHTMLFormat;
#endif
#if PLATFORM(COCOA)
    encoder << instance.dataInStringFormat;
#endif
#if PLATFORM(COCOA)
    encoder << instance.clientTypes;
#endif
#if PLATFORM(COCOA)
    encoder << instance.clientData;
#endif
#if PLATFORM(GTK)
    encoder << instance.contentOrigin;
#endif
#if PLATFORM(GTK)
    encoder << instance.canSmartCopyOrDelete;
#endif
#if PLATFORM(GTK)
    encoder << instance.text;
#endif
#if PLATFORM(GTK)
    encoder << instance.markup;
#endif
#if USE(LIBWPE)
    encoder << instance.text;
#endif
#if USE(LIBWPE)
    encoder << instance.markup;
#endif
}

std::optional<WebCore::PasteboardWebContent> ArgumentCoder<WebCore::PasteboardWebContent>::decode(Decoder& decoder)
{
#if PLATFORM(COCOA)
    auto contentOrigin = decoder.decode<String>();
    if (!contentOrigin)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto canSmartCopyOrDelete = decoder.decode<bool>();
    if (!canSmartCopyOrDelete)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto dataInWebArchiveFormat = decoder.decode<RefPtr<WebCore::SharedBuffer>>();
    if (!dataInWebArchiveFormat)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto dataInRTFDFormat = decoder.decode<RefPtr<WebCore::SharedBuffer>>();
    if (!dataInRTFDFormat)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto dataInRTFFormat = decoder.decode<RefPtr<WebCore::SharedBuffer>>();
    if (!dataInRTFFormat)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto dataInAttributedStringFormat = decoder.decode<RefPtr<WebCore::SharedBuffer>>();
    if (!dataInAttributedStringFormat)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto dataInHTMLFormat = decoder.decode<String>();
    if (!dataInHTMLFormat)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto dataInStringFormat = decoder.decode<String>();
    if (!dataInStringFormat)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto clientTypes = decoder.decode<Vector<String>>();
    if (!clientTypes)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto clientData = decoder.decode<Vector<RefPtr<WebCore::SharedBuffer>>>();
    if (!clientData)
        return std::nullopt;
#endif

#if PLATFORM(GTK)
    auto contentOrigin = decoder.decode<String>();
    if (!contentOrigin)
        return std::nullopt;
#endif

#if PLATFORM(GTK)
    auto canSmartCopyOrDelete = decoder.decode<bool>();
    if (!canSmartCopyOrDelete)
        return std::nullopt;
#endif

#if PLATFORM(GTK)
    auto text = decoder.decode<String>();
    if (!text)
        return std::nullopt;
#endif

#if PLATFORM(GTK)
    auto markup = decoder.decode<String>();
    if (!markup)
        return std::nullopt;
#endif

#if USE(LIBWPE)
    auto text = decoder.decode<String>();
    if (!text)
        return std::nullopt;
#endif

#if USE(LIBWPE)
    auto markup = decoder.decode<String>();
    if (!markup)
        return std::nullopt;
#endif

    return {
        WebCore::PasteboardWebContent {
#if PLATFORM(COCOA)
            WTFMove(*contentOrigin),
#endif
#if PLATFORM(COCOA)
            WTFMove(*canSmartCopyOrDelete),
#endif
#if PLATFORM(COCOA)
            WTFMove(*dataInWebArchiveFormat),
#endif
#if PLATFORM(COCOA)
            WTFMove(*dataInRTFDFormat),
#endif
#if PLATFORM(COCOA)
            WTFMove(*dataInRTFFormat),
#endif
#if PLATFORM(COCOA)
            WTFMove(*dataInAttributedStringFormat),
#endif
#if PLATFORM(COCOA)
            WTFMove(*dataInHTMLFormat),
#endif
#if PLATFORM(COCOA)
            WTFMove(*dataInStringFormat),
#endif
#if PLATFORM(COCOA)
            WTFMove(*clientTypes),
#endif
#if PLATFORM(COCOA)
            WTFMove(*clientData),
#endif
#if PLATFORM(GTK)
            WTFMove(*contentOrigin),
#endif
#if PLATFORM(GTK)
            WTFMove(*canSmartCopyOrDelete),
#endif
#if PLATFORM(GTK)
            WTFMove(*text),
#endif
#if PLATFORM(GTK)
            WTFMove(*markup),
#endif
#if USE(LIBWPE)
            WTFMove(*text),
#endif
#if USE(LIBWPE)
            WTFMove(*markup)
#endif
        }
    };
}


void ArgumentCoder<WebCore::PasteboardURL>::encode(Encoder& encoder, const WebCore::PasteboardURL& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.title)>, String>);
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.userVisibleForm)>, String>);
#endif
#if PLATFORM(GTK)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.markup)>, String>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PasteboardURL, url)
        , offsetof(WebCore::PasteboardURL, title)
#if PLATFORM(MAC)
        , offsetof(WebCore::PasteboardURL, userVisibleForm)
#endif
#if PLATFORM(GTK)
        , offsetof(WebCore::PasteboardURL, markup)
#endif
    >::value);
    encoder << instance.url;
    encoder << instance.title;
#if PLATFORM(MAC)
    encoder << instance.userVisibleForm;
#endif
#if PLATFORM(GTK)
    encoder << instance.markup;
#endif
}

std::optional<WebCore::PasteboardURL> ArgumentCoder<WebCore::PasteboardURL>::decode(Decoder& decoder)
{
    auto url = decoder.decode<URL>();
    if (!url)
        return std::nullopt;

    auto title = decoder.decode<String>();
    if (!title)
        return std::nullopt;

#if PLATFORM(MAC)
    auto userVisibleForm = decoder.decode<String>();
    if (!userVisibleForm)
        return std::nullopt;
#endif

#if PLATFORM(GTK)
    auto markup = decoder.decode<String>();
    if (!markup)
        return std::nullopt;
#endif

    return {
        WebCore::PasteboardURL {
            WTFMove(*url),
            WTFMove(*title),
#if PLATFORM(MAC)
            WTFMove(*userVisibleForm),
#endif
#if PLATFORM(GTK)
            WTFMove(*markup)
#endif
        }
    };
}


void ArgumentCoder<WebCore::PasteboardBuffer>::encode(Encoder& encoder, const WebCore::PasteboardBuffer& instance)
{
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentOrigin)>, String>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data)>, RefPtr<WebCore::SharedBuffer>>);
    static_assert(MembersInCorrectOrder<0
#if PLATFORM(COCOA)
        , offsetof(WebCore::PasteboardBuffer, contentOrigin)
#endif
        , offsetof(WebCore::PasteboardBuffer, type)
        , offsetof(WebCore::PasteboardBuffer, data)
    >::value);
#if PLATFORM(COCOA)
    encoder << instance.contentOrigin;
#endif
    encoder << instance.type;
    encoder << instance.data;
}

std::optional<WebCore::PasteboardBuffer> ArgumentCoder<WebCore::PasteboardBuffer>::decode(Decoder& decoder)
{
#if PLATFORM(COCOA)
    auto contentOrigin = decoder.decode<String>();
    if (!contentOrigin)
        return std::nullopt;
#endif

    auto type = decoder.decode<String>();
    if (!type)
        return std::nullopt;

    auto data = decoder.decode<RefPtr<WebCore::SharedBuffer>>();
    if (!data)
        return std::nullopt;

    return {
        WebCore::PasteboardBuffer {
#if PLATFORM(COCOA)
            WTFMove(*contentOrigin),
#endif
            WTFMove(*type),
            WTFMove(*data)
        }
    };
}


void ArgumentCoder<WebKit::HTTPBody>::encode(Encoder& encoder, const WebKit::HTTPBody& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentType)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.elements)>, Vector<WebKit::HTTPBody::Element>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::HTTPBody, contentType)
        , offsetof(WebKit::HTTPBody, elements)
    >::value);
    encoder << instance.contentType;
    encoder << instance.elements;
}

std::optional<WebKit::HTTPBody> ArgumentCoder<WebKit::HTTPBody>::decode(Decoder& decoder)
{
    auto contentType = decoder.decode<String>();
    if (!contentType)
        return std::nullopt;

    auto elements = decoder.decode<Vector<WebKit::HTTPBody::Element>>();
    if (!elements)
        return std::nullopt;

    return {
        WebKit::HTTPBody {
            WTFMove(*contentType),
            WTFMove(*elements)
        }
    };
}


void ArgumentCoder<WebKit::HTTPBody::Element>::encode(Encoder& encoder, const WebKit::HTTPBody::Element& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data)>, std::variant<Vector<uint8_t>, WebKit::HTTPBody::Element::FileData, String>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::HTTPBody::Element, data)
    >::value);
    encoder << instance.data;
}

std::optional<WebKit::HTTPBody::Element> ArgumentCoder<WebKit::HTTPBody::Element>::decode(Decoder& decoder)
{
    auto data = decoder.decode<std::variant<Vector<uint8_t>, WebKit::HTTPBody::Element::FileData, String>>();
    if (!data)
        return std::nullopt;

    return {
        WebKit::HTTPBody::Element {
            WTFMove(*data)
        }
    };
}


void ArgumentCoder<WebKit::HTTPBody::Element::FileData>::encode(Encoder& encoder, const WebKit::HTTPBody::Element::FileData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.filePath)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fileStart)>, int64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fileLength)>, std::optional<int64_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.expectedFileModificationTime)>, std::optional<WallTime>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::HTTPBody::Element::FileData, filePath)
        , offsetof(WebKit::HTTPBody::Element::FileData, fileStart)
        , offsetof(WebKit::HTTPBody::Element::FileData, fileLength)
        , offsetof(WebKit::HTTPBody::Element::FileData, expectedFileModificationTime)
    >::value);
    encoder << instance.filePath;
    encoder << instance.fileStart;
    encoder << instance.fileLength;
    encoder << instance.expectedFileModificationTime;
}

std::optional<WebKit::HTTPBody::Element::FileData> ArgumentCoder<WebKit::HTTPBody::Element::FileData>::decode(Decoder& decoder)
{
    auto filePath = decoder.decode<String>();
    if (!filePath)
        return std::nullopt;

    auto fileStart = decoder.decode<int64_t>();
    if (!fileStart)
        return std::nullopt;

    auto fileLength = decoder.decode<std::optional<int64_t>>();
    if (!fileLength)
        return std::nullopt;

    auto expectedFileModificationTime = decoder.decode<std::optional<WallTime>>();
    if (!expectedFileModificationTime)
        return std::nullopt;

    return {
        WebKit::HTTPBody::Element::FileData {
            WTFMove(*filePath),
            WTFMove(*fileStart),
            WTFMove(*fileLength),
            WTFMove(*expectedFileModificationTime)
        }
    };
}


void ArgumentCoder<WebKit::FrameState>::encode(Encoder& encoder, const WebKit::FrameState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.urlString)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.originalURLString)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.referrer)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.target)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stateObjectData)>, std::optional<Vector<uint8_t>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.documentSequenceNumber)>, int64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.itemSequenceNumber)>, int64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scrollPosition)>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldRestoreScrollPosition)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageScaleFactor)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.httpBody)>, std::optional<WebKit::HTTPBody>>);
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.exposedContentRect)>, WebCore::FloatRect>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.unobscuredContentRect)>, WebCore::IntRect>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minimumLayoutSizeInScrollViewCoordinates)>, WebCore::FloatSize>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentSize)>, WebCore::IntSize>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scaleIsInitial)>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.obscuredInsets)>, WebCore::FloatBoxExtent>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.children)>, Vector<WebKit::FrameState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_documentState)>, Vector<AtomString>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::FrameState, urlString)
        , offsetof(WebKit::FrameState, originalURLString)
        , offsetof(WebKit::FrameState, referrer)
        , offsetof(WebKit::FrameState, target)
        , offsetof(WebKit::FrameState, stateObjectData)
        , offsetof(WebKit::FrameState, documentSequenceNumber)
        , offsetof(WebKit::FrameState, itemSequenceNumber)
        , offsetof(WebKit::FrameState, scrollPosition)
        , offsetof(WebKit::FrameState, shouldRestoreScrollPosition)
        , offsetof(WebKit::FrameState, pageScaleFactor)
        , offsetof(WebKit::FrameState, httpBody)
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::FrameState, exposedContentRect)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::FrameState, unobscuredContentRect)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::FrameState, minimumLayoutSizeInScrollViewCoordinates)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::FrameState, contentSize)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::FrameState, scaleIsInitial)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::FrameState, obscuredInsets)
#endif
        , offsetof(WebKit::FrameState, children)
        , offsetof(WebKit::FrameState, m_documentState)
    >::value);
    encoder << instance.urlString;
    encoder << instance.originalURLString;
    encoder << instance.referrer;
    encoder << instance.target;
    encoder << instance.stateObjectData;
    encoder << instance.documentSequenceNumber;
    encoder << instance.itemSequenceNumber;
    encoder << instance.scrollPosition;
    encoder << instance.shouldRestoreScrollPosition;
    encoder << instance.pageScaleFactor;
    encoder << instance.httpBody;
#if PLATFORM(IOS_FAMILY)
    encoder << instance.exposedContentRect;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.unobscuredContentRect;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.minimumLayoutSizeInScrollViewCoordinates;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.contentSize;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.scaleIsInitial;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.obscuredInsets;
#endif
    encoder << instance.children;
    encoder << instance.m_documentState;
}

std::optional<WebKit::FrameState> ArgumentCoder<WebKit::FrameState>::decode(Decoder& decoder)
{
    auto urlString = decoder.decode<String>();
    if (!urlString)
        return std::nullopt;

    auto originalURLString = decoder.decode<String>();
    if (!originalURLString)
        return std::nullopt;

    auto referrer = decoder.decode<String>();
    if (!referrer)
        return std::nullopt;

    auto target = decoder.decode<AtomString>();
    if (!target)
        return std::nullopt;

    auto stateObjectData = decoder.decode<std::optional<Vector<uint8_t>>>();
    if (!stateObjectData)
        return std::nullopt;

    auto documentSequenceNumber = decoder.decode<int64_t>();
    if (!documentSequenceNumber)
        return std::nullopt;

    auto itemSequenceNumber = decoder.decode<int64_t>();
    if (!itemSequenceNumber)
        return std::nullopt;

    auto scrollPosition = decoder.decode<WebCore::IntPoint>();
    if (!scrollPosition)
        return std::nullopt;

    auto shouldRestoreScrollPosition = decoder.decode<bool>();
    if (!shouldRestoreScrollPosition)
        return std::nullopt;

    auto pageScaleFactor = decoder.decode<float>();
    if (!pageScaleFactor)
        return std::nullopt;

    auto httpBody = decoder.decode<std::optional<WebKit::HTTPBody>>();
    if (!httpBody)
        return std::nullopt;

#if PLATFORM(IOS_FAMILY)
    auto exposedContentRect = decoder.decode<WebCore::FloatRect>();
    if (!exposedContentRect)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto unobscuredContentRect = decoder.decode<WebCore::IntRect>();
    if (!unobscuredContentRect)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto minimumLayoutSizeInScrollViewCoordinates = decoder.decode<WebCore::FloatSize>();
    if (!minimumLayoutSizeInScrollViewCoordinates)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto contentSize = decoder.decode<WebCore::IntSize>();
    if (!contentSize)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto scaleIsInitial = decoder.decode<bool>();
    if (!scaleIsInitial)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto obscuredInsets = decoder.decode<WebCore::FloatBoxExtent>();
    if (!obscuredInsets)
        return std::nullopt;
#endif

    auto children = decoder.decode<Vector<WebKit::FrameState>>();
    if (!children)
        return std::nullopt;

    auto m_documentState = decoder.decode<Vector<AtomString>>();
    if (!m_documentState)
        return std::nullopt;

    if (!(WebKit::FrameState::validateDocumentState(*m_documentState)))
        return std::nullopt;

    WebKit::FrameState result;
    result.urlString = WTFMove(*urlString);
    result.originalURLString = WTFMove(*originalURLString);
    result.referrer = WTFMove(*referrer);
    result.target = WTFMove(*target);
    result.stateObjectData = WTFMove(*stateObjectData);
    result.documentSequenceNumber = WTFMove(*documentSequenceNumber);
    result.itemSequenceNumber = WTFMove(*itemSequenceNumber);
    result.scrollPosition = WTFMove(*scrollPosition);
    result.shouldRestoreScrollPosition = WTFMove(*shouldRestoreScrollPosition);
    result.pageScaleFactor = WTFMove(*pageScaleFactor);
    result.httpBody = WTFMove(*httpBody);
#if PLATFORM(IOS_FAMILY)
    result.exposedContentRect = WTFMove(*exposedContentRect);
#endif
#if PLATFORM(IOS_FAMILY)
    result.unobscuredContentRect = WTFMove(*unobscuredContentRect);
#endif
#if PLATFORM(IOS_FAMILY)
    result.minimumLayoutSizeInScrollViewCoordinates = WTFMove(*minimumLayoutSizeInScrollViewCoordinates);
#endif
#if PLATFORM(IOS_FAMILY)
    result.contentSize = WTFMove(*contentSize);
#endif
#if PLATFORM(IOS_FAMILY)
    result.scaleIsInitial = WTFMove(*scaleIsInitial);
#endif
#if PLATFORM(IOS_FAMILY)
    result.obscuredInsets = WTFMove(*obscuredInsets);
#endif
    result.children = WTFMove(*children);
    result.m_documentState = WTFMove(*m_documentState);
    return { WTFMove(result) };
}


void ArgumentCoder<WebKit::PageState>::encode(Encoder& encoder, const WebKit::PageState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.title)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mainFrameState)>, WebKit::FrameState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldOpenExternalURLsPolicy)>, WebCore::ShouldOpenExternalURLsPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sessionStateObject)>, RefPtr<WebCore::SerializedScriptValue>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.wasCreatedByJSWithoutUserInteraction)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::PageState, title)
        , offsetof(WebKit::PageState, mainFrameState)
        , offsetof(WebKit::PageState, shouldOpenExternalURLsPolicy)
        , offsetof(WebKit::PageState, sessionStateObject)
        , offsetof(WebKit::PageState, wasCreatedByJSWithoutUserInteraction)
    >::value);
    encoder << instance.title;
    encoder << instance.mainFrameState;
    encoder << instance.shouldOpenExternalURLsPolicy;
    encoder << instance.sessionStateObject;
    encoder << instance.wasCreatedByJSWithoutUserInteraction;
}

std::optional<WebKit::PageState> ArgumentCoder<WebKit::PageState>::decode(Decoder& decoder)
{
    auto title = decoder.decode<String>();
    if (!title)
        return std::nullopt;

    auto mainFrameState = decoder.decode<WebKit::FrameState>();
    if (!mainFrameState)
        return std::nullopt;

    auto shouldOpenExternalURLsPolicy = decoder.decode<WebCore::ShouldOpenExternalURLsPolicy>();
    if (!shouldOpenExternalURLsPolicy)
        return std::nullopt;

    auto sessionStateObject = decoder.decode<RefPtr<WebCore::SerializedScriptValue>>();
    if (!sessionStateObject)
        return std::nullopt;

    auto wasCreatedByJSWithoutUserInteraction = decoder.decode<bool>();
    if (!wasCreatedByJSWithoutUserInteraction)
        return std::nullopt;

    return {
        WebKit::PageState {
            WTFMove(*title),
            WTFMove(*mainFrameState),
            WTFMove(*shouldOpenExternalURLsPolicy),
            WTFMove(*sessionStateObject),
            WTFMove(*wasCreatedByJSWithoutUserInteraction)
        }
    };
}


void ArgumentCoder<WebKit::BackForwardListItemState>::encode(Encoder& encoder, const WebKit::BackForwardListItemState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::BackForwardItemIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageState)>, WebKit::PageState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasCachedPage)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::BackForwardListItemState, identifier)
        , offsetof(WebKit::BackForwardListItemState, pageState)
        , offsetof(WebKit::BackForwardListItemState, hasCachedPage)
    >::value);
    encoder << instance.identifier;
    encoder << instance.pageState;
    encoder << instance.hasCachedPage;
}

std::optional<WebKit::BackForwardListItemState> ArgumentCoder<WebKit::BackForwardListItemState>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::BackForwardItemIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto pageState = decoder.decode<WebKit::PageState>();
    if (!pageState)
        return std::nullopt;

    auto hasCachedPage = decoder.decode<bool>();
    if (!hasCachedPage)
        return std::nullopt;

    return {
        WebKit::BackForwardListItemState {
            WTFMove(*identifier),
            WTFMove(*pageState),
            WTFMove(*hasCachedPage)
        }
    };
}


void ArgumentCoder<WebKit::BackForwardListState>::encode(Encoder& encoder, const WebKit::BackForwardListState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.items)>, Vector<WebKit::BackForwardListItemState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.currentIndex)>, std::optional<uint32_t>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::BackForwardListState, items)
        , offsetof(WebKit::BackForwardListState, currentIndex)
    >::value);
    encoder << instance.items;
    encoder << instance.currentIndex;
}

std::optional<WebKit::BackForwardListState> ArgumentCoder<WebKit::BackForwardListState>::decode(Decoder& decoder)
{
    auto items = decoder.decode<Vector<WebKit::BackForwardListItemState>>();
    if (!items)
        return std::nullopt;

    auto currentIndex = decoder.decode<std::optional<uint32_t>>();
    if (!currentIndex)
        return std::nullopt;

    return {
        WebKit::BackForwardListState {
            WTFMove(*items),
            WTFMove(*currentIndex)
        }
    };
}


void ArgumentCoder<WebKit::ShareableBitmapConfiguration>::encode(Encoder& encoder, const WebKit::ShareableBitmapConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, std::optional<WebCore::DestinationColorSpace>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isOpaque)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::ShareableBitmapConfiguration, colorSpace)
        , offsetof(WebKit::ShareableBitmapConfiguration, isOpaque)
    >::value);
    encoder << instance.colorSpace;
    encoder << instance.isOpaque;
}

std::optional<WebKit::ShareableBitmapConfiguration> ArgumentCoder<WebKit::ShareableBitmapConfiguration>::decode(Decoder& decoder)
{
    auto colorSpace = decoder.decode<std::optional<WebCore::DestinationColorSpace>>();
    if (!colorSpace)
        return std::nullopt;

    auto isOpaque = decoder.decode<bool>();
    if (!isOpaque)
        return std::nullopt;

    return {
        WebKit::ShareableBitmapConfiguration {
            WTFMove(*colorSpace),
            WTFMove(*isOpaque)
        }
    };
}


void ArgumentCoder<WebKit::ShareableBitmapHandle>::encode(Encoder& encoder, const WebKit::ShareableBitmapHandle& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_handle)>, WebKit::SharedMemory::Handle>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_size)>, WebCore::IntSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_configuration)>, WebKit::ShareableBitmapConfiguration>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::ShareableBitmapHandle, m_handle)
        , offsetof(WebKit::ShareableBitmapHandle, m_size)
        , offsetof(WebKit::ShareableBitmapHandle, m_configuration)
    >::value);
    encoder << instance.m_handle;
    encoder << instance.m_size;
    encoder << instance.m_configuration;
}

std::optional<WebKit::ShareableBitmapHandle> ArgumentCoder<WebKit::ShareableBitmapHandle>::decode(Decoder& decoder)
{
    auto m_handle = decoder.decode<WebKit::SharedMemory::Handle>();
    if (!m_handle)
        return std::nullopt;

    auto m_size = decoder.decode<WebCore::IntSize>();
    if (!m_size)
        return std::nullopt;

    if (!(m_size->width() >= 0 && m_size->height() >= 0))
        return std::nullopt;

    auto m_configuration = decoder.decode<WebKit::ShareableBitmapConfiguration>();
    if (!m_configuration)
        return std::nullopt;

    if (!(!WebKit::ShareableBitmap::numBytesForSize(*m_size, *m_configuration).hasOverflowed() && m_handle->size() >= WebKit::ShareableBitmap::numBytesForSize(*m_size, *m_configuration)))
        return std::nullopt;

    return {
        WebKit::ShareableBitmapHandle {
            WTFMove(*m_handle),
            WTFMove(*m_size),
            WTFMove(*m_configuration)
        }
    };
}


void ArgumentCoder<WebKit::ShareableBitmap>::encode(Encoder& encoder, const WebKit::ShareableBitmap& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.createReadOnlyHandle())>, std::optional<WebKit::ShareableBitmapHandle>>);
    encoder << instance.createReadOnlyHandle();
}

std::optional<Ref<WebKit::ShareableBitmap>> ArgumentCoder<WebKit::ShareableBitmap>::decode(Decoder& decoder)
{
    auto createReadOnlyHandle = decoder.decode<std::optional<WebKit::ShareableBitmapHandle>>();
    if (!createReadOnlyHandle)
        return std::nullopt;

    return {
        WebKit::ShareableBitmap::createReadOnly(
            WTFMove(*createReadOnlyHandle)
        )
    };
}

#if ENABLE(IMAGE_ANALYSIS)

void ArgumentCoder<WebCore::TextRecognitionWordData>::encode(Encoder& encoder, const WebCore::TextRecognitionWordData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.text)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.normalizedQuad)>, WebCore::FloatQuad>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasLeadingWhitespace)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextRecognitionWordData, text)
        , offsetof(WebCore::TextRecognitionWordData, normalizedQuad)
        , offsetof(WebCore::TextRecognitionWordData, hasLeadingWhitespace)
    >::value);
    encoder << instance.text;
    encoder << instance.normalizedQuad;
    encoder << instance.hasLeadingWhitespace;
}

std::optional<WebCore::TextRecognitionWordData> ArgumentCoder<WebCore::TextRecognitionWordData>::decode(Decoder& decoder)
{
    auto text = decoder.decode<String>();
    if (!text)
        return std::nullopt;

    auto normalizedQuad = decoder.decode<WebCore::FloatQuad>();
    if (!normalizedQuad)
        return std::nullopt;

    auto hasLeadingWhitespace = decoder.decode<bool>();
    if (!hasLeadingWhitespace)
        return std::nullopt;

    return {
        WebCore::TextRecognitionWordData {
            WTFMove(*text),
            WTFMove(*normalizedQuad),
            WTFMove(*hasLeadingWhitespace)
        }
    };
}

#endif

#if ENABLE(IMAGE_ANALYSIS)

void ArgumentCoder<WebCore::TextRecognitionLineData>::encode(Encoder& encoder, const WebCore::TextRecognitionLineData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.normalizedQuad)>, WebCore::FloatQuad>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.children)>, Vector<WebCore::TextRecognitionWordData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasTrailingNewline)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextRecognitionLineData, normalizedQuad)
        , offsetof(WebCore::TextRecognitionLineData, children)
        , offsetof(WebCore::TextRecognitionLineData, hasTrailingNewline)
    >::value);
    encoder << instance.normalizedQuad;
    encoder << instance.children;
    encoder << instance.hasTrailingNewline;
}

std::optional<WebCore::TextRecognitionLineData> ArgumentCoder<WebCore::TextRecognitionLineData>::decode(Decoder& decoder)
{
    auto normalizedQuad = decoder.decode<WebCore::FloatQuad>();
    if (!normalizedQuad)
        return std::nullopt;

    auto children = decoder.decode<Vector<WebCore::TextRecognitionWordData>>();
    if (!children)
        return std::nullopt;

    auto hasTrailingNewline = decoder.decode<bool>();
    if (!hasTrailingNewline)
        return std::nullopt;

    return {
        WebCore::TextRecognitionLineData {
            WTFMove(*normalizedQuad),
            WTFMove(*children),
            WTFMove(*hasTrailingNewline)
        }
    };
}

#endif

#if ENABLE(IMAGE_ANALYSIS)

void ArgumentCoder<WebCore::TextRecognitionBlockData>::encode(Encoder& encoder, const WebCore::TextRecognitionBlockData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.text)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.normalizedQuad)>, WebCore::FloatQuad>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextRecognitionBlockData, text)
        , offsetof(WebCore::TextRecognitionBlockData, normalizedQuad)
    >::value);
    encoder << instance.text;
    encoder << instance.normalizedQuad;
}

std::optional<WebCore::TextRecognitionBlockData> ArgumentCoder<WebCore::TextRecognitionBlockData>::decode(Decoder& decoder)
{
    auto text = decoder.decode<String>();
    if (!text)
        return std::nullopt;

    auto normalizedQuad = decoder.decode<WebCore::FloatQuad>();
    if (!normalizedQuad)
        return std::nullopt;

    return {
        WebCore::TextRecognitionBlockData {
            WTFMove(*text),
            WTFMove(*normalizedQuad)
        }
    };
}

#endif

#if ENABLE(IMAGE_ANALYSIS)

void ArgumentCoder<WebCore::TextRecognitionResult>::encode(Encoder& encoder, const WebCore::TextRecognitionResult& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lines)>, Vector<WebCore::TextRecognitionLineData>>);
#if ENABLE(DATA_DETECTION)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataDetectors)>, Vector<WebCore::TextRecognitionDataDetector>>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blocks)>, Vector<WebCore::TextRecognitionBlockData>>);
#if ENABLE(IMAGE_ANALYSIS_ENHANCEMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.platformData)>, RetainPtr<VKCImageAnalysis>>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextRecognitionResult, lines)
#if ENABLE(DATA_DETECTION)
        , offsetof(WebCore::TextRecognitionResult, dataDetectors)
#endif
        , offsetof(WebCore::TextRecognitionResult, blocks)
#if ENABLE(IMAGE_ANALYSIS_ENHANCEMENTS)
        , offsetof(WebCore::TextRecognitionResult, platformData)
#endif
    >::value);
    encoder << instance.lines;
#if ENABLE(DATA_DETECTION)
    encoder << instance.dataDetectors;
#endif
    encoder << instance.blocks;
#if ENABLE(IMAGE_ANALYSIS_ENHANCEMENTS)
    encoder << instance.platformData;
#endif
}

std::optional<WebCore::TextRecognitionResult> ArgumentCoder<WebCore::TextRecognitionResult>::decode(Decoder& decoder)
{
    auto lines = decoder.decode<Vector<WebCore::TextRecognitionLineData>>();
    if (!lines)
        return std::nullopt;

#if ENABLE(DATA_DETECTION)
    auto dataDetectors = decoder.decode<Vector<WebCore::TextRecognitionDataDetector>>();
    if (!dataDetectors)
        return std::nullopt;
#endif

    auto blocks = decoder.decode<Vector<WebCore::TextRecognitionBlockData>>();
    if (!blocks)
        return std::nullopt;

#if ENABLE(IMAGE_ANALYSIS_ENHANCEMENTS)
    auto platformData = decoder.decode<RetainPtr<VKCImageAnalysis>>();
    if (!platformData)
        return std::nullopt;
#endif

    return {
        WebCore::TextRecognitionResult {
            WTFMove(*lines),
#if ENABLE(DATA_DETECTION)
            WTFMove(*dataDetectors),
#endif
            WTFMove(*blocks),
#if ENABLE(IMAGE_ANALYSIS_ENHANCEMENTS)
            WTFMove(*platformData)
#endif
        }
    };
}

#endif


void ArgumentCoder<WTF::URL>::encode(Encoder& encoder, const WTF::URL& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.string())>, String>);
    encoder << instance.string();
}

std::optional<WTF::URL> ArgumentCoder<WTF::URL>::decode(Decoder& decoder)
{
    auto string = decoder.decode<String>();
    if (!string)
        return std::nullopt;

    return {
        WTF::URL {
            WTFMove(*string)
        }
    };
}


void ArgumentCoder<WTF::MediaTime>::encode(Encoder& encoder, const WTF::MediaTime& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timeValue())>, int64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timeScale())>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timeFlags())>, uint8_t>);
    encoder << instance.timeValue();
    encoder << instance.timeScale();
    encoder << instance.timeFlags();
}

void ArgumentCoder<WTF::MediaTime>::encode(StreamConnectionEncoder& encoder, const WTF::MediaTime& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timeValue())>, int64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timeScale())>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timeFlags())>, uint8_t>);
    encoder << instance.timeValue();
    encoder << instance.timeScale();
    encoder << instance.timeFlags();
}

std::optional<WTF::MediaTime> ArgumentCoder<WTF::MediaTime>::decode(Decoder& decoder)
{
    auto timeValue = decoder.decode<int64_t>();
    if (!timeValue)
        return std::nullopt;

    auto timeScale = decoder.decode<uint32_t>();
    if (!timeScale)
        return std::nullopt;

    auto timeFlags = decoder.decode<uint8_t>();
    if (!timeFlags)
        return std::nullopt;

    return {
        WTF::MediaTime {
            WTFMove(*timeValue),
            WTFMove(*timeScale),
            WTFMove(*timeFlags)
        }
    };
}


void ArgumentCoder<WTF::Seconds>::encode(Encoder& encoder, const WTF::Seconds& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value())>, double>);
    encoder << instance.value();
}

void ArgumentCoder<WTF::Seconds>::encode(StreamConnectionEncoder& encoder, const WTF::Seconds& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value())>, double>);
    encoder << instance.value();
}

std::optional<WTF::Seconds> ArgumentCoder<WTF::Seconds>::decode(Decoder& decoder)
{
    auto value = decoder.decode<double>();
    if (!value)
        return std::nullopt;

    return {
        WTF::Seconds {
            WTFMove(*value)
        }
    };
}


void ArgumentCoder<WTF::MonotonicTime>::encode(Encoder& encoder, const WTF::MonotonicTime& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.secondsSinceEpoch().seconds())>, double>);
    encoder << instance.secondsSinceEpoch().seconds();
}

std::optional<WTF::MonotonicTime> ArgumentCoder<WTF::MonotonicTime>::decode(Decoder& decoder)
{
    auto secondsSinceEpochseconds = decoder.decode<double>();
    if (!secondsSinceEpochseconds)
        return std::nullopt;

    return {
        WTF::MonotonicTime::fromRawSeconds(
            WTFMove(*secondsSinceEpochseconds)
        )
    };
}


void ArgumentCoder<WTF::WallTime>::encode(Encoder& encoder, const WTF::WallTime& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.secondsSinceEpoch().seconds())>, double>);
    encoder << instance.secondsSinceEpoch().seconds();
}

std::optional<WTF::WallTime> ArgumentCoder<WTF::WallTime>::decode(Decoder& decoder)
{
    auto secondsSinceEpochseconds = decoder.decode<double>();
    if (!secondsSinceEpochseconds)
        return std::nullopt;

    return {
        WTF::WallTime::fromRawSeconds(
            WTFMove(*secondsSinceEpochseconds)
        )
    };
}


void ArgumentCoder<WTF::AtomString>::encode(Encoder& encoder, const WTF::AtomString& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.string())>, String>);
    encoder << instance.string();
}

void ArgumentCoder<WTF::AtomString>::encode(StreamConnectionEncoder& encoder, const WTF::AtomString& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.string())>, String>);
    encoder << instance.string();
}

std::optional<WTF::AtomString> ArgumentCoder<WTF::AtomString>::decode(Decoder& decoder)
{
    auto string = decoder.decode<String>();
    if (!string)
        return std::nullopt;

    return {
        WTF::AtomString {
            WTFMove(*string)
        }
    };
}


void ArgumentCoder<WebCore::DOMCacheEngine::CacheInfo>::encode(Encoder& encoder, const WebCore::DOMCacheEngine::CacheInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::DOMCacheIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DOMCacheEngine::CacheInfo, identifier)
        , offsetof(WebCore::DOMCacheEngine::CacheInfo, name)
    >::value);
    encoder << instance.identifier;
    encoder << instance.name;
}

std::optional<WebCore::DOMCacheEngine::CacheInfo> ArgumentCoder<WebCore::DOMCacheEngine::CacheInfo>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::DOMCacheIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    return {
        WebCore::DOMCacheEngine::CacheInfo {
            WTFMove(*identifier),
            WTFMove(*name)
        }
    };
}


void ArgumentCoder<WebCore::DOMCacheEngine::CacheInfos>::encode(Encoder& encoder, const WebCore::DOMCacheEngine::CacheInfos& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.infos)>, Vector<WebCore::DOMCacheEngine::CacheInfo>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.updateCounter)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DOMCacheEngine::CacheInfos, infos)
        , offsetof(WebCore::DOMCacheEngine::CacheInfos, updateCounter)
    >::value);
    encoder << instance.infos;
    encoder << instance.updateCounter;
}

std::optional<WebCore::DOMCacheEngine::CacheInfos> ArgumentCoder<WebCore::DOMCacheEngine::CacheInfos>::decode(Decoder& decoder)
{
    auto infos = decoder.decode<Vector<WebCore::DOMCacheEngine::CacheInfo>>();
    if (!infos)
        return std::nullopt;

    auto updateCounter = decoder.decode<uint64_t>();
    if (!updateCounter)
        return std::nullopt;

    return {
        WebCore::DOMCacheEngine::CacheInfos {
            WTFMove(*infos),
            WTFMove(*updateCounter)
        }
    };
}


void ArgumentCoder<WebCore::DOMCacheEngine::CacheIdentifierOperationResult>::encode(Encoder& encoder, const WebCore::DOMCacheEngine::CacheIdentifierOperationResult& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::DOMCacheIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hadStorageError)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DOMCacheEngine::CacheIdentifierOperationResult, identifier)
        , offsetof(WebCore::DOMCacheEngine::CacheIdentifierOperationResult, hadStorageError)
    >::value);
    encoder << instance.identifier;
    encoder << instance.hadStorageError;
}

std::optional<WebCore::DOMCacheEngine::CacheIdentifierOperationResult> ArgumentCoder<WebCore::DOMCacheEngine::CacheIdentifierOperationResult>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::DOMCacheIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto hadStorageError = decoder.decode<bool>();
    if (!hadStorageError)
        return std::nullopt;

    return {
        WebCore::DOMCacheEngine::CacheIdentifierOperationResult {
            WTFMove(*identifier),
            WTFMove(*hadStorageError)
        }
    };
}


void ArgumentCoder<WebCore::TransformationMatrix>::encode(Encoder& encoder, const WebCore::TransformationMatrix& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m11())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m12())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m13())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m14())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m21())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m22())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m23())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m24())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m31())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m32())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m33())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m34())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m41())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m42())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m43())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m44())>, double>);
    encoder << instance.m11();
    encoder << instance.m12();
    encoder << instance.m13();
    encoder << instance.m14();
    encoder << instance.m21();
    encoder << instance.m22();
    encoder << instance.m23();
    encoder << instance.m24();
    encoder << instance.m31();
    encoder << instance.m32();
    encoder << instance.m33();
    encoder << instance.m34();
    encoder << instance.m41();
    encoder << instance.m42();
    encoder << instance.m43();
    encoder << instance.m44();
}

void ArgumentCoder<WebCore::TransformationMatrix>::encode(StreamConnectionEncoder& encoder, const WebCore::TransformationMatrix& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m11())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m12())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m13())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m14())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m21())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m22())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m23())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m24())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m31())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m32())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m33())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m34())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m41())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m42())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m43())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m44())>, double>);
    encoder << instance.m11();
    encoder << instance.m12();
    encoder << instance.m13();
    encoder << instance.m14();
    encoder << instance.m21();
    encoder << instance.m22();
    encoder << instance.m23();
    encoder << instance.m24();
    encoder << instance.m31();
    encoder << instance.m32();
    encoder << instance.m33();
    encoder << instance.m34();
    encoder << instance.m41();
    encoder << instance.m42();
    encoder << instance.m43();
    encoder << instance.m44();
}

std::optional<WebCore::TransformationMatrix> ArgumentCoder<WebCore::TransformationMatrix>::decode(Decoder& decoder)
{
    auto m11 = decoder.decode<double>();
    if (!m11)
        return std::nullopt;

    auto m12 = decoder.decode<double>();
    if (!m12)
        return std::nullopt;

    auto m13 = decoder.decode<double>();
    if (!m13)
        return std::nullopt;

    auto m14 = decoder.decode<double>();
    if (!m14)
        return std::nullopt;

    auto m21 = decoder.decode<double>();
    if (!m21)
        return std::nullopt;

    auto m22 = decoder.decode<double>();
    if (!m22)
        return std::nullopt;

    auto m23 = decoder.decode<double>();
    if (!m23)
        return std::nullopt;

    auto m24 = decoder.decode<double>();
    if (!m24)
        return std::nullopt;

    auto m31 = decoder.decode<double>();
    if (!m31)
        return std::nullopt;

    auto m32 = decoder.decode<double>();
    if (!m32)
        return std::nullopt;

    auto m33 = decoder.decode<double>();
    if (!m33)
        return std::nullopt;

    auto m34 = decoder.decode<double>();
    if (!m34)
        return std::nullopt;

    auto m41 = decoder.decode<double>();
    if (!m41)
        return std::nullopt;

    auto m42 = decoder.decode<double>();
    if (!m42)
        return std::nullopt;

    auto m43 = decoder.decode<double>();
    if (!m43)
        return std::nullopt;

    auto m44 = decoder.decode<double>();
    if (!m44)
        return std::nullopt;

    return {
        WebCore::TransformationMatrix {
            WTFMove(*m11),
            WTFMove(*m12),
            WTFMove(*m13),
            WTFMove(*m14),
            WTFMove(*m21),
            WTFMove(*m22),
            WTFMove(*m23),
            WTFMove(*m24),
            WTFMove(*m31),
            WTFMove(*m32),
            WTFMove(*m33),
            WTFMove(*m34),
            WTFMove(*m41),
            WTFMove(*m42),
            WTFMove(*m43),
            WTFMove(*m44)
        }
    };
}


void ArgumentCoder<WebCore::CacheQueryOptions>::encode(Encoder& encoder, const WebCore::CacheQueryOptions& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ignoreSearch)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ignoreMethod)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ignoreVary)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CacheQueryOptions, ignoreSearch)
        , offsetof(WebCore::CacheQueryOptions, ignoreMethod)
        , offsetof(WebCore::CacheQueryOptions, ignoreVary)
    >::value);
    encoder << instance.ignoreSearch;
    encoder << instance.ignoreMethod;
    encoder << instance.ignoreVary;
}

std::optional<WebCore::CacheQueryOptions> ArgumentCoder<WebCore::CacheQueryOptions>::decode(Decoder& decoder)
{
    auto ignoreSearch = decoder.decode<bool>();
    if (!ignoreSearch)
        return std::nullopt;

    auto ignoreMethod = decoder.decode<bool>();
    if (!ignoreMethod)
        return std::nullopt;

    auto ignoreVary = decoder.decode<bool>();
    if (!ignoreVary)
        return std::nullopt;

    return {
        WebCore::CacheQueryOptions {
            WTFMove(*ignoreSearch),
            WTFMove(*ignoreMethod),
            WTFMove(*ignoreVary)
        }
    };
}


void ArgumentCoder<WebCore::CharacterRange>::encode(Encoder& encoder, const WebCore::CharacterRange& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.length)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CharacterRange, location)
        , offsetof(WebCore::CharacterRange, length)
    >::value);
    encoder << instance.location;
    encoder << instance.length;
}

std::optional<WebCore::CharacterRange> ArgumentCoder<WebCore::CharacterRange>::decode(Decoder& decoder)
{
    auto location = decoder.decode<uint64_t>();
    if (!location)
        return std::nullopt;

    auto length = decoder.decode<uint64_t>();
    if (!length)
        return std::nullopt;

    return {
        WebCore::CharacterRange {
            WTFMove(*location),
            WTFMove(*length)
        }
    };
}


void ArgumentCoder<WebCore::AffineTransform>::encode(Encoder& encoder, const WebCore::AffineTransform& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.a())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.b())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.c())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.d())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.e())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.f())>, double>);
    encoder << instance.a();
    encoder << instance.b();
    encoder << instance.c();
    encoder << instance.d();
    encoder << instance.e();
    encoder << instance.f();
}

void ArgumentCoder<WebCore::AffineTransform>::encode(StreamConnectionEncoder& encoder, const WebCore::AffineTransform& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.a())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.b())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.c())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.d())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.e())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.f())>, double>);
    encoder << instance.a();
    encoder << instance.b();
    encoder << instance.c();
    encoder << instance.d();
    encoder << instance.e();
    encoder << instance.f();
}

std::optional<WebCore::AffineTransform> ArgumentCoder<WebCore::AffineTransform>::decode(Decoder& decoder)
{
    auto a = decoder.decode<double>();
    if (!a)
        return std::nullopt;

    auto b = decoder.decode<double>();
    if (!b)
        return std::nullopt;

    auto c = decoder.decode<double>();
    if (!c)
        return std::nullopt;

    auto d = decoder.decode<double>();
    if (!d)
        return std::nullopt;

    auto e = decoder.decode<double>();
    if (!e)
        return std::nullopt;

    auto f = decoder.decode<double>();
    if (!f)
        return std::nullopt;

    return {
        WebCore::AffineTransform {
            WTFMove(*a),
            WTFMove(*b),
            WTFMove(*c),
            WTFMove(*d),
            WTFMove(*e),
            WTFMove(*f)
        }
    };
}


void ArgumentCoder<WebCore::FloatPoint>::encode(Encoder& encoder, const WebCore::FloatPoint& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, float>);
    encoder << instance.x();
    encoder << instance.y();
}

void ArgumentCoder<WebCore::FloatPoint>::encode(StreamConnectionEncoder& encoder, const WebCore::FloatPoint& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, float>);
    encoder << instance.x();
    encoder << instance.y();
}

std::optional<WebCore::FloatPoint> ArgumentCoder<WebCore::FloatPoint>::decode(Decoder& decoder)
{
    auto x = decoder.decode<float>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<float>();
    if (!y)
        return std::nullopt;

    return {
        WebCore::FloatPoint {
            WTFMove(*x),
            WTFMove(*y)
        }
    };
}


void ArgumentCoder<WebCore::FloatPoint3D>::encode(Encoder& encoder, const WebCore::FloatPoint3D& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.z())>, float>);
    encoder << instance.x();
    encoder << instance.y();
    encoder << instance.z();
}

void ArgumentCoder<WebCore::FloatPoint3D>::encode(StreamConnectionEncoder& encoder, const WebCore::FloatPoint3D& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.z())>, float>);
    encoder << instance.x();
    encoder << instance.y();
    encoder << instance.z();
}

std::optional<WebCore::FloatPoint3D> ArgumentCoder<WebCore::FloatPoint3D>::decode(Decoder& decoder)
{
    auto x = decoder.decode<float>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<float>();
    if (!y)
        return std::nullopt;

    auto z = decoder.decode<float>();
    if (!z)
        return std::nullopt;

    return {
        WebCore::FloatPoint3D {
            WTFMove(*x),
            WTFMove(*y),
            WTFMove(*z)
        }
    };
}


void ArgumentCoder<WebCore::FloatQuad>::encode(Encoder& encoder, const WebCore::FloatQuad& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.p1())>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.p2())>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.p3())>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.p4())>, WebCore::FloatPoint>);
    encoder << instance.p1();
    encoder << instance.p2();
    encoder << instance.p3();
    encoder << instance.p4();
}

std::optional<WebCore::FloatQuad> ArgumentCoder<WebCore::FloatQuad>::decode(Decoder& decoder)
{
    auto p1 = decoder.decode<WebCore::FloatPoint>();
    if (!p1)
        return std::nullopt;

    auto p2 = decoder.decode<WebCore::FloatPoint>();
    if (!p2)
        return std::nullopt;

    auto p3 = decoder.decode<WebCore::FloatPoint>();
    if (!p3)
        return std::nullopt;

    auto p4 = decoder.decode<WebCore::FloatPoint>();
    if (!p4)
        return std::nullopt;

    return {
        WebCore::FloatQuad {
            WTFMove(*p1),
            WTFMove(*p2),
            WTFMove(*p3),
            WTFMove(*p4)
        }
    };
}


void ArgumentCoder<WebCore::IDBCursorRecord>::encode(Encoder& encoder, const WebCore::IDBCursorRecord& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.key)>, WebCore::IDBKeyData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.primaryKey)>, WebCore::IDBKeyData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, WebCore::IDBValue>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBCursorRecord, key)
        , offsetof(WebCore::IDBCursorRecord, primaryKey)
        , offsetof(WebCore::IDBCursorRecord, value)
    >::value);
    encoder << instance.key;
    encoder << instance.primaryKey;
    encoder << instance.value;
}

std::optional<WebCore::IDBCursorRecord> ArgumentCoder<WebCore::IDBCursorRecord>::decode(Decoder& decoder)
{
    auto key = decoder.decode<WebCore::IDBKeyData>();
    if (!key)
        return std::nullopt;

    auto primaryKey = decoder.decode<WebCore::IDBKeyData>();
    if (!primaryKey)
        return std::nullopt;

    auto value = decoder.decode<WebCore::IDBValue>();
    if (!value)
        return std::nullopt;

    return {
        WebCore::IDBCursorRecord {
            WTFMove(*key),
            WTFMove(*primaryKey),
            WTFMove(*value)
        }
    };
}


void ArgumentCoder<WebCore::IDBCursorInfo>::encode(Encoder& encoder, const WebCore::IDBCursorInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier())>, WebCore::IDBResourceIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.transactionIdentifier())>, WebCore::IDBResourceIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.objectStoreIdentifier())>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceIdentifier())>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.range())>, WebCore::IDBKeyRangeData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cursorSource())>, WebCore::IndexedDB::CursorSource>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cursorDirection())>, WebCore::IndexedDB::CursorDirection>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cursorType())>, WebCore::IndexedDB::CursorType>);
    encoder << instance.identifier();
    encoder << instance.transactionIdentifier();
    encoder << instance.objectStoreIdentifier();
    encoder << instance.sourceIdentifier();
    encoder << instance.range();
    encoder << instance.cursorSource();
    encoder << instance.cursorDirection();
    encoder << instance.cursorType();
}

std::optional<WebCore::IDBCursorInfo> ArgumentCoder<WebCore::IDBCursorInfo>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::IDBResourceIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto transactionIdentifier = decoder.decode<WebCore::IDBResourceIdentifier>();
    if (!transactionIdentifier)
        return std::nullopt;

    auto objectStoreIdentifier = decoder.decode<uint64_t>();
    if (!objectStoreIdentifier)
        return std::nullopt;

    auto sourceIdentifier = decoder.decode<uint64_t>();
    if (!sourceIdentifier)
        return std::nullopt;

    auto range = decoder.decode<WebCore::IDBKeyRangeData>();
    if (!range)
        return std::nullopt;

    auto cursorSource = decoder.decode<WebCore::IndexedDB::CursorSource>();
    if (!cursorSource)
        return std::nullopt;

    auto cursorDirection = decoder.decode<WebCore::IndexedDB::CursorDirection>();
    if (!cursorDirection)
        return std::nullopt;

    auto cursorType = decoder.decode<WebCore::IndexedDB::CursorType>();
    if (!cursorType)
        return std::nullopt;

    return {
        WebCore::IDBCursorInfo {
            WTFMove(*identifier),
            WTFMove(*transactionIdentifier),
            WTFMove(*objectStoreIdentifier),
            WTFMove(*sourceIdentifier),
            WTFMove(*range),
            WTFMove(*cursorSource),
            WTFMove(*cursorDirection),
            WTFMove(*cursorType)
        }
    };
}


void ArgumentCoder<WebCore::IDBError>::encode(Encoder& encoder, const WebCore::IDBError& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.code())>, std::optional<WebCore::ExceptionCode>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.messageForSerialization())>, String>);
    encoder << instance.code();
    encoder << instance.messageForSerialization();
}

std::optional<WebCore::IDBError> ArgumentCoder<WebCore::IDBError>::decode(Decoder& decoder)
{
    auto code = decoder.decode<std::optional<WebCore::ExceptionCode>>();
    if (!code)
        return std::nullopt;

    auto messageForSerialization = decoder.decode<String>();
    if (!messageForSerialization)
        return std::nullopt;

    return {
        WebCore::IDBError {
            WTFMove(*code),
            WTFMove(*messageForSerialization)
        }
    };
}


void ArgumentCoder<WebCore::IDBGetAllRecordsData>::encode(Encoder& encoder, const WebCore::IDBGetAllRecordsData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyRangeData)>, WebCore::IDBKeyRangeData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.getAllType)>, WebCore::IndexedDB::GetAllType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.count)>, std::optional<uint32_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.objectStoreIdentifier)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.indexIdentifier)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBGetAllRecordsData, keyRangeData)
        , offsetof(WebCore::IDBGetAllRecordsData, getAllType)
        , offsetof(WebCore::IDBGetAllRecordsData, count)
        , offsetof(WebCore::IDBGetAllRecordsData, objectStoreIdentifier)
        , offsetof(WebCore::IDBGetAllRecordsData, indexIdentifier)
    >::value);
    encoder << instance.keyRangeData;
    encoder << instance.getAllType;
    encoder << instance.count;
    encoder << instance.objectStoreIdentifier;
    encoder << instance.indexIdentifier;
}

std::optional<WebCore::IDBGetAllRecordsData> ArgumentCoder<WebCore::IDBGetAllRecordsData>::decode(Decoder& decoder)
{
    auto keyRangeData = decoder.decode<WebCore::IDBKeyRangeData>();
    if (!keyRangeData)
        return std::nullopt;

    auto getAllType = decoder.decode<WebCore::IndexedDB::GetAllType>();
    if (!getAllType)
        return std::nullopt;

    auto count = decoder.decode<std::optional<uint32_t>>();
    if (!count)
        return std::nullopt;

    auto objectStoreIdentifier = decoder.decode<uint64_t>();
    if (!objectStoreIdentifier)
        return std::nullopt;

    auto indexIdentifier = decoder.decode<uint64_t>();
    if (!indexIdentifier)
        return std::nullopt;

    return {
        WebCore::IDBGetAllRecordsData {
            WTFMove(*keyRangeData),
            WTFMove(*getAllType),
            WTFMove(*count),
            WTFMove(*objectStoreIdentifier),
            WTFMove(*indexIdentifier)
        }
    };
}


void ArgumentCoder<WebCore::IDBGetResult>::encode(Encoder& encoder, const WebCore::IDBGetResult& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyData())>, WebCore::IDBKeyData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.primaryKeyData())>, WebCore::IDBKeyData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value())>, WebCore::IDBValue>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyPath())>, std::optional<WebCore::IDBKeyPath>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.prefetchedRecords())>, Vector<WebCore::IDBCursorRecord>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isDefined())>, bool>);
    encoder << instance.keyData();
    encoder << instance.primaryKeyData();
    encoder << instance.value();
    encoder << instance.keyPath();
    encoder << instance.prefetchedRecords();
    encoder << instance.isDefined();
}

std::optional<WebCore::IDBGetResult> ArgumentCoder<WebCore::IDBGetResult>::decode(Decoder& decoder)
{
    auto keyData = decoder.decode<WebCore::IDBKeyData>();
    if (!keyData)
        return std::nullopt;

    auto primaryKeyData = decoder.decode<WebCore::IDBKeyData>();
    if (!primaryKeyData)
        return std::nullopt;

    auto value = decoder.decode<WebCore::IDBValue>();
    if (!value)
        return std::nullopt;

    auto keyPath = decoder.decode<std::optional<WebCore::IDBKeyPath>>();
    if (!keyPath)
        return std::nullopt;

    auto prefetchedRecords = decoder.decode<Vector<WebCore::IDBCursorRecord>>();
    if (!prefetchedRecords)
        return std::nullopt;

    auto isDefined = decoder.decode<bool>();
    if (!isDefined)
        return std::nullopt;

    return {
        WebCore::IDBGetResult {
            WTFMove(*keyData),
            WTFMove(*primaryKeyData),
            WTFMove(*value),
            WTFMove(*keyPath),
            WTFMove(*prefetchedRecords),
            WTFMove(*isDefined)
        }
    };
}


void ArgumentCoder<WebCore::IDBGetAllResult>::encode(Encoder& encoder, const WebCore::IDBGetAllResult& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::IndexedDB::GetAllType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keys())>, Vector<WebCore::IDBKeyData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.values())>, Vector<WebCore::IDBValue>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyPath())>, std::optional<WebCore::IDBKeyPath>>);
    encoder << instance.type();
    encoder << instance.keys();
    encoder << instance.values();
    encoder << instance.keyPath();
}

std::optional<WebCore::IDBGetAllResult> ArgumentCoder<WebCore::IDBGetAllResult>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::IndexedDB::GetAllType>();
    if (!type)
        return std::nullopt;

    auto keys = decoder.decode<Vector<WebCore::IDBKeyData>>();
    if (!keys)
        return std::nullopt;

    auto values = decoder.decode<Vector<WebCore::IDBValue>>();
    if (!values)
        return std::nullopt;

    auto keyPath = decoder.decode<std::optional<WebCore::IDBKeyPath>>();
    if (!keyPath)
        return std::nullopt;

    return {
        WebCore::IDBGetAllResult {
            WTFMove(*type),
            WTFMove(*keys),
            WTFMove(*values),
            WTFMove(*keyPath)
        }
    };
}


void ArgumentCoder<WebCore::IDBDatabaseInfo>::encode(Encoder& encoder, const WebCore::IDBDatabaseInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_version)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_maxIndexID)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_maxObjectStoreID)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_objectStoreMap)>, HashMap<uint64_t, WebCore::IDBObjectStoreInfo>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBDatabaseInfo, m_name)
        , offsetof(WebCore::IDBDatabaseInfo, m_version)
        , offsetof(WebCore::IDBDatabaseInfo, m_maxIndexID)
        , offsetof(WebCore::IDBDatabaseInfo, m_maxObjectStoreID)
        , offsetof(WebCore::IDBDatabaseInfo, m_objectStoreMap)
    >::value);
    encoder << instance.m_name;
    encoder << instance.m_version;
    encoder << instance.m_maxIndexID;
    encoder << instance.m_maxObjectStoreID;
    encoder << instance.m_objectStoreMap;
}

std::optional<WebCore::IDBDatabaseInfo> ArgumentCoder<WebCore::IDBDatabaseInfo>::decode(Decoder& decoder)
{
    auto m_name = decoder.decode<String>();
    if (!m_name)
        return std::nullopt;

    auto m_version = decoder.decode<uint64_t>();
    if (!m_version)
        return std::nullopt;

    auto m_maxIndexID = decoder.decode<uint64_t>();
    if (!m_maxIndexID)
        return std::nullopt;

    auto m_maxObjectStoreID = decoder.decode<uint64_t>();
    if (!m_maxObjectStoreID)
        return std::nullopt;

    auto m_objectStoreMap = decoder.decode<HashMap<uint64_t, WebCore::IDBObjectStoreInfo>>();
    if (!m_objectStoreMap)
        return std::nullopt;

    return {
        WebCore::IDBDatabaseInfo {
            WTFMove(*m_name),
            WTFMove(*m_version),
            WTFMove(*m_maxIndexID),
            WTFMove(*m_maxObjectStoreID),
            WTFMove(*m_objectStoreMap)
        }
    };
}


void ArgumentCoder<WebCore::IDBKeyRangeData>::encode(Encoder& encoder, const WebCore::IDBKeyRangeData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isNull)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lowerKey)>, WebCore::IDBKeyData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.upperKey)>, WebCore::IDBKeyData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lowerOpen)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.upperOpen)>, bool>);
    encoder << instance.isNull;
    if (instance.isNull)
        return;
    encoder << instance.lowerKey;
    encoder << instance.upperKey;
    encoder << instance.lowerOpen;
    encoder << instance.upperOpen;
}

std::optional<WebCore::IDBKeyRangeData> ArgumentCoder<WebCore::IDBKeyRangeData>::decode(Decoder& decoder)
{
    auto isNull = decoder.decode<bool>();
    if (!isNull)
        return std::nullopt;
    if (*isNull)
        return { WebCore::IDBKeyRangeData { } };

    auto lowerKey = decoder.decode<WebCore::IDBKeyData>();
    if (!lowerKey)
        return std::nullopt;

    auto upperKey = decoder.decode<WebCore::IDBKeyData>();
    if (!upperKey)
        return std::nullopt;

    auto lowerOpen = decoder.decode<bool>();
    if (!lowerOpen)
        return std::nullopt;

    auto upperOpen = decoder.decode<bool>();
    if (!upperOpen)
        return std::nullopt;

    return {
        WebCore::IDBKeyRangeData {
            WTFMove(*isNull),
            WTFMove(*lowerKey),
            WTFMove(*upperKey),
            WTFMove(*lowerOpen),
            WTFMove(*upperOpen)
        }
    };
}


void ArgumentCoder<WebCore::IDBTransactionInfo>::encode(Encoder& encoder, const WebCore::IDBTransactionInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier())>, WebCore::IDBResourceIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mode())>, WebCore::IDBTransactionMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.durability())>, WebCore::IDBTransactionDurability>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newVersion())>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.objectStores())>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.originalDatabaseInfo())>, std::unique_ptr<WebCore::IDBDatabaseInfo>>);
    encoder << instance.identifier();
    encoder << instance.mode();
    encoder << instance.durability();
    encoder << instance.newVersion();
    encoder << instance.objectStores();
    encoder << instance.originalDatabaseInfo();
}

std::optional<WebCore::IDBTransactionInfo> ArgumentCoder<WebCore::IDBTransactionInfo>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::IDBResourceIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto mode = decoder.decode<WebCore::IDBTransactionMode>();
    if (!mode)
        return std::nullopt;

    auto durability = decoder.decode<WebCore::IDBTransactionDurability>();
    if (!durability)
        return std::nullopt;

    auto newVersion = decoder.decode<uint64_t>();
    if (!newVersion)
        return std::nullopt;

    auto objectStores = decoder.decode<Vector<String>>();
    if (!objectStores)
        return std::nullopt;

    auto originalDatabaseInfo = decoder.decode<std::unique_ptr<WebCore::IDBDatabaseInfo>>();
    if (!originalDatabaseInfo)
        return std::nullopt;

    return {
        WebCore::IDBTransactionInfo {
            WTFMove(*identifier),
            WTFMove(*mode),
            WTFMove(*durability),
            WTFMove(*newVersion),
            WTFMove(*objectStores),
            WTFMove(*originalDatabaseInfo)
        }
    };
}


void ArgumentCoder<WebCore::IDBGetRecordData>::encode(Encoder& encoder, const WebCore::IDBGetRecordData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyRangeData)>, WebCore::IDBKeyRangeData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::IDBGetRecordDataType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBGetRecordData, keyRangeData)
        , offsetof(WebCore::IDBGetRecordData, type)
    >::value);
    encoder << instance.keyRangeData;
    encoder << instance.type;
}

std::optional<WebCore::IDBGetRecordData> ArgumentCoder<WebCore::IDBGetRecordData>::decode(Decoder& decoder)
{
    auto keyRangeData = decoder.decode<WebCore::IDBKeyRangeData>();
    if (!keyRangeData)
        return std::nullopt;

    auto type = decoder.decode<WebCore::IDBGetRecordDataType>();
    if (!type)
        return std::nullopt;

    return {
        WebCore::IDBGetRecordData {
            WTFMove(*keyRangeData),
            WTFMove(*type)
        }
    };
}


void ArgumentCoder<WebCore::IDBIndexInfo>::encode(Encoder& encoder, const WebCore::IDBIndexInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier())>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.objectStoreIdentifier())>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyPath())>, WebCore::IDBKeyPath>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.unique())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.multiEntry())>, bool>);
    encoder << instance.identifier();
    encoder << instance.objectStoreIdentifier();
    encoder << instance.name();
    encoder << instance.keyPath();
    encoder << instance.unique();
    encoder << instance.multiEntry();
}

std::optional<WebCore::IDBIndexInfo> ArgumentCoder<WebCore::IDBIndexInfo>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<uint64_t>();
    if (!identifier)
        return std::nullopt;

    auto objectStoreIdentifier = decoder.decode<uint64_t>();
    if (!objectStoreIdentifier)
        return std::nullopt;

    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto keyPath = decoder.decode<WebCore::IDBKeyPath>();
    if (!keyPath)
        return std::nullopt;

    auto unique = decoder.decode<bool>();
    if (!unique)
        return std::nullopt;

    auto multiEntry = decoder.decode<bool>();
    if (!multiEntry)
        return std::nullopt;

    return {
        WebCore::IDBIndexInfo {
            WTFMove(*identifier),
            WTFMove(*objectStoreIdentifier),
            WTFMove(*name),
            WTFMove(*keyPath),
            WTFMove(*unique),
            WTFMove(*multiEntry)
        }
    };
}


void ArgumentCoder<WebCore::IDBObjectStoreInfo>::encode(Encoder& encoder, const WebCore::IDBObjectStoreInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier())>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyPath())>, std::optional<WebCore::IDBKeyPath>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.autoIncrement())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.indexMap())>, HashMap<uint64_t, WebCore::IDBIndexInfo>>);
    encoder << instance.identifier();
    encoder << instance.name();
    encoder << instance.keyPath();
    encoder << instance.autoIncrement();
    encoder << instance.indexMap();
}

std::optional<WebCore::IDBObjectStoreInfo> ArgumentCoder<WebCore::IDBObjectStoreInfo>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<uint64_t>();
    if (!identifier)
        return std::nullopt;

    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto keyPath = decoder.decode<std::optional<WebCore::IDBKeyPath>>();
    if (!keyPath)
        return std::nullopt;

    auto autoIncrement = decoder.decode<bool>();
    if (!autoIncrement)
        return std::nullopt;

    auto indexMap = decoder.decode<HashMap<uint64_t, WebCore::IDBIndexInfo>>();
    if (!indexMap)
        return std::nullopt;

    return {
        WebCore::IDBObjectStoreInfo {
            WTFMove(*identifier),
            WTFMove(*name),
            WTFMove(*keyPath),
            WTFMove(*autoIncrement),
            WTFMove(*indexMap)
        }
    };
}


void ArgumentCoder<WebCore::IDBIterateCursorData>::encode(Encoder& encoder, const WebCore::IDBIterateCursorData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyData)>, WebCore::IDBKeyData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.primaryKeyData)>, WebCore::IDBKeyData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.count)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.option)>, WebCore::IndexedDB::CursorIterateOption>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBIterateCursorData, keyData)
        , offsetof(WebCore::IDBIterateCursorData, primaryKeyData)
        , offsetof(WebCore::IDBIterateCursorData, count)
        , offsetof(WebCore::IDBIterateCursorData, option)
    >::value);
    encoder << instance.keyData;
    encoder << instance.primaryKeyData;
    encoder << instance.count;
    encoder << instance.option;
}

std::optional<WebCore::IDBIterateCursorData> ArgumentCoder<WebCore::IDBIterateCursorData>::decode(Decoder& decoder)
{
    auto keyData = decoder.decode<WebCore::IDBKeyData>();
    if (!keyData)
        return std::nullopt;

    auto primaryKeyData = decoder.decode<WebCore::IDBKeyData>();
    if (!primaryKeyData)
        return std::nullopt;

    auto count = decoder.decode<unsigned>();
    if (!count)
        return std::nullopt;

    auto option = decoder.decode<WebCore::IndexedDB::CursorIterateOption>();
    if (!option)
        return std::nullopt;

    return {
        WebCore::IDBIterateCursorData {
            WTFMove(*keyData),
            WTFMove(*primaryKeyData),
            WTFMove(*count),
            WTFMove(*option)
        }
    };
}


void ArgumentCoder<WebCore::IDBResourceIdentifier>::encode(Encoder& encoder, const WebCore::IDBResourceIdentifier& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_idbConnectionIdentifier)>, WebCore::IDBConnectionIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_resourceNumber)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBResourceIdentifier, m_idbConnectionIdentifier)
        , offsetof(WebCore::IDBResourceIdentifier, m_resourceNumber)
    >::value);
    encoder << instance.m_idbConnectionIdentifier;
    encoder << instance.m_resourceNumber;
}

std::optional<WebCore::IDBResourceIdentifier> ArgumentCoder<WebCore::IDBResourceIdentifier>::decode(Decoder& decoder)
{
    auto m_idbConnectionIdentifier = decoder.decode<WebCore::IDBConnectionIdentifier>();
    if (!m_idbConnectionIdentifier)
        return std::nullopt;

    auto m_resourceNumber = decoder.decode<uint64_t>();
    if (!m_resourceNumber)
        return std::nullopt;

    return {
        WebCore::IDBResourceIdentifier {
            WTFMove(*m_idbConnectionIdentifier),
            WTFMove(*m_resourceNumber)
        }
    };
}


void ArgumentCoder<WebCore::IDBValue>::encode(Encoder& encoder, const WebCore::IDBValue& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data())>, WebCore::ThreadSafeDataBuffer>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blobURLs())>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blobFilePaths())>, Vector<String>>);
    encoder << instance.data();
    encoder << instance.blobURLs();
    encoder << instance.blobFilePaths();
}

std::optional<WebCore::IDBValue> ArgumentCoder<WebCore::IDBValue>::decode(Decoder& decoder)
{
    auto data = decoder.decode<WebCore::ThreadSafeDataBuffer>();
    if (!data)
        return std::nullopt;

    auto blobURLs = decoder.decode<Vector<String>>();
    if (!blobURLs)
        return std::nullopt;

    auto blobFilePaths = decoder.decode<Vector<String>>();
    if (!blobFilePaths)
        return std::nullopt;

    return {
        WebCore::IDBValue {
            WTFMove(*data),
            WTFMove(*blobURLs),
            WTFMove(*blobFilePaths)
        }
    };
}


void ArgumentCoder<WebCore::IDBRequestData>::encode(Encoder& encoder, const WebCore::IDBRequestData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_serverConnectionIdentifier)>, WebCore::IDBConnectionIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_requestIdentifier)>, WebCore::IDBResourceIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_transactionIdentifier)>, std::optional<WebCore::IDBResourceIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_cursorIdentifier)>, std::optional<WebCore::IDBResourceIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_objectStoreIdentifier)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_indexIdentifier)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_indexRecordType)>, WebCore::IndexedDB::IndexRecordType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_databaseIdentifier)>, std::optional<WebCore::IDBDatabaseIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_requestedVersion)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_requestType)>, WebCore::IndexedDB::RequestType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBRequestData, m_serverConnectionIdentifier)
        , offsetof(WebCore::IDBRequestData, m_requestIdentifier)
        , offsetof(WebCore::IDBRequestData, m_transactionIdentifier)
        , offsetof(WebCore::IDBRequestData, m_cursorIdentifier)
        , offsetof(WebCore::IDBRequestData, m_objectStoreIdentifier)
        , offsetof(WebCore::IDBRequestData, m_indexIdentifier)
        , offsetof(WebCore::IDBRequestData, m_indexRecordType)
        , offsetof(WebCore::IDBRequestData, m_databaseIdentifier)
        , offsetof(WebCore::IDBRequestData, m_requestedVersion)
        , offsetof(WebCore::IDBRequestData, m_requestType)
    >::value);
    encoder << instance.m_serverConnectionIdentifier;
    encoder << instance.m_requestIdentifier;
    encoder << instance.m_transactionIdentifier;
    encoder << instance.m_cursorIdentifier;
    encoder << instance.m_objectStoreIdentifier;
    encoder << instance.m_indexIdentifier;
    encoder << instance.m_indexRecordType;
    encoder << instance.m_databaseIdentifier;
    encoder << instance.m_requestedVersion;
    encoder << instance.m_requestType;
}

std::optional<WebCore::IDBRequestData> ArgumentCoder<WebCore::IDBRequestData>::decode(Decoder& decoder)
{
    auto m_serverConnectionIdentifier = decoder.decode<WebCore::IDBConnectionIdentifier>();
    if (!m_serverConnectionIdentifier)
        return std::nullopt;

    auto m_requestIdentifier = decoder.decode<WebCore::IDBResourceIdentifier>();
    if (!m_requestIdentifier)
        return std::nullopt;

    auto m_transactionIdentifier = decoder.decode<std::optional<WebCore::IDBResourceIdentifier>>();
    if (!m_transactionIdentifier)
        return std::nullopt;

    auto m_cursorIdentifier = decoder.decode<std::optional<WebCore::IDBResourceIdentifier>>();
    if (!m_cursorIdentifier)
        return std::nullopt;

    auto m_objectStoreIdentifier = decoder.decode<uint64_t>();
    if (!m_objectStoreIdentifier)
        return std::nullopt;

    auto m_indexIdentifier = decoder.decode<uint64_t>();
    if (!m_indexIdentifier)
        return std::nullopt;

    auto m_indexRecordType = decoder.decode<WebCore::IndexedDB::IndexRecordType>();
    if (!m_indexRecordType)
        return std::nullopt;

    auto m_databaseIdentifier = decoder.decode<std::optional<WebCore::IDBDatabaseIdentifier>>();
    if (!m_databaseIdentifier)
        return std::nullopt;

    auto m_requestedVersion = decoder.decode<uint64_t>();
    if (!m_requestedVersion)
        return std::nullopt;

    auto m_requestType = decoder.decode<WebCore::IndexedDB::RequestType>();
    if (!m_requestType)
        return std::nullopt;

    return {
        WebCore::IDBRequestData {
            WTFMove(*m_serverConnectionIdentifier),
            WTFMove(*m_requestIdentifier),
            WTFMove(*m_transactionIdentifier),
            WTFMove(*m_cursorIdentifier),
            WTFMove(*m_objectStoreIdentifier),
            WTFMove(*m_indexIdentifier),
            WTFMove(*m_indexRecordType),
            WTFMove(*m_databaseIdentifier),
            WTFMove(*m_requestedVersion),
            WTFMove(*m_requestType)
        }
    };
}


void ArgumentCoder<WebCore::IDBDatabaseIdentifier>::encode(Encoder& encoder, const WebCore::IDBDatabaseIdentifier& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_databaseName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_origin)>, WebCore::ClientOrigin>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isTransient)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBDatabaseIdentifier, m_databaseName)
        , offsetof(WebCore::IDBDatabaseIdentifier, m_origin)
        , offsetof(WebCore::IDBDatabaseIdentifier, m_isTransient)
    >::value);
    encoder << instance.m_databaseName;
    encoder << instance.m_origin;
    encoder << instance.m_isTransient;
}

std::optional<WebCore::IDBDatabaseIdentifier> ArgumentCoder<WebCore::IDBDatabaseIdentifier>::decode(Decoder& decoder)
{
    auto m_databaseName = decoder.decode<String>();
    if (!m_databaseName)
        return std::nullopt;

    auto m_origin = decoder.decode<WebCore::ClientOrigin>();
    if (!m_origin)
        return std::nullopt;

    auto m_isTransient = decoder.decode<bool>();
    if (!m_isTransient)
        return std::nullopt;

    WebCore::IDBDatabaseIdentifier result;
    result.m_databaseName = WTFMove(*m_databaseName);
    result.m_origin = WTFMove(*m_origin);
    result.m_isTransient = WTFMove(*m_isTransient);
    return { WTFMove(result) };
}


void ArgumentCoder<WebCore::IDBDatabaseNameAndVersion>::encode(Encoder& encoder, const WebCore::IDBDatabaseNameAndVersion& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.version)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBDatabaseNameAndVersion, name)
        , offsetof(WebCore::IDBDatabaseNameAndVersion, version)
    >::value);
    encoder << instance.name;
    encoder << instance.version;
}

std::optional<WebCore::IDBDatabaseNameAndVersion> ArgumentCoder<WebCore::IDBDatabaseNameAndVersion>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto version = decoder.decode<uint64_t>();
    if (!version)
        return std::nullopt;

    return {
        WebCore::IDBDatabaseNameAndVersion {
            WTFMove(*name),
            WTFMove(*version)
        }
    };
}


void ArgumentCoder<WebCore::IDBResultData>::encode(Encoder& encoder, const WebCore::IDBResultData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_type)>, WebCore::IDBResultType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_requestIdentifier)>, WebCore::IDBResourceIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_error)>, WebCore::IDBError>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_databaseConnectionIdentifier)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_databaseInfo)>, std::unique_ptr<WebCore::IDBDatabaseInfo>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_transactionInfo)>, std::unique_ptr<WebCore::IDBTransactionInfo>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_resultKey)>, std::unique_ptr<WebCore::IDBKeyData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_getResult)>, std::unique_ptr<WebCore::IDBGetResult>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_getAllResult)>, std::unique_ptr<WebCore::IDBGetAllResult>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_resultInteger)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::IDBResultData, m_type)
        , offsetof(WebCore::IDBResultData, m_requestIdentifier)
        , offsetof(WebCore::IDBResultData, m_error)
        , offsetof(WebCore::IDBResultData, m_databaseConnectionIdentifier)
        , offsetof(WebCore::IDBResultData, m_databaseInfo)
        , offsetof(WebCore::IDBResultData, m_transactionInfo)
        , offsetof(WebCore::IDBResultData, m_resultKey)
        , offsetof(WebCore::IDBResultData, m_getResult)
        , offsetof(WebCore::IDBResultData, m_getAllResult)
        , offsetof(WebCore::IDBResultData, m_resultInteger)
    >::value);
    encoder << instance.m_type;
    encoder << instance.m_requestIdentifier;
    encoder << instance.m_error;
    encoder << instance.m_databaseConnectionIdentifier;
    encoder << instance.m_databaseInfo;
    encoder << instance.m_transactionInfo;
    encoder << instance.m_resultKey;
    encoder << instance.m_getResult;
    encoder << instance.m_getAllResult;
    encoder << instance.m_resultInteger;
}

std::optional<WebCore::IDBResultData> ArgumentCoder<WebCore::IDBResultData>::decode(Decoder& decoder)
{
    auto m_type = decoder.decode<WebCore::IDBResultType>();
    if (!m_type)
        return std::nullopt;

    auto m_requestIdentifier = decoder.decode<WebCore::IDBResourceIdentifier>();
    if (!m_requestIdentifier)
        return std::nullopt;

    auto m_error = decoder.decode<WebCore::IDBError>();
    if (!m_error)
        return std::nullopt;

    auto m_databaseConnectionIdentifier = decoder.decode<uint64_t>();
    if (!m_databaseConnectionIdentifier)
        return std::nullopt;

    auto m_databaseInfo = decoder.decode<std::unique_ptr<WebCore::IDBDatabaseInfo>>();
    if (!m_databaseInfo)
        return std::nullopt;

    auto m_transactionInfo = decoder.decode<std::unique_ptr<WebCore::IDBTransactionInfo>>();
    if (!m_transactionInfo)
        return std::nullopt;

    auto m_resultKey = decoder.decode<std::unique_ptr<WebCore::IDBKeyData>>();
    if (!m_resultKey)
        return std::nullopt;

    auto m_getResult = decoder.decode<std::unique_ptr<WebCore::IDBGetResult>>();
    if (!m_getResult)
        return std::nullopt;

    auto m_getAllResult = decoder.decode<std::unique_ptr<WebCore::IDBGetAllResult>>();
    if (!m_getAllResult)
        return std::nullopt;

    auto m_resultInteger = decoder.decode<uint64_t>();
    if (!m_resultInteger)
        return std::nullopt;

    WebCore::IDBResultData result;
    result.m_type = WTFMove(*m_type);
    result.m_requestIdentifier = WTFMove(*m_requestIdentifier);
    result.m_error = WTFMove(*m_error);
    result.m_databaseConnectionIdentifier = WTFMove(*m_databaseConnectionIdentifier);
    result.m_databaseInfo = WTFMove(*m_databaseInfo);
    result.m_transactionInfo = WTFMove(*m_transactionInfo);
    result.m_resultKey = WTFMove(*m_resultKey);
    result.m_getResult = WTFMove(*m_getResult);
    result.m_getAllResult = WTFMove(*m_getAllResult);
    result.m_resultInteger = WTFMove(*m_resultInteger);
    return { WTFMove(result) };
}


void ArgumentCoder<WebCore::IDBKeyData>::encode(Encoder& encoder, const WebCore::IDBKeyData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isNull)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_type)>, WebCore::IndexedDB::KeyType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_value)>, std::variant<Vector<WebCore::IDBKeyData>, String, double, WebCore::ThreadSafeDataBuffer>>);
    encoder << instance.m_isNull;
    if (instance.m_isNull)
        return;
    encoder << instance.m_type;
    encoder << instance.m_value;
}

std::optional<WebCore::IDBKeyData> ArgumentCoder<WebCore::IDBKeyData>::decode(Decoder& decoder)
{
    auto m_isNull = decoder.decode<bool>();
    if (!m_isNull)
        return std::nullopt;
    if (*m_isNull)
        return { WebCore::IDBKeyData { } };

    auto m_type = decoder.decode<WebCore::IndexedDB::KeyType>();
    if (!m_type)
        return std::nullopt;

    auto m_value = decoder.decode<std::variant<Vector<WebCore::IDBKeyData>, String, double, WebCore::ThreadSafeDataBuffer>>();
    if (!m_value)
        return std::nullopt;

    WebCore::IDBKeyData result;
    result.m_isNull = WTFMove(*m_isNull);
    result.m_type = WTFMove(*m_type);
    result.m_value = WTFMove(*m_value);
    return { WTFMove(result) };
}

#if USE(CG)

void ArgumentCoder<CGSize>::encode(Encoder& encoder, const CGSize& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width)>, CGFloat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height)>, CGFloat>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(CGSize, width)
        , offsetof(CGSize, height)
    >::value);
    encoder << instance.width;
    encoder << instance.height;
}

void ArgumentCoder<CGSize>::encode(StreamConnectionEncoder& encoder, const CGSize& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width)>, CGFloat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height)>, CGFloat>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(CGSize, width)
        , offsetof(CGSize, height)
    >::value);
    encoder << instance.width;
    encoder << instance.height;
}

std::optional<CGSize> ArgumentCoder<CGSize>::decode(Decoder& decoder)
{
    auto width = decoder.decode<CGFloat>();
    if (!width)
        return std::nullopt;

    auto height = decoder.decode<CGFloat>();
    if (!height)
        return std::nullopt;

    return {
        CGSize {
            WTFMove(*width),
            WTFMove(*height)
        }
    };
}

#endif

#if USE(CG)

void ArgumentCoder<CGPoint>::encode(Encoder& encoder, const CGPoint& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x)>, CGFloat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y)>, CGFloat>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(CGPoint, x)
        , offsetof(CGPoint, y)
    >::value);
    encoder << instance.x;
    encoder << instance.y;
}

std::optional<CGPoint> ArgumentCoder<CGPoint>::decode(Decoder& decoder)
{
    auto x = decoder.decode<CGFloat>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<CGFloat>();
    if (!y)
        return std::nullopt;

    return {
        CGPoint {
            WTFMove(*x),
            WTFMove(*y)
        }
    };
}

#endif

#if USE(CG)

void ArgumentCoder<CGRect>::encode(Encoder& encoder, const CGRect& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.origin)>, CGPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size)>, CGSize>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(CGRect, origin)
        , offsetof(CGRect, size)
    >::value);
    encoder << instance.origin;
    encoder << instance.size;
}

std::optional<CGRect> ArgumentCoder<CGRect>::decode(Decoder& decoder)
{
    auto origin = decoder.decode<CGPoint>();
    if (!origin)
        return std::nullopt;

    auto size = decoder.decode<CGSize>();
    if (!size)
        return std::nullopt;

    return {
        CGRect {
            WTFMove(*origin),
            WTFMove(*size)
        }
    };
}

#endif

#if USE(CG)

void ArgumentCoder<CGAffineTransform>::encode(Encoder& encoder, const CGAffineTransform& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.a)>, CGFloat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.b)>, CGFloat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.c)>, CGFloat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.d)>, CGFloat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tx)>, CGFloat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ty)>, CGFloat>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(CGAffineTransform, a)
        , offsetof(CGAffineTransform, b)
        , offsetof(CGAffineTransform, c)
        , offsetof(CGAffineTransform, d)
        , offsetof(CGAffineTransform, tx)
        , offsetof(CGAffineTransform, ty)
    >::value);
    encoder << instance.a;
    encoder << instance.b;
    encoder << instance.c;
    encoder << instance.d;
    encoder << instance.tx;
    encoder << instance.ty;
}

std::optional<CGAffineTransform> ArgumentCoder<CGAffineTransform>::decode(Decoder& decoder)
{
    auto a = decoder.decode<CGFloat>();
    if (!a)
        return std::nullopt;

    auto b = decoder.decode<CGFloat>();
    if (!b)
        return std::nullopt;

    auto c = decoder.decode<CGFloat>();
    if (!c)
        return std::nullopt;

    auto d = decoder.decode<CGFloat>();
    if (!d)
        return std::nullopt;

    auto tx = decoder.decode<CGFloat>();
    if (!tx)
        return std::nullopt;

    auto ty = decoder.decode<CGFloat>();
    if (!ty)
        return std::nullopt;

    return {
        CGAffineTransform {
            WTFMove(*a),
            WTFMove(*b),
            WTFMove(*c),
            WTFMove(*d),
            WTFMove(*tx),
            WTFMove(*ty)
        }
    };
}

#endif


void ArgumentCoder<WebCore::FloatRect>::encode(Encoder& encoder, const WebCore::FloatRect& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location())>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size())>, WebCore::FloatSize>);
    encoder << instance.location();
    encoder << instance.size();
}

void ArgumentCoder<WebCore::FloatRect>::encode(StreamConnectionEncoder& encoder, const WebCore::FloatRect& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location())>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size())>, WebCore::FloatSize>);
    encoder << instance.location();
    encoder << instance.size();
}

std::optional<WebCore::FloatRect> ArgumentCoder<WebCore::FloatRect>::decode(Decoder& decoder)
{
    auto location = decoder.decode<WebCore::FloatPoint>();
    if (!location)
        return std::nullopt;

    auto size = decoder.decode<WebCore::FloatSize>();
    if (!size)
        return std::nullopt;

    return {
        WebCore::FloatRect {
            WTFMove(*location),
            WTFMove(*size)
        }
    };
}


void ArgumentCoder<WebCore::LinearTimingFunction>::encode(Encoder& encoder, const WebCore::LinearTimingFunction& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<Ref<WebCore::LinearTimingFunction>> ArgumentCoder<WebCore::LinearTimingFunction>::decode(Decoder& decoder)
{
    return {
        WebCore::LinearTimingFunction::create(
        )
    };
}


void ArgumentCoder<WebCore::CubicBezierTimingFunction>::encode(Encoder& encoder, const WebCore::CubicBezierTimingFunction& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timingFunctionPreset())>, WebCore::CubicBezierTimingFunction::TimingFunctionPreset>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x1())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y1())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x2())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y2())>, double>);
    encoder << instance.timingFunctionPreset();
    encoder << instance.x1();
    encoder << instance.y1();
    encoder << instance.x2();
    encoder << instance.y2();
}

std::optional<Ref<WebCore::CubicBezierTimingFunction>> ArgumentCoder<WebCore::CubicBezierTimingFunction>::decode(Decoder& decoder)
{
    auto timingFunctionPreset = decoder.decode<WebCore::CubicBezierTimingFunction::TimingFunctionPreset>();
    if (!timingFunctionPreset)
        return std::nullopt;

    auto x1 = decoder.decode<double>();
    if (!x1)
        return std::nullopt;

    auto y1 = decoder.decode<double>();
    if (!y1)
        return std::nullopt;

    auto x2 = decoder.decode<double>();
    if (!x2)
        return std::nullopt;

    auto y2 = decoder.decode<double>();
    if (!y2)
        return std::nullopt;

    return {
        WebCore::CubicBezierTimingFunction::create(
            WTFMove(*timingFunctionPreset),
            WTFMove(*x1),
            WTFMove(*y1),
            WTFMove(*x2),
            WTFMove(*y2)
        )
    };
}


void ArgumentCoder<WebCore::StepsTimingFunction>::encode(Encoder& encoder, const WebCore::StepsTimingFunction& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.numberOfSteps())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stepPosition())>, std::optional<WebCore::StepsTimingFunction::StepPosition>>);
    encoder << instance.numberOfSteps();
    encoder << instance.stepPosition();
}

std::optional<Ref<WebCore::StepsTimingFunction>> ArgumentCoder<WebCore::StepsTimingFunction>::decode(Decoder& decoder)
{
    auto numberOfSteps = decoder.decode<int>();
    if (!numberOfSteps)
        return std::nullopt;

    auto stepPosition = decoder.decode<std::optional<WebCore::StepsTimingFunction::StepPosition>>();
    if (!stepPosition)
        return std::nullopt;

    return {
        WebCore::StepsTimingFunction::create(
            WTFMove(*numberOfSteps),
            WTFMove(*stepPosition)
        )
    };
}


void ArgumentCoder<WebCore::SpringTimingFunction>::encode(Encoder& encoder, const WebCore::SpringTimingFunction& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mass())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stiffness())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.damping())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.initialVelocity())>, double>);
    encoder << instance.mass();
    encoder << instance.stiffness();
    encoder << instance.damping();
    encoder << instance.initialVelocity();
}

std::optional<Ref<WebCore::SpringTimingFunction>> ArgumentCoder<WebCore::SpringTimingFunction>::decode(Decoder& decoder)
{
    auto mass = decoder.decode<double>();
    if (!mass)
        return std::nullopt;

    auto stiffness = decoder.decode<double>();
    if (!stiffness)
        return std::nullopt;

    auto damping = decoder.decode<double>();
    if (!damping)
        return std::nullopt;

    auto initialVelocity = decoder.decode<double>();
    if (!initialVelocity)
        return std::nullopt;

    return {
        WebCore::SpringTimingFunction::create(
            WTFMove(*mass),
            WTFMove(*stiffness),
            WTFMove(*damping),
            WTFMove(*initialVelocity)
        )
    };
}


void ArgumentCoder<WebCore::ResourceLoadStatistics>::encode(Encoder& encoder, const WebCore::ResourceLoadStatistics& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.registrableDomain)>, WebCore::RegistrableDomain>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lastSeen)>, WallTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hadUserInteraction)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mostRecentUserInteractionTime)>, WallTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.grandfathered)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.storageAccessUnderTopFrameDomains)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topFrameUniqueRedirectsTo)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topFrameUniqueRedirectsToSinceSameSiteStrictEnforcement)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topFrameUniqueRedirectsFrom)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topFrameLinkDecorationsFrom)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gotLinkDecorationFromPrevalentResource)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topFrameLoadedThirdPartyScripts)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.subframeUnderTopFrameDomains)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.subresourceUnderTopFrameDomains)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.subresourceUniqueRedirectsTo)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.subresourceUniqueRedirectsFrom)>, HashSet<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isPrevalentResource)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isVeryPrevalentResource)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataRecordsRemoved)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timesAccessedAsFirstPartyDueToUserInteraction)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timesAccessedAsFirstPartyDueToStorageAccessAPI)>, unsigned>);
#if ENABLE(WEB_API_STATISTICS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topFrameRegistrableDomainsWhichAccessedWebAPIs)>, HashSet<WebCore::RegistrableDomain>>);
#endif
#if ENABLE(WEB_API_STATISTICS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fontsFailedToLoad)>, HashSet<String>>);
#endif
#if ENABLE(WEB_API_STATISTICS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fontsSuccessfullyLoaded)>, HashSet<String>>);
#endif
#if ENABLE(WEB_API_STATISTICS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canvasActivityRecord)>, WebCore::CanvasActivityRecord>);
#endif
#if ENABLE(WEB_API_STATISTICS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.navigatorFunctionsAccessed)>, OptionSet<WebCore::NavigatorAPIsAccessed>>);
#endif
#if ENABLE(WEB_API_STATISTICS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenFunctionsAccessed)>, OptionSet<WebCore::ScreenAPIsAccessed>>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ResourceLoadStatistics, registrableDomain)
        , offsetof(WebCore::ResourceLoadStatistics, lastSeen)
        , offsetof(WebCore::ResourceLoadStatistics, hadUserInteraction)
        , offsetof(WebCore::ResourceLoadStatistics, mostRecentUserInteractionTime)
        , offsetof(WebCore::ResourceLoadStatistics, grandfathered)
        , offsetof(WebCore::ResourceLoadStatistics, storageAccessUnderTopFrameDomains)
        , offsetof(WebCore::ResourceLoadStatistics, topFrameUniqueRedirectsTo)
        , offsetof(WebCore::ResourceLoadStatistics, topFrameUniqueRedirectsToSinceSameSiteStrictEnforcement)
        , offsetof(WebCore::ResourceLoadStatistics, topFrameUniqueRedirectsFrom)
        , offsetof(WebCore::ResourceLoadStatistics, topFrameLinkDecorationsFrom)
        , offsetof(WebCore::ResourceLoadStatistics, gotLinkDecorationFromPrevalentResource)
        , offsetof(WebCore::ResourceLoadStatistics, topFrameLoadedThirdPartyScripts)
        , offsetof(WebCore::ResourceLoadStatistics, subframeUnderTopFrameDomains)
        , offsetof(WebCore::ResourceLoadStatistics, subresourceUnderTopFrameDomains)
        , offsetof(WebCore::ResourceLoadStatistics, subresourceUniqueRedirectsTo)
        , offsetof(WebCore::ResourceLoadStatistics, subresourceUniqueRedirectsFrom)
        , offsetof(WebCore::ResourceLoadStatistics, isPrevalentResource)
        , offsetof(WebCore::ResourceLoadStatistics, isVeryPrevalentResource)
        , offsetof(WebCore::ResourceLoadStatistics, dataRecordsRemoved)
        , offsetof(WebCore::ResourceLoadStatistics, timesAccessedAsFirstPartyDueToUserInteraction)
        , offsetof(WebCore::ResourceLoadStatistics, timesAccessedAsFirstPartyDueToStorageAccessAPI)
#if ENABLE(WEB_API_STATISTICS)
        , offsetof(WebCore::ResourceLoadStatistics, topFrameRegistrableDomainsWhichAccessedWebAPIs)
#endif
#if ENABLE(WEB_API_STATISTICS)
        , offsetof(WebCore::ResourceLoadStatistics, fontsFailedToLoad)
#endif
#if ENABLE(WEB_API_STATISTICS)
        , offsetof(WebCore::ResourceLoadStatistics, fontsSuccessfullyLoaded)
#endif
#if ENABLE(WEB_API_STATISTICS)
        , offsetof(WebCore::ResourceLoadStatistics, canvasActivityRecord)
#endif
#if ENABLE(WEB_API_STATISTICS)
        , offsetof(WebCore::ResourceLoadStatistics, navigatorFunctionsAccessed)
#endif
#if ENABLE(WEB_API_STATISTICS)
        , offsetof(WebCore::ResourceLoadStatistics, screenFunctionsAccessed)
#endif
    >::value);
    encoder << instance.registrableDomain;
    encoder << instance.lastSeen;
    encoder << instance.hadUserInteraction;
    encoder << instance.mostRecentUserInteractionTime;
    encoder << instance.grandfathered;
    encoder << instance.storageAccessUnderTopFrameDomains;
    encoder << instance.topFrameUniqueRedirectsTo;
    encoder << instance.topFrameUniqueRedirectsToSinceSameSiteStrictEnforcement;
    encoder << instance.topFrameUniqueRedirectsFrom;
    encoder << instance.topFrameLinkDecorationsFrom;
    encoder << instance.gotLinkDecorationFromPrevalentResource;
    encoder << instance.topFrameLoadedThirdPartyScripts;
    encoder << instance.subframeUnderTopFrameDomains;
    encoder << instance.subresourceUnderTopFrameDomains;
    encoder << instance.subresourceUniqueRedirectsTo;
    encoder << instance.subresourceUniqueRedirectsFrom;
    encoder << instance.isPrevalentResource;
    encoder << instance.isVeryPrevalentResource;
    encoder << instance.dataRecordsRemoved;
    encoder << instance.timesAccessedAsFirstPartyDueToUserInteraction;
    encoder << instance.timesAccessedAsFirstPartyDueToStorageAccessAPI;
#if ENABLE(WEB_API_STATISTICS)
    encoder << instance.topFrameRegistrableDomainsWhichAccessedWebAPIs;
#endif
#if ENABLE(WEB_API_STATISTICS)
    encoder << instance.fontsFailedToLoad;
#endif
#if ENABLE(WEB_API_STATISTICS)
    encoder << instance.fontsSuccessfullyLoaded;
#endif
#if ENABLE(WEB_API_STATISTICS)
    encoder << instance.canvasActivityRecord;
#endif
#if ENABLE(WEB_API_STATISTICS)
    encoder << instance.navigatorFunctionsAccessed;
#endif
#if ENABLE(WEB_API_STATISTICS)
    encoder << instance.screenFunctionsAccessed;
#endif
}

std::optional<WebCore::ResourceLoadStatistics> ArgumentCoder<WebCore::ResourceLoadStatistics>::decode(Decoder& decoder)
{
    auto registrableDomain = decoder.decode<WebCore::RegistrableDomain>();
    if (!registrableDomain)
        return std::nullopt;

    auto lastSeen = decoder.decode<WallTime>();
    if (!lastSeen)
        return std::nullopt;

    auto hadUserInteraction = decoder.decode<bool>();
    if (!hadUserInteraction)
        return std::nullopt;

    auto mostRecentUserInteractionTime = decoder.decode<WallTime>();
    if (!mostRecentUserInteractionTime)
        return std::nullopt;

    auto grandfathered = decoder.decode<bool>();
    if (!grandfathered)
        return std::nullopt;

    auto storageAccessUnderTopFrameDomains = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!storageAccessUnderTopFrameDomains)
        return std::nullopt;

    auto topFrameUniqueRedirectsTo = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!topFrameUniqueRedirectsTo)
        return std::nullopt;

    auto topFrameUniqueRedirectsToSinceSameSiteStrictEnforcement = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!topFrameUniqueRedirectsToSinceSameSiteStrictEnforcement)
        return std::nullopt;

    auto topFrameUniqueRedirectsFrom = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!topFrameUniqueRedirectsFrom)
        return std::nullopt;

    auto topFrameLinkDecorationsFrom = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!topFrameLinkDecorationsFrom)
        return std::nullopt;

    auto gotLinkDecorationFromPrevalentResource = decoder.decode<bool>();
    if (!gotLinkDecorationFromPrevalentResource)
        return std::nullopt;

    auto topFrameLoadedThirdPartyScripts = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!topFrameLoadedThirdPartyScripts)
        return std::nullopt;

    auto subframeUnderTopFrameDomains = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!subframeUnderTopFrameDomains)
        return std::nullopt;

    auto subresourceUnderTopFrameDomains = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!subresourceUnderTopFrameDomains)
        return std::nullopt;

    auto subresourceUniqueRedirectsTo = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!subresourceUniqueRedirectsTo)
        return std::nullopt;

    auto subresourceUniqueRedirectsFrom = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!subresourceUniqueRedirectsFrom)
        return std::nullopt;

    auto isPrevalentResource = decoder.decode<bool>();
    if (!isPrevalentResource)
        return std::nullopt;

    auto isVeryPrevalentResource = decoder.decode<bool>();
    if (!isVeryPrevalentResource)
        return std::nullopt;

    auto dataRecordsRemoved = decoder.decode<unsigned>();
    if (!dataRecordsRemoved)
        return std::nullopt;

    auto timesAccessedAsFirstPartyDueToUserInteraction = decoder.decode<unsigned>();
    if (!timesAccessedAsFirstPartyDueToUserInteraction)
        return std::nullopt;

    auto timesAccessedAsFirstPartyDueToStorageAccessAPI = decoder.decode<unsigned>();
    if (!timesAccessedAsFirstPartyDueToStorageAccessAPI)
        return std::nullopt;

#if ENABLE(WEB_API_STATISTICS)
    auto topFrameRegistrableDomainsWhichAccessedWebAPIs = decoder.decode<HashSet<WebCore::RegistrableDomain>>();
    if (!topFrameRegistrableDomainsWhichAccessedWebAPIs)
        return std::nullopt;
#endif

#if ENABLE(WEB_API_STATISTICS)
    auto fontsFailedToLoad = decoder.decode<HashSet<String>>();
    if (!fontsFailedToLoad)
        return std::nullopt;
#endif

#if ENABLE(WEB_API_STATISTICS)
    auto fontsSuccessfullyLoaded = decoder.decode<HashSet<String>>();
    if (!fontsSuccessfullyLoaded)
        return std::nullopt;
#endif

#if ENABLE(WEB_API_STATISTICS)
    auto canvasActivityRecord = decoder.decode<WebCore::CanvasActivityRecord>();
    if (!canvasActivityRecord)
        return std::nullopt;
#endif

#if ENABLE(WEB_API_STATISTICS)
    auto navigatorFunctionsAccessed = decoder.decode<OptionSet<WebCore::NavigatorAPIsAccessed>>();
    if (!navigatorFunctionsAccessed)
        return std::nullopt;
#endif

#if ENABLE(WEB_API_STATISTICS)
    auto screenFunctionsAccessed = decoder.decode<OptionSet<WebCore::ScreenAPIsAccessed>>();
    if (!screenFunctionsAccessed)
        return std::nullopt;
#endif

    WebCore::ResourceLoadStatistics result;
    result.registrableDomain = WTFMove(*registrableDomain);
    result.lastSeen = WTFMove(*lastSeen);
    result.hadUserInteraction = WTFMove(*hadUserInteraction);
    result.mostRecentUserInteractionTime = WTFMove(*mostRecentUserInteractionTime);
    result.grandfathered = WTFMove(*grandfathered);
    result.storageAccessUnderTopFrameDomains = WTFMove(*storageAccessUnderTopFrameDomains);
    result.topFrameUniqueRedirectsTo = WTFMove(*topFrameUniqueRedirectsTo);
    result.topFrameUniqueRedirectsToSinceSameSiteStrictEnforcement = WTFMove(*topFrameUniqueRedirectsToSinceSameSiteStrictEnforcement);
    result.topFrameUniqueRedirectsFrom = WTFMove(*topFrameUniqueRedirectsFrom);
    result.topFrameLinkDecorationsFrom = WTFMove(*topFrameLinkDecorationsFrom);
    result.gotLinkDecorationFromPrevalentResource = WTFMove(*gotLinkDecorationFromPrevalentResource);
    result.topFrameLoadedThirdPartyScripts = WTFMove(*topFrameLoadedThirdPartyScripts);
    result.subframeUnderTopFrameDomains = WTFMove(*subframeUnderTopFrameDomains);
    result.subresourceUnderTopFrameDomains = WTFMove(*subresourceUnderTopFrameDomains);
    result.subresourceUniqueRedirectsTo = WTFMove(*subresourceUniqueRedirectsTo);
    result.subresourceUniqueRedirectsFrom = WTFMove(*subresourceUniqueRedirectsFrom);
    result.isPrevalentResource = WTFMove(*isPrevalentResource);
    result.isVeryPrevalentResource = WTFMove(*isVeryPrevalentResource);
    result.dataRecordsRemoved = WTFMove(*dataRecordsRemoved);
    result.timesAccessedAsFirstPartyDueToUserInteraction = WTFMove(*timesAccessedAsFirstPartyDueToUserInteraction);
    result.timesAccessedAsFirstPartyDueToStorageAccessAPI = WTFMove(*timesAccessedAsFirstPartyDueToStorageAccessAPI);
#if ENABLE(WEB_API_STATISTICS)
    result.topFrameRegistrableDomainsWhichAccessedWebAPIs = WTFMove(*topFrameRegistrableDomainsWhichAccessedWebAPIs);
#endif
#if ENABLE(WEB_API_STATISTICS)
    result.fontsFailedToLoad = WTFMove(*fontsFailedToLoad);
#endif
#if ENABLE(WEB_API_STATISTICS)
    result.fontsSuccessfullyLoaded = WTFMove(*fontsSuccessfullyLoaded);
#endif
#if ENABLE(WEB_API_STATISTICS)
    result.canvasActivityRecord = WTFMove(*canvasActivityRecord);
#endif
#if ENABLE(WEB_API_STATISTICS)
    result.navigatorFunctionsAccessed = WTFMove(*navigatorFunctionsAccessed);
#endif
#if ENABLE(WEB_API_STATISTICS)
    result.screenFunctionsAccessed = WTFMove(*screenFunctionsAccessed);
#endif
    return { WTFMove(result) };
}

#if ENABLE(GPU_PROCESS) && ENABLE(WEBGL)

void ArgumentCoder<WebCore::GraphicsContextGLActiveInfo>::encode(Encoder& encoder, const WebCore::GraphicsContextGLActiveInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, GCGLenum>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size)>, GCGLint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GraphicsContextGLActiveInfo, name)
        , offsetof(WebCore::GraphicsContextGLActiveInfo, type)
        , offsetof(WebCore::GraphicsContextGLActiveInfo, size)
    >::value);
    encoder << instance.name;
    encoder << instance.type;
    encoder << instance.size;
}

void ArgumentCoder<WebCore::GraphicsContextGLActiveInfo>::encode(StreamConnectionEncoder& encoder, const WebCore::GraphicsContextGLActiveInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, GCGLenum>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size)>, GCGLint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GraphicsContextGLActiveInfo, name)
        , offsetof(WebCore::GraphicsContextGLActiveInfo, type)
        , offsetof(WebCore::GraphicsContextGLActiveInfo, size)
    >::value);
    encoder << instance.name;
    encoder << instance.type;
    encoder << instance.size;
}

std::optional<WebCore::GraphicsContextGLActiveInfo> ArgumentCoder<WebCore::GraphicsContextGLActiveInfo>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto type = decoder.decode<GCGLenum>();
    if (!type)
        return std::nullopt;

    auto size = decoder.decode<GCGLint>();
    if (!size)
        return std::nullopt;

    return {
        WebCore::GraphicsContextGLActiveInfo {
            WTFMove(*name),
            WTFMove(*type),
            WTFMove(*size)
        }
    };
}

#endif


void ArgumentCoder<WebCore::ViewportAttributes>::encode(Encoder& encoder, const WebCore::ViewportAttributes& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.layoutSize)>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.initialScale)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minimumScale)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maximumScale)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.userScalable)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.orientation)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shrinkToFit)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.viewportFit)>, WebCore::ViewportFit>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ViewportAttributes, layoutSize)
        , offsetof(WebCore::ViewportAttributes, initialScale)
        , offsetof(WebCore::ViewportAttributes, minimumScale)
        , offsetof(WebCore::ViewportAttributes, maximumScale)
        , offsetof(WebCore::ViewportAttributes, userScalable)
        , offsetof(WebCore::ViewportAttributes, orientation)
        , offsetof(WebCore::ViewportAttributes, shrinkToFit)
        , offsetof(WebCore::ViewportAttributes, viewportFit)
    >::value);
    encoder << instance.layoutSize;
    encoder << instance.initialScale;
    encoder << instance.minimumScale;
    encoder << instance.maximumScale;
    encoder << instance.userScalable;
    encoder << instance.orientation;
    encoder << instance.shrinkToFit;
    encoder << instance.viewportFit;
}

std::optional<WebCore::ViewportAttributes> ArgumentCoder<WebCore::ViewportAttributes>::decode(Decoder& decoder)
{
    auto layoutSize = decoder.decode<WebCore::FloatSize>();
    if (!layoutSize)
        return std::nullopt;

    auto initialScale = decoder.decode<float>();
    if (!initialScale)
        return std::nullopt;

    auto minimumScale = decoder.decode<float>();
    if (!minimumScale)
        return std::nullopt;

    auto maximumScale = decoder.decode<float>();
    if (!maximumScale)
        return std::nullopt;

    auto userScalable = decoder.decode<float>();
    if (!userScalable)
        return std::nullopt;

    auto orientation = decoder.decode<float>();
    if (!orientation)
        return std::nullopt;

    auto shrinkToFit = decoder.decode<float>();
    if (!shrinkToFit)
        return std::nullopt;

    auto viewportFit = decoder.decode<WebCore::ViewportFit>();
    if (!viewportFit)
        return std::nullopt;

    return {
        WebCore::ViewportAttributes {
            WTFMove(*layoutSize),
            WTFMove(*initialScale),
            WTFMove(*minimumScale),
            WTFMove(*maximumScale),
            WTFMove(*userScalable),
            WTFMove(*orientation),
            WTFMove(*shrinkToFit),
            WTFMove(*viewportFit)
        }
    };
}


void ArgumentCoder<WebCore::ShareDataWithParsedURL>::encode(Encoder& encoder, const WebCore::ShareDataWithParsedURL& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shareData)>, WebCore::ShareData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, std::optional<URL>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.files)>, Vector<WebCore::RawFile>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.originator)>, WebCore::ShareDataOriginator>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ShareDataWithParsedURL, shareData)
        , offsetof(WebCore::ShareDataWithParsedURL, url)
        , offsetof(WebCore::ShareDataWithParsedURL, files)
        , offsetof(WebCore::ShareDataWithParsedURL, originator)
    >::value);
    encoder << instance.shareData;
    encoder << instance.url;
    encoder << instance.files;
    encoder << instance.originator;
}

std::optional<WebCore::ShareDataWithParsedURL> ArgumentCoder<WebCore::ShareDataWithParsedURL>::decode(Decoder& decoder)
{
    auto shareData = decoder.decode<WebCore::ShareData>();
    if (!shareData)
        return std::nullopt;

    auto url = decoder.decode<std::optional<URL>>();
    if (!url)
        return std::nullopt;

    auto files = decoder.decode<Vector<WebCore::RawFile>>();
    if (!files)
        return std::nullopt;

    auto originator = decoder.decode<WebCore::ShareDataOriginator>();
    if (!originator)
        return std::nullopt;

    return {
        WebCore::ShareDataWithParsedURL {
            WTFMove(*shareData),
            WTFMove(*url),
            WTFMove(*files),
            WTFMove(*originator)
        }
    };
}


void ArgumentCoder<WebCore::ShareData>::encode(Encoder& encoder, const WebCore::ShareData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.title)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.text)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ShareData, title)
        , offsetof(WebCore::ShareData, text)
        , offsetof(WebCore::ShareData, url)
    >::value);
    encoder << instance.title;
    encoder << instance.text;
    encoder << instance.url;
}

std::optional<WebCore::ShareData> ArgumentCoder<WebCore::ShareData>::decode(Decoder& decoder)
{
    auto title = decoder.decode<String>();
    if (!title)
        return std::nullopt;

    auto text = decoder.decode<String>();
    if (!text)
        return std::nullopt;

    auto url = decoder.decode<String>();
    if (!url)
        return std::nullopt;

    return {
        WebCore::ShareData {
            WTFMove(*title),
            WTFMove(*text),
            WTFMove(*url)
        }
    };
}


void ArgumentCoder<WebCore::RawFile>::encode(Encoder& encoder, const WebCore::RawFile& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fileName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fileData)>, RefPtr<WebCore::SharedBuffer>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::RawFile, fileName)
        , offsetof(WebCore::RawFile, fileData)
    >::value);
    encoder << instance.fileName;
    encoder << instance.fileData;
}

std::optional<WebCore::RawFile> ArgumentCoder<WebCore::RawFile>::decode(Decoder& decoder)
{
    auto fileName = decoder.decode<String>();
    if (!fileName)
        return std::nullopt;

    auto fileData = decoder.decode<RefPtr<WebCore::SharedBuffer>>();
    if (!fileData)
        return std::nullopt;

    return {
        WebCore::RawFile {
            WTFMove(*fileName),
            WTFMove(*fileData)
        }
    };
}


void ArgumentCoder<WebCore::FloatRoundedRect>::encode(Encoder& encoder, const WebCore::FloatRoundedRect& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rect())>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radii().topLeft())>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radii().topRight())>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radii().bottomLeft())>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radii().bottomRight())>, WebCore::FloatSize>);
    encoder << instance.rect();
    encoder << instance.radii().topLeft();
    encoder << instance.radii().topRight();
    encoder << instance.radii().bottomLeft();
    encoder << instance.radii().bottomRight();
}

void ArgumentCoder<WebCore::FloatRoundedRect>::encode(StreamConnectionEncoder& encoder, const WebCore::FloatRoundedRect& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rect())>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radii().topLeft())>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radii().topRight())>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radii().bottomLeft())>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radii().bottomRight())>, WebCore::FloatSize>);
    encoder << instance.rect();
    encoder << instance.radii().topLeft();
    encoder << instance.radii().topRight();
    encoder << instance.radii().bottomLeft();
    encoder << instance.radii().bottomRight();
}

std::optional<WebCore::FloatRoundedRect> ArgumentCoder<WebCore::FloatRoundedRect>::decode(Decoder& decoder)
{
    auto rect = decoder.decode<WebCore::FloatRect>();
    if (!rect)
        return std::nullopt;

    auto radiitopLeft = decoder.decode<WebCore::FloatSize>();
    if (!radiitopLeft)
        return std::nullopt;

    auto radiitopRight = decoder.decode<WebCore::FloatSize>();
    if (!radiitopRight)
        return std::nullopt;

    auto radiibottomLeft = decoder.decode<WebCore::FloatSize>();
    if (!radiibottomLeft)
        return std::nullopt;

    auto radiibottomRight = decoder.decode<WebCore::FloatSize>();
    if (!radiibottomRight)
        return std::nullopt;

    return {
        WebCore::FloatRoundedRect {
            WTFMove(*rect),
            WTFMove(*radiitopLeft),
            WTFMove(*radiitopRight),
            WTFMove(*radiibottomLeft),
            WTFMove(*radiibottomRight)
        }
    };
}


void ArgumentCoder<WebCore::IntRect>::encode(Encoder& encoder, const WebCore::IntRect& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size())>, WebCore::IntSize>);
    encoder << instance.location();
    encoder << instance.size();
}

void ArgumentCoder<WebCore::IntRect>::encode(StreamConnectionEncoder& encoder, const WebCore::IntRect& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size())>, WebCore::IntSize>);
    encoder << instance.location();
    encoder << instance.size();
}

std::optional<WebCore::IntRect> ArgumentCoder<WebCore::IntRect>::decode(Decoder& decoder)
{
    auto location = decoder.decode<WebCore::IntPoint>();
    if (!location)
        return std::nullopt;

    auto size = decoder.decode<WebCore::IntSize>();
    if (!size)
        return std::nullopt;

    if (!(WebCore::IntRect { *location, *size }.isValid()))
        return std::nullopt;

    return {
        WebCore::IntRect {
            WTFMove(*location),
            WTFMove(*size)
        }
    };
}


void ArgumentCoder<WebCore::IntPoint>::encode(Encoder& encoder, const WebCore::IntPoint& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, int>);
    encoder << instance.x();
    encoder << instance.y();
}

void ArgumentCoder<WebCore::IntPoint>::encode(StreamConnectionEncoder& encoder, const WebCore::IntPoint& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, int>);
    encoder << instance.x();
    encoder << instance.y();
}

std::optional<WebCore::IntPoint> ArgumentCoder<WebCore::IntPoint>::decode(Decoder& decoder)
{
    auto x = decoder.decode<int>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<int>();
    if (!y)
        return std::nullopt;

    return {
        WebCore::IntPoint {
            WTFMove(*x),
            WTFMove(*y)
        }
    };
}


void ArgumentCoder<WebCore::IntSize>::encode(Encoder& encoder, const WebCore::IntSize& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height())>, int>);
    encoder << instance.width();
    encoder << instance.height();
}

void ArgumentCoder<WebCore::IntSize>::encode(StreamConnectionEncoder& encoder, const WebCore::IntSize& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height())>, int>);
    encoder << instance.width();
    encoder << instance.height();
}

std::optional<WebCore::IntSize> ArgumentCoder<WebCore::IntSize>::decode(Decoder& decoder)
{
    auto width = decoder.decode<int>();
    if (!width)
        return std::nullopt;

    auto height = decoder.decode<int>();
    if (!height)
        return std::nullopt;

    return {
        WebCore::IntSize {
            WTFMove(*width),
            WTFMove(*height)
        }
    };
}


void ArgumentCoder<WebCore::FloatSize>::encode(Encoder& encoder, const WebCore::FloatSize& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height())>, float>);
    encoder << instance.width();
    encoder << instance.height();
}

void ArgumentCoder<WebCore::FloatSize>::encode(StreamConnectionEncoder& encoder, const WebCore::FloatSize& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height())>, float>);
    encoder << instance.width();
    encoder << instance.height();
}

std::optional<WebCore::FloatSize> ArgumentCoder<WebCore::FloatSize>::decode(Decoder& decoder)
{
    auto width = decoder.decode<float>();
    if (!width)
        return std::nullopt;

    auto height = decoder.decode<float>();
    if (!height)
        return std::nullopt;

    return {
        WebCore::FloatSize {
            WTFMove(*width),
            WTFMove(*height)
        }
    };
}


void ArgumentCoder<WebCore::LayoutUnit>::encode(Encoder& encoder, const WebCore::LayoutUnit& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rawValue())>, int>);
    encoder << instance.rawValue();
}

void ArgumentCoder<WebCore::LayoutUnit>::encode(StreamConnectionEncoder& encoder, const WebCore::LayoutUnit& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rawValue())>, int>);
    encoder << instance.rawValue();
}

std::optional<WebCore::LayoutUnit> ArgumentCoder<WebCore::LayoutUnit>::decode(Decoder& decoder)
{
    auto rawValue = decoder.decode<int>();
    if (!rawValue)
        return std::nullopt;

    return {
        WebCore::LayoutUnit::fromRawValue(
            WTFMove(*rawValue)
        )
    };
}


void ArgumentCoder<WebCore::LayoutPoint>::encode(Encoder& encoder, const WebCore::LayoutPoint& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, WebCore::LayoutUnit>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, WebCore::LayoutUnit>);
    encoder << instance.x();
    encoder << instance.y();
}

void ArgumentCoder<WebCore::LayoutPoint>::encode(StreamConnectionEncoder& encoder, const WebCore::LayoutPoint& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, WebCore::LayoutUnit>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, WebCore::LayoutUnit>);
    encoder << instance.x();
    encoder << instance.y();
}

std::optional<WebCore::LayoutPoint> ArgumentCoder<WebCore::LayoutPoint>::decode(Decoder& decoder)
{
    auto x = decoder.decode<WebCore::LayoutUnit>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<WebCore::LayoutUnit>();
    if (!y)
        return std::nullopt;

    return {
        WebCore::LayoutPoint {
            WTFMove(*x),
            WTFMove(*y)
        }
    };
}


void ArgumentCoder<WebCore::LayoutSize>::encode(Encoder& encoder, const WebCore::LayoutSize& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width())>, WebCore::LayoutUnit>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height())>, WebCore::LayoutUnit>);
    encoder << instance.width();
    encoder << instance.height();
}

void ArgumentCoder<WebCore::LayoutSize>::encode(StreamConnectionEncoder& encoder, const WebCore::LayoutSize& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width())>, WebCore::LayoutUnit>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height())>, WebCore::LayoutUnit>);
    encoder << instance.width();
    encoder << instance.height();
}

std::optional<WebCore::LayoutSize> ArgumentCoder<WebCore::LayoutSize>::decode(Decoder& decoder)
{
    auto width = decoder.decode<WebCore::LayoutUnit>();
    if (!width)
        return std::nullopt;

    auto height = decoder.decode<WebCore::LayoutUnit>();
    if (!height)
        return std::nullopt;

    return {
        WebCore::LayoutSize {
            WTFMove(*width),
            WTFMove(*height)
        }
    };
}


void ArgumentCoder<WebCore::DictionaryPopupInfo>::encode(Encoder& encoder, const WebCore::DictionaryPopupInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.origin)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textIndicator)>, WebCore::TextIndicatorData>);
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.platformData)>, WebCore::DictionaryPopupInfoCocoa>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DictionaryPopupInfo, origin)
        , offsetof(WebCore::DictionaryPopupInfo, textIndicator)
#if PLATFORM(COCOA)
        , offsetof(WebCore::DictionaryPopupInfo, platformData)
#endif
    >::value);
    encoder << instance.origin;
    encoder << instance.textIndicator;
#if PLATFORM(COCOA)
    encoder << instance.platformData;
#endif
}

std::optional<WebCore::DictionaryPopupInfo> ArgumentCoder<WebCore::DictionaryPopupInfo>::decode(Decoder& decoder)
{
    auto origin = decoder.decode<WebCore::FloatPoint>();
    if (!origin)
        return std::nullopt;

    auto textIndicator = decoder.decode<WebCore::TextIndicatorData>();
    if (!textIndicator)
        return std::nullopt;

#if PLATFORM(COCOA)
    auto platformData = decoder.decode<WebCore::DictionaryPopupInfoCocoa>();
    if (!platformData)
        return std::nullopt;
#endif

    return {
        WebCore::DictionaryPopupInfo {
            WTFMove(*origin),
            WTFMove(*textIndicator),
#if PLATFORM(COCOA)
            WTFMove(*platformData)
#endif
        }
    };
}


void ArgumentCoder<WebCore::PrivateClickMeasurement>::encode(Encoder& encoder, const WebCore::PrivateClickMeasurement& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceID())>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceSite())>, WebCore::PCM::SourceSite>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.destinationSite())>, WebCore::PCM::AttributionDestinationSite>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timeOfAdClick())>, WallTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isEphemeral())>, WebCore::PCM::AttributionEphemeral>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.adamID())>, std::optional<uint64_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.attributionTriggerData())>, std::optional<WebCore::PCM::AttributionTriggerData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timesToSend())>, WebCore::PCM::AttributionTimeToSendData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ephemeralSourceNonce())>, std::optional<WebCore::PCM::EphemeralNonce>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceApplicationBundleID())>, String>);
    encoder << instance.sourceID();
    encoder << instance.sourceSite();
    encoder << instance.destinationSite();
    encoder << instance.timeOfAdClick();
    encoder << instance.isEphemeral();
    encoder << instance.adamID();
    encoder << instance.attributionTriggerData();
    encoder << instance.timesToSend();
    encoder << instance.ephemeralSourceNonce();
    encoder << instance.sourceApplicationBundleID();
}

std::optional<WebCore::PrivateClickMeasurement> ArgumentCoder<WebCore::PrivateClickMeasurement>::decode(Decoder& decoder)
{
    auto sourceID = decoder.decode<uint8_t>();
    if (!sourceID)
        return std::nullopt;

    auto sourceSite = decoder.decode<WebCore::PCM::SourceSite>();
    if (!sourceSite)
        return std::nullopt;

    auto destinationSite = decoder.decode<WebCore::PCM::AttributionDestinationSite>();
    if (!destinationSite)
        return std::nullopt;

    auto timeOfAdClick = decoder.decode<WallTime>();
    if (!timeOfAdClick)
        return std::nullopt;

    auto isEphemeral = decoder.decode<WebCore::PCM::AttributionEphemeral>();
    if (!isEphemeral)
        return std::nullopt;

    auto adamID = decoder.decode<std::optional<uint64_t>>();
    if (!adamID)
        return std::nullopt;

    auto attributionTriggerData = decoder.decode<std::optional<WebCore::PCM::AttributionTriggerData>>();
    if (!attributionTriggerData)
        return std::nullopt;

    auto timesToSend = decoder.decode<WebCore::PCM::AttributionTimeToSendData>();
    if (!timesToSend)
        return std::nullopt;

    auto ephemeralSourceNonce = decoder.decode<std::optional<WebCore::PCM::EphemeralNonce>>();
    if (!ephemeralSourceNonce)
        return std::nullopt;

    auto sourceApplicationBundleID = decoder.decode<String>();
    if (!sourceApplicationBundleID)
        return std::nullopt;

    return {
        WebCore::PrivateClickMeasurement {
            WTFMove(*sourceID),
            WTFMove(*sourceSite),
            WTFMove(*destinationSite),
            WTFMove(*timeOfAdClick),
            WTFMove(*isEphemeral),
            WTFMove(*adamID),
            WTFMove(*attributionTriggerData),
            WTFMove(*timesToSend),
            WTFMove(*ephemeralSourceNonce),
            WTFMove(*sourceApplicationBundleID)
        }
    };
}


void ArgumentCoder<WebCore::PCM::SourceSite>::encode(Encoder& encoder, const WebCore::PCM::SourceSite& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.registrableDomain)>, WebCore::RegistrableDomain>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PCM::SourceSite, registrableDomain)
    >::value);
    encoder << instance.registrableDomain;
}

std::optional<WebCore::PCM::SourceSite> ArgumentCoder<WebCore::PCM::SourceSite>::decode(Decoder& decoder)
{
    auto registrableDomain = decoder.decode<WebCore::RegistrableDomain>();
    if (!registrableDomain)
        return std::nullopt;

    return {
        WebCore::PCM::SourceSite {
            WTFMove(*registrableDomain)
        }
    };
}


void ArgumentCoder<WebCore::PCM::AttributionDestinationSite>::encode(Encoder& encoder, const WebCore::PCM::AttributionDestinationSite& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.registrableDomain)>, WebCore::RegistrableDomain>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PCM::AttributionDestinationSite, registrableDomain)
    >::value);
    encoder << instance.registrableDomain;
}

std::optional<WebCore::PCM::AttributionDestinationSite> ArgumentCoder<WebCore::PCM::AttributionDestinationSite>::decode(Decoder& decoder)
{
    auto registrableDomain = decoder.decode<WebCore::RegistrableDomain>();
    if (!registrableDomain)
        return std::nullopt;

    return {
        WebCore::PCM::AttributionDestinationSite {
            WTFMove(*registrableDomain)
        }
    };
}


void ArgumentCoder<WebCore::PCM::EphemeralNonce>::encode(Encoder& encoder, const WebCore::PCM::EphemeralNonce& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.nonce)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PCM::EphemeralNonce, nonce)
    >::value);
    encoder << instance.nonce;
}

std::optional<WebCore::PCM::EphemeralNonce> ArgumentCoder<WebCore::PCM::EphemeralNonce>::decode(Decoder& decoder)
{
    auto nonce = decoder.decode<String>();
    if (!nonce)
        return std::nullopt;

    return {
        WebCore::PCM::EphemeralNonce {
            WTFMove(*nonce)
        }
    };
}


void ArgumentCoder<WebCore::PCM::AttributionTriggerData>::encode(Encoder& encoder, const WebCore::PCM::AttributionTriggerData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.priority)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.wasSent)>, WebCore::PCM::WasSent>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceRegistrableDomain)>, std::optional<WebCore::RegistrableDomain>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ephemeralDestinationNonce)>, std::optional<WebCore::PCM::EphemeralNonce>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.destinationSite)>, std::optional<WebCore::RegistrableDomain>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PCM::AttributionTriggerData, data)
        , offsetof(WebCore::PCM::AttributionTriggerData, priority)
        , offsetof(WebCore::PCM::AttributionTriggerData, wasSent)
        , offsetof(WebCore::PCM::AttributionTriggerData, sourceRegistrableDomain)
        , offsetof(WebCore::PCM::AttributionTriggerData, ephemeralDestinationNonce)
        , offsetof(WebCore::PCM::AttributionTriggerData, destinationSite)
    >::value);
    encoder << instance.data;
    encoder << instance.priority;
    encoder << instance.wasSent;
    encoder << instance.sourceRegistrableDomain;
    encoder << instance.ephemeralDestinationNonce;
    encoder << instance.destinationSite;
}

std::optional<WebCore::PCM::AttributionTriggerData> ArgumentCoder<WebCore::PCM::AttributionTriggerData>::decode(Decoder& decoder)
{
    auto data = decoder.decode<uint8_t>();
    if (!data)
        return std::nullopt;

    auto priority = decoder.decode<uint8_t>();
    if (!priority)
        return std::nullopt;

    auto wasSent = decoder.decode<WebCore::PCM::WasSent>();
    if (!wasSent)
        return std::nullopt;

    auto sourceRegistrableDomain = decoder.decode<std::optional<WebCore::RegistrableDomain>>();
    if (!sourceRegistrableDomain)
        return std::nullopt;

    auto ephemeralDestinationNonce = decoder.decode<std::optional<WebCore::PCM::EphemeralNonce>>();
    if (!ephemeralDestinationNonce)
        return std::nullopt;

    auto destinationSite = decoder.decode<std::optional<WebCore::RegistrableDomain>>();
    if (!destinationSite)
        return std::nullopt;

    return {
        WebCore::PCM::AttributionTriggerData {
            WTFMove(*data),
            WTFMove(*priority),
            WTFMove(*wasSent),
            WTFMove(*sourceRegistrableDomain),
            WTFMove(*ephemeralDestinationNonce),
            WTFMove(*destinationSite)
        }
    };
}


void ArgumentCoder<WebCore::PCM::AttributionTimeToSendData>::encode(Encoder& encoder, const WebCore::PCM::AttributionTimeToSendData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceEarliestTimeToSend)>, std::optional<WallTime>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.destinationEarliestTimeToSend)>, std::optional<WallTime>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PCM::AttributionTimeToSendData, sourceEarliestTimeToSend)
        , offsetof(WebCore::PCM::AttributionTimeToSendData, destinationEarliestTimeToSend)
    >::value);
    encoder << instance.sourceEarliestTimeToSend;
    encoder << instance.destinationEarliestTimeToSend;
}

std::optional<WebCore::PCM::AttributionTimeToSendData> ArgumentCoder<WebCore::PCM::AttributionTimeToSendData>::decode(Decoder& decoder)
{
    auto sourceEarliestTimeToSend = decoder.decode<std::optional<WallTime>>();
    if (!sourceEarliestTimeToSend)
        return std::nullopt;

    auto destinationEarliestTimeToSend = decoder.decode<std::optional<WallTime>>();
    if (!destinationEarliestTimeToSend)
        return std::nullopt;

    return {
        WebCore::PCM::AttributionTimeToSendData {
            WTFMove(*sourceEarliestTimeToSend),
            WTFMove(*destinationEarliestTimeToSend)
        }
    };
}

#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)

void ArgumentCoder<WebCore::ApplePayRecurringPaymentRequest>::encode(Encoder& encoder, const WebCore::ApplePayRecurringPaymentRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.paymentDescription)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.regularBilling)>, WebCore::ApplePayLineItem>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.trialBilling)>, std::optional<WebCore::ApplePayLineItem>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.billingAgreement)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.managementURL)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tokenNotificationURL)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayRecurringPaymentRequest, paymentDescription)
        , offsetof(WebCore::ApplePayRecurringPaymentRequest, regularBilling)
        , offsetof(WebCore::ApplePayRecurringPaymentRequest, trialBilling)
        , offsetof(WebCore::ApplePayRecurringPaymentRequest, billingAgreement)
        , offsetof(WebCore::ApplePayRecurringPaymentRequest, managementURL)
        , offsetof(WebCore::ApplePayRecurringPaymentRequest, tokenNotificationURL)
    >::value);
    encoder << instance.paymentDescription;
    encoder << instance.regularBilling;
    encoder << instance.trialBilling;
    encoder << instance.billingAgreement;
    encoder << instance.managementURL;
    encoder << instance.tokenNotificationURL;
}

std::optional<WebCore::ApplePayRecurringPaymentRequest> ArgumentCoder<WebCore::ApplePayRecurringPaymentRequest>::decode(Decoder& decoder)
{
    auto paymentDescription = decoder.decode<String>();
    if (!paymentDescription)
        return std::nullopt;

    auto regularBilling = decoder.decode<WebCore::ApplePayLineItem>();
    if (!regularBilling)
        return std::nullopt;

    auto trialBilling = decoder.decode<std::optional<WebCore::ApplePayLineItem>>();
    if (!trialBilling)
        return std::nullopt;

    auto billingAgreement = decoder.decode<String>();
    if (!billingAgreement)
        return std::nullopt;

    auto managementURL = decoder.decode<String>();
    if (!managementURL)
        return std::nullopt;

    auto tokenNotificationURL = decoder.decode<String>();
    if (!tokenNotificationURL)
        return std::nullopt;

    return {
        WebCore::ApplePayRecurringPaymentRequest {
            WTFMove(*paymentDescription),
            WTFMove(*regularBilling),
            WTFMove(*trialBilling),
            WTFMove(*billingAgreement),
            WTFMove(*managementURL),
            WTFMove(*tokenNotificationURL)
        }
    };
}

#endif

#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)

void ArgumentCoder<WebCore::ApplePayPaymentTokenContext>::encode(Encoder& encoder, const WebCore::ApplePayPaymentTokenContext& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.merchantIdentifier)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.externalIdentifier)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.merchantName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.merchantDomain)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.amount)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayPaymentTokenContext, merchantIdentifier)
        , offsetof(WebCore::ApplePayPaymentTokenContext, externalIdentifier)
        , offsetof(WebCore::ApplePayPaymentTokenContext, merchantName)
        , offsetof(WebCore::ApplePayPaymentTokenContext, merchantDomain)
        , offsetof(WebCore::ApplePayPaymentTokenContext, amount)
    >::value);
    encoder << instance.merchantIdentifier;
    encoder << instance.externalIdentifier;
    encoder << instance.merchantName;
    encoder << instance.merchantDomain;
    encoder << instance.amount;
}

std::optional<WebCore::ApplePayPaymentTokenContext> ArgumentCoder<WebCore::ApplePayPaymentTokenContext>::decode(Decoder& decoder)
{
    auto merchantIdentifier = decoder.decode<String>();
    if (!merchantIdentifier)
        return std::nullopt;

    auto externalIdentifier = decoder.decode<String>();
    if (!externalIdentifier)
        return std::nullopt;

    auto merchantName = decoder.decode<String>();
    if (!merchantName)
        return std::nullopt;

    auto merchantDomain = decoder.decode<String>();
    if (!merchantDomain)
        return std::nullopt;

    auto amount = decoder.decode<String>();
    if (!amount)
        return std::nullopt;

    return {
        WebCore::ApplePayPaymentTokenContext {
            WTFMove(*merchantIdentifier),
            WTFMove(*externalIdentifier),
            WTFMove(*merchantName),
            WTFMove(*merchantDomain),
            WTFMove(*amount)
        }
    };
}

#endif

#if ENABLE(APPLE_PAY_PAYMENT_ORDER_DETAILS)

void ArgumentCoder<WebCore::ApplePayPaymentOrderDetails>::encode(Encoder& encoder, const WebCore::ApplePayPaymentOrderDetails& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.orderTypeIdentifier)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.orderIdentifier)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webServiceURL)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.authenticationToken)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayPaymentOrderDetails, orderTypeIdentifier)
        , offsetof(WebCore::ApplePayPaymentOrderDetails, orderIdentifier)
        , offsetof(WebCore::ApplePayPaymentOrderDetails, webServiceURL)
        , offsetof(WebCore::ApplePayPaymentOrderDetails, authenticationToken)
    >::value);
    encoder << instance.orderTypeIdentifier;
    encoder << instance.orderIdentifier;
    encoder << instance.webServiceURL;
    encoder << instance.authenticationToken;
}

std::optional<WebCore::ApplePayPaymentOrderDetails> ArgumentCoder<WebCore::ApplePayPaymentOrderDetails>::decode(Decoder& decoder)
{
    auto orderTypeIdentifier = decoder.decode<String>();
    if (!orderTypeIdentifier)
        return std::nullopt;

    auto orderIdentifier = decoder.decode<String>();
    if (!orderIdentifier)
        return std::nullopt;

    auto webServiceURL = decoder.decode<String>();
    if (!webServiceURL)
        return std::nullopt;

    auto authenticationToken = decoder.decode<String>();
    if (!authenticationToken)
        return std::nullopt;

    return {
        WebCore::ApplePayPaymentOrderDetails {
            WTFMove(*orderTypeIdentifier),
            WTFMove(*orderIdentifier),
            WTFMove(*webServiceURL),
            WTFMove(*authenticationToken)
        }
    };
}

#endif

#if ENABLE(APPLE_PAY_AMS_UI) && ENABLE(PAYMENT_REQUEST)

void ArgumentCoder<WebCore::ApplePayAMSUIRequest>::encode(Encoder& encoder, const WebCore::ApplePayAMSUIRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.engagementRequest)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayAMSUIRequest, engagementRequest)
    >::value);
    encoder << instance.engagementRequest;
}

std::optional<WebCore::ApplePayAMSUIRequest> ArgumentCoder<WebCore::ApplePayAMSUIRequest>::decode(Decoder& decoder)
{
    auto engagementRequest = decoder.decode<String>();
    if (!engagementRequest)
        return std::nullopt;

    return {
        WebCore::ApplePayAMSUIRequest {
            WTFMove(*engagementRequest)
        }
    };
}

#endif

#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)

void ArgumentCoder<WebCore::ApplePayAutomaticReloadPaymentRequest>::encode(Encoder& encoder, const WebCore::ApplePayAutomaticReloadPaymentRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.paymentDescription)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.automaticReloadBilling)>, WebCore::ApplePayLineItem>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.billingAgreement)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.managementURL)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tokenNotificationURL)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayAutomaticReloadPaymentRequest, paymentDescription)
        , offsetof(WebCore::ApplePayAutomaticReloadPaymentRequest, automaticReloadBilling)
        , offsetof(WebCore::ApplePayAutomaticReloadPaymentRequest, billingAgreement)
        , offsetof(WebCore::ApplePayAutomaticReloadPaymentRequest, managementURL)
        , offsetof(WebCore::ApplePayAutomaticReloadPaymentRequest, tokenNotificationURL)
    >::value);
    encoder << instance.paymentDescription;
    encoder << instance.automaticReloadBilling;
    encoder << instance.billingAgreement;
    encoder << instance.managementURL;
    encoder << instance.tokenNotificationURL;
}

std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest> ArgumentCoder<WebCore::ApplePayAutomaticReloadPaymentRequest>::decode(Decoder& decoder)
{
    auto paymentDescription = decoder.decode<String>();
    if (!paymentDescription)
        return std::nullopt;

    auto automaticReloadBilling = decoder.decode<WebCore::ApplePayLineItem>();
    if (!automaticReloadBilling)
        return std::nullopt;

    auto billingAgreement = decoder.decode<String>();
    if (!billingAgreement)
        return std::nullopt;

    auto managementURL = decoder.decode<String>();
    if (!managementURL)
        return std::nullopt;

    auto tokenNotificationURL = decoder.decode<String>();
    if (!tokenNotificationURL)
        return std::nullopt;

    return {
        WebCore::ApplePayAutomaticReloadPaymentRequest {
            WTFMove(*paymentDescription),
            WTFMove(*automaticReloadBilling),
            WTFMove(*billingAgreement),
            WTFMove(*managementURL),
            WTFMove(*tokenNotificationURL)
        }
    };
}

#endif

#if ENABLE(APPLE_PAY_SHIPPING_METHOD_DATE_COMPONENTS_RANGE)

void ArgumentCoder<WebCore::ApplePayDateComponents>::encode(Encoder& encoder, const WebCore::ApplePayDateComponents& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.years)>, std::optional<unsigned>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.months)>, std::optional<unsigned>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.days)>, std::optional<unsigned>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hours)>, std::optional<unsigned>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayDateComponents, years)
        , offsetof(WebCore::ApplePayDateComponents, months)
        , offsetof(WebCore::ApplePayDateComponents, days)
        , offsetof(WebCore::ApplePayDateComponents, hours)
    >::value);
    encoder << instance.years;
    encoder << instance.months;
    encoder << instance.days;
    encoder << instance.hours;
}

std::optional<WebCore::ApplePayDateComponents> ArgumentCoder<WebCore::ApplePayDateComponents>::decode(Decoder& decoder)
{
    auto years = decoder.decode<std::optional<unsigned>>();
    if (!years)
        return std::nullopt;

    auto months = decoder.decode<std::optional<unsigned>>();
    if (!months)
        return std::nullopt;

    auto days = decoder.decode<std::optional<unsigned>>();
    if (!days)
        return std::nullopt;

    auto hours = decoder.decode<std::optional<unsigned>>();
    if (!hours)
        return std::nullopt;

    return {
        WebCore::ApplePayDateComponents {
            WTFMove(*years),
            WTFMove(*months),
            WTFMove(*days),
            WTFMove(*hours)
        }
    };
}

#endif

#if ENABLE(APPLE_PAY_SHIPPING_METHOD_DATE_COMPONENTS_RANGE)

void ArgumentCoder<WebCore::ApplePayDateComponentsRange>::encode(Encoder& encoder, const WebCore::ApplePayDateComponentsRange& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startDateComponents)>, WebCore::ApplePayDateComponents>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endDateComponents)>, WebCore::ApplePayDateComponents>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayDateComponentsRange, startDateComponents)
        , offsetof(WebCore::ApplePayDateComponentsRange, endDateComponents)
    >::value);
    encoder << instance.startDateComponents;
    encoder << instance.endDateComponents;
}

std::optional<WebCore::ApplePayDateComponentsRange> ArgumentCoder<WebCore::ApplePayDateComponentsRange>::decode(Decoder& decoder)
{
    auto startDateComponents = decoder.decode<WebCore::ApplePayDateComponents>();
    if (!startDateComponents)
        return std::nullopt;

    auto endDateComponents = decoder.decode<WebCore::ApplePayDateComponents>();
    if (!endDateComponents)
        return std::nullopt;

    return {
        WebCore::ApplePayDateComponentsRange {
            WTFMove(*startDateComponents),
            WTFMove(*endDateComponents)
        }
    };
}

#endif

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayLineItem>::encode(Encoder& encoder, const WebCore::ApplePayLineItem& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ApplePayLineItem::Type>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.amount)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.paymentTiming)>, WebCore::ApplePayPaymentTiming>);
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.recurringPaymentStartDate)>, WallTime>);
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.recurringPaymentIntervalUnit)>, WebCore::ApplePayRecurringPaymentDateUnit>);
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.recurringPaymentIntervalCount)>, unsigned>);
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.recurringPaymentEndDate)>, WallTime>);
#endif
#if ENABLE(APPLE_PAY_DEFERRED_LINE_ITEM)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.deferredPaymentDate)>, WallTime>);
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_LINE_ITEM)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.automaticReloadPaymentThresholdAmount)>, String>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayLineItem, type)
        , offsetof(WebCore::ApplePayLineItem, label)
        , offsetof(WebCore::ApplePayLineItem, amount)
        , offsetof(WebCore::ApplePayLineItem, paymentTiming)
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
        , offsetof(WebCore::ApplePayLineItem, recurringPaymentStartDate)
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
        , offsetof(WebCore::ApplePayLineItem, recurringPaymentIntervalUnit)
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
        , offsetof(WebCore::ApplePayLineItem, recurringPaymentIntervalCount)
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
        , offsetof(WebCore::ApplePayLineItem, recurringPaymentEndDate)
#endif
#if ENABLE(APPLE_PAY_DEFERRED_LINE_ITEM)
        , offsetof(WebCore::ApplePayLineItem, deferredPaymentDate)
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_LINE_ITEM)
        , offsetof(WebCore::ApplePayLineItem, automaticReloadPaymentThresholdAmount)
#endif
    >::value);
    encoder << instance.type;
    encoder << instance.label;
    encoder << instance.amount;
    encoder << instance.paymentTiming;
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    encoder << instance.recurringPaymentStartDate;
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    encoder << instance.recurringPaymentIntervalUnit;
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    encoder << instance.recurringPaymentIntervalCount;
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    encoder << instance.recurringPaymentEndDate;
#endif
#if ENABLE(APPLE_PAY_DEFERRED_LINE_ITEM)
    encoder << instance.deferredPaymentDate;
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_LINE_ITEM)
    encoder << instance.automaticReloadPaymentThresholdAmount;
#endif
}

std::optional<WebCore::ApplePayLineItem> ArgumentCoder<WebCore::ApplePayLineItem>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::ApplePayLineItem::Type>();
    if (!type)
        return std::nullopt;

    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto amount = decoder.decode<String>();
    if (!amount)
        return std::nullopt;

    auto paymentTiming = decoder.decode<WebCore::ApplePayPaymentTiming>();
    if (!paymentTiming)
        return std::nullopt;

#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    auto recurringPaymentStartDate = decoder.decode<WallTime>();
    if (!recurringPaymentStartDate)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    auto recurringPaymentIntervalUnit = decoder.decode<WebCore::ApplePayRecurringPaymentDateUnit>();
    if (!recurringPaymentIntervalUnit)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    auto recurringPaymentIntervalCount = decoder.decode<unsigned>();
    if (!recurringPaymentIntervalCount)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
    auto recurringPaymentEndDate = decoder.decode<WallTime>();
    if (!recurringPaymentEndDate)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_DEFERRED_LINE_ITEM)
    auto deferredPaymentDate = decoder.decode<WallTime>();
    if (!deferredPaymentDate)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_LINE_ITEM)
    auto automaticReloadPaymentThresholdAmount = decoder.decode<String>();
    if (!automaticReloadPaymentThresholdAmount)
        return std::nullopt;
#endif

    return {
        WebCore::ApplePayLineItem {
            WTFMove(*type),
            WTFMove(*label),
            WTFMove(*amount),
            WTFMove(*paymentTiming),
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
            WTFMove(*recurringPaymentStartDate),
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
            WTFMove(*recurringPaymentIntervalUnit),
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
            WTFMove(*recurringPaymentIntervalCount),
#endif
#if ENABLE(APPLE_PAY_RECURRING_LINE_ITEM)
            WTFMove(*recurringPaymentEndDate),
#endif
#if ENABLE(APPLE_PAY_DEFERRED_LINE_ITEM)
            WTFMove(*deferredPaymentDate),
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_LINE_ITEM)
            WTFMove(*automaticReloadPaymentThresholdAmount)
#endif
        }
    };
}

#endif

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayShippingMethod>::encode(Encoder& encoder, const WebCore::ApplePayShippingMethod& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.detail)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.amount)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, String>);
#if ENABLE(APPLE_PAY_SHIPPING_METHOD_DATE_COMPONENTS_RANGE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dateComponentsRange)>, std::optional<WebCore::ApplePayDateComponentsRange>>);
#endif
#if ENABLE(APPLE_PAY_SELECTED_SHIPPING_METHOD)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selected)>, bool>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayShippingMethod, label)
        , offsetof(WebCore::ApplePayShippingMethod, detail)
        , offsetof(WebCore::ApplePayShippingMethod, amount)
        , offsetof(WebCore::ApplePayShippingMethod, identifier)
#if ENABLE(APPLE_PAY_SHIPPING_METHOD_DATE_COMPONENTS_RANGE)
        , offsetof(WebCore::ApplePayShippingMethod, dateComponentsRange)
#endif
#if ENABLE(APPLE_PAY_SELECTED_SHIPPING_METHOD)
        , offsetof(WebCore::ApplePayShippingMethod, selected)
#endif
    >::value);
    encoder << instance.label;
    encoder << instance.detail;
    encoder << instance.amount;
    encoder << instance.identifier;
#if ENABLE(APPLE_PAY_SHIPPING_METHOD_DATE_COMPONENTS_RANGE)
    encoder << instance.dateComponentsRange;
#endif
#if ENABLE(APPLE_PAY_SELECTED_SHIPPING_METHOD)
    encoder << instance.selected;
#endif
}

std::optional<WebCore::ApplePayShippingMethod> ArgumentCoder<WebCore::ApplePayShippingMethod>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto detail = decoder.decode<String>();
    if (!detail)
        return std::nullopt;

    auto amount = decoder.decode<String>();
    if (!amount)
        return std::nullopt;

    auto identifier = decoder.decode<String>();
    if (!identifier)
        return std::nullopt;

#if ENABLE(APPLE_PAY_SHIPPING_METHOD_DATE_COMPONENTS_RANGE)
    auto dateComponentsRange = decoder.decode<std::optional<WebCore::ApplePayDateComponentsRange>>();
    if (!dateComponentsRange)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_SELECTED_SHIPPING_METHOD)
    auto selected = decoder.decode<bool>();
    if (!selected)
        return std::nullopt;
#endif

    return {
        WebCore::ApplePayShippingMethod {
            WTFMove(*label),
            WTFMove(*detail),
            WTFMove(*amount),
            WTFMove(*identifier),
#if ENABLE(APPLE_PAY_SHIPPING_METHOD_DATE_COMPONENTS_RANGE)
            WTFMove(*dateComponentsRange),
#endif
#if ENABLE(APPLE_PAY_SELECTED_SHIPPING_METHOD)
            WTFMove(*selected)
#endif
        }
    };
}

#endif

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayError>::encode(Encoder& encoder, const WebCore::ApplePayError& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.code())>, WebCore::ApplePayErrorCode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contactField())>, std::optional<WebCore::ApplePayErrorContactField>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message())>, String>);
    encoder << instance.code();
    encoder << instance.contactField();
    encoder << instance.message();
}

std::optional<Ref<WebCore::ApplePayError>> ArgumentCoder<WebCore::ApplePayError>::decode(Decoder& decoder)
{
    auto code = decoder.decode<WebCore::ApplePayErrorCode>();
    if (!code)
        return std::nullopt;

    auto contactField = decoder.decode<std::optional<WebCore::ApplePayErrorContactField>>();
    if (!contactField)
        return std::nullopt;

    auto message = decoder.decode<String>();
    if (!message)
        return std::nullopt;

    return {
        WebCore::ApplePayError::create(
            WTFMove(*code),
            WTFMove(*contactField),
            WTFMove(*message)
        )
    };
}

#endif

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayLogoSystemImage>::encode(Encoder& encoder, const WebCore::ApplePayLogoSystemImage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.applePayLogoStyle())>, WebCore::ApplePayLogoStyle>);
    encoder << instance.applePayLogoStyle();
}

void ArgumentCoder<WebCore::ApplePayLogoSystemImage>::encode(StreamConnectionEncoder& encoder, const WebCore::ApplePayLogoSystemImage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.applePayLogoStyle())>, WebCore::ApplePayLogoStyle>);
    encoder << instance.applePayLogoStyle();
}

std::optional<Ref<WebCore::ApplePayLogoSystemImage>> ArgumentCoder<WebCore::ApplePayLogoSystemImage>::decode(Decoder& decoder)
{
    auto applePayLogoStyle = decoder.decode<WebCore::ApplePayLogoStyle>();
    if (!applePayLogoStyle)
        return std::nullopt;

    return {
        WebCore::ApplePayLogoSystemImage::create(
            WTFMove(*applePayLogoStyle)
        )
    };
}

#endif

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayDetailsUpdateBase>::encode(Encoder& encoder, const WebCore::ApplePayDetailsUpdateBase& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newTotal)>, WebCore::ApplePayLineItem>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newLineItems)>, Vector<WebCore::ApplePayLineItem>>);
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newRecurringPaymentRequest)>, std::optional<WebCore::ApplePayRecurringPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newAutomaticReloadPaymentRequest)>, std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newMultiTokenContexts)>, std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newTotal)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newLineItems)
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newRecurringPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newAutomaticReloadPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newMultiTokenContexts)
#endif
    >::value);
    encoder << instance.newTotal;
    encoder << instance.newLineItems;
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    encoder << instance.newRecurringPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    encoder << instance.newAutomaticReloadPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    encoder << instance.newMultiTokenContexts;
#endif
}

std::optional<WebCore::ApplePayDetailsUpdateBase> ArgumentCoder<WebCore::ApplePayDetailsUpdateBase>::decode(Decoder& decoder)
{
    auto newTotal = decoder.decode<WebCore::ApplePayLineItem>();
    if (!newTotal)
        return std::nullopt;

    auto newLineItems = decoder.decode<Vector<WebCore::ApplePayLineItem>>();
    if (!newLineItems)
        return std::nullopt;

#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    auto newRecurringPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayRecurringPaymentRequest>>();
    if (!newRecurringPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    auto newAutomaticReloadPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>();
    if (!newAutomaticReloadPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    auto newMultiTokenContexts = decoder.decode<std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>();
    if (!newMultiTokenContexts)
        return std::nullopt;
#endif

    return {
        WebCore::ApplePayDetailsUpdateBase {
            WTFMove(*newTotal),
            WTFMove(*newLineItems),
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
            WTFMove(*newRecurringPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
            WTFMove(*newAutomaticReloadPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
            WTFMove(*newMultiTokenContexts)
#endif
        }
    };
}

#endif

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayPaymentMethodUpdate>::encode(Encoder& encoder, const WebCore::ApplePayPaymentMethodUpdate& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newTotal)>, WebCore::ApplePayLineItem>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newLineItems)>, Vector<WebCore::ApplePayLineItem>>);
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newRecurringPaymentRequest)>, std::optional<WebCore::ApplePayRecurringPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newAutomaticReloadPaymentRequest)>, std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newMultiTokenContexts)>, std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newTotal)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newLineItems)
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newRecurringPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newAutomaticReloadPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newMultiTokenContexts)
#endif
    >::value);
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.errors)>, Vector<RefPtr<WebCore::ApplePayError>>>);
#endif
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newShippingMethods)>, Vector<WebCore::ApplePayShippingMethod>>);
#endif
#if ENABLE(APPLE_PAY_INSTALLMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.installmentGroupIdentifier)>, String>);
#endif
    static_assert(MembersInCorrectOrder<0
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
        , offsetof(WebCore::ApplePayPaymentMethodUpdate, errors)
#endif
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
        , offsetof(WebCore::ApplePayPaymentMethodUpdate, newShippingMethods)
#endif
#if ENABLE(APPLE_PAY_INSTALLMENTS)
        , offsetof(WebCore::ApplePayPaymentMethodUpdate, installmentGroupIdentifier)
#endif
    >::value);
    encoder << instance.newTotal;
    encoder << instance.newLineItems;
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    encoder << instance.newRecurringPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    encoder << instance.newAutomaticReloadPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    encoder << instance.newMultiTokenContexts;
#endif
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
    encoder << instance.errors;
#endif
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
    encoder << instance.newShippingMethods;
#endif
#if ENABLE(APPLE_PAY_INSTALLMENTS)
    encoder << instance.installmentGroupIdentifier;
#endif
}

std::optional<WebCore::ApplePayPaymentMethodUpdate> ArgumentCoder<WebCore::ApplePayPaymentMethodUpdate>::decode(Decoder& decoder)
{
    auto newTotal = decoder.decode<WebCore::ApplePayLineItem>();
    if (!newTotal)
        return std::nullopt;

    auto newLineItems = decoder.decode<Vector<WebCore::ApplePayLineItem>>();
    if (!newLineItems)
        return std::nullopt;

#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    auto newRecurringPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayRecurringPaymentRequest>>();
    if (!newRecurringPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    auto newAutomaticReloadPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>();
    if (!newAutomaticReloadPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    auto newMultiTokenContexts = decoder.decode<std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>();
    if (!newMultiTokenContexts)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
    auto errors = decoder.decode<Vector<RefPtr<WebCore::ApplePayError>>>();
    if (!errors)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
    auto newShippingMethods = decoder.decode<Vector<WebCore::ApplePayShippingMethod>>();
    if (!newShippingMethods)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_INSTALLMENTS)
    auto installmentGroupIdentifier = decoder.decode<String>();
    if (!installmentGroupIdentifier)
        return std::nullopt;
#endif

    return {
        WebCore::ApplePayPaymentMethodUpdate {
            WebCore::ApplePayDetailsUpdateBase {
                WTFMove(*newTotal),
                WTFMove(*newLineItems),
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
                WTFMove(*newRecurringPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
                WTFMove(*newAutomaticReloadPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
                WTFMove(*newMultiTokenContexts)
#endif
            },
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
            WTFMove(*errors),
#endif
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
            WTFMove(*newShippingMethods),
#endif
#if ENABLE(APPLE_PAY_INSTALLMENTS)
            WTFMove(*installmentGroupIdentifier)
#endif
        }
    };
}

#endif

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayShippingContactUpdate>::encode(Encoder& encoder, const WebCore::ApplePayShippingContactUpdate& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newTotal)>, WebCore::ApplePayLineItem>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newLineItems)>, Vector<WebCore::ApplePayLineItem>>);
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newRecurringPaymentRequest)>, std::optional<WebCore::ApplePayRecurringPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newAutomaticReloadPaymentRequest)>, std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newMultiTokenContexts)>, std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newTotal)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newLineItems)
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newRecurringPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newAutomaticReloadPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newMultiTokenContexts)
#endif
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.errors)>, Vector<RefPtr<WebCore::ApplePayError>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newShippingMethods)>, Vector<WebCore::ApplePayShippingMethod>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayShippingContactUpdate, errors)
        , offsetof(WebCore::ApplePayShippingContactUpdate, newShippingMethods)
    >::value);
    encoder << instance.newTotal;
    encoder << instance.newLineItems;
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    encoder << instance.newRecurringPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    encoder << instance.newAutomaticReloadPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    encoder << instance.newMultiTokenContexts;
#endif
    encoder << instance.errors;
    encoder << instance.newShippingMethods;
}

std::optional<WebCore::ApplePayShippingContactUpdate> ArgumentCoder<WebCore::ApplePayShippingContactUpdate>::decode(Decoder& decoder)
{
    auto newTotal = decoder.decode<WebCore::ApplePayLineItem>();
    if (!newTotal)
        return std::nullopt;

    auto newLineItems = decoder.decode<Vector<WebCore::ApplePayLineItem>>();
    if (!newLineItems)
        return std::nullopt;

#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    auto newRecurringPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayRecurringPaymentRequest>>();
    if (!newRecurringPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    auto newAutomaticReloadPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>();
    if (!newAutomaticReloadPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    auto newMultiTokenContexts = decoder.decode<std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>();
    if (!newMultiTokenContexts)
        return std::nullopt;
#endif

    auto errors = decoder.decode<Vector<RefPtr<WebCore::ApplePayError>>>();
    if (!errors)
        return std::nullopt;

    auto newShippingMethods = decoder.decode<Vector<WebCore::ApplePayShippingMethod>>();
    if (!newShippingMethods)
        return std::nullopt;

    return {
        WebCore::ApplePayShippingContactUpdate {
            WebCore::ApplePayDetailsUpdateBase {
                WTFMove(*newTotal),
                WTFMove(*newLineItems),
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
                WTFMove(*newRecurringPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
                WTFMove(*newAutomaticReloadPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
                WTFMove(*newMultiTokenContexts)
#endif
            },
            WTFMove(*errors),
            WTFMove(*newShippingMethods)
        }
    };
}

#endif

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayShippingMethodUpdate>::encode(Encoder& encoder, const WebCore::ApplePayShippingMethodUpdate& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newTotal)>, WebCore::ApplePayLineItem>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newLineItems)>, Vector<WebCore::ApplePayLineItem>>);
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newRecurringPaymentRequest)>, std::optional<WebCore::ApplePayRecurringPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newAutomaticReloadPaymentRequest)>, std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newMultiTokenContexts)>, std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newTotal)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newLineItems)
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newRecurringPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newAutomaticReloadPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newMultiTokenContexts)
#endif
    >::value);
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newShippingMethods)>, Vector<WebCore::ApplePayShippingMethod>>);
#endif
    static_assert(MembersInCorrectOrder<0
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
        , offsetof(WebCore::ApplePayShippingMethodUpdate, newShippingMethods)
#endif
    >::value);
    encoder << instance.newTotal;
    encoder << instance.newLineItems;
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    encoder << instance.newRecurringPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    encoder << instance.newAutomaticReloadPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    encoder << instance.newMultiTokenContexts;
#endif
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
    encoder << instance.newShippingMethods;
#endif
}

std::optional<WebCore::ApplePayShippingMethodUpdate> ArgumentCoder<WebCore::ApplePayShippingMethodUpdate>::decode(Decoder& decoder)
{
    auto newTotal = decoder.decode<WebCore::ApplePayLineItem>();
    if (!newTotal)
        return std::nullopt;

    auto newLineItems = decoder.decode<Vector<WebCore::ApplePayLineItem>>();
    if (!newLineItems)
        return std::nullopt;

#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    auto newRecurringPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayRecurringPaymentRequest>>();
    if (!newRecurringPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    auto newAutomaticReloadPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>();
    if (!newAutomaticReloadPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    auto newMultiTokenContexts = decoder.decode<std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>();
    if (!newMultiTokenContexts)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
    auto newShippingMethods = decoder.decode<Vector<WebCore::ApplePayShippingMethod>>();
    if (!newShippingMethods)
        return std::nullopt;
#endif

    return {
        WebCore::ApplePayShippingMethodUpdate {
            WebCore::ApplePayDetailsUpdateBase {
                WTFMove(*newTotal),
                WTFMove(*newLineItems),
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
                WTFMove(*newRecurringPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
                WTFMove(*newAutomaticReloadPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
                WTFMove(*newMultiTokenContexts)
#endif
            },
#if ENABLE(APPLE_PAY_UPDATE_SHIPPING_METHODS_WHEN_CHANGING_LINE_ITEMS)
            WTFMove(*newShippingMethods)
#endif
        }
    };
}

#endif

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayPaymentAuthorizationResult>::encode(Encoder& encoder, const WebCore::ApplePayPaymentAuthorizationResult& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.status)>, unsigned short>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.errors)>, Vector<RefPtr<WebCore::ApplePayError>>>);
#if ENABLE(APPLE_PAY_PAYMENT_ORDER_DETAILS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.orderDetails)>, std::optional<WebCore::ApplePayPaymentOrderDetails>>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayPaymentAuthorizationResult, status)
        , offsetof(WebCore::ApplePayPaymentAuthorizationResult, errors)
#if ENABLE(APPLE_PAY_PAYMENT_ORDER_DETAILS)
        , offsetof(WebCore::ApplePayPaymentAuthorizationResult, orderDetails)
#endif
    >::value);
    encoder << instance.status;
    encoder << instance.errors;
#if ENABLE(APPLE_PAY_PAYMENT_ORDER_DETAILS)
    encoder << instance.orderDetails;
#endif
}

std::optional<WebCore::ApplePayPaymentAuthorizationResult> ArgumentCoder<WebCore::ApplePayPaymentAuthorizationResult>::decode(Decoder& decoder)
{
    auto status = decoder.decode<unsigned short>();
    if (!status)
        return std::nullopt;

    auto errors = decoder.decode<Vector<RefPtr<WebCore::ApplePayError>>>();
    if (!errors)
        return std::nullopt;

#if ENABLE(APPLE_PAY_PAYMENT_ORDER_DETAILS)
    auto orderDetails = decoder.decode<std::optional<WebCore::ApplePayPaymentOrderDetails>>();
    if (!orderDetails)
        return std::nullopt;
#endif

    return {
        WebCore::ApplePayPaymentAuthorizationResult {
            WTFMove(*status),
            WTFMove(*errors),
#if ENABLE(APPLE_PAY_PAYMENT_ORDER_DETAILS)
            WTFMove(*orderDetails)
#endif
        }
    };
}

#endif

#if ENABLE(APPLE_PAY_COUPON_CODE)

void ArgumentCoder<WebCore::ApplePayCouponCodeUpdate>::encode(Encoder& encoder, const WebCore::ApplePayCouponCodeUpdate& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newTotal)>, WebCore::ApplePayLineItem>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newLineItems)>, Vector<WebCore::ApplePayLineItem>>);
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newRecurringPaymentRequest)>, std::optional<WebCore::ApplePayRecurringPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newAutomaticReloadPaymentRequest)>, std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>);
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newMultiTokenContexts)>, std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newTotal)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newLineItems)
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newRecurringPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newAutomaticReloadPaymentRequest)
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
        , offsetof(WebCore::ApplePayDetailsUpdateBase, newMultiTokenContexts)
#endif
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.errors)>, Vector<RefPtr<WebCore::ApplePayError>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.newShippingMethods)>, Vector<WebCore::ApplePayShippingMethod>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplePayCouponCodeUpdate, errors)
        , offsetof(WebCore::ApplePayCouponCodeUpdate, newShippingMethods)
    >::value);
    encoder << instance.newTotal;
    encoder << instance.newLineItems;
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    encoder << instance.newRecurringPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    encoder << instance.newAutomaticReloadPaymentRequest;
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    encoder << instance.newMultiTokenContexts;
#endif
    encoder << instance.errors;
    encoder << instance.newShippingMethods;
}

std::optional<WebCore::ApplePayCouponCodeUpdate> ArgumentCoder<WebCore::ApplePayCouponCodeUpdate>::decode(Decoder& decoder)
{
    auto newTotal = decoder.decode<WebCore::ApplePayLineItem>();
    if (!newTotal)
        return std::nullopt;

    auto newLineItems = decoder.decode<Vector<WebCore::ApplePayLineItem>>();
    if (!newLineItems)
        return std::nullopt;

#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
    auto newRecurringPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayRecurringPaymentRequest>>();
    if (!newRecurringPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
    auto newAutomaticReloadPaymentRequest = decoder.decode<std::optional<WebCore::ApplePayAutomaticReloadPaymentRequest>>();
    if (!newAutomaticReloadPaymentRequest)
        return std::nullopt;
#endif

#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
    auto newMultiTokenContexts = decoder.decode<std::optional<Vector<WebCore::ApplePayPaymentTokenContext>>>();
    if (!newMultiTokenContexts)
        return std::nullopt;
#endif

    auto errors = decoder.decode<Vector<RefPtr<WebCore::ApplePayError>>>();
    if (!errors)
        return std::nullopt;

    auto newShippingMethods = decoder.decode<Vector<WebCore::ApplePayShippingMethod>>();
    if (!newShippingMethods)
        return std::nullopt;

    return {
        WebCore::ApplePayCouponCodeUpdate {
            WebCore::ApplePayDetailsUpdateBase {
                WTFMove(*newTotal),
                WTFMove(*newLineItems),
#if ENABLE(APPLE_PAY_RECURRING_PAYMENTS)
                WTFMove(*newRecurringPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_AUTOMATIC_RELOAD_PAYMENTS)
                WTFMove(*newAutomaticReloadPaymentRequest),
#endif
#if ENABLE(APPLE_PAY_MULTI_MERCHANT_PAYMENTS)
                WTFMove(*newMultiTokenContexts)
#endif
            },
            WTFMove(*errors),
            WTFMove(*newShippingMethods)
        }
    };
}

#endif

#if ENABLE(APPLICATION_MANIFEST)

void ArgumentCoder<WebCore::ApplicationManifest::Icon>::encode(Encoder& encoder, const WebCore::ApplicationManifest::Icon& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.src)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sizes)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.purposes)>, OptionSet<WebCore::ApplicationManifest::Icon::Purpose>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplicationManifest::Icon, src)
        , offsetof(WebCore::ApplicationManifest::Icon, sizes)
        , offsetof(WebCore::ApplicationManifest::Icon, type)
        , offsetof(WebCore::ApplicationManifest::Icon, purposes)
    >::value);
    encoder << instance.src;
    encoder << instance.sizes;
    encoder << instance.type;
    encoder << instance.purposes;
}

std::optional<WebCore::ApplicationManifest::Icon> ArgumentCoder<WebCore::ApplicationManifest::Icon>::decode(Decoder& decoder)
{
    auto src = decoder.decode<URL>();
    if (!src)
        return std::nullopt;

    auto sizes = decoder.decode<Vector<String>>();
    if (!sizes)
        return std::nullopt;

    auto type = decoder.decode<String>();
    if (!type)
        return std::nullopt;

    auto purposes = decoder.decode<OptionSet<WebCore::ApplicationManifest::Icon::Purpose>>();
    if (!purposes)
        return std::nullopt;

    return {
        WebCore::ApplicationManifest::Icon {
            WTFMove(*src),
            WTFMove(*sizes),
            WTFMove(*type),
            WTFMove(*purposes)
        }
    };
}

#endif

#if ENABLE(APPLICATION_MANIFEST)

void ArgumentCoder<WebCore::ApplicationManifest>::encode(Encoder& encoder, const WebCore::ApplicationManifest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shortName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.description)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scope)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.display)>, WebCore::ApplicationManifest::Display>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.id)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.themeColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.icons)>, Vector<WebCore::ApplicationManifest::Icon>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ApplicationManifest, name)
        , offsetof(WebCore::ApplicationManifest, shortName)
        , offsetof(WebCore::ApplicationManifest, description)
        , offsetof(WebCore::ApplicationManifest, scope)
        , offsetof(WebCore::ApplicationManifest, display)
        , offsetof(WebCore::ApplicationManifest, startURL)
        , offsetof(WebCore::ApplicationManifest, id)
        , offsetof(WebCore::ApplicationManifest, themeColor)
        , offsetof(WebCore::ApplicationManifest, icons)
    >::value);
    encoder << instance.name;
    encoder << instance.shortName;
    encoder << instance.description;
    encoder << instance.scope;
    encoder << instance.display;
    encoder << instance.startURL;
    encoder << instance.id;
    encoder << instance.themeColor;
    encoder << instance.icons;
}

std::optional<WebCore::ApplicationManifest> ArgumentCoder<WebCore::ApplicationManifest>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto shortName = decoder.decode<String>();
    if (!shortName)
        return std::nullopt;

    auto description = decoder.decode<String>();
    if (!description)
        return std::nullopt;

    auto scope = decoder.decode<URL>();
    if (!scope)
        return std::nullopt;

    auto display = decoder.decode<WebCore::ApplicationManifest::Display>();
    if (!display)
        return std::nullopt;

    auto startURL = decoder.decode<URL>();
    if (!startURL)
        return std::nullopt;

    auto id = decoder.decode<URL>();
    if (!id)
        return std::nullopt;

    auto themeColor = decoder.decode<WebCore::Color>();
    if (!themeColor)
        return std::nullopt;

    auto icons = decoder.decode<Vector<WebCore::ApplicationManifest::Icon>>();
    if (!icons)
        return std::nullopt;

    return {
        WebCore::ApplicationManifest {
            WTFMove(*name),
            WTFMove(*shortName),
            WTFMove(*description),
            WTFMove(*scope),
            WTFMove(*display),
            WTFMove(*startURL),
            WTFMove(*id),
            WTFMove(*themeColor),
            WTFMove(*icons)
        }
    };
}

#endif


void ArgumentCoder<WebCore::RetrieveRecordsOptions>::encode(Encoder& encoder, const WebCore::RetrieveRecordsOptions& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.request)>, WebCore::ResourceRequest>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.crossOriginEmbedderPolicy)>, WebCore::CrossOriginEmbedderPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceOrigin)>, Ref<WebCore::SecurityOrigin>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ignoreSearch)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ignoreMethod)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ignoreVary)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldProvideResponse)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::RetrieveRecordsOptions, request)
        , offsetof(WebCore::RetrieveRecordsOptions, crossOriginEmbedderPolicy)
        , offsetof(WebCore::RetrieveRecordsOptions, sourceOrigin)
        , offsetof(WebCore::RetrieveRecordsOptions, ignoreSearch)
        , offsetof(WebCore::RetrieveRecordsOptions, ignoreMethod)
        , offsetof(WebCore::RetrieveRecordsOptions, ignoreVary)
        , offsetof(WebCore::RetrieveRecordsOptions, shouldProvideResponse)
    >::value);
    encoder << instance.request;
    encoder << instance.crossOriginEmbedderPolicy;
    encoder << instance.sourceOrigin;
    encoder << instance.ignoreSearch;
    encoder << instance.ignoreMethod;
    encoder << instance.ignoreVary;
    encoder << instance.shouldProvideResponse;
}

std::optional<WebCore::RetrieveRecordsOptions> ArgumentCoder<WebCore::RetrieveRecordsOptions>::decode(Decoder& decoder)
{
    auto request = decoder.decode<WebCore::ResourceRequest>();
    if (!request)
        return std::nullopt;

    auto crossOriginEmbedderPolicy = decoder.decode<WebCore::CrossOriginEmbedderPolicy>();
    if (!crossOriginEmbedderPolicy)
        return std::nullopt;

    auto sourceOrigin = decoder.decode<Ref<WebCore::SecurityOrigin>>();
    if (!sourceOrigin)
        return std::nullopt;

    auto ignoreSearch = decoder.decode<bool>();
    if (!ignoreSearch)
        return std::nullopt;

    auto ignoreMethod = decoder.decode<bool>();
    if (!ignoreMethod)
        return std::nullopt;

    auto ignoreVary = decoder.decode<bool>();
    if (!ignoreVary)
        return std::nullopt;

    auto shouldProvideResponse = decoder.decode<bool>();
    if (!shouldProvideResponse)
        return std::nullopt;

    return {
        WebCore::RetrieveRecordsOptions {
            WTFMove(*request),
            WTFMove(*crossOriginEmbedderPolicy),
            WTFMove(*sourceOrigin),
            WTFMove(*ignoreSearch),
            WTFMove(*ignoreMethod),
            WTFMove(*ignoreVary),
            WTFMove(*shouldProvideResponse)
        }
    };
}


void ArgumentCoder<WebCore::ContactInfo>::encode(Encoder& encoder, const WebCore::ContactInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.email)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tel)>, Vector<String>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ContactInfo, name)
        , offsetof(WebCore::ContactInfo, email)
        , offsetof(WebCore::ContactInfo, tel)
    >::value);
    encoder << instance.name;
    encoder << instance.email;
    encoder << instance.tel;
}

std::optional<WebCore::ContactInfo> ArgumentCoder<WebCore::ContactInfo>::decode(Decoder& decoder)
{
    auto name = decoder.decode<Vector<String>>();
    if (!name)
        return std::nullopt;

    auto email = decoder.decode<Vector<String>>();
    if (!email)
        return std::nullopt;

    auto tel = decoder.decode<Vector<String>>();
    if (!tel)
        return std::nullopt;

    return {
        WebCore::ContactInfo {
            WTFMove(*name),
            WTFMove(*email),
            WTFMove(*tel)
        }
    };
}


void ArgumentCoder<WebCore::ContactsRequestData>::encode(Encoder& encoder, const WebCore::ContactsRequestData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.properties)>, Vector<WebCore::ContactProperty>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.multiple)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ContactsRequestData, properties)
        , offsetof(WebCore::ContactsRequestData, multiple)
        , offsetof(WebCore::ContactsRequestData, url)
    >::value);
    encoder << instance.properties;
    encoder << instance.multiple;
    encoder << instance.url;
}

std::optional<WebCore::ContactsRequestData> ArgumentCoder<WebCore::ContactsRequestData>::decode(Decoder& decoder)
{
    auto properties = decoder.decode<Vector<WebCore::ContactProperty>>();
    if (!properties)
        return std::nullopt;

    auto multiple = decoder.decode<bool>();
    if (!multiple)
        return std::nullopt;

    auto url = decoder.decode<String>();
    if (!url)
        return std::nullopt;

    return {
        WebCore::ContactsRequestData {
            WTFMove(*properties),
            WTFMove(*multiple),
            WTFMove(*url)
        }
    };
}

#if ENABLE(MEDIA_SESSION)

void ArgumentCoder<WebCore::MediaPositionState>::encode(Encoder& encoder, const WebCore::MediaPositionState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.duration)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.playbackRate)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position)>, double>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaPositionState, duration)
        , offsetof(WebCore::MediaPositionState, playbackRate)
        , offsetof(WebCore::MediaPositionState, position)
    >::value);
    encoder << instance.duration;
    encoder << instance.playbackRate;
    encoder << instance.position;
}

std::optional<WebCore::MediaPositionState> ArgumentCoder<WebCore::MediaPositionState>::decode(Decoder& decoder)
{
    auto duration = decoder.decode<double>();
    if (!duration)
        return std::nullopt;

    auto playbackRate = decoder.decode<double>();
    if (!playbackRate)
        return std::nullopt;

    auto position = decoder.decode<double>();
    if (!position)
        return std::nullopt;

    return {
        WebCore::MediaPositionState {
            WTFMove(*duration),
            WTFMove(*playbackRate),
            WTFMove(*position)
        }
    };
}

#endif

#if ENABLE(WEB_RTC)

void ArgumentCoder<WebCore::DetachedRTCDataChannel>::encode(Encoder& encoder, const WebCore::DetachedRTCDataChannel& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::RTCDataChannelIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.options)>, WebCore::RTCDataChannelInit>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.state)>, WebCore::RTCDataChannelState>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DetachedRTCDataChannel, identifier)
        , offsetof(WebCore::DetachedRTCDataChannel, label)
        , offsetof(WebCore::DetachedRTCDataChannel, options)
        , offsetof(WebCore::DetachedRTCDataChannel, state)
    >::value);
    encoder << instance.identifier;
    encoder << instance.label;
    encoder << instance.options;
    encoder << instance.state;
}

std::optional<WebCore::DetachedRTCDataChannel> ArgumentCoder<WebCore::DetachedRTCDataChannel>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::RTCDataChannelIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto options = decoder.decode<WebCore::RTCDataChannelInit>();
    if (!options)
        return std::nullopt;

    auto state = decoder.decode<WebCore::RTCDataChannelState>();
    if (!state)
        return std::nullopt;

    return {
        WebCore::DetachedRTCDataChannel {
            WTFMove(*identifier),
            WTFMove(*label),
            WTFMove(*options),
            WTFMove(*state)
        }
    };
}

#endif

#if ENABLE(WEB_CODECS)

void ArgumentCoder<WebCore::WebCodecsEncodedVideoChunkData>::encode(Encoder& encoder, const WebCore::WebCodecsEncodedVideoChunkData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::WebCodecsEncodedVideoChunkType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestamp)>, int64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.duration)>, std::optional<uint64_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buffer)>, Vector<uint8_t>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::WebCodecsEncodedVideoChunkData, type)
        , offsetof(WebCore::WebCodecsEncodedVideoChunkData, timestamp)
        , offsetof(WebCore::WebCodecsEncodedVideoChunkData, duration)
        , offsetof(WebCore::WebCodecsEncodedVideoChunkData, buffer)
    >::value);
    encoder << instance.type;
    encoder << instance.timestamp;
    encoder << instance.duration;
    encoder << instance.buffer;
}

std::optional<WebCore::WebCodecsEncodedVideoChunkData> ArgumentCoder<WebCore::WebCodecsEncodedVideoChunkData>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::WebCodecsEncodedVideoChunkType>();
    if (!type)
        return std::nullopt;

    auto timestamp = decoder.decode<int64_t>();
    if (!timestamp)
        return std::nullopt;

    auto duration = decoder.decode<std::optional<uint64_t>>();
    if (!duration)
        return std::nullopt;

    auto buffer = decoder.decode<Vector<uint8_t>>();
    if (!buffer)
        return std::nullopt;

    return {
        WebCore::WebCodecsEncodedVideoChunkData {
            WTFMove(*type),
            WTFMove(*timestamp),
            WTFMove(*duration),
            WTFMove(*buffer)
        }
    };
}

#endif


void ArgumentCoder<WebCore::HTMLModelElementCamera>::encode(Encoder& encoder, const WebCore::HTMLModelElementCamera& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pitch)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.yaw)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scale)>, double>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::HTMLModelElementCamera, pitch)
        , offsetof(WebCore::HTMLModelElementCamera, yaw)
        , offsetof(WebCore::HTMLModelElementCamera, scale)
    >::value);
    encoder << instance.pitch;
    encoder << instance.yaw;
    encoder << instance.scale;
}

std::optional<WebCore::HTMLModelElementCamera> ArgumentCoder<WebCore::HTMLModelElementCamera>::decode(Decoder& decoder)
{
    auto pitch = decoder.decode<double>();
    if (!pitch)
        return std::nullopt;

    auto yaw = decoder.decode<double>();
    if (!yaw)
        return std::nullopt;

    auto scale = decoder.decode<double>();
    if (!scale)
        return std::nullopt;

    return {
        WebCore::HTMLModelElementCamera {
            WTFMove(*pitch),
            WTFMove(*yaw),
            WTFMove(*scale)
        }
    };
}


void ArgumentCoder<WebCore::NotificationData>::encode(Encoder& encoder, const WebCore::NotificationData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.title)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.body)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.iconURL)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tag)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.language)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.direction)>, WebCore::NotificationDirection>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.originString)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.serviceWorkerRegistrationURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.notificationID)>, UUID>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contextIdentifier)>, WebCore::ScriptExecutionContextIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceSession)>, PAL::SessionID>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.creationTime)>, MonotonicTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data)>, Vector<uint8_t>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::NotificationData, title)
        , offsetof(WebCore::NotificationData, body)
        , offsetof(WebCore::NotificationData, iconURL)
        , offsetof(WebCore::NotificationData, tag)
        , offsetof(WebCore::NotificationData, language)
        , offsetof(WebCore::NotificationData, direction)
        , offsetof(WebCore::NotificationData, originString)
        , offsetof(WebCore::NotificationData, serviceWorkerRegistrationURL)
        , offsetof(WebCore::NotificationData, notificationID)
        , offsetof(WebCore::NotificationData, contextIdentifier)
        , offsetof(WebCore::NotificationData, sourceSession)
        , offsetof(WebCore::NotificationData, creationTime)
        , offsetof(WebCore::NotificationData, data)
    >::value);
    encoder << instance.title;
    encoder << instance.body;
    encoder << instance.iconURL;
    encoder << instance.tag;
    encoder << instance.language;
    encoder << instance.direction;
    encoder << instance.originString;
    encoder << instance.serviceWorkerRegistrationURL;
    encoder << instance.notificationID;
    encoder << instance.contextIdentifier;
    encoder << instance.sourceSession;
    encoder << instance.creationTime;
    encoder << instance.data;
}

std::optional<WebCore::NotificationData> ArgumentCoder<WebCore::NotificationData>::decode(Decoder& decoder)
{
    auto title = decoder.decode<String>();
    if (!title)
        return std::nullopt;

    auto body = decoder.decode<String>();
    if (!body)
        return std::nullopt;

    auto iconURL = decoder.decode<String>();
    if (!iconURL)
        return std::nullopt;

    auto tag = decoder.decode<String>();
    if (!tag)
        return std::nullopt;

    auto language = decoder.decode<String>();
    if (!language)
        return std::nullopt;

    auto direction = decoder.decode<WebCore::NotificationDirection>();
    if (!direction)
        return std::nullopt;

    auto originString = decoder.decode<String>();
    if (!originString)
        return std::nullopt;

    auto serviceWorkerRegistrationURL = decoder.decode<URL>();
    if (!serviceWorkerRegistrationURL)
        return std::nullopt;

    auto notificationID = decoder.decode<UUID>();
    if (!notificationID)
        return std::nullopt;

    auto contextIdentifier = decoder.decode<WebCore::ScriptExecutionContextIdentifier>();
    if (!contextIdentifier)
        return std::nullopt;

    auto sourceSession = decoder.decode<PAL::SessionID>();
    if (!sourceSession)
        return std::nullopt;

    auto creationTime = decoder.decode<MonotonicTime>();
    if (!creationTime)
        return std::nullopt;

    auto data = decoder.decode<Vector<uint8_t>>();
    if (!data)
        return std::nullopt;

    return {
        WebCore::NotificationData {
            WTFMove(*title),
            WTFMove(*body),
            WTFMove(*iconURL),
            WTFMove(*tag),
            WTFMove(*language),
            WTFMove(*direction),
            WTFMove(*originString),
            WTFMove(*serviceWorkerRegistrationURL),
            WTFMove(*notificationID),
            WTFMove(*contextIdentifier),
            WTFMove(*sourceSession),
            WTFMove(*creationTime),
            WTFMove(*data)
        }
    };
}


void ArgumentCoder<WebCore::PermissionDescriptor>::encode(Encoder& encoder, const WebCore::PermissionDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, WebCore::PermissionName>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PermissionDescriptor, name)
    >::value);
    encoder << instance.name;
}

std::optional<WebCore::PermissionDescriptor> ArgumentCoder<WebCore::PermissionDescriptor>::decode(Decoder& decoder)
{
    auto name = decoder.decode<WebCore::PermissionName>();
    if (!name)
        return std::nullopt;

    return {
        WebCore::PermissionDescriptor {
            WTFMove(*name)
        }
    };
}

#if ENABLE(SERVICE_WORKER)

void ArgumentCoder<WebCore::PushSubscriptionData>::encode(Encoder& encoder, const WebCore::PushSubscriptionData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::PushSubscriptionIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endpoint)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.expirationTime)>, std::optional<WebCore::EpochTimeStamp>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.serverVAPIDPublicKey)>, Vector<uint8_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientECDHPublicKey)>, Vector<uint8_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sharedAuthenticationSecret)>, Vector<uint8_t>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PushSubscriptionData, identifier)
        , offsetof(WebCore::PushSubscriptionData, endpoint)
        , offsetof(WebCore::PushSubscriptionData, expirationTime)
        , offsetof(WebCore::PushSubscriptionData, serverVAPIDPublicKey)
        , offsetof(WebCore::PushSubscriptionData, clientECDHPublicKey)
        , offsetof(WebCore::PushSubscriptionData, sharedAuthenticationSecret)
    >::value);
    encoder << instance.identifier;
    encoder << instance.endpoint;
    encoder << instance.expirationTime;
    encoder << instance.serverVAPIDPublicKey;
    encoder << instance.clientECDHPublicKey;
    encoder << instance.sharedAuthenticationSecret;
}

std::optional<WebCore::PushSubscriptionData> ArgumentCoder<WebCore::PushSubscriptionData>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::PushSubscriptionIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto endpoint = decoder.decode<String>();
    if (!endpoint)
        return std::nullopt;

    auto expirationTime = decoder.decode<std::optional<WebCore::EpochTimeStamp>>();
    if (!expirationTime)
        return std::nullopt;

    auto serverVAPIDPublicKey = decoder.decode<Vector<uint8_t>>();
    if (!serverVAPIDPublicKey)
        return std::nullopt;

    auto clientECDHPublicKey = decoder.decode<Vector<uint8_t>>();
    if (!clientECDHPublicKey)
        return std::nullopt;

    auto sharedAuthenticationSecret = decoder.decode<Vector<uint8_t>>();
    if (!sharedAuthenticationSecret)
        return std::nullopt;

    return {
        WebCore::PushSubscriptionData {
            WTFMove(*identifier),
            WTFMove(*endpoint),
            WTFMove(*expirationTime),
            WTFMove(*serverVAPIDPublicKey),
            WTFMove(*clientECDHPublicKey),
            WTFMove(*sharedAuthenticationSecret)
        }
    };
}

#endif


void ArgumentCoder<WebCore::DeprecationReportBody>::encode(Encoder& encoder, const WebCore::DeprecationReportBody& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.id())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.anticipatedRemoval())>, WallTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceFile())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lineNumber())>, std::optional<unsigned>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.columnNumber())>, std::optional<unsigned>>);
    encoder << instance.id();
    encoder << instance.anticipatedRemoval();
    encoder << instance.message();
    encoder << instance.sourceFile();
    encoder << instance.lineNumber();
    encoder << instance.columnNumber();
}

std::optional<Ref<WebCore::DeprecationReportBody>> ArgumentCoder<WebCore::DeprecationReportBody>::decode(Decoder& decoder)
{
    auto id = decoder.decode<String>();
    if (!id)
        return std::nullopt;

    auto anticipatedRemoval = decoder.decode<WallTime>();
    if (!anticipatedRemoval)
        return std::nullopt;

    auto message = decoder.decode<String>();
    if (!message)
        return std::nullopt;

    auto sourceFile = decoder.decode<String>();
    if (!sourceFile)
        return std::nullopt;

    auto lineNumber = decoder.decode<std::optional<unsigned>>();
    if (!lineNumber)
        return std::nullopt;

    auto columnNumber = decoder.decode<std::optional<unsigned>>();
    if (!columnNumber)
        return std::nullopt;

    return {
        WebCore::DeprecationReportBody::create(
            WTFMove(*id),
            WTFMove(*anticipatedRemoval),
            WTFMove(*message),
            WTFMove(*sourceFile),
            WTFMove(*lineNumber),
            WTFMove(*columnNumber)
        )
    };
}


void ArgumentCoder<WebCore::Report>::encode(Encoder& encoder, const WebCore::Report& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.body())>, RefPtr<WebCore::ReportBody>>);
    encoder << instance.type();
    encoder << instance.url();
    encoder << instance.body();
}

std::optional<Ref<WebCore::Report>> ArgumentCoder<WebCore::Report>::decode(Decoder& decoder)
{
    auto type = decoder.decode<String>();
    if (!type)
        return std::nullopt;

    auto url = decoder.decode<String>();
    if (!url)
        return std::nullopt;

    auto body = decoder.decode<RefPtr<WebCore::ReportBody>>();
    if (!body)
        return std::nullopt;

    return {
        WebCore::Report::create(
            WTFMove(*type),
            WTFMove(*url),
            WTFMove(*body)
        )
    };
}


void ArgumentCoder<WebCore::TestReportBody>::encode(Encoder& encoder, const WebCore::TestReportBody& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message())>, String>);
    encoder << instance.message();
}

std::optional<Ref<WebCore::TestReportBody>> ArgumentCoder<WebCore::TestReportBody>::decode(Decoder& decoder)
{
    auto message = decoder.decode<String>();
    if (!message)
        return std::nullopt;

    return {
        WebCore::TestReportBody::create(
            WTFMove(*message)
        )
    };
}


void ArgumentCoder<WebCore::SpeechRecognitionError>::encode(Encoder& encoder, const WebCore::SpeechRecognitionError& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::SpeechRecognitionErrorType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SpeechRecognitionError, type)
        , offsetof(WebCore::SpeechRecognitionError, message)
    >::value);
    encoder << instance.type;
    encoder << instance.message;
}

std::optional<WebCore::SpeechRecognitionError> ArgumentCoder<WebCore::SpeechRecognitionError>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::SpeechRecognitionErrorType>();
    if (!type)
        return std::nullopt;

    auto message = decoder.decode<String>();
    if (!message)
        return std::nullopt;

    return {
        WebCore::SpeechRecognitionError {
            WTFMove(*type),
            WTFMove(*message)
        }
    };
}


void ArgumentCoder<WebCore::SpeechRecognitionRequestInfo>::encode(Encoder& encoder, const WebCore::SpeechRecognitionRequestInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientIdentifier)>, WebCore::SpeechRecognitionConnectionClientIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lang)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.continuous)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.interimResults)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxAlternatives)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientOrigin)>, WebCore::ClientOrigin>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameIdentifier)>, WebCore::FrameIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SpeechRecognitionRequestInfo, clientIdentifier)
        , offsetof(WebCore::SpeechRecognitionRequestInfo, lang)
        , offsetof(WebCore::SpeechRecognitionRequestInfo, continuous)
        , offsetof(WebCore::SpeechRecognitionRequestInfo, interimResults)
        , offsetof(WebCore::SpeechRecognitionRequestInfo, maxAlternatives)
        , offsetof(WebCore::SpeechRecognitionRequestInfo, clientOrigin)
        , offsetof(WebCore::SpeechRecognitionRequestInfo, frameIdentifier)
    >::value);
    encoder << instance.clientIdentifier;
    encoder << instance.lang;
    encoder << instance.continuous;
    encoder << instance.interimResults;
    encoder << instance.maxAlternatives;
    encoder << instance.clientOrigin;
    encoder << instance.frameIdentifier;
}

std::optional<WebCore::SpeechRecognitionRequestInfo> ArgumentCoder<WebCore::SpeechRecognitionRequestInfo>::decode(Decoder& decoder)
{
    auto clientIdentifier = decoder.decode<WebCore::SpeechRecognitionConnectionClientIdentifier>();
    if (!clientIdentifier)
        return std::nullopt;

    auto lang = decoder.decode<String>();
    if (!lang)
        return std::nullopt;

    auto continuous = decoder.decode<bool>();
    if (!continuous)
        return std::nullopt;

    auto interimResults = decoder.decode<bool>();
    if (!interimResults)
        return std::nullopt;

    auto maxAlternatives = decoder.decode<uint64_t>();
    if (!maxAlternatives)
        return std::nullopt;

    auto clientOrigin = decoder.decode<WebCore::ClientOrigin>();
    if (!clientOrigin)
        return std::nullopt;

    auto frameIdentifier = decoder.decode<WebCore::FrameIdentifier>();
    if (!frameIdentifier)
        return std::nullopt;

    return {
        WebCore::SpeechRecognitionRequestInfo {
            WTFMove(*clientIdentifier),
            WTFMove(*lang),
            WTFMove(*continuous),
            WTFMove(*interimResults),
            WTFMove(*maxAlternatives),
            WTFMove(*clientOrigin),
            WTFMove(*frameIdentifier)
        }
    };
}


void ArgumentCoder<WebCore::SpeechRecognitionAlternativeData>::encode(Encoder& encoder, const WebCore::SpeechRecognitionAlternativeData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.transcript)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.confidence)>, double>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SpeechRecognitionAlternativeData, transcript)
        , offsetof(WebCore::SpeechRecognitionAlternativeData, confidence)
    >::value);
    encoder << instance.transcript;
    encoder << instance.confidence;
}

std::optional<WebCore::SpeechRecognitionAlternativeData> ArgumentCoder<WebCore::SpeechRecognitionAlternativeData>::decode(Decoder& decoder)
{
    auto transcript = decoder.decode<String>();
    if (!transcript)
        return std::nullopt;

    auto confidence = decoder.decode<double>();
    if (!confidence)
        return std::nullopt;

    return {
        WebCore::SpeechRecognitionAlternativeData {
            WTFMove(*transcript),
            WTFMove(*confidence)
        }
    };
}


void ArgumentCoder<WebCore::SpeechRecognitionResultData>::encode(Encoder& encoder, const WebCore::SpeechRecognitionResultData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alternatives)>, Vector<WebCore::SpeechRecognitionAlternativeData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isFinal)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SpeechRecognitionResultData, alternatives)
        , offsetof(WebCore::SpeechRecognitionResultData, isFinal)
    >::value);
    encoder << instance.alternatives;
    encoder << instance.isFinal;
}

std::optional<WebCore::SpeechRecognitionResultData> ArgumentCoder<WebCore::SpeechRecognitionResultData>::decode(Decoder& decoder)
{
    auto alternatives = decoder.decode<Vector<WebCore::SpeechRecognitionAlternativeData>>();
    if (!alternatives)
        return std::nullopt;

    auto isFinal = decoder.decode<bool>();
    if (!isFinal)
        return std::nullopt;

    return {
        WebCore::SpeechRecognitionResultData {
            WTFMove(*alternatives),
            WTFMove(*isFinal)
        }
    };
}


void ArgumentCoder<WebCore::WebLockManagerSnapshot>::encode(Encoder& encoder, const WebCore::WebLockManagerSnapshot& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.held)>, Vector<WebCore::WebLockManagerSnapshot::Info>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pending)>, Vector<WebCore::WebLockManagerSnapshot::Info>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::WebLockManagerSnapshot, held)
        , offsetof(WebCore::WebLockManagerSnapshot, pending)
    >::value);
    encoder << instance.held;
    encoder << instance.pending;
}

std::optional<WebCore::WebLockManagerSnapshot> ArgumentCoder<WebCore::WebLockManagerSnapshot>::decode(Decoder& decoder)
{
    auto held = decoder.decode<Vector<WebCore::WebLockManagerSnapshot::Info>>();
    if (!held)
        return std::nullopt;

    auto pending = decoder.decode<Vector<WebCore::WebLockManagerSnapshot::Info>>();
    if (!pending)
        return std::nullopt;

    return {
        WebCore::WebLockManagerSnapshot {
            WTFMove(*held),
            WTFMove(*pending)
        }
    };
}


void ArgumentCoder<WebCore::WebLockManagerSnapshot::Info>::encode(Encoder& encoder, const WebCore::WebLockManagerSnapshot::Info& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mode)>, WebCore::WebLockMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientId)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::WebLockManagerSnapshot::Info, name)
        , offsetof(WebCore::WebLockManagerSnapshot::Info, mode)
        , offsetof(WebCore::WebLockManagerSnapshot::Info, clientId)
    >::value);
    encoder << instance.name;
    encoder << instance.mode;
    encoder << instance.clientId;
}

std::optional<WebCore::WebLockManagerSnapshot::Info> ArgumentCoder<WebCore::WebLockManagerSnapshot::Info>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto mode = decoder.decode<WebCore::WebLockMode>();
    if (!mode)
        return std::nullopt;

    auto clientId = decoder.decode<String>();
    if (!clientId)
        return std::nullopt;

    return {
        WebCore::WebLockManagerSnapshot::Info {
            WTFMove(*name),
            WTFMove(*mode),
            WTFMove(*clientId)
        }
    };
}

#if ENABLE(WEB_AUTHN)

void ArgumentCoder<WebCore::AuthenticationExtensionsClientInputs>::encode(Encoder& encoder, const WebCore::AuthenticationExtensionsClientInputs& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.appid)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.googleLegacyAppidSupport)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::AuthenticationExtensionsClientInputs, appid)
        , offsetof(WebCore::AuthenticationExtensionsClientInputs, googleLegacyAppidSupport)
    >::value);
    encoder << instance.appid;
    encoder << instance.googleLegacyAppidSupport;
}

std::optional<WebCore::AuthenticationExtensionsClientInputs> ArgumentCoder<WebCore::AuthenticationExtensionsClientInputs>::decode(Decoder& decoder)
{
    auto appid = decoder.decode<String>();
    if (!appid)
        return std::nullopt;

    auto googleLegacyAppidSupport = decoder.decode<bool>();
    if (!googleLegacyAppidSupport)
        return std::nullopt;

    WebCore::AuthenticationExtensionsClientInputs result;
    result.appid = WTFMove(*appid);
    result.googleLegacyAppidSupport = WTFMove(*googleLegacyAppidSupport);
    return { WTFMove(result) };
}

#endif

#if ENABLE(WEB_AUTHN)

void ArgumentCoder<WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput>::encode(Encoder& encoder, const WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rk)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput, rk)
    >::value);
    encoder << instance.rk;
}

std::optional<WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput> ArgumentCoder<WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput>::decode(Decoder& decoder)
{
    auto rk = decoder.decode<bool>();
    if (!rk)
        return std::nullopt;

    return {
        WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput {
            WTFMove(*rk)
        }
    };
}

#endif

#if ENABLE(WEB_AUTHN)

void ArgumentCoder<WebCore::AuthenticationExtensionsClientOutputs>::encode(Encoder& encoder, const WebCore::AuthenticationExtensionsClientOutputs& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.appid)>, std::optional<bool>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.credProps)>, std::optional<WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::AuthenticationExtensionsClientOutputs, appid)
        , offsetof(WebCore::AuthenticationExtensionsClientOutputs, credProps)
    >::value);
    encoder << instance.appid;
    encoder << instance.credProps;
}

std::optional<WebCore::AuthenticationExtensionsClientOutputs> ArgumentCoder<WebCore::AuthenticationExtensionsClientOutputs>::decode(Decoder& decoder)
{
    auto appid = decoder.decode<std::optional<bool>>();
    if (!appid)
        return std::nullopt;

    auto credProps = decoder.decode<std::optional<WebCore::AuthenticationExtensionsClientOutputs::CredentialPropertiesOutput>>();
    if (!credProps)
        return std::nullopt;

    return {
        WebCore::AuthenticationExtensionsClientOutputs {
            WTFMove(*appid),
            WTFMove(*credProps)
        }
    };
}

#endif

#if ENABLE(WEB_AUTHN)

void ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::Parameters>::encode(Encoder& encoder, const WebCore::PublicKeyCredentialCreationOptions::Parameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::PublicKeyCredentialType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alg)>, int64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::Parameters, type)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::Parameters, alg)
    >::value);
    encoder << instance.type;
    encoder << instance.alg;
}

std::optional<WebCore::PublicKeyCredentialCreationOptions::Parameters> ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::Parameters>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::PublicKeyCredentialType>();
    if (!type)
        return std::nullopt;

    auto alg = decoder.decode<int64_t>();
    if (!alg)
        return std::nullopt;

    return {
        WebCore::PublicKeyCredentialCreationOptions::Parameters {
            WTFMove(*type),
            WTFMove(*alg)
        }
    };
}

#endif

#if ENABLE(WEB_AUTHN)

void ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria>::encode(Encoder& encoder, const WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.authenticatorAttachment)>, std::optional<WebCore::AuthenticatorAttachment>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.residentKey)>, std::optional<WebCore::ResidentKeyRequirement>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.requireResidentKey)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.userVerification)>, WebCore::UserVerificationRequirement>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria, authenticatorAttachment)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria, residentKey)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria, requireResidentKey)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria, userVerification)
    >::value);
    encoder << instance.authenticatorAttachment;
    encoder << instance.residentKey;
    encoder << instance.requireResidentKey;
    encoder << instance.userVerification;
}

std::optional<WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria> ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria>::decode(Decoder& decoder)
{
    auto authenticatorAttachment = decoder.decode<std::optional<WebCore::AuthenticatorAttachment>>();
    if (!authenticatorAttachment)
        return std::nullopt;

    auto residentKey = decoder.decode<std::optional<WebCore::ResidentKeyRequirement>>();
    if (!residentKey)
        return std::nullopt;

    auto requireResidentKey = decoder.decode<bool>();
    if (!requireResidentKey)
        return std::nullopt;

    auto userVerification = decoder.decode<WebCore::UserVerificationRequirement>();
    if (!userVerification)
        return std::nullopt;

    return {
        WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria {
            WTFMove(*authenticatorAttachment),
            WTFMove(*residentKey),
            WTFMove(*requireResidentKey),
            WTFMove(*userVerification)
        }
    };
}

#endif

#if ENABLE(WEB_AUTHN)

void ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::Entity>::encode(Encoder& encoder, const WebCore::PublicKeyCredentialCreationOptions::Entity& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.icon)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::Entity, name)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::Entity, icon)
    >::value);
    encoder << instance.name;
    encoder << instance.icon;
}

std::optional<WebCore::PublicKeyCredentialCreationOptions::Entity> ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::Entity>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto icon = decoder.decode<String>();
    if (!icon)
        return std::nullopt;

    return {
        WebCore::PublicKeyCredentialCreationOptions::Entity {
            WTFMove(*name),
            WTFMove(*icon)
        }
    };
}

#endif

#if ENABLE(WEB_AUTHN)

void ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::RpEntity>::encode(Encoder& encoder, const WebCore::PublicKeyCredentialCreationOptions::RpEntity& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.icon)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::Entity, name)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::Entity, icon)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.id)>, std::optional<String>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::RpEntity, id)
    >::value);
    encoder << instance.name;
    encoder << instance.icon;
    encoder << instance.id;
}

std::optional<WebCore::PublicKeyCredentialCreationOptions::RpEntity> ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::RpEntity>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto icon = decoder.decode<String>();
    if (!icon)
        return std::nullopt;

    auto id = decoder.decode<std::optional<String>>();
    if (!id)
        return std::nullopt;

    return {
        WebCore::PublicKeyCredentialCreationOptions::RpEntity {
            WebCore::PublicKeyCredentialCreationOptions::Entity {
                WTFMove(*name),
                WTFMove(*icon)
            },
            WTFMove(*id)
        }
    };
}

#endif

#if ENABLE(WEB_AUTHN)

void ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::UserEntity>::encode(Encoder& encoder, const WebCore::PublicKeyCredentialCreationOptions::UserEntity& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.icon)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::Entity, name)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::Entity, icon)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.id)>, WebCore::BufferSource>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.displayName)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::UserEntity, id)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions::UserEntity, displayName)
    >::value);
    encoder << instance.name;
    encoder << instance.icon;
    encoder << instance.id;
    encoder << instance.displayName;
}

std::optional<WebCore::PublicKeyCredentialCreationOptions::UserEntity> ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions::UserEntity>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto icon = decoder.decode<String>();
    if (!icon)
        return std::nullopt;

    auto id = decoder.decode<WebCore::BufferSource>();
    if (!id)
        return std::nullopt;

    auto displayName = decoder.decode<String>();
    if (!displayName)
        return std::nullopt;

    return {
        WebCore::PublicKeyCredentialCreationOptions::UserEntity {
            WebCore::PublicKeyCredentialCreationOptions::Entity {
                WTFMove(*name),
                WTFMove(*icon)
            },
            WTFMove(*id),
            WTFMove(*displayName)
        }
    };
}

#endif

#if ENABLE(WEB_AUTHN)

void ArgumentCoder<WebCore::PublicKeyCredentialDescriptor>::encode(Encoder& encoder, const WebCore::PublicKeyCredentialDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::PublicKeyCredentialType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.id)>, WebCore::BufferSource>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.transports)>, Vector<WebCore::AuthenticatorTransport>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PublicKeyCredentialDescriptor, type)
        , offsetof(WebCore::PublicKeyCredentialDescriptor, id)
        , offsetof(WebCore::PublicKeyCredentialDescriptor, transports)
    >::value);
    encoder << instance.type;
    encoder << instance.id;
    encoder << instance.transports;
}

std::optional<WebCore::PublicKeyCredentialDescriptor> ArgumentCoder<WebCore::PublicKeyCredentialDescriptor>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::PublicKeyCredentialType>();
    if (!type)
        return std::nullopt;

    auto id = decoder.decode<WebCore::BufferSource>();
    if (!id)
        return std::nullopt;

    auto transports = decoder.decode<Vector<WebCore::AuthenticatorTransport>>();
    if (!transports)
        return std::nullopt;

    return {
        WebCore::PublicKeyCredentialDescriptor {
            WTFMove(*type),
            WTFMove(*id),
            WTFMove(*transports)
        }
    };
}

#endif


void ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions>::encode(Encoder& encoder, const WebCore::PublicKeyCredentialCreationOptions& instance)
{
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rp)>, WebCore::PublicKeyCredentialCreationOptions::RpEntity>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.user)>, WebCore::PublicKeyCredentialCreationOptions::UserEntity>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.challenge)>, WebCore::BufferSource>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pubKeyCredParams)>, Vector<WebCore::PublicKeyCredentialCreationOptions::Parameters>>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timeout)>, std::optional<unsigned>>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.excludeCredentials)>, Vector<WebCore::PublicKeyCredentialDescriptor>>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.authenticatorSelection)>, std::optional<WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria>>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.attestation)>, WebCore::AttestationConveyancePreference>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.extensions)>, std::optional<WebCore::AuthenticationExtensionsClientInputs>>);
#endif
    static_assert(MembersInCorrectOrder<0
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions, rp)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions, user)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions, challenge)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions, pubKeyCredParams)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions, timeout)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions, excludeCredentials)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions, authenticatorSelection)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions, attestation)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialCreationOptions, extensions)
#endif
    >::value);
#if ENABLE(WEB_AUTHN)
    encoder << instance.rp;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.user;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.challenge;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.pubKeyCredParams;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.timeout;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.excludeCredentials;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.authenticatorSelection;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.attestation;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.extensions;
#endif
}

std::optional<WebCore::PublicKeyCredentialCreationOptions> ArgumentCoder<WebCore::PublicKeyCredentialCreationOptions>::decode(Decoder& decoder)
{
#if ENABLE(WEB_AUTHN)
    auto rp = decoder.decode<WebCore::PublicKeyCredentialCreationOptions::RpEntity>();
    if (!rp)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto user = decoder.decode<WebCore::PublicKeyCredentialCreationOptions::UserEntity>();
    if (!user)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto challenge = decoder.decode<WebCore::BufferSource>();
    if (!challenge)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto pubKeyCredParams = decoder.decode<Vector<WebCore::PublicKeyCredentialCreationOptions::Parameters>>();
    if (!pubKeyCredParams)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto timeout = decoder.decode<std::optional<unsigned>>();
    if (!timeout)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto excludeCredentials = decoder.decode<Vector<WebCore::PublicKeyCredentialDescriptor>>();
    if (!excludeCredentials)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto authenticatorSelection = decoder.decode<std::optional<WebCore::PublicKeyCredentialCreationOptions::AuthenticatorSelectionCriteria>>();
    if (!authenticatorSelection)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto attestation = decoder.decode<WebCore::AttestationConveyancePreference>();
    if (!attestation)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto extensions = decoder.decode<std::optional<WebCore::AuthenticationExtensionsClientInputs>>();
    if (!extensions)
        return std::nullopt;
#endif

    return {
        WebCore::PublicKeyCredentialCreationOptions {
#if ENABLE(WEB_AUTHN)
            WTFMove(*rp),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*user),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*challenge),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*pubKeyCredParams),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*timeout),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*excludeCredentials),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*authenticatorSelection),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*attestation),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*extensions)
#endif
        }
    };
}


void ArgumentCoder<WebCore::PublicKeyCredentialRequestOptions>::encode(Encoder& encoder, const WebCore::PublicKeyCredentialRequestOptions& instance)
{
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.challenge)>, WebCore::BufferSource>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timeout)>, std::optional<unsigned>>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rpId)>, String>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowCredentials)>, Vector<WebCore::PublicKeyCredentialDescriptor>>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.userVerification)>, WebCore::UserVerificationRequirement>);
#endif
#if ENABLE(WEB_AUTHN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.extensions)>, std::optional<WebCore::AuthenticationExtensionsClientInputs>>);
#endif
    static_assert(MembersInCorrectOrder<0
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialRequestOptions, challenge)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialRequestOptions, timeout)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialRequestOptions, rpId)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialRequestOptions, allowCredentials)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialRequestOptions, userVerification)
#endif
#if ENABLE(WEB_AUTHN)
        , offsetof(WebCore::PublicKeyCredentialRequestOptions, extensions)
#endif
    >::value);
#if ENABLE(WEB_AUTHN)
    encoder << instance.challenge;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.timeout;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.rpId;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.allowCredentials;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.userVerification;
#endif
#if ENABLE(WEB_AUTHN)
    encoder << instance.extensions;
#endif
}

std::optional<WebCore::PublicKeyCredentialRequestOptions> ArgumentCoder<WebCore::PublicKeyCredentialRequestOptions>::decode(Decoder& decoder)
{
#if ENABLE(WEB_AUTHN)
    auto challenge = decoder.decode<WebCore::BufferSource>();
    if (!challenge)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto timeout = decoder.decode<std::optional<unsigned>>();
    if (!timeout)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto rpId = decoder.decode<String>();
    if (!rpId)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto allowCredentials = decoder.decode<Vector<WebCore::PublicKeyCredentialDescriptor>>();
    if (!allowCredentials)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto userVerification = decoder.decode<WebCore::UserVerificationRequirement>();
    if (!userVerification)
        return std::nullopt;
#endif

#if ENABLE(WEB_AUTHN)
    auto extensions = decoder.decode<std::optional<WebCore::AuthenticationExtensionsClientInputs>>();
    if (!extensions)
        return std::nullopt;
#endif

    return {
        WebCore::PublicKeyCredentialRequestOptions {
#if ENABLE(WEB_AUTHN)
            WTFMove(*challenge),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*timeout),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*rpId),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*allowCredentials),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*userVerification),
#endif
#if ENABLE(WEB_AUTHN)
            WTFMove(*extensions)
#endif
        }
    };
}


void ArgumentCoder<WebCore::RegistrableDomain>::encode(Encoder& encoder, const WebCore::RegistrableDomain& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.string())>, String>);
    encoder << instance.string();
}

std::optional<WebCore::RegistrableDomain> ArgumentCoder<WebCore::RegistrableDomain>::decode(Decoder& decoder)
{
    auto string = decoder.decode<String>();
    if (!string)
        return std::nullopt;

    return {
        WebCore::RegistrableDomain::fromRawString(
            WTFMove(*string)
        )
    };
}


void ArgumentCoder<WebCore::AudioConfiguration>::encode(Encoder& encoder, const WebCore::AudioConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentType)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.channels)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bitrate)>, std::optional<uint64_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.samplerate)>, std::optional<uint32_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.spatialRendering)>, std::optional<bool>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::AudioConfiguration, contentType)
        , offsetof(WebCore::AudioConfiguration, channels)
        , offsetof(WebCore::AudioConfiguration, bitrate)
        , offsetof(WebCore::AudioConfiguration, samplerate)
        , offsetof(WebCore::AudioConfiguration, spatialRendering)
    >::value);
    encoder << instance.contentType;
    encoder << instance.channels;
    encoder << instance.bitrate;
    encoder << instance.samplerate;
    encoder << instance.spatialRendering;
}

std::optional<WebCore::AudioConfiguration> ArgumentCoder<WebCore::AudioConfiguration>::decode(Decoder& decoder)
{
    auto contentType = decoder.decode<String>();
    if (!contentType)
        return std::nullopt;

    auto channels = decoder.decode<String>();
    if (!channels)
        return std::nullopt;

    auto bitrate = decoder.decode<std::optional<uint64_t>>();
    if (!bitrate)
        return std::nullopt;

    auto samplerate = decoder.decode<std::optional<uint32_t>>();
    if (!samplerate)
        return std::nullopt;

    auto spatialRendering = decoder.decode<std::optional<bool>>();
    if (!spatialRendering)
        return std::nullopt;

    return {
        WebCore::AudioConfiguration {
            WTFMove(*contentType),
            WTFMove(*channels),
            WTFMove(*bitrate),
            WTFMove(*samplerate),
            WTFMove(*spatialRendering)
        }
    };
}


void ArgumentCoder<WebCore::Cookie>::encode(Encoder& encoder, const WebCore::Cookie& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.domain)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.path)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.created)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.expires)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.httpOnly)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.secure)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.session)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.comment)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.commentURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ports)>, Vector<uint16_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sameSite)>, WebCore::Cookie::SameSitePolicy>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::Cookie, name)
        , offsetof(WebCore::Cookie, value)
        , offsetof(WebCore::Cookie, domain)
        , offsetof(WebCore::Cookie, path)
        , offsetof(WebCore::Cookie, created)
        , offsetof(WebCore::Cookie, expires)
        , offsetof(WebCore::Cookie, httpOnly)
        , offsetof(WebCore::Cookie, secure)
        , offsetof(WebCore::Cookie, session)
        , offsetof(WebCore::Cookie, comment)
        , offsetof(WebCore::Cookie, commentURL)
        , offsetof(WebCore::Cookie, ports)
        , offsetof(WebCore::Cookie, sameSite)
    >::value);
    encoder << instance.name;
    encoder << instance.value;
    encoder << instance.domain;
    encoder << instance.path;
    encoder << instance.created;
    encoder << instance.expires;
    encoder << instance.httpOnly;
    encoder << instance.secure;
    encoder << instance.session;
    encoder << instance.comment;
    encoder << instance.commentURL;
    encoder << instance.ports;
    encoder << instance.sameSite;
}

std::optional<WebCore::Cookie> ArgumentCoder<WebCore::Cookie>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto value = decoder.decode<String>();
    if (!value)
        return std::nullopt;

    auto domain = decoder.decode<String>();
    if (!domain)
        return std::nullopt;

    auto path = decoder.decode<String>();
    if (!path)
        return std::nullopt;

    auto created = decoder.decode<double>();
    if (!created)
        return std::nullopt;

    auto expires = decoder.decode<std::optional<double>>();
    if (!expires)
        return std::nullopt;

    auto httpOnly = decoder.decode<bool>();
    if (!httpOnly)
        return std::nullopt;

    auto secure = decoder.decode<bool>();
    if (!secure)
        return std::nullopt;

    auto session = decoder.decode<bool>();
    if (!session)
        return std::nullopt;

    auto comment = decoder.decode<String>();
    if (!comment)
        return std::nullopt;

    auto commentURL = decoder.decode<URL>();
    if (!commentURL)
        return std::nullopt;

    auto ports = decoder.decode<Vector<uint16_t>>();
    if (!ports)
        return std::nullopt;

    auto sameSite = decoder.decode<WebCore::Cookie::SameSitePolicy>();
    if (!sameSite)
        return std::nullopt;

    return {
        WebCore::Cookie {
            WTFMove(*name),
            WTFMove(*value),
            WTFMove(*domain),
            WTFMove(*path),
            WTFMove(*created),
            WTFMove(*expires),
            WTFMove(*httpOnly),
            WTFMove(*secure),
            WTFMove(*session),
            WTFMove(*comment),
            WTFMove(*commentURL),
            WTFMove(*ports),
            WTFMove(*sameSite)
        }
    };
}

#if ENABLE(VIDEO)

void ArgumentCoder<WebCore::VideoFrameMetadata>::encode(Encoder& encoder, const WebCore::VideoFrameMetadata& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.presentationTime)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.expectedDisplayTime)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mediaTime)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.presentedFrames)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.processingDuration)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.captureTime)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.receiveTime)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rtpTimestamp)>, std::optional<unsigned>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::VideoFrameMetadata, presentationTime)
        , offsetof(WebCore::VideoFrameMetadata, expectedDisplayTime)
        , offsetof(WebCore::VideoFrameMetadata, width)
        , offsetof(WebCore::VideoFrameMetadata, height)
        , offsetof(WebCore::VideoFrameMetadata, mediaTime)
        , offsetof(WebCore::VideoFrameMetadata, presentedFrames)
        , offsetof(WebCore::VideoFrameMetadata, processingDuration)
        , offsetof(WebCore::VideoFrameMetadata, captureTime)
        , offsetof(WebCore::VideoFrameMetadata, receiveTime)
        , offsetof(WebCore::VideoFrameMetadata, rtpTimestamp)
    >::value);
    encoder << instance.presentationTime;
    encoder << instance.expectedDisplayTime;
    encoder << instance.width;
    encoder << instance.height;
    encoder << instance.mediaTime;
    encoder << instance.presentedFrames;
    encoder << instance.processingDuration;
    encoder << instance.captureTime;
    encoder << instance.receiveTime;
    encoder << instance.rtpTimestamp;
}

std::optional<WebCore::VideoFrameMetadata> ArgumentCoder<WebCore::VideoFrameMetadata>::decode(Decoder& decoder)
{
    auto presentationTime = decoder.decode<double>();
    if (!presentationTime)
        return std::nullopt;

    auto expectedDisplayTime = decoder.decode<double>();
    if (!expectedDisplayTime)
        return std::nullopt;

    auto width = decoder.decode<unsigned>();
    if (!width)
        return std::nullopt;

    auto height = decoder.decode<unsigned>();
    if (!height)
        return std::nullopt;

    auto mediaTime = decoder.decode<double>();
    if (!mediaTime)
        return std::nullopt;

    auto presentedFrames = decoder.decode<unsigned>();
    if (!presentedFrames)
        return std::nullopt;

    auto processingDuration = decoder.decode<std::optional<double>>();
    if (!processingDuration)
        return std::nullopt;

    auto captureTime = decoder.decode<std::optional<double>>();
    if (!captureTime)
        return std::nullopt;

    auto receiveTime = decoder.decode<std::optional<double>>();
    if (!receiveTime)
        return std::nullopt;

    auto rtpTimestamp = decoder.decode<std::optional<unsigned>>();
    if (!rtpTimestamp)
        return std::nullopt;

    return {
        WebCore::VideoFrameMetadata {
            WTFMove(*presentationTime),
            WTFMove(*expectedDisplayTime),
            WTFMove(*width),
            WTFMove(*height),
            WTFMove(*mediaTime),
            WTFMove(*presentedFrames),
            WTFMove(*processingDuration),
            WTFMove(*captureTime),
            WTFMove(*receiveTime),
            WTFMove(*rtpTimestamp)
        }
    };
}

#endif

#if ENABLE(SERVICE_WORKER)

void ArgumentCoder<WebCore::NavigationPreloadState>::encode(Encoder& encoder, const WebCore::NavigationPreloadState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.enabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.headerValue)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::NavigationPreloadState, enabled)
        , offsetof(WebCore::NavigationPreloadState, headerValue)
    >::value);
    encoder << instance.enabled;
    encoder << instance.headerValue;
}

std::optional<WebCore::NavigationPreloadState> ArgumentCoder<WebCore::NavigationPreloadState>::decode(Decoder& decoder)
{
    auto enabled = decoder.decode<bool>();
    if (!enabled)
        return std::nullopt;

    auto headerValue = decoder.decode<String>();
    if (!headerValue)
        return std::nullopt;

    return {
        WebCore::NavigationPreloadState {
            WTFMove(*enabled),
            WTFMove(*headerValue)
        }
    };
}

#endif

#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)

void ArgumentCoder<WebCore::MockContentFilterSettings>::encode(Encoder& encoder, const WebCore::MockContentFilterSettings& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_enabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_decisionPoint)>, WebCore::MockContentFilterSettings::DecisionPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_decision)>, WebCore::MockContentFilterSettings::Decision>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_unblockRequestDecision)>, WebCore::MockContentFilterSettings::Decision>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_blockedString)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_modifiedRequestURL)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MockContentFilterSettings, m_enabled)
        , offsetof(WebCore::MockContentFilterSettings, m_decisionPoint)
        , offsetof(WebCore::MockContentFilterSettings, m_decision)
        , offsetof(WebCore::MockContentFilterSettings, m_unblockRequestDecision)
        , offsetof(WebCore::MockContentFilterSettings, m_blockedString)
        , offsetof(WebCore::MockContentFilterSettings, m_modifiedRequestURL)
    >::value);
    encoder << instance.m_enabled;
    encoder << instance.m_decisionPoint;
    encoder << instance.m_decision;
    encoder << instance.m_unblockRequestDecision;
    encoder << instance.m_blockedString;
    encoder << instance.m_modifiedRequestURL;
}

std::optional<WebCore::MockContentFilterSettings> ArgumentCoder<WebCore::MockContentFilterSettings>::decode(Decoder& decoder)
{
    auto m_enabled = decoder.decode<bool>();
    if (!m_enabled)
        return std::nullopt;

    auto m_decisionPoint = decoder.decode<WebCore::MockContentFilterSettings::DecisionPoint>();
    if (!m_decisionPoint)
        return std::nullopt;

    auto m_decision = decoder.decode<WebCore::MockContentFilterSettings::Decision>();
    if (!m_decision)
        return std::nullopt;

    auto m_unblockRequestDecision = decoder.decode<WebCore::MockContentFilterSettings::Decision>();
    if (!m_unblockRequestDecision)
        return std::nullopt;

    auto m_blockedString = decoder.decode<String>();
    if (!m_blockedString)
        return std::nullopt;

    auto m_modifiedRequestURL = decoder.decode<String>();
    if (!m_modifiedRequestURL)
        return std::nullopt;

    WebCore::MockContentFilterSettings result;
    result.m_enabled = WTFMove(*m_enabled);
    result.m_decisionPoint = WTFMove(*m_decisionPoint);
    result.m_decision = WTFMove(*m_decision);
    result.m_unblockRequestDecision = WTFMove(*m_unblockRequestDecision);
    result.m_blockedString = WTFMove(*m_blockedString);
    result.m_modifiedRequestURL = WTFMove(*m_modifiedRequestURL);
    return { WTFMove(result) };
}

#endif


void ArgumentCoder<WebCore::ExceptionDetails>::encode(Encoder& encoder, const WebCore::ExceptionDetails& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lineNumber)>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.columnNumber)>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ExceptionDetails::Type>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceURL)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ExceptionDetails, message)
        , offsetof(WebCore::ExceptionDetails, lineNumber)
        , offsetof(WebCore::ExceptionDetails, columnNumber)
        , offsetof(WebCore::ExceptionDetails, type)
        , offsetof(WebCore::ExceptionDetails, sourceURL)
    >::value);
    encoder << instance.message;
    encoder << instance.lineNumber;
    encoder << instance.columnNumber;
    encoder << instance.type;
    encoder << instance.sourceURL;
}

std::optional<WebCore::ExceptionDetails> ArgumentCoder<WebCore::ExceptionDetails>::decode(Decoder& decoder)
{
    auto message = decoder.decode<String>();
    if (!message)
        return std::nullopt;

    auto lineNumber = decoder.decode<int>();
    if (!lineNumber)
        return std::nullopt;

    auto columnNumber = decoder.decode<int>();
    if (!columnNumber)
        return std::nullopt;

    auto type = decoder.decode<WebCore::ExceptionDetails::Type>();
    if (!type)
        return std::nullopt;

    auto sourceURL = decoder.decode<String>();
    if (!sourceURL)
        return std::nullopt;

    return {
        WebCore::ExceptionDetails {
            WTFMove(*message),
            WTFMove(*lineNumber),
            WTFMove(*columnNumber),
            WTFMove(*type),
            WTFMove(*sourceURL)
        }
    };
}


void ArgumentCoder<WebCore::FloatBoxExtent>::encode(Encoder& encoder, const WebCore::FloatBoxExtent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.top())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.right())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bottom())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.left())>, float>);
    encoder << instance.top();
    encoder << instance.right();
    encoder << instance.bottom();
    encoder << instance.left();
}

void ArgumentCoder<WebCore::FloatBoxExtent>::encode(StreamConnectionEncoder& encoder, const WebCore::FloatBoxExtent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.top())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.right())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bottom())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.left())>, float>);
    encoder << instance.top();
    encoder << instance.right();
    encoder << instance.bottom();
    encoder << instance.left();
}

std::optional<WebCore::FloatBoxExtent> ArgumentCoder<WebCore::FloatBoxExtent>::decode(Decoder& decoder)
{
    auto top = decoder.decode<float>();
    if (!top)
        return std::nullopt;

    auto right = decoder.decode<float>();
    if (!right)
        return std::nullopt;

    auto bottom = decoder.decode<float>();
    if (!bottom)
        return std::nullopt;

    auto left = decoder.decode<float>();
    if (!left)
        return std::nullopt;

    return {
        WebCore::FloatBoxExtent {
            WTFMove(*top),
            WTFMove(*right),
            WTFMove(*bottom),
            WTFMove(*left)
        }
    };
}


void ArgumentCoder<WebCore::DisplayList::SetInlineFillColor>::encode(Encoder& encoder, const WebCore::DisplayList::SetInlineFillColor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().red)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().green)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().blue)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().alpha)>, uint8_t>);
    encoder << instance.colorData().resolved().red;
    encoder << instance.colorData().resolved().green;
    encoder << instance.colorData().resolved().blue;
    encoder << instance.colorData().resolved().alpha;
}

void ArgumentCoder<WebCore::DisplayList::SetInlineFillColor>::encode(StreamConnectionEncoder& encoder, const WebCore::DisplayList::SetInlineFillColor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().red)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().green)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().blue)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().alpha)>, uint8_t>);
    encoder << instance.colorData().resolved().red;
    encoder << instance.colorData().resolved().green;
    encoder << instance.colorData().resolved().blue;
    encoder << instance.colorData().resolved().alpha;
}

std::optional<WebCore::DisplayList::SetInlineFillColor> ArgumentCoder<WebCore::DisplayList::SetInlineFillColor>::decode(Decoder& decoder)
{
    auto colorDataresolvedred = decoder.decode<uint8_t>();
    if (!colorDataresolvedred)
        return std::nullopt;

    auto colorDataresolvedgreen = decoder.decode<uint8_t>();
    if (!colorDataresolvedgreen)
        return std::nullopt;

    auto colorDataresolvedblue = decoder.decode<uint8_t>();
    if (!colorDataresolvedblue)
        return std::nullopt;

    auto colorDataresolvedalpha = decoder.decode<uint8_t>();
    if (!colorDataresolvedalpha)
        return std::nullopt;

    return {
        WebCore::DisplayList::SetInlineFillColor {
            WTFMove(*colorDataresolvedred),
            WTFMove(*colorDataresolvedgreen),
            WTFMove(*colorDataresolvedblue),
            WTFMove(*colorDataresolvedalpha)
        }
    };
}


void ArgumentCoder<WebCore::DisplayList::SetInlineStrokeColor>::encode(Encoder& encoder, const WebCore::DisplayList::SetInlineStrokeColor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().red)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().green)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().blue)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().alpha)>, uint8_t>);
    encoder << instance.colorData().resolved().red;
    encoder << instance.colorData().resolved().green;
    encoder << instance.colorData().resolved().blue;
    encoder << instance.colorData().resolved().alpha;
}

void ArgumentCoder<WebCore::DisplayList::SetInlineStrokeColor>::encode(StreamConnectionEncoder& encoder, const WebCore::DisplayList::SetInlineStrokeColor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().red)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().green)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().blue)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorData().resolved().alpha)>, uint8_t>);
    encoder << instance.colorData().resolved().red;
    encoder << instance.colorData().resolved().green;
    encoder << instance.colorData().resolved().blue;
    encoder << instance.colorData().resolved().alpha;
}

std::optional<WebCore::DisplayList::SetInlineStrokeColor> ArgumentCoder<WebCore::DisplayList::SetInlineStrokeColor>::decode(Decoder& decoder)
{
    auto colorDataresolvedred = decoder.decode<uint8_t>();
    if (!colorDataresolvedred)
        return std::nullopt;

    auto colorDataresolvedgreen = decoder.decode<uint8_t>();
    if (!colorDataresolvedgreen)
        return std::nullopt;

    auto colorDataresolvedblue = decoder.decode<uint8_t>();
    if (!colorDataresolvedblue)
        return std::nullopt;

    auto colorDataresolvedalpha = decoder.decode<uint8_t>();
    if (!colorDataresolvedalpha)
        return std::nullopt;

    return {
        WebCore::DisplayList::SetInlineStrokeColor {
            WTFMove(*colorDataresolvedred),
            WTFMove(*colorDataresolvedgreen),
            WTFMove(*colorDataresolvedblue),
            WTFMove(*colorDataresolvedalpha)
        }
    };
}


void ArgumentCoder<WebCore::HTTPHeaderMap::CommonHeader>::encode(Encoder& encoder, const WebCore::HTTPHeaderMap::CommonHeader& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.key)>, WebCore::HTTPHeaderName>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::HTTPHeaderMap::CommonHeader, key)
        , offsetof(WebCore::HTTPHeaderMap::CommonHeader, value)
    >::value);
    encoder << instance.key;
    encoder << instance.value;
}

std::optional<WebCore::HTTPHeaderMap::CommonHeader> ArgumentCoder<WebCore::HTTPHeaderMap::CommonHeader>::decode(Decoder& decoder)
{
    auto key = decoder.decode<WebCore::HTTPHeaderName>();
    if (!key)
        return std::nullopt;

    auto value = decoder.decode<String>();
    if (!value)
        return std::nullopt;

    return {
        WebCore::HTTPHeaderMap::CommonHeader {
            WTFMove(*key),
            WTFMove(*value)
        }
    };
}


void ArgumentCoder<WebCore::HTTPHeaderMap::UncommonHeader>::encode(Encoder& encoder, const WebCore::HTTPHeaderMap::UncommonHeader& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.key)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::HTTPHeaderMap::UncommonHeader, key)
        , offsetof(WebCore::HTTPHeaderMap::UncommonHeader, value)
    >::value);
    encoder << instance.key;
    encoder << instance.value;
}

std::optional<WebCore::HTTPHeaderMap::UncommonHeader> ArgumentCoder<WebCore::HTTPHeaderMap::UncommonHeader>::decode(Decoder& decoder)
{
    auto key = decoder.decode<String>();
    if (!key)
        return std::nullopt;

    auto value = decoder.decode<String>();
    if (!value)
        return std::nullopt;

    return {
        WebCore::HTTPHeaderMap::UncommonHeader {
            WTFMove(*key),
            WTFMove(*value)
        }
    };
}


void ArgumentCoder<WebCore::HTTPHeaderMap>::encode(Encoder& encoder, const WebCore::HTTPHeaderMap& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.commonHeaders())>, Vector<WebCore::HTTPHeaderMap::CommonHeader, 0, CrashOnOverflow, 6>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.uncommonHeaders())>, Vector<WebCore::HTTPHeaderMap::UncommonHeader, 0, CrashOnOverflow, 0>>);
    encoder << instance.commonHeaders();
    encoder << instance.uncommonHeaders();
}

std::optional<WebCore::HTTPHeaderMap> ArgumentCoder<WebCore::HTTPHeaderMap>::decode(Decoder& decoder)
{
    auto commonHeaders = decoder.decode<Vector<WebCore::HTTPHeaderMap::CommonHeader, 0, CrashOnOverflow, 6>>();
    if (!commonHeaders)
        return std::nullopt;

    auto uncommonHeaders = decoder.decode<Vector<WebCore::HTTPHeaderMap::UncommonHeader, 0, CrashOnOverflow, 0>>();
    if (!uncommonHeaders)
        return std::nullopt;

    return {
        WebCore::HTTPHeaderMap {
            WTFMove(*commonHeaders),
            WTFMove(*uncommonHeaders)
        }
    };
}


void ArgumentCoder<WebCore::ElementContext>::encode(Encoder& encoder, const WebCore::ElementContext& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.boundingRect)>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webPageIdentifier)>, WebCore::PageIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.documentIdentifier)>, WebCore::ScriptExecutionContextIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.elementIdentifier)>, WebCore::ElementIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ElementContext, boundingRect)
        , offsetof(WebCore::ElementContext, webPageIdentifier)
        , offsetof(WebCore::ElementContext, documentIdentifier)
        , offsetof(WebCore::ElementContext, elementIdentifier)
    >::value);
    encoder << instance.boundingRect;
    encoder << instance.webPageIdentifier;
    encoder << instance.documentIdentifier;
    encoder << instance.elementIdentifier;
}

std::optional<WebCore::ElementContext> ArgumentCoder<WebCore::ElementContext>::decode(Decoder& decoder)
{
    auto boundingRect = decoder.decode<WebCore::FloatRect>();
    if (!boundingRect)
        return std::nullopt;

    auto webPageIdentifier = decoder.decode<WebCore::PageIdentifier>();
    if (!webPageIdentifier)
        return std::nullopt;

    auto documentIdentifier = decoder.decode<WebCore::ScriptExecutionContextIdentifier>();
    if (!documentIdentifier)
        return std::nullopt;

    auto elementIdentifier = decoder.decode<WebCore::ElementIdentifier>();
    if (!elementIdentifier)
        return std::nullopt;

    return {
        WebCore::ElementContext {
            WTFMove(*boundingRect),
            WTFMove(*webPageIdentifier),
            WTFMove(*documentIdentifier),
            WTFMove(*elementIdentifier)
        }
    };
}


void ArgumentCoder<WebCore::SystemPreviewInfo>::encode(Encoder& encoder, const WebCore::SystemPreviewInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.element)>, WebCore::ElementContext>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.previewRect)>, WebCore::IntRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isPreview)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SystemPreviewInfo, element)
        , offsetof(WebCore::SystemPreviewInfo, previewRect)
        , offsetof(WebCore::SystemPreviewInfo, isPreview)
    >::value);
    encoder << instance.element;
    encoder << instance.previewRect;
    encoder << instance.isPreview;
}

std::optional<WebCore::SystemPreviewInfo> ArgumentCoder<WebCore::SystemPreviewInfo>::decode(Decoder& decoder)
{
    auto element = decoder.decode<WebCore::ElementContext>();
    if (!element)
        return std::nullopt;

    auto previewRect = decoder.decode<WebCore::IntRect>();
    if (!previewRect)
        return std::nullopt;

    auto isPreview = decoder.decode<bool>();
    if (!isPreview)
        return std::nullopt;

    return {
        WebCore::SystemPreviewInfo {
            WTFMove(*element),
            WTFMove(*previewRect),
            WTFMove(*isPreview)
        }
    };
}


void ArgumentCoder<WebCore::ResourceRequest::RequestData>::encode(Encoder& encoder, const WebCore::ResourceRequest::RequestData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_url)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_firstPartyForCookies)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_timeoutInterval)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_httpMethod)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_httpHeaderFields)>, WebCore::HTTPHeaderMap>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_responseContentDispositionEncodingFallbackArray)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_cachePolicy)>, WebCore::ResourceRequestCachePolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_sameSiteDisposition)>, WebCore::ResourceRequestBase::SameSiteDisposition>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_priority)>, WebCore::ResourceLoadPriority>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_requester)>, WebCore::ResourceRequestRequester>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_allowCookies)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isTopSite)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isAppInitiated)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ResourceRequest::RequestData, m_url)
        , offsetof(WebCore::ResourceRequest::RequestData, m_firstPartyForCookies)
        , offsetof(WebCore::ResourceRequest::RequestData, m_timeoutInterval)
        , offsetof(WebCore::ResourceRequest::RequestData, m_httpMethod)
        , offsetof(WebCore::ResourceRequest::RequestData, m_httpHeaderFields)
        , offsetof(WebCore::ResourceRequest::RequestData, m_responseContentDispositionEncodingFallbackArray)
        , offsetof(WebCore::ResourceRequest::RequestData, m_cachePolicy)
        , offsetof(WebCore::ResourceRequest::RequestData, m_sameSiteDisposition)
        , offsetof(WebCore::ResourceRequest::RequestData, m_priority)
        , offsetof(WebCore::ResourceRequest::RequestData, m_requester)
    >::value);
    encoder << instance.m_url;
    encoder << instance.m_firstPartyForCookies;
    encoder << instance.m_timeoutInterval;
    encoder << instance.m_httpMethod;
    encoder << instance.m_httpHeaderFields;
    encoder << instance.m_responseContentDispositionEncodingFallbackArray;
    encoder << instance.m_cachePolicy;
    encoder << instance.m_sameSiteDisposition;
    encoder << instance.m_priority;
    encoder << instance.m_requester;
    encoder << instance.m_allowCookies;
    encoder << instance.m_isTopSite;
    encoder << instance.m_isAppInitiated;
}

std::optional<WebCore::ResourceRequest::RequestData> ArgumentCoder<WebCore::ResourceRequest::RequestData>::decode(Decoder& decoder)
{
    auto m_url = decoder.decode<URL>();
    if (!m_url)
        return std::nullopt;

    auto m_firstPartyForCookies = decoder.decode<URL>();
    if (!m_firstPartyForCookies)
        return std::nullopt;

    auto m_timeoutInterval = decoder.decode<double>();
    if (!m_timeoutInterval)
        return std::nullopt;

    auto m_httpMethod = decoder.decode<String>();
    if (!m_httpMethod)
        return std::nullopt;

    auto m_httpHeaderFields = decoder.decode<WebCore::HTTPHeaderMap>();
    if (!m_httpHeaderFields)
        return std::nullopt;

    auto m_responseContentDispositionEncodingFallbackArray = decoder.decode<Vector<String>>();
    if (!m_responseContentDispositionEncodingFallbackArray)
        return std::nullopt;

    auto m_cachePolicy = decoder.decode<WebCore::ResourceRequestCachePolicy>();
    if (!m_cachePolicy)
        return std::nullopt;

    auto m_sameSiteDisposition = decoder.decode<WebCore::ResourceRequestBase::SameSiteDisposition>();
    if (!m_sameSiteDisposition)
        return std::nullopt;

    auto m_priority = decoder.decode<WebCore::ResourceLoadPriority>();
    if (!m_priority)
        return std::nullopt;

    auto m_requester = decoder.decode<WebCore::ResourceRequestRequester>();
    if (!m_requester)
        return std::nullopt;

    auto m_allowCookies = decoder.decode<bool>();
    if (!m_allowCookies)
        return std::nullopt;

    auto m_isTopSite = decoder.decode<bool>();
    if (!m_isTopSite)
        return std::nullopt;

    auto m_isAppInitiated = decoder.decode<bool>();
    if (!m_isAppInitiated)
        return std::nullopt;

    return {
        WebCore::ResourceRequest::RequestData {
            WTFMove(*m_url),
            WTFMove(*m_firstPartyForCookies),
            WTFMove(*m_timeoutInterval),
            WTFMove(*m_httpMethod),
            WTFMove(*m_httpHeaderFields),
            WTFMove(*m_responseContentDispositionEncodingFallbackArray),
            WTFMove(*m_cachePolicy),
            WTFMove(*m_sameSiteDisposition),
            WTFMove(*m_priority),
            WTFMove(*m_requester),
            WTFMove(*m_allowCookies),
            WTFMove(*m_isTopSite),
            WTFMove(*m_isAppInitiated)
        }
    };
}

#if USE(SOUP)

void ArgumentCoder<WebCore::ResourceRequestPlatformData>::encode(Encoder& encoder, const WebCore::ResourceRequestPlatformData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.requestData)>, WebCore::ResourceRequest::RequestData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.acceptEncoding)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.redirectCount)>, uint16_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ResourceRequestPlatformData, requestData)
        , offsetof(WebCore::ResourceRequestPlatformData, acceptEncoding)
        , offsetof(WebCore::ResourceRequestPlatformData, redirectCount)
    >::value);
    encoder << instance.requestData;
    encoder << instance.acceptEncoding;
    encoder << instance.redirectCount;
}

std::optional<WebCore::ResourceRequestPlatformData> ArgumentCoder<WebCore::ResourceRequestPlatformData>::decode(Decoder& decoder)
{
    auto requestData = decoder.decode<WebCore::ResourceRequest::RequestData>();
    if (!requestData)
        return std::nullopt;

    auto acceptEncoding = decoder.decode<bool>();
    if (!acceptEncoding)
        return std::nullopt;

    auto redirectCount = decoder.decode<uint16_t>();
    if (!redirectCount)
        return std::nullopt;

    return {
        WebCore::ResourceRequestPlatformData {
            WTFMove(*requestData),
            WTFMove(*acceptEncoding),
            WTFMove(*redirectCount)
        }
    };
}

#endif

#if PLATFORM(COCOA) && USE(SYSTEM_PREVIEW)

void ArgumentCoder<WebCore::ResourceRequest>::encode(Encoder& encoder, const WebCore::ResourceRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.getRequestDataToSerialize())>, std::variant<WebCore::ResourceRequest::RequestData, WebCore::ResourceRequestPlatformData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cachePartition())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hiddenFromInspector())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.systemPreviewInfo())>, std::optional<WebCore::SystemPreviewInfo>>);
    encoder << instance.getRequestDataToSerialize();
    encoder << instance.cachePartition();
    encoder << instance.hiddenFromInspector();
    encoder << instance.systemPreviewInfo();
}

std::optional<WebCore::ResourceRequest> ArgumentCoder<WebCore::ResourceRequest>::decode(Decoder& decoder)
{
    auto getRequestDataToSerialize = decoder.decode<std::variant<WebCore::ResourceRequest::RequestData, WebCore::ResourceRequestPlatformData>>();
    if (!getRequestDataToSerialize)
        return std::nullopt;

    auto cachePartition = decoder.decode<String>();
    if (!cachePartition)
        return std::nullopt;

    auto hiddenFromInspector = decoder.decode<bool>();
    if (!hiddenFromInspector)
        return std::nullopt;

    auto systemPreviewInfo = decoder.decode<std::optional<WebCore::SystemPreviewInfo>>();
    if (!systemPreviewInfo)
        return std::nullopt;

    return {
        WebCore::ResourceRequest::fromResourceRequestData(
            WTFMove(*getRequestDataToSerialize),
            WTFMove(*cachePartition),
            WTFMove(*hiddenFromInspector),
            WTFMove(*systemPreviewInfo)
        )
    };
}

#endif

#if PLATFORM(COCOA) && !USE(SYSTEM_PREVIEW)

void ArgumentCoder<WebCore::ResourceRequest>::encode(Encoder& encoder, const WebCore::ResourceRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.getRequestDataToSerialize())>, std::variant<WebCore::ResourceRequest::RequestData, WebCore::ResourceRequestPlatformData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cachePartition())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hiddenFromInspector())>, bool>);
    encoder << instance.getRequestDataToSerialize();
    encoder << instance.cachePartition();
    encoder << instance.hiddenFromInspector();
}

std::optional<WebCore::ResourceRequest> ArgumentCoder<WebCore::ResourceRequest>::decode(Decoder& decoder)
{
    auto getRequestDataToSerialize = decoder.decode<std::variant<WebCore::ResourceRequest::RequestData, WebCore::ResourceRequestPlatformData>>();
    if (!getRequestDataToSerialize)
        return std::nullopt;

    auto cachePartition = decoder.decode<String>();
    if (!cachePartition)
        return std::nullopt;

    auto hiddenFromInspector = decoder.decode<bool>();
    if (!hiddenFromInspector)
        return std::nullopt;

    return {
        WebCore::ResourceRequest::fromResourceRequestData(
            WTFMove(*getRequestDataToSerialize),
            WTFMove(*cachePartition),
            WTFMove(*hiddenFromInspector)
        )
    };
}

#endif

#if USE(CURL)

void ArgumentCoder<WebCore::ResourceRequest>::encode(Encoder& encoder, const WebCore::ResourceRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.getRequestDataToSerialize())>, WebCore::ResourceRequest::RequestData>);
    encoder << instance.getRequestDataToSerialize();
}

std::optional<WebCore::ResourceRequest> ArgumentCoder<WebCore::ResourceRequest>::decode(Decoder& decoder)
{
    auto getRequestDataToSerialize = decoder.decode<WebCore::ResourceRequest::RequestData>();
    if (!getRequestDataToSerialize)
        return std::nullopt;

    return {
        WebCore::ResourceRequest::fromResourceRequestData(
            WTFMove(*getRequestDataToSerialize)
        )
    };
}

#endif

#if !USE(CURL) && !PLATFORM(COCOA)

void ArgumentCoder<WebCore::ResourceRequest>::encode(Encoder& encoder, const WebCore::ResourceRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.getRequestDataToSerialize())>, std::variant<WebCore::ResourceRequest::RequestData, WebCore::ResourceRequestPlatformData>>);
    encoder << instance.getRequestDataToSerialize();
}

std::optional<WebCore::ResourceRequest> ArgumentCoder<WebCore::ResourceRequest>::decode(Decoder& decoder)
{
    auto getRequestDataToSerialize = decoder.decode<std::variant<WebCore::ResourceRequest::RequestData, WebCore::ResourceRequestPlatformData>>();
    if (!getRequestDataToSerialize)
        return std::nullopt;

    return {
        WebCore::ResourceRequest::fromResourceRequestData(
            WTFMove(*getRequestDataToSerialize)
        )
    };
}

#endif

#if !USE(CG)

void ArgumentCoder<WebCore::PlatformColorSpace>::encode(Encoder& encoder, const WebCore::PlatformColorSpace& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.get())>, WebCore::PlatformColorSpace::Name>);
    encoder << instance.get();
}

void ArgumentCoder<WebCore::PlatformColorSpace>::encode(StreamConnectionEncoder& encoder, const WebCore::PlatformColorSpace& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.get())>, WebCore::PlatformColorSpace::Name>);
    encoder << instance.get();
}

std::optional<WebCore::PlatformColorSpace> ArgumentCoder<WebCore::PlatformColorSpace>::decode(Decoder& decoder)
{
    auto get = decoder.decode<WebCore::PlatformColorSpace::Name>();
    if (!get)
        return std::nullopt;

    return {
        WebCore::PlatformColorSpace {
            WTFMove(*get)
        }
    };
}

#endif


void ArgumentCoder<WebCore::DestinationColorSpace>::encode(Encoder& encoder, const WebCore::DestinationColorSpace& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.serializableColorSpace())>, WebCore::PlatformColorSpace>);
    encoder << instance.serializableColorSpace();
}

void ArgumentCoder<WebCore::DestinationColorSpace>::encode(StreamConnectionEncoder& encoder, const WebCore::DestinationColorSpace& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.serializableColorSpace())>, WebCore::PlatformColorSpace>);
    encoder << instance.serializableColorSpace();
}

std::optional<WebCore::DestinationColorSpace> ArgumentCoder<WebCore::DestinationColorSpace>::decode(Decoder& decoder)
{
    auto serializableColorSpace = decoder.decode<WebCore::PlatformColorSpace>();
    if (!serializableColorSpace)
        return std::nullopt;

    return {
        WebCore::DestinationColorSpace {
            WTFMove(*serializableColorSpace)
        }
    };
}


void ArgumentCoder<WebCore::WindowFeatures>::encode(Encoder& encoder, const WebCore::WindowFeatures& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x)>, std::optional<float>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y)>, std::optional<float>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width)>, std::optional<float>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height)>, std::optional<float>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.menuBarVisible)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.statusBarVisible)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.toolBarVisible)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.locationBarVisible)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scrollbarsVisible)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.resizable)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fullscreen)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dialog)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::WindowFeatures, x)
        , offsetof(WebCore::WindowFeatures, y)
        , offsetof(WebCore::WindowFeatures, width)
        , offsetof(WebCore::WindowFeatures, height)
        , offsetof(WebCore::WindowFeatures, menuBarVisible)
        , offsetof(WebCore::WindowFeatures, statusBarVisible)
        , offsetof(WebCore::WindowFeatures, toolBarVisible)
        , offsetof(WebCore::WindowFeatures, locationBarVisible)
        , offsetof(WebCore::WindowFeatures, scrollbarsVisible)
        , offsetof(WebCore::WindowFeatures, resizable)
        , offsetof(WebCore::WindowFeatures, fullscreen)
        , offsetof(WebCore::WindowFeatures, dialog)
    >::value);
    encoder << instance.x;
    encoder << instance.y;
    encoder << instance.width;
    encoder << instance.height;
    encoder << instance.menuBarVisible;
    encoder << instance.statusBarVisible;
    encoder << instance.toolBarVisible;
    encoder << instance.locationBarVisible;
    encoder << instance.scrollbarsVisible;
    encoder << instance.resizable;
    encoder << instance.fullscreen;
    encoder << instance.dialog;
}

std::optional<WebCore::WindowFeatures> ArgumentCoder<WebCore::WindowFeatures>::decode(Decoder& decoder)
{
    auto x = decoder.decode<std::optional<float>>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<std::optional<float>>();
    if (!y)
        return std::nullopt;

    auto width = decoder.decode<std::optional<float>>();
    if (!width)
        return std::nullopt;

    auto height = decoder.decode<std::optional<float>>();
    if (!height)
        return std::nullopt;

    auto menuBarVisible = decoder.decode<bool>();
    if (!menuBarVisible)
        return std::nullopt;

    auto statusBarVisible = decoder.decode<bool>();
    if (!statusBarVisible)
        return std::nullopt;

    auto toolBarVisible = decoder.decode<bool>();
    if (!toolBarVisible)
        return std::nullopt;

    auto locationBarVisible = decoder.decode<bool>();
    if (!locationBarVisible)
        return std::nullopt;

    auto scrollbarsVisible = decoder.decode<bool>();
    if (!scrollbarsVisible)
        return std::nullopt;

    auto resizable = decoder.decode<bool>();
    if (!resizable)
        return std::nullopt;

    auto fullscreen = decoder.decode<bool>();
    if (!fullscreen)
        return std::nullopt;

    auto dialog = decoder.decode<bool>();
    if (!dialog)
        return std::nullopt;

    return {
        WebCore::WindowFeatures {
            WTFMove(*x),
            WTFMove(*y),
            WTFMove(*width),
            WTFMove(*height),
            WTFMove(*menuBarVisible),
            WTFMove(*statusBarVisible),
            WTFMove(*toolBarVisible),
            WTFMove(*locationBarVisible),
            WTFMove(*scrollbarsVisible),
            WTFMove(*resizable),
            WTFMove(*fullscreen),
            WTFMove(*dialog)
        }
    };
}


void ArgumentCoder<WebCore::CompositionUnderline>::encode(Encoder& encoder, const WebCore::CompositionUnderline& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startOffset)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endOffset)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compositionUnderlineColor)>, WebCore::CompositionUnderlineColor>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.thick)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CompositionUnderline, startOffset)
        , offsetof(WebCore::CompositionUnderline, endOffset)
        , offsetof(WebCore::CompositionUnderline, compositionUnderlineColor)
        , offsetof(WebCore::CompositionUnderline, color)
        , offsetof(WebCore::CompositionUnderline, thick)
    >::value);
    encoder << instance.startOffset;
    encoder << instance.endOffset;
    encoder << instance.compositionUnderlineColor;
    encoder << instance.color;
    encoder << instance.thick;
}

std::optional<WebCore::CompositionUnderline> ArgumentCoder<WebCore::CompositionUnderline>::decode(Decoder& decoder)
{
    auto startOffset = decoder.decode<unsigned>();
    if (!startOffset)
        return std::nullopt;

    auto endOffset = decoder.decode<unsigned>();
    if (!endOffset)
        return std::nullopt;

    auto compositionUnderlineColor = decoder.decode<WebCore::CompositionUnderlineColor>();
    if (!compositionUnderlineColor)
        return std::nullopt;

    auto color = decoder.decode<WebCore::Color>();
    if (!color)
        return std::nullopt;

    auto thick = decoder.decode<bool>();
    if (!thick)
        return std::nullopt;

    return {
        WebCore::CompositionUnderline {
            WTFMove(*startOffset),
            WTFMove(*endOffset),
            WTFMove(*compositionUnderlineColor),
            WTFMove(*color),
            WTFMove(*thick)
        }
    };
}


void ArgumentCoder<WebCore::FileChooserSettings>::encode(Encoder& encoder, const WebCore::FileChooserSettings& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowsDirectories)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowsMultipleFiles)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.acceptMIMETypes)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.acceptFileExtensions)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectedFiles)>, Vector<String>>);
#if ENABLE(MEDIA_CAPTURE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mediaCaptureType)>, WebCore::MediaCaptureType>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FileChooserSettings, allowsDirectories)
        , offsetof(WebCore::FileChooserSettings, allowsMultipleFiles)
        , offsetof(WebCore::FileChooserSettings, acceptMIMETypes)
        , offsetof(WebCore::FileChooserSettings, acceptFileExtensions)
        , offsetof(WebCore::FileChooserSettings, selectedFiles)
#if ENABLE(MEDIA_CAPTURE)
        , offsetof(WebCore::FileChooserSettings, mediaCaptureType)
#endif
    >::value);
    encoder << instance.allowsDirectories;
    encoder << instance.allowsMultipleFiles;
    encoder << instance.acceptMIMETypes;
    encoder << instance.acceptFileExtensions;
    encoder << instance.selectedFiles;
#if ENABLE(MEDIA_CAPTURE)
    encoder << instance.mediaCaptureType;
#endif
}

std::optional<WebCore::FileChooserSettings> ArgumentCoder<WebCore::FileChooserSettings>::decode(Decoder& decoder)
{
    auto allowsDirectories = decoder.decode<bool>();
    if (!allowsDirectories)
        return std::nullopt;

    auto allowsMultipleFiles = decoder.decode<bool>();
    if (!allowsMultipleFiles)
        return std::nullopt;

    auto acceptMIMETypes = decoder.decode<Vector<String>>();
    if (!acceptMIMETypes)
        return std::nullopt;

    auto acceptFileExtensions = decoder.decode<Vector<String>>();
    if (!acceptFileExtensions)
        return std::nullopt;

    auto selectedFiles = decoder.decode<Vector<String>>();
    if (!selectedFiles)
        return std::nullopt;

#if ENABLE(MEDIA_CAPTURE)
    auto mediaCaptureType = decoder.decode<WebCore::MediaCaptureType>();
    if (!mediaCaptureType)
        return std::nullopt;
#endif

    return {
        WebCore::FileChooserSettings {
            WTFMove(*allowsDirectories),
            WTFMove(*allowsMultipleFiles),
            WTFMove(*acceptMIMETypes),
            WTFMove(*acceptFileExtensions),
            WTFMove(*selectedFiles),
#if ENABLE(MEDIA_CAPTURE)
            WTFMove(*mediaCaptureType)
#endif
        }
    };
}


void ArgumentCoder<WebCore::GrammarDetail>::encode(Encoder& encoder, const WebCore::GrammarDetail& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.range)>, WebCore::CharacterRange>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.guesses)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.userDescription)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GrammarDetail, range)
        , offsetof(WebCore::GrammarDetail, guesses)
        , offsetof(WebCore::GrammarDetail, userDescription)
    >::value);
    encoder << instance.range;
    encoder << instance.guesses;
    encoder << instance.userDescription;
}

std::optional<WebCore::GrammarDetail> ArgumentCoder<WebCore::GrammarDetail>::decode(Decoder& decoder)
{
    auto range = decoder.decode<WebCore::CharacterRange>();
    if (!range)
        return std::nullopt;

    auto guesses = decoder.decode<Vector<String>>();
    if (!guesses)
        return std::nullopt;

    auto userDescription = decoder.decode<String>();
    if (!userDescription)
        return std::nullopt;

    return {
        WebCore::GrammarDetail {
            WTFMove(*range),
            WTFMove(*guesses),
            WTFMove(*userDescription)
        }
    };
}


void ArgumentCoder<WebCore::TextCheckingResult>::encode(Encoder& encoder, const WebCore::TextCheckingResult& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, OptionSet<WebCore::TextCheckingType>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.range)>, WebCore::CharacterRange>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.details)>, Vector<WebCore::GrammarDetail>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.replacement)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextCheckingResult, type)
        , offsetof(WebCore::TextCheckingResult, range)
        , offsetof(WebCore::TextCheckingResult, details)
        , offsetof(WebCore::TextCheckingResult, replacement)
    >::value);
    encoder << instance.type;
    encoder << instance.range;
    encoder << instance.details;
    encoder << instance.replacement;
}

std::optional<WebCore::TextCheckingResult> ArgumentCoder<WebCore::TextCheckingResult>::decode(Decoder& decoder)
{
    auto type = decoder.decode<OptionSet<WebCore::TextCheckingType>>();
    if (!type)
        return std::nullopt;

    auto range = decoder.decode<WebCore::CharacterRange>();
    if (!range)
        return std::nullopt;

    auto details = decoder.decode<Vector<WebCore::GrammarDetail>>();
    if (!details)
        return std::nullopt;

    auto replacement = decoder.decode<String>();
    if (!replacement)
        return std::nullopt;

    return {
        WebCore::TextCheckingResult {
            WTFMove(*type),
            WTFMove(*range),
            WTFMove(*details),
            WTFMove(*replacement)
        }
    };
}


void ArgumentCoder<WebCore::TextCheckingRequestData>::encode(Encoder& encoder, const WebCore::TextCheckingRequestData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier())>, std::optional<WebCore::TextCheckingRequestIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.text())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.checkingTypes())>, OptionSet<WebCore::TextCheckingType>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.processType())>, WebCore::TextCheckingProcessType>);
    encoder << instance.identifier();
    encoder << instance.text();
    encoder << instance.checkingTypes();
    encoder << instance.processType();
}

std::optional<WebCore::TextCheckingRequestData> ArgumentCoder<WebCore::TextCheckingRequestData>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<std::optional<WebCore::TextCheckingRequestIdentifier>>();
    if (!identifier)
        return std::nullopt;

    auto text = decoder.decode<String>();
    if (!text)
        return std::nullopt;

    auto checkingTypes = decoder.decode<OptionSet<WebCore::TextCheckingType>>();
    if (!checkingTypes)
        return std::nullopt;

    auto processType = decoder.decode<WebCore::TextCheckingProcessType>();
    if (!processType)
        return std::nullopt;

    return {
        WebCore::TextCheckingRequestData {
            WTFMove(*identifier),
            WTFMove(*text),
            WTFMove(*checkingTypes),
            WTFMove(*processType)
        }
    };
}


void ArgumentCoder<WebCore::LayoutRect>::encode(Encoder& encoder, const WebCore::LayoutRect& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_location)>, WebCore::LayoutPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_size)>, WebCore::LayoutSize>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::LayoutRect, m_location)
        , offsetof(WebCore::LayoutRect, m_size)
    >::value);
    encoder << instance.m_location;
    encoder << instance.m_size;
}

std::optional<WebCore::LayoutRect> ArgumentCoder<WebCore::LayoutRect>::decode(Decoder& decoder)
{
    auto m_location = decoder.decode<WebCore::LayoutPoint>();
    if (!m_location)
        return std::nullopt;

    auto m_size = decoder.decode<WebCore::LayoutSize>();
    if (!m_size)
        return std::nullopt;

    return {
        WebCore::LayoutRect {
            WTFMove(*m_location),
            WTFMove(*m_size)
        }
    };
}


void ArgumentCoder<WebCore::ScreenDataOverrides>::encode(Encoder& encoder, const WebCore::ScreenDataOverrides& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scale)>, double>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ScreenDataOverrides, width)
        , offsetof(WebCore::ScreenDataOverrides, height)
        , offsetof(WebCore::ScreenDataOverrides, scale)
    >::value);
    encoder << instance.width;
    encoder << instance.height;
    encoder << instance.scale;
}

std::optional<WebCore::ScreenDataOverrides> ArgumentCoder<WebCore::ScreenDataOverrides>::decode(Decoder& decoder)
{
    auto width = decoder.decode<double>();
    if (!width)
        return std::nullopt;

    auto height = decoder.decode<double>();
    if (!height)
        return std::nullopt;

    auto scale = decoder.decode<double>();
    if (!scale)
        return std::nullopt;

    return {
        WebCore::ScreenDataOverrides {
            WTFMove(*width),
            WTFMove(*height),
            WTFMove(*scale)
        }
    };
}


void ArgumentCoder<WebCore::MediaCapabilitiesInfo>::encode(Encoder& encoder, const WebCore::MediaCapabilitiesInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supported)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.smooth)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.powerEfficient)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaCapabilitiesInfo, supported)
        , offsetof(WebCore::MediaCapabilitiesInfo, smooth)
        , offsetof(WebCore::MediaCapabilitiesInfo, powerEfficient)
    >::value);
    encoder << instance.supported;
    encoder << instance.smooth;
    encoder << instance.powerEfficient;
}

std::optional<WebCore::MediaCapabilitiesInfo> ArgumentCoder<WebCore::MediaCapabilitiesInfo>::decode(Decoder& decoder)
{
    auto supported = decoder.decode<bool>();
    if (!supported)
        return std::nullopt;

    auto smooth = decoder.decode<bool>();
    if (!smooth)
        return std::nullopt;

    auto powerEfficient = decoder.decode<bool>();
    if (!powerEfficient)
        return std::nullopt;

    return {
        WebCore::MediaCapabilitiesInfo {
            WTFMove(*supported),
            WTFMove(*smooth),
            WTFMove(*powerEfficient)
        }
    };
}

#if ENABLE(MEDIA_STREAM)

void ArgumentCoder<WebCore::MediaStreamRequest>::encode(Encoder& encoder, const WebCore::MediaStreamRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::MediaStreamRequest::Type>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.audioConstraints)>, WebCore::MediaConstraints>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.videoConstraints)>, WebCore::MediaConstraints>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isUserGesturePriviledged)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageIdentifier)>, WebCore::PageIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaStreamRequest, type)
        , offsetof(WebCore::MediaStreamRequest, audioConstraints)
        , offsetof(WebCore::MediaStreamRequest, videoConstraints)
        , offsetof(WebCore::MediaStreamRequest, isUserGesturePriviledged)
        , offsetof(WebCore::MediaStreamRequest, pageIdentifier)
    >::value);
    encoder << instance.type;
    encoder << instance.audioConstraints;
    encoder << instance.videoConstraints;
    encoder << instance.isUserGesturePriviledged;
    encoder << instance.pageIdentifier;
}

std::optional<WebCore::MediaStreamRequest> ArgumentCoder<WebCore::MediaStreamRequest>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::MediaStreamRequest::Type>();
    if (!type)
        return std::nullopt;

    auto audioConstraints = decoder.decode<WebCore::MediaConstraints>();
    if (!audioConstraints)
        return std::nullopt;

    auto videoConstraints = decoder.decode<WebCore::MediaConstraints>();
    if (!videoConstraints)
        return std::nullopt;

    auto isUserGesturePriviledged = decoder.decode<bool>();
    if (!isUserGesturePriviledged)
        return std::nullopt;

    auto pageIdentifier = decoder.decode<WebCore::PageIdentifier>();
    if (!pageIdentifier)
        return std::nullopt;

    return {
        WebCore::MediaStreamRequest {
            WTFMove(*type),
            WTFMove(*audioConstraints),
            WTFMove(*videoConstraints),
            WTFMove(*isUserGesturePriviledged),
            WTFMove(*pageIdentifier)
        }
    };
}

#endif

#if ENABLE(MEDIA_STREAM)

void ArgumentCoder<WebCore::MediaTrackConstraintSetMap>::encode(Encoder& encoder, const WebCore::MediaTrackConstraintSetMap& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_width)>, std::optional<WebCore::IntConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_height)>, std::optional<WebCore::IntConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_sampleRate)>, std::optional<WebCore::IntConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_sampleSize)>, std::optional<WebCore::IntConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_aspectRatio)>, std::optional<WebCore::DoubleConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_frameRate)>, std::optional<WebCore::DoubleConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_volume)>, std::optional<WebCore::DoubleConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_echoCancellation)>, std::optional<WebCore::BooleanConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_displaySurface)>, std::optional<WebCore::BooleanConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_logicalSurface)>, std::optional<WebCore::BooleanConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_facingMode)>, std::optional<WebCore::StringConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_deviceId)>, std::optional<WebCore::StringConstraint>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_groupId)>, std::optional<WebCore::StringConstraint>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_width)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_height)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_sampleRate)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_sampleSize)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_aspectRatio)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_frameRate)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_volume)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_echoCancellation)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_displaySurface)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_logicalSurface)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_facingMode)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_deviceId)
        , offsetof(WebCore::MediaTrackConstraintSetMap, m_groupId)
    >::value);
    encoder << instance.m_width;
    encoder << instance.m_height;
    encoder << instance.m_sampleRate;
    encoder << instance.m_sampleSize;
    encoder << instance.m_aspectRatio;
    encoder << instance.m_frameRate;
    encoder << instance.m_volume;
    encoder << instance.m_echoCancellation;
    encoder << instance.m_displaySurface;
    encoder << instance.m_logicalSurface;
    encoder << instance.m_facingMode;
    encoder << instance.m_deviceId;
    encoder << instance.m_groupId;
}

std::optional<WebCore::MediaTrackConstraintSetMap> ArgumentCoder<WebCore::MediaTrackConstraintSetMap>::decode(Decoder& decoder)
{
    auto m_width = decoder.decode<std::optional<WebCore::IntConstraint>>();
    if (!m_width)
        return std::nullopt;

    auto m_height = decoder.decode<std::optional<WebCore::IntConstraint>>();
    if (!m_height)
        return std::nullopt;

    auto m_sampleRate = decoder.decode<std::optional<WebCore::IntConstraint>>();
    if (!m_sampleRate)
        return std::nullopt;

    auto m_sampleSize = decoder.decode<std::optional<WebCore::IntConstraint>>();
    if (!m_sampleSize)
        return std::nullopt;

    auto m_aspectRatio = decoder.decode<std::optional<WebCore::DoubleConstraint>>();
    if (!m_aspectRatio)
        return std::nullopt;

    auto m_frameRate = decoder.decode<std::optional<WebCore::DoubleConstraint>>();
    if (!m_frameRate)
        return std::nullopt;

    auto m_volume = decoder.decode<std::optional<WebCore::DoubleConstraint>>();
    if (!m_volume)
        return std::nullopt;

    auto m_echoCancellation = decoder.decode<std::optional<WebCore::BooleanConstraint>>();
    if (!m_echoCancellation)
        return std::nullopt;

    auto m_displaySurface = decoder.decode<std::optional<WebCore::BooleanConstraint>>();
    if (!m_displaySurface)
        return std::nullopt;

    auto m_logicalSurface = decoder.decode<std::optional<WebCore::BooleanConstraint>>();
    if (!m_logicalSurface)
        return std::nullopt;

    auto m_facingMode = decoder.decode<std::optional<WebCore::StringConstraint>>();
    if (!m_facingMode)
        return std::nullopt;

    auto m_deviceId = decoder.decode<std::optional<WebCore::StringConstraint>>();
    if (!m_deviceId)
        return std::nullopt;

    auto m_groupId = decoder.decode<std::optional<WebCore::StringConstraint>>();
    if (!m_groupId)
        return std::nullopt;

    WebCore::MediaTrackConstraintSetMap result;
    result.m_width = WTFMove(*m_width);
    result.m_height = WTFMove(*m_height);
    result.m_sampleRate = WTFMove(*m_sampleRate);
    result.m_sampleSize = WTFMove(*m_sampleSize);
    result.m_aspectRatio = WTFMove(*m_aspectRatio);
    result.m_frameRate = WTFMove(*m_frameRate);
    result.m_volume = WTFMove(*m_volume);
    result.m_echoCancellation = WTFMove(*m_echoCancellation);
    result.m_displaySurface = WTFMove(*m_displaySurface);
    result.m_logicalSurface = WTFMove(*m_logicalSurface);
    result.m_facingMode = WTFMove(*m_facingMode);
    result.m_deviceId = WTFMove(*m_deviceId);
    result.m_groupId = WTFMove(*m_groupId);
    return { WTFMove(result) };
}

#endif

#if ! ENABLE(MEDIA_STREAM)

void ArgumentCoder<WebCore::MediaStreamRequest>::encode(Encoder& encoder, const WebCore::MediaStreamRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::MediaStreamRequest::Type>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaStreamRequest, type)
    >::value);
    encoder << instance.type;
}

std::optional<WebCore::MediaStreamRequest> ArgumentCoder<WebCore::MediaStreamRequest>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::MediaStreamRequest::Type>();
    if (!type)
        return std::nullopt;

    return {
        WebCore::MediaStreamRequest {
            WTFMove(*type)
        }
    };
}

#endif


void ArgumentCoder<WebCore::MediaCapabilitiesDecodingInfo>::encode(Encoder& encoder, const WebCore::MediaCapabilitiesDecodingInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supported)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.smooth)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.powerEfficient)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaCapabilitiesInfo, supported)
        , offsetof(WebCore::MediaCapabilitiesInfo, smooth)
        , offsetof(WebCore::MediaCapabilitiesInfo, powerEfficient)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supportedConfiguration)>, WebCore::MediaDecodingConfiguration>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaCapabilitiesDecodingInfo, supportedConfiguration)
    >::value);
    encoder << instance.supported;
    encoder << instance.smooth;
    encoder << instance.powerEfficient;
    encoder << instance.supportedConfiguration;
}

std::optional<WebCore::MediaCapabilitiesDecodingInfo> ArgumentCoder<WebCore::MediaCapabilitiesDecodingInfo>::decode(Decoder& decoder)
{
    auto supported = decoder.decode<bool>();
    if (!supported)
        return std::nullopt;

    auto smooth = decoder.decode<bool>();
    if (!smooth)
        return std::nullopt;

    auto powerEfficient = decoder.decode<bool>();
    if (!powerEfficient)
        return std::nullopt;

    auto supportedConfiguration = decoder.decode<WebCore::MediaDecodingConfiguration>();
    if (!supportedConfiguration)
        return std::nullopt;

    return {
        WebCore::MediaCapabilitiesDecodingInfo {
            WebCore::MediaCapabilitiesInfo {
                WTFMove(*supported),
                WTFMove(*smooth),
                WTFMove(*powerEfficient)
            },
            WTFMove(*supportedConfiguration)
        }
    };
}


void ArgumentCoder<WebCore::MediaCapabilitiesEncodingInfo>::encode(Encoder& encoder, const WebCore::MediaCapabilitiesEncodingInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supported)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.smooth)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.powerEfficient)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaCapabilitiesInfo, supported)
        , offsetof(WebCore::MediaCapabilitiesInfo, smooth)
        , offsetof(WebCore::MediaCapabilitiesInfo, powerEfficient)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supportedConfiguration)>, WebCore::MediaEncodingConfiguration>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaCapabilitiesEncodingInfo, supportedConfiguration)
    >::value);
    encoder << instance.supported;
    encoder << instance.smooth;
    encoder << instance.powerEfficient;
    encoder << instance.supportedConfiguration;
}

std::optional<WebCore::MediaCapabilitiesEncodingInfo> ArgumentCoder<WebCore::MediaCapabilitiesEncodingInfo>::decode(Decoder& decoder)
{
    auto supported = decoder.decode<bool>();
    if (!supported)
        return std::nullopt;

    auto smooth = decoder.decode<bool>();
    if (!smooth)
        return std::nullopt;

    auto powerEfficient = decoder.decode<bool>();
    if (!powerEfficient)
        return std::nullopt;

    auto supportedConfiguration = decoder.decode<WebCore::MediaEncodingConfiguration>();
    if (!supportedConfiguration)
        return std::nullopt;

    return {
        WebCore::MediaCapabilitiesEncodingInfo {
            WebCore::MediaCapabilitiesInfo {
                WTFMove(*supported),
                WTFMove(*smooth),
                WTFMove(*powerEfficient)
            },
            WTFMove(*supportedConfiguration)
        }
    };
}


void ArgumentCoder<WebCore::FormDataElement>::encode(Encoder& encoder, const WebCore::FormDataElement& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data)>, std::variant<Vector<uint8_t>, WebCore::FormDataElement::EncodedFileData, WebCore::FormDataElement::EncodedBlobData>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FormDataElement, data)
    >::value);
    encoder << instance.data;
}

std::optional<WebCore::FormDataElement> ArgumentCoder<WebCore::FormDataElement>::decode(Decoder& decoder)
{
    auto data = decoder.decode<std::variant<Vector<uint8_t>, WebCore::FormDataElement::EncodedFileData, WebCore::FormDataElement::EncodedBlobData>>();
    if (!data)
        return std::nullopt;

    return {
        WebCore::FormDataElement {
            WTFMove(*data)
        }
    };
}


void ArgumentCoder<WebCore::FormDataElement::EncodedFileData>::encode(Encoder& encoder, const WebCore::FormDataElement::EncodedFileData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.filename)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fileStart)>, int64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fileLength)>, int64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.expectedFileModificationTime)>, std::optional<WallTime>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FormDataElement::EncodedFileData, filename)
        , offsetof(WebCore::FormDataElement::EncodedFileData, fileStart)
        , offsetof(WebCore::FormDataElement::EncodedFileData, fileLength)
        , offsetof(WebCore::FormDataElement::EncodedFileData, expectedFileModificationTime)
    >::value);
    encoder << instance.filename;
    encoder << instance.fileStart;
    encoder << instance.fileLength;
    encoder << instance.expectedFileModificationTime;
}

std::optional<WebCore::FormDataElement::EncodedFileData> ArgumentCoder<WebCore::FormDataElement::EncodedFileData>::decode(Decoder& decoder)
{
    auto filename = decoder.decode<String>();
    if (!filename)
        return std::nullopt;

    auto fileStart = decoder.decode<int64_t>();
    if (!fileStart)
        return std::nullopt;

    auto fileLength = decoder.decode<int64_t>();
    if (!fileLength)
        return std::nullopt;

    auto expectedFileModificationTime = decoder.decode<std::optional<WallTime>>();
    if (!expectedFileModificationTime)
        return std::nullopt;

    return {
        WebCore::FormDataElement::EncodedFileData {
            WTFMove(*filename),
            WTFMove(*fileStart),
            WTFMove(*fileLength),
            WTFMove(*expectedFileModificationTime)
        }
    };
}


void ArgumentCoder<WebCore::FormDataElement::EncodedBlobData>::encode(Encoder& encoder, const WebCore::FormDataElement::EncodedBlobData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, URL>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FormDataElement::EncodedBlobData, url)
    >::value);
    encoder << instance.url;
}

std::optional<WebCore::FormDataElement::EncodedBlobData> ArgumentCoder<WebCore::FormDataElement::EncodedBlobData>::decode(Decoder& decoder)
{
    auto url = decoder.decode<URL>();
    if (!url)
        return std::nullopt;

    return {
        WebCore::FormDataElement::EncodedBlobData {
            WTFMove(*url)
        }
    };
}


void ArgumentCoder<WebCore::NetworkTransactionInformation>::encode(Encoder& encoder, const WebCore::NetworkTransactionInformation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::NetworkTransactionInformation::Type>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.request)>, WebCore::ResourceRequest>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.response)>, WebCore::ResourceResponse>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.metrics)>, WebCore::NetworkLoadMetrics>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::NetworkTransactionInformation, type)
        , offsetof(WebCore::NetworkTransactionInformation, request)
        , offsetof(WebCore::NetworkTransactionInformation, response)
        , offsetof(WebCore::NetworkTransactionInformation, metrics)
    >::value);
    encoder << instance.type;
    encoder << instance.request;
    encoder << instance.response;
    encoder << instance.metrics;
}

std::optional<WebCore::NetworkTransactionInformation> ArgumentCoder<WebCore::NetworkTransactionInformation>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::NetworkTransactionInformation::Type>();
    if (!type)
        return std::nullopt;

    auto request = decoder.decode<WebCore::ResourceRequest>();
    if (!request)
        return std::nullopt;

    auto response = decoder.decode<WebCore::ResourceResponse>();
    if (!response)
        return std::nullopt;

    auto metrics = decoder.decode<WebCore::NetworkLoadMetrics>();
    if (!metrics)
        return std::nullopt;

    return {
        WebCore::NetworkTransactionInformation {
            WTFMove(*type),
            WTFMove(*request),
            WTFMove(*response),
            WTFMove(*metrics)
        }
    };
}


void ArgumentCoder<WebCore::ContentType>::encode(Encoder& encoder, const WebCore::ContentType& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.raw())>, String>);
    encoder << instance.raw();
}

std::optional<WebCore::ContentType> ArgumentCoder<WebCore::ContentType>::decode(Decoder& decoder)
{
    auto raw = decoder.decode<String>();
    if (!raw)
        return std::nullopt;

    return {
        WebCore::ContentType {
            WTFMove(*raw)
        }
    };
}

#if ENABLE(DATE_AND_TIME_INPUT_TYPES)

void ArgumentCoder<WebCore::DateTimeChooserParameters>::encode(Encoder& encoder, const WebCore::DateTimeChooserParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.anchorRectInRootView)>, WebCore::IntRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.locale)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.currentValue)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.suggestionValues)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.localizedSuggestionValues)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.suggestionLabels)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minimum)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maximum)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.step)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stepBase)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.required)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isAnchorElementRTL)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.useDarkAppearance)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasSecondField)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasMillisecondField)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DateTimeChooserParameters, type)
        , offsetof(WebCore::DateTimeChooserParameters, anchorRectInRootView)
        , offsetof(WebCore::DateTimeChooserParameters, locale)
        , offsetof(WebCore::DateTimeChooserParameters, currentValue)
        , offsetof(WebCore::DateTimeChooserParameters, suggestionValues)
        , offsetof(WebCore::DateTimeChooserParameters, localizedSuggestionValues)
        , offsetof(WebCore::DateTimeChooserParameters, suggestionLabels)
        , offsetof(WebCore::DateTimeChooserParameters, minimum)
        , offsetof(WebCore::DateTimeChooserParameters, maximum)
        , offsetof(WebCore::DateTimeChooserParameters, step)
        , offsetof(WebCore::DateTimeChooserParameters, stepBase)
        , offsetof(WebCore::DateTimeChooserParameters, required)
        , offsetof(WebCore::DateTimeChooserParameters, isAnchorElementRTL)
        , offsetof(WebCore::DateTimeChooserParameters, useDarkAppearance)
        , offsetof(WebCore::DateTimeChooserParameters, hasSecondField)
        , offsetof(WebCore::DateTimeChooserParameters, hasMillisecondField)
    >::value);
    encoder << instance.type;
    encoder << instance.anchorRectInRootView;
    encoder << instance.locale;
    encoder << instance.currentValue;
    encoder << instance.suggestionValues;
    encoder << instance.localizedSuggestionValues;
    encoder << instance.suggestionLabels;
    encoder << instance.minimum;
    encoder << instance.maximum;
    encoder << instance.step;
    encoder << instance.stepBase;
    encoder << instance.required;
    encoder << instance.isAnchorElementRTL;
    encoder << instance.useDarkAppearance;
    encoder << instance.hasSecondField;
    encoder << instance.hasMillisecondField;
}

std::optional<WebCore::DateTimeChooserParameters> ArgumentCoder<WebCore::DateTimeChooserParameters>::decode(Decoder& decoder)
{
    auto type = decoder.decode<AtomString>();
    if (!type)
        return std::nullopt;

    auto anchorRectInRootView = decoder.decode<WebCore::IntRect>();
    if (!anchorRectInRootView)
        return std::nullopt;

    auto locale = decoder.decode<AtomString>();
    if (!locale)
        return std::nullopt;

    auto currentValue = decoder.decode<String>();
    if (!currentValue)
        return std::nullopt;

    auto suggestionValues = decoder.decode<Vector<String>>();
    if (!suggestionValues)
        return std::nullopt;

    auto localizedSuggestionValues = decoder.decode<Vector<String>>();
    if (!localizedSuggestionValues)
        return std::nullopt;

    auto suggestionLabels = decoder.decode<Vector<String>>();
    if (!suggestionLabels)
        return std::nullopt;

    auto minimum = decoder.decode<double>();
    if (!minimum)
        return std::nullopt;

    auto maximum = decoder.decode<double>();
    if (!maximum)
        return std::nullopt;

    auto step = decoder.decode<double>();
    if (!step)
        return std::nullopt;

    auto stepBase = decoder.decode<double>();
    if (!stepBase)
        return std::nullopt;

    auto required = decoder.decode<bool>();
    if (!required)
        return std::nullopt;

    auto isAnchorElementRTL = decoder.decode<bool>();
    if (!isAnchorElementRTL)
        return std::nullopt;

    auto useDarkAppearance = decoder.decode<bool>();
    if (!useDarkAppearance)
        return std::nullopt;

    auto hasSecondField = decoder.decode<bool>();
    if (!hasSecondField)
        return std::nullopt;

    auto hasMillisecondField = decoder.decode<bool>();
    if (!hasMillisecondField)
        return std::nullopt;

    return {
        WebCore::DateTimeChooserParameters {
            WTFMove(*type),
            WTFMove(*anchorRectInRootView),
            WTFMove(*locale),
            WTFMove(*currentValue),
            WTFMove(*suggestionValues),
            WTFMove(*localizedSuggestionValues),
            WTFMove(*suggestionLabels),
            WTFMove(*minimum),
            WTFMove(*maximum),
            WTFMove(*step),
            WTFMove(*stepBase),
            WTFMove(*required),
            WTFMove(*isAnchorElementRTL),
            WTFMove(*useDarkAppearance),
            WTFMove(*hasSecondField),
            WTFMove(*hasMillisecondField)
        }
    };
}

#endif


void ArgumentCoder<WebCore::ScreenData>::encode(Encoder& encoder, const WebCore::ScreenData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenAvailableRect)>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenRect)>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, WebCore::DestinationColorSpace>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenDepth)>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenDepthPerComponent)>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenSupportsExtendedColor)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenHasInvertedColors)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenSupportsHighDynamicRange)>, bool>);
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenIsMonochrome)>, bool>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.displayMask)>, uint32_t>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gpuID)>, WebCore::PlatformGPUID>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preferredDynamicRangeMode)>, WebCore::DynamicRangeMode>);
#endif
#if PLATFORM(MAC) || PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scaleFactor)>, float>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ScreenData, screenAvailableRect)
        , offsetof(WebCore::ScreenData, screenRect)
        , offsetof(WebCore::ScreenData, colorSpace)
        , offsetof(WebCore::ScreenData, screenDepth)
        , offsetof(WebCore::ScreenData, screenDepthPerComponent)
        , offsetof(WebCore::ScreenData, screenSupportsExtendedColor)
        , offsetof(WebCore::ScreenData, screenHasInvertedColors)
        , offsetof(WebCore::ScreenData, screenSupportsHighDynamicRange)
#if PLATFORM(MAC)
        , offsetof(WebCore::ScreenData, screenIsMonochrome)
#endif
#if PLATFORM(MAC)
        , offsetof(WebCore::ScreenData, displayMask)
#endif
#if PLATFORM(MAC)
        , offsetof(WebCore::ScreenData, gpuID)
#endif
#if PLATFORM(MAC)
        , offsetof(WebCore::ScreenData, preferredDynamicRangeMode)
#endif
#if PLATFORM(MAC) || PLATFORM(IOS_FAMILY)
        , offsetof(WebCore::ScreenData, scaleFactor)
#endif
    >::value);
    encoder << instance.screenAvailableRect;
    encoder << instance.screenRect;
    encoder << instance.colorSpace;
    encoder << instance.screenDepth;
    encoder << instance.screenDepthPerComponent;
    encoder << instance.screenSupportsExtendedColor;
    encoder << instance.screenHasInvertedColors;
    encoder << instance.screenSupportsHighDynamicRange;
#if PLATFORM(MAC)
    encoder << instance.screenIsMonochrome;
#endif
#if PLATFORM(MAC)
    encoder << instance.displayMask;
#endif
#if PLATFORM(MAC)
    encoder << instance.gpuID;
#endif
#if PLATFORM(MAC)
    encoder << instance.preferredDynamicRangeMode;
#endif
#if PLATFORM(MAC) || PLATFORM(IOS_FAMILY)
    encoder << instance.scaleFactor;
#endif
}

std::optional<WebCore::ScreenData> ArgumentCoder<WebCore::ScreenData>::decode(Decoder& decoder)
{
    auto screenAvailableRect = decoder.decode<WebCore::FloatRect>();
    if (!screenAvailableRect)
        return std::nullopt;

    auto screenRect = decoder.decode<WebCore::FloatRect>();
    if (!screenRect)
        return std::nullopt;

    auto colorSpace = decoder.decode<WebCore::DestinationColorSpace>();
    if (!colorSpace)
        return std::nullopt;

    auto screenDepth = decoder.decode<int>();
    if (!screenDepth)
        return std::nullopt;

    auto screenDepthPerComponent = decoder.decode<int>();
    if (!screenDepthPerComponent)
        return std::nullopt;

    auto screenSupportsExtendedColor = decoder.decode<bool>();
    if (!screenSupportsExtendedColor)
        return std::nullopt;

    auto screenHasInvertedColors = decoder.decode<bool>();
    if (!screenHasInvertedColors)
        return std::nullopt;

    auto screenSupportsHighDynamicRange = decoder.decode<bool>();
    if (!screenSupportsHighDynamicRange)
        return std::nullopt;

#if PLATFORM(MAC)
    auto screenIsMonochrome = decoder.decode<bool>();
    if (!screenIsMonochrome)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto displayMask = decoder.decode<uint32_t>();
    if (!displayMask)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto gpuID = decoder.decode<WebCore::PlatformGPUID>();
    if (!gpuID)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto preferredDynamicRangeMode = decoder.decode<WebCore::DynamicRangeMode>();
    if (!preferredDynamicRangeMode)
        return std::nullopt;
#endif

#if PLATFORM(MAC) || PLATFORM(IOS_FAMILY)
    auto scaleFactor = decoder.decode<float>();
    if (!scaleFactor)
        return std::nullopt;
#endif

    return {
        WebCore::ScreenData {
            WTFMove(*screenAvailableRect),
            WTFMove(*screenRect),
            WTFMove(*colorSpace),
            WTFMove(*screenDepth),
            WTFMove(*screenDepthPerComponent),
            WTFMove(*screenSupportsExtendedColor),
            WTFMove(*screenHasInvertedColors),
            WTFMove(*screenSupportsHighDynamicRange),
#if PLATFORM(MAC)
            WTFMove(*screenIsMonochrome),
#endif
#if PLATFORM(MAC)
            WTFMove(*displayMask),
#endif
#if PLATFORM(MAC)
            WTFMove(*gpuID),
#endif
#if PLATFORM(MAC)
            WTFMove(*preferredDynamicRangeMode),
#endif
#if PLATFORM(MAC) || PLATFORM(IOS_FAMILY)
            WTFMove(*scaleFactor)
#endif
        }
    };
}


void ArgumentCoder<WebCore::ScreenProperties>::encode(Encoder& encoder, const WebCore::ScreenProperties& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.primaryDisplayID)>, WebCore::PlatformDisplayID>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.screenDataMap)>, HashMap<WebCore::PlatformDisplayID, WebCore::ScreenData>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ScreenProperties, primaryDisplayID)
        , offsetof(WebCore::ScreenProperties, screenDataMap)
    >::value);
    encoder << instance.primaryDisplayID;
    encoder << instance.screenDataMap;
}

std::optional<WebCore::ScreenProperties> ArgumentCoder<WebCore::ScreenProperties>::decode(Decoder& decoder)
{
    auto primaryDisplayID = decoder.decode<WebCore::PlatformDisplayID>();
    if (!primaryDisplayID)
        return std::nullopt;

    auto screenDataMap = decoder.decode<HashMap<WebCore::PlatformDisplayID, WebCore::ScreenData>>();
    if (!screenDataMap)
        return std::nullopt;

    return {
        WebCore::ScreenProperties {
            WTFMove(*primaryDisplayID),
            WTFMove(*screenDataMap)
        }
    };
}


void ArgumentCoder<WebCore::PlatformTimeRanges>::encode(Encoder& encoder, const WebCore::PlatformTimeRanges& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_ranges)>, Vector<WebCore::PlatformTimeRanges::Range>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PlatformTimeRanges, m_ranges)
    >::value);
    encoder << instance.m_ranges;
}

std::optional<WebCore::PlatformTimeRanges> ArgumentCoder<WebCore::PlatformTimeRanges>::decode(Decoder& decoder)
{
    auto m_ranges = decoder.decode<Vector<WebCore::PlatformTimeRanges::Range>>();
    if (!m_ranges)
        return std::nullopt;

    return {
        WebCore::PlatformTimeRanges {
            WTFMove(*m_ranges)
        }
    };
}


void ArgumentCoder<WebCore::PlatformTimeRanges::Range>::encode(Encoder& encoder, const WebCore::PlatformTimeRanges::Range& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.start)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.end)>, MediaTime>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PlatformTimeRanges::Range, start)
        , offsetof(WebCore::PlatformTimeRanges::Range, end)
    >::value);
    encoder << instance.start;
    encoder << instance.end;
}

std::optional<WebCore::PlatformTimeRanges::Range> ArgumentCoder<WebCore::PlatformTimeRanges::Range>::decode(Decoder& decoder)
{
    auto start = decoder.decode<MediaTime>();
    if (!start)
        return std::nullopt;

    auto end = decoder.decode<MediaTime>();
    if (!end)
        return std::nullopt;

    return {
        WebCore::PlatformTimeRanges::Range {
            WTFMove(*start),
            WTFMove(*end)
        }
    };
}

#if ENABLE(VIDEO)

void ArgumentCoder<WebCore::VideoPlaybackQualityMetrics>::encode(Encoder& encoder, const WebCore::VideoPlaybackQualityMetrics& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.totalVideoFrames)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.droppedVideoFrames)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.corruptedVideoFrames)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.totalFrameDelay)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.displayCompositedVideoFrames)>, uint32_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::VideoPlaybackQualityMetrics, totalVideoFrames)
        , offsetof(WebCore::VideoPlaybackQualityMetrics, droppedVideoFrames)
        , offsetof(WebCore::VideoPlaybackQualityMetrics, corruptedVideoFrames)
        , offsetof(WebCore::VideoPlaybackQualityMetrics, totalFrameDelay)
        , offsetof(WebCore::VideoPlaybackQualityMetrics, displayCompositedVideoFrames)
    >::value);
    encoder << instance.totalVideoFrames;
    encoder << instance.droppedVideoFrames;
    encoder << instance.corruptedVideoFrames;
    encoder << instance.totalFrameDelay;
    encoder << instance.displayCompositedVideoFrames;
}

std::optional<WebCore::VideoPlaybackQualityMetrics> ArgumentCoder<WebCore::VideoPlaybackQualityMetrics>::decode(Decoder& decoder)
{
    auto totalVideoFrames = decoder.decode<uint32_t>();
    if (!totalVideoFrames)
        return std::nullopt;

    auto droppedVideoFrames = decoder.decode<uint32_t>();
    if (!droppedVideoFrames)
        return std::nullopt;

    auto corruptedVideoFrames = decoder.decode<uint32_t>();
    if (!corruptedVideoFrames)
        return std::nullopt;

    auto totalFrameDelay = decoder.decode<double>();
    if (!totalFrameDelay)
        return std::nullopt;

    auto displayCompositedVideoFrames = decoder.decode<uint32_t>();
    if (!displayCompositedVideoFrames)
        return std::nullopt;

    return {
        WebCore::VideoPlaybackQualityMetrics {
            WTFMove(*totalVideoFrames),
            WTFMove(*droppedVideoFrames),
            WTFMove(*corruptedVideoFrames),
            WTFMove(*totalFrameDelay),
            WTFMove(*displayCompositedVideoFrames)
        }
    };
}

#endif

#if PLATFORM(IOS_FAMILY)

void ArgumentCoder<WebCore::SelectionGeometry>::encode(Encoder& encoder, const WebCore::SelectionGeometry& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.quad())>, WebCore::FloatQuad>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.behavior())>, WebCore::SelectionRenderingBehavior>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.direction())>, WebCore::TextDirection>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minX())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxX())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxY())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lineNumber())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isLineBreak())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isFirstOnLine())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isLastOnLine())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.containsStart())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.containsEnd())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isHorizontal())>, bool>);
    encoder << instance.quad();
    encoder << instance.behavior();
    encoder << instance.direction();
    encoder << instance.minX();
    encoder << instance.maxX();
    encoder << instance.maxY();
    encoder << instance.lineNumber();
    encoder << instance.isLineBreak();
    encoder << instance.isFirstOnLine();
    encoder << instance.isLastOnLine();
    encoder << instance.containsStart();
    encoder << instance.containsEnd();
    encoder << instance.isHorizontal();
}

std::optional<WebCore::SelectionGeometry> ArgumentCoder<WebCore::SelectionGeometry>::decode(Decoder& decoder)
{
    auto quad = decoder.decode<WebCore::FloatQuad>();
    if (!quad)
        return std::nullopt;

    auto behavior = decoder.decode<WebCore::SelectionRenderingBehavior>();
    if (!behavior)
        return std::nullopt;

    auto direction = decoder.decode<WebCore::TextDirection>();
    if (!direction)
        return std::nullopt;

    auto minX = decoder.decode<int>();
    if (!minX)
        return std::nullopt;

    auto maxX = decoder.decode<int>();
    if (!maxX)
        return std::nullopt;

    auto maxY = decoder.decode<int>();
    if (!maxY)
        return std::nullopt;

    auto lineNumber = decoder.decode<int>();
    if (!lineNumber)
        return std::nullopt;

    auto isLineBreak = decoder.decode<bool>();
    if (!isLineBreak)
        return std::nullopt;

    auto isFirstOnLine = decoder.decode<bool>();
    if (!isFirstOnLine)
        return std::nullopt;

    auto isLastOnLine = decoder.decode<bool>();
    if (!isLastOnLine)
        return std::nullopt;

    auto containsStart = decoder.decode<bool>();
    if (!containsStart)
        return std::nullopt;

    auto containsEnd = decoder.decode<bool>();
    if (!containsEnd)
        return std::nullopt;

    auto isHorizontal = decoder.decode<bool>();
    if (!isHorizontal)
        return std::nullopt;

    return {
        WebCore::SelectionGeometry {
            WTFMove(*quad),
            WTFMove(*behavior),
            WTFMove(*direction),
            WTFMove(*minX),
            WTFMove(*maxX),
            WTFMove(*maxY),
            WTFMove(*lineNumber),
            WTFMove(*isLineBreak),
            WTFMove(*isFirstOnLine),
            WTFMove(*isLastOnLine),
            WTFMove(*containsStart),
            WTFMove(*containsEnd),
            WTFMove(*isHorizontal)
        }
    };
}

#endif

#if ENABLE(DATALIST_ELEMENT)

void ArgumentCoder<WebCore::DataListSuggestion>::encode(Encoder& encoder, const WebCore::DataListSuggestion& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DataListSuggestion, value)
        , offsetof(WebCore::DataListSuggestion, label)
    >::value);
    encoder << instance.value;
    encoder << instance.label;
}

std::optional<WebCore::DataListSuggestion> ArgumentCoder<WebCore::DataListSuggestion>::decode(Decoder& decoder)
{
    auto value = decoder.decode<String>();
    if (!value)
        return std::nullopt;

    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    return {
        WebCore::DataListSuggestion {
            WTFMove(*value),
            WTFMove(*label)
        }
    };
}

#endif

#if ENABLE(DATALIST_ELEMENT)

void ArgumentCoder<WebCore::DataListSuggestionInformation>::encode(Encoder& encoder, const WebCore::DataListSuggestionInformation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.activationType)>, WebCore::DataListSuggestionActivationType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.suggestions)>, Vector<WebCore::DataListSuggestion>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.elementRect)>, WebCore::IntRect>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DataListSuggestionInformation, activationType)
        , offsetof(WebCore::DataListSuggestionInformation, suggestions)
        , offsetof(WebCore::DataListSuggestionInformation, elementRect)
    >::value);
    encoder << instance.activationType;
    encoder << instance.suggestions;
    encoder << instance.elementRect;
}

std::optional<WebCore::DataListSuggestionInformation> ArgumentCoder<WebCore::DataListSuggestionInformation>::decode(Decoder& decoder)
{
    auto activationType = decoder.decode<WebCore::DataListSuggestionActivationType>();
    if (!activationType)
        return std::nullopt;

    auto suggestions = decoder.decode<Vector<WebCore::DataListSuggestion>>();
    if (!suggestions)
        return std::nullopt;

    auto elementRect = decoder.decode<WebCore::IntRect>();
    if (!elementRect)
        return std::nullopt;

    return {
        WebCore::DataListSuggestionInformation {
            WTFMove(*activationType),
            WTFMove(*suggestions),
            WTFMove(*elementRect)
        }
    };
}

#endif


void ArgumentCoder<WebCore::ClientOrigin>::encode(Encoder& encoder, const WebCore::ClientOrigin& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topOrigin)>, WebCore::SecurityOriginData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientOrigin)>, WebCore::SecurityOriginData>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ClientOrigin, topOrigin)
        , offsetof(WebCore::ClientOrigin, clientOrigin)
    >::value);
    encoder << instance.topOrigin;
    encoder << instance.clientOrigin;
}

std::optional<WebCore::ClientOrigin> ArgumentCoder<WebCore::ClientOrigin>::decode(Decoder& decoder)
{
    auto topOrigin = decoder.decode<WebCore::SecurityOriginData>();
    if (!topOrigin)
        return std::nullopt;

    if (!(!topOrigin->isNull()))
        return std::nullopt;

    auto clientOrigin = decoder.decode<WebCore::SecurityOriginData>();
    if (!clientOrigin)
        return std::nullopt;

    if (!(!topOrigin->isNull()))
        return std::nullopt;

    return {
        WebCore::ClientOrigin {
            WTFMove(*topOrigin),
            WTFMove(*clientOrigin)
        }
    };
}


void ArgumentCoder<WebCore::PixelBufferFormat>::encode(Encoder& encoder, const WebCore::PixelBufferFormat& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alphaFormat)>, WebCore::AlphaPremultiplication>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pixelFormat)>, WebCore::PixelFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, WebCore::DestinationColorSpace>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PixelBufferFormat, alphaFormat)
        , offsetof(WebCore::PixelBufferFormat, pixelFormat)
        , offsetof(WebCore::PixelBufferFormat, colorSpace)
    >::value);
    encoder << instance.alphaFormat;
    encoder << instance.pixelFormat;
    encoder << instance.colorSpace;
}

void ArgumentCoder<WebCore::PixelBufferFormat>::encode(StreamConnectionEncoder& encoder, const WebCore::PixelBufferFormat& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alphaFormat)>, WebCore::AlphaPremultiplication>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pixelFormat)>, WebCore::PixelFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, WebCore::DestinationColorSpace>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PixelBufferFormat, alphaFormat)
        , offsetof(WebCore::PixelBufferFormat, pixelFormat)
        , offsetof(WebCore::PixelBufferFormat, colorSpace)
    >::value);
    encoder << instance.alphaFormat;
    encoder << instance.pixelFormat;
    encoder << instance.colorSpace;
}

std::optional<WebCore::PixelBufferFormat> ArgumentCoder<WebCore::PixelBufferFormat>::decode(Decoder& decoder)
{
    auto alphaFormat = decoder.decode<WebCore::AlphaPremultiplication>();
    if (!alphaFormat)
        return std::nullopt;

    auto pixelFormat = decoder.decode<WebCore::PixelFormat>();
    if (!pixelFormat)
        return std::nullopt;

    auto colorSpace = decoder.decode<WebCore::DestinationColorSpace>();
    if (!colorSpace)
        return std::nullopt;

    return {
        WebCore::PixelBufferFormat {
            WTFMove(*alphaFormat),
            WTFMove(*pixelFormat),
            WTFMove(*colorSpace)
        }
    };
}


void ArgumentCoder<WebCore::TextIndicator>::encode(Encoder& encoder, const WebCore::TextIndicator& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data())>, WebCore::TextIndicatorData>);
    encoder << instance.data();
}

std::optional<Ref<WebCore::TextIndicator>> ArgumentCoder<WebCore::TextIndicator>::decode(Decoder& decoder)
{
    auto data = decoder.decode<WebCore::TextIndicatorData>();
    if (!data)
        return std::nullopt;

    return {
        WebCore::TextIndicator::create(
            WTFMove(*data)
        )
    };
}


void ArgumentCoder<WebCore::CertificateInfo>::encode(Encoder& encoder, const WebCore::CertificateInfo& instance)
{
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.trust())>, RetainPtr<SecTrustRef>>);
#endif
#if USE(CURL)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.verificationError())>, int>);
#endif
#if USE(CURL)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.certificateChain())>, Vector<Vector<uint8_t>>>);
#endif
#if USE(SOUP)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.certificate())>, GRefPtr<GTlsCertificate>>);
#endif
#if USE(SOUP)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tlsErrors())>, GTlsCertificateFlags>);
#endif
#if PLATFORM(COCOA)
    encoder << instance.trust();
#endif
#if USE(CURL)
    encoder << instance.verificationError();
#endif
#if USE(CURL)
    encoder << instance.certificateChain();
#endif
#if USE(SOUP)
    encoder << instance.certificate();
#endif
#if USE(SOUP)
    encoder << instance.tlsErrors();
#endif
}

std::optional<WebCore::CertificateInfo> ArgumentCoder<WebCore::CertificateInfo>::decode(Decoder& decoder)
{
#if PLATFORM(COCOA)
    auto trust = decoder.decode<RetainPtr<SecTrustRef>>();
    if (!trust)
        return std::nullopt;
#endif

#if USE(CURL)
    auto verificationError = decoder.decode<int>();
    if (!verificationError)
        return std::nullopt;
#endif

#if USE(CURL)
    auto certificateChain = decoder.decode<Vector<Vector<uint8_t>>>();
    if (!certificateChain)
        return std::nullopt;
#endif

#if USE(SOUP)
    auto certificate = decoder.decode<GRefPtr<GTlsCertificate>>();
    if (!certificate)
        return std::nullopt;
#endif

#if USE(SOUP)
    auto tlsErrors = decoder.decode<GTlsCertificateFlags>();
    if (!tlsErrors)
        return std::nullopt;
#endif

    return {
        WebCore::CertificateInfo {
#if PLATFORM(COCOA)
            WTFMove(*trust),
#endif
#if USE(CURL)
            WTFMove(*verificationError),
#endif
#if USE(CURL)
            WTFMove(*certificateChain),
#endif
#if USE(SOUP)
            WTFMove(*certificate),
#endif
#if USE(SOUP)
            WTFMove(*tlsErrors)
#endif
        }
    };
}


void ArgumentCoder<WebCore::PasteboardCustomData::Entry>::encode(Encoder& encoder, const WebCore::PasteboardCustomData::Entry& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.customData)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.platformData)>, std::variant<String, Ref<WebCore::SharedBuffer>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PasteboardCustomData::Entry, type)
        , offsetof(WebCore::PasteboardCustomData::Entry, customData)
        , offsetof(WebCore::PasteboardCustomData::Entry, platformData)
    >::value);
    encoder << instance.type;
    encoder << instance.customData;
    encoder << instance.platformData;
}

std::optional<WebCore::PasteboardCustomData::Entry> ArgumentCoder<WebCore::PasteboardCustomData::Entry>::decode(Decoder& decoder)
{
    auto type = decoder.decode<String>();
    if (!type)
        return std::nullopt;

    auto customData = decoder.decode<String>();
    if (!customData)
        return std::nullopt;

    auto platformData = decoder.decode<std::variant<String, Ref<WebCore::SharedBuffer>>>();
    if (!platformData)
        return std::nullopt;

    return {
        WebCore::PasteboardCustomData::Entry {
            WTFMove(*type),
            WTFMove(*customData),
            WTFMove(*platformData)
        }
    };
}


void ArgumentCoder<WebCore::PasteboardCustomData>::encode(Encoder& encoder, const WebCore::PasteboardCustomData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.origin())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data())>, Vector<WebCore::PasteboardCustomData::Entry>>);
    encoder << instance.origin();
    encoder << instance.data();
}

std::optional<WebCore::PasteboardCustomData> ArgumentCoder<WebCore::PasteboardCustomData>::decode(Decoder& decoder)
{
    auto origin = decoder.decode<String>();
    if (!origin)
        return std::nullopt;

    auto data = decoder.decode<Vector<WebCore::PasteboardCustomData::Entry>>();
    if (!data)
        return std::nullopt;

    return {
        WebCore::PasteboardCustomData {
            WTFMove(*origin),
            WTFMove(*data)
        }
    };
}


void ArgumentCoder<WebCore::DatabaseDetails>::encode(Encoder& encoder, const WebCore::DatabaseDetails& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.displayName())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.expectedUsage())>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.currentUsage())>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.creationTime())>, std::optional<WallTime>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.modificationTime())>, std::optional<WallTime>>);
    encoder << instance.name();
    encoder << instance.displayName();
    encoder << instance.expectedUsage();
    encoder << instance.currentUsage();
    encoder << instance.creationTime();
    encoder << instance.modificationTime();
}

std::optional<WebCore::DatabaseDetails> ArgumentCoder<WebCore::DatabaseDetails>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto displayName = decoder.decode<String>();
    if (!displayName)
        return std::nullopt;

    auto expectedUsage = decoder.decode<uint64_t>();
    if (!expectedUsage)
        return std::nullopt;

    auto currentUsage = decoder.decode<uint64_t>();
    if (!currentUsage)
        return std::nullopt;

    auto creationTime = decoder.decode<std::optional<WallTime>>();
    if (!creationTime)
        return std::nullopt;

    auto modificationTime = decoder.decode<std::optional<WallTime>>();
    if (!modificationTime)
        return std::nullopt;

    return {
        WebCore::DatabaseDetails {
            WTFMove(*name),
            WTFMove(*displayName),
            WTFMove(*expectedUsage),
            WTFMove(*currentUsage),
            WTFMove(*creationTime),
            WTFMove(*modificationTime)
        }
    };
}


void ArgumentCoder<WebCore::DecomposedGlyphs>::encode(Encoder& encoder, const WebCore::DecomposedGlyphs& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.positionedGlyphs())>, WebCore::PositionedGlyphs>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.renderingResourceIdentifier())>, WebCore::RenderingResourceIdentifier>);
    encoder << instance.positionedGlyphs();
    encoder << instance.renderingResourceIdentifier();
}

std::optional<Ref<WebCore::DecomposedGlyphs>> ArgumentCoder<WebCore::DecomposedGlyphs>::decode(Decoder& decoder)
{
    auto positionedGlyphs = decoder.decode<WebCore::PositionedGlyphs>();
    if (!positionedGlyphs)
        return std::nullopt;

    auto renderingResourceIdentifier = decoder.decode<WebCore::RenderingResourceIdentifier>();
    if (!renderingResourceIdentifier)
        return std::nullopt;

    return {
        WebCore::DecomposedGlyphs::create(
            WTFMove(*positionedGlyphs),
            WTFMove(*renderingResourceIdentifier)
        )
    };
}


void ArgumentCoder<WebCore::TextIndicatorData>::encode(Encoder& encoder, const WebCore::TextIndicatorData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.selectionRectInRootViewCoordinates)>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textBoundingRectInRootViewCoordinates)>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentImageWithoutSelectionRectInRootViewCoordinates)>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textRectsInBoundingRectCoordinates)>, Vector<WebCore::FloatRect>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentImageScaleFactor)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentImageWithHighlight)>, RefPtr<WebCore::Image>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentImageWithoutSelection)>, RefPtr<WebCore::Image>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentImage)>, RefPtr<WebCore::Image>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.estimatedBackgroundColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.presentationTransition)>, WebCore::TextIndicatorPresentationTransition>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.options)>, OptionSet<WebCore::TextIndicatorOption>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextIndicatorData, selectionRectInRootViewCoordinates)
        , offsetof(WebCore::TextIndicatorData, textBoundingRectInRootViewCoordinates)
        , offsetof(WebCore::TextIndicatorData, contentImageWithoutSelectionRectInRootViewCoordinates)
        , offsetof(WebCore::TextIndicatorData, textRectsInBoundingRectCoordinates)
        , offsetof(WebCore::TextIndicatorData, contentImageScaleFactor)
        , offsetof(WebCore::TextIndicatorData, contentImageWithHighlight)
        , offsetof(WebCore::TextIndicatorData, contentImageWithoutSelection)
        , offsetof(WebCore::TextIndicatorData, contentImage)
        , offsetof(WebCore::TextIndicatorData, estimatedBackgroundColor)
        , offsetof(WebCore::TextIndicatorData, presentationTransition)
        , offsetof(WebCore::TextIndicatorData, options)
    >::value);
    encoder << instance.selectionRectInRootViewCoordinates;
    encoder << instance.textBoundingRectInRootViewCoordinates;
    encoder << instance.contentImageWithoutSelectionRectInRootViewCoordinates;
    encoder << instance.textRectsInBoundingRectCoordinates;
    encoder << instance.contentImageScaleFactor;
    encoder << instance.contentImageWithHighlight;
    encoder << instance.contentImageWithoutSelection;
    encoder << instance.contentImage;
    encoder << instance.estimatedBackgroundColor;
    encoder << instance.presentationTransition;
    encoder << instance.options;
}

std::optional<WebCore::TextIndicatorData> ArgumentCoder<WebCore::TextIndicatorData>::decode(Decoder& decoder)
{
    auto selectionRectInRootViewCoordinates = decoder.decode<WebCore::FloatRect>();
    if (!selectionRectInRootViewCoordinates)
        return std::nullopt;

    auto textBoundingRectInRootViewCoordinates = decoder.decode<WebCore::FloatRect>();
    if (!textBoundingRectInRootViewCoordinates)
        return std::nullopt;

    auto contentImageWithoutSelectionRectInRootViewCoordinates = decoder.decode<WebCore::FloatRect>();
    if (!contentImageWithoutSelectionRectInRootViewCoordinates)
        return std::nullopt;

    auto textRectsInBoundingRectCoordinates = decoder.decode<Vector<WebCore::FloatRect>>();
    if (!textRectsInBoundingRectCoordinates)
        return std::nullopt;

    auto contentImageScaleFactor = decoder.decode<float>();
    if (!contentImageScaleFactor)
        return std::nullopt;

    auto contentImageWithHighlight = decoder.decode<RefPtr<WebCore::Image>>();
    if (!contentImageWithHighlight)
        return std::nullopt;

    auto contentImageWithoutSelection = decoder.decode<RefPtr<WebCore::Image>>();
    if (!contentImageWithoutSelection)
        return std::nullopt;

    auto contentImage = decoder.decode<RefPtr<WebCore::Image>>();
    if (!contentImage)
        return std::nullopt;

    auto estimatedBackgroundColor = decoder.decode<WebCore::Color>();
    if (!estimatedBackgroundColor)
        return std::nullopt;

    auto presentationTransition = decoder.decode<WebCore::TextIndicatorPresentationTransition>();
    if (!presentationTransition)
        return std::nullopt;

    auto options = decoder.decode<OptionSet<WebCore::TextIndicatorOption>>();
    if (!options)
        return std::nullopt;

    return {
        WebCore::TextIndicatorData {
            WTFMove(*selectionRectInRootViewCoordinates),
            WTFMove(*textBoundingRectInRootViewCoordinates),
            WTFMove(*contentImageWithoutSelectionRectInRootViewCoordinates),
            WTFMove(*textRectsInBoundingRectCoordinates),
            WTFMove(*contentImageScaleFactor),
            WTFMove(*contentImageWithHighlight),
            WTFMove(*contentImageWithoutSelection),
            WTFMove(*contentImage),
            WTFMove(*estimatedBackgroundColor),
            WTFMove(*presentationTransition),
            WTFMove(*options)
        }
    };
}

#if ENABLE(MEDIA_STREAM)

void ArgumentCoder<WebCore::MediaConstraints>::encode(Encoder& encoder, const WebCore::MediaConstraints& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mandatoryConstraints)>, WebCore::MediaTrackConstraintSetMap>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.advancedConstraints)>, Vector<WebCore::MediaTrackConstraintSetMap>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isValid)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaConstraints, mandatoryConstraints)
        , offsetof(WebCore::MediaConstraints, advancedConstraints)
        , offsetof(WebCore::MediaConstraints, isValid)
    >::value);
    encoder << instance.mandatoryConstraints;
    encoder << instance.advancedConstraints;
    encoder << instance.isValid;
}

std::optional<WebCore::MediaConstraints> ArgumentCoder<WebCore::MediaConstraints>::decode(Decoder& decoder)
{
    auto mandatoryConstraints = decoder.decode<WebCore::MediaTrackConstraintSetMap>();
    if (!mandatoryConstraints)
        return std::nullopt;

    auto advancedConstraints = decoder.decode<Vector<WebCore::MediaTrackConstraintSetMap>>();
    if (!advancedConstraints)
        return std::nullopt;

    auto isValid = decoder.decode<bool>();
    if (!isValid)
        return std::nullopt;

    return {
        WebCore::MediaConstraints {
            WTFMove(*mandatoryConstraints),
            WTFMove(*advancedConstraints),
            WTFMove(*isValid)
        }
    };
}

#endif


void ArgumentCoder<WebCore::PromisedAttachmentInfo>::encode(Encoder& encoder, const WebCore::PromisedAttachmentInfo& instance)
{
#if ENABLE(ATTACHMENT_ELEMENT)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.attachmentIdentifier)>, String>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.additionalTypes)>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.additionalData)>, Vector<RefPtr<WebCore::SharedBuffer>>>);
    static_assert(MembersInCorrectOrder<0
#if ENABLE(ATTACHMENT_ELEMENT)
        , offsetof(WebCore::PromisedAttachmentInfo, attachmentIdentifier)
#endif
        , offsetof(WebCore::PromisedAttachmentInfo, additionalTypes)
        , offsetof(WebCore::PromisedAttachmentInfo, additionalData)
    >::value);
#if ENABLE(ATTACHMENT_ELEMENT)
    encoder << instance.attachmentIdentifier;
#endif
    encoder << instance.additionalTypes;
    encoder << instance.additionalData;
}

std::optional<WebCore::PromisedAttachmentInfo> ArgumentCoder<WebCore::PromisedAttachmentInfo>::decode(Decoder& decoder)
{
#if ENABLE(ATTACHMENT_ELEMENT)
    auto attachmentIdentifier = decoder.decode<String>();
    if (!attachmentIdentifier)
        return std::nullopt;
#endif

    auto additionalTypes = decoder.decode<Vector<String>>();
    if (!additionalTypes)
        return std::nullopt;

    auto additionalData = decoder.decode<Vector<RefPtr<WebCore::SharedBuffer>>>();
    if (!additionalData)
        return std::nullopt;

    return {
        WebCore::PromisedAttachmentInfo {
#if ENABLE(ATTACHMENT_ELEMENT)
            WTFMove(*attachmentIdentifier),
#endif
            WTFMove(*additionalTypes),
            WTFMove(*additionalData)
        }
    };
}


void ArgumentCoder<WebCore::RecentSearch>::encode(Encoder& encoder, const WebCore::RecentSearch& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.string)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.time)>, WallTime>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::RecentSearch, string)
        , offsetof(WebCore::RecentSearch, time)
    >::value);
    encoder << instance.string;
    encoder << instance.time;
}

std::optional<WebCore::RecentSearch> ArgumentCoder<WebCore::RecentSearch>::decode(Decoder& decoder)
{
    auto string = decoder.decode<String>();
    if (!string)
        return std::nullopt;

    auto time = decoder.decode<WallTime>();
    if (!time)
        return std::nullopt;

    return {
        WebCore::RecentSearch {
            WTFMove(*string),
            WTFMove(*time)
        }
    };
}


void ArgumentCoder<WebCore::EventTrackingRegions>::encode(Encoder& encoder, const WebCore::EventTrackingRegions& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.asynchronousDispatchRegion)>, WebCore::Region>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.eventSpecificSynchronousDispatchRegions)>, HashMap<WebCore::EventTrackingRegions::EventType, WebCore::Region, WTF::IntHash<WebCore::EventTrackingRegions::EventType>, WTF::StrongEnumHashTraits<WebCore::EventTrackingRegions::EventType>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::EventTrackingRegions, asynchronousDispatchRegion)
        , offsetof(WebCore::EventTrackingRegions, eventSpecificSynchronousDispatchRegions)
    >::value);
    encoder << instance.asynchronousDispatchRegion;
    encoder << instance.eventSpecificSynchronousDispatchRegions;
}

std::optional<WebCore::EventTrackingRegions> ArgumentCoder<WebCore::EventTrackingRegions>::decode(Decoder& decoder)
{
    auto asynchronousDispatchRegion = decoder.decode<WebCore::Region>();
    if (!asynchronousDispatchRegion)
        return std::nullopt;

    auto eventSpecificSynchronousDispatchRegions = decoder.decode<HashMap<WebCore::EventTrackingRegions::EventType, WebCore::Region, WTF::IntHash<WebCore::EventTrackingRegions::EventType>, WTF::StrongEnumHashTraits<WebCore::EventTrackingRegions::EventType>>>();
    if (!eventSpecificSynchronousDispatchRegions)
        return std::nullopt;

    return {
        WebCore::EventTrackingRegions {
            WTFMove(*asynchronousDispatchRegion),
            WTFMove(*eventSpecificSynchronousDispatchRegions)
        }
    };
}


void ArgumentCoder<WebCore::TextManipulationItem>::encode(Encoder& encoder, const WebCore::TextManipulationItem& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::TextManipulationItemIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tokens)>, Vector<WebCore::TextManipulationToken>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextManipulationItem, identifier)
        , offsetof(WebCore::TextManipulationItem, tokens)
    >::value);
    encoder << instance.identifier;
    encoder << instance.tokens;
}

std::optional<WebCore::TextManipulationItem> ArgumentCoder<WebCore::TextManipulationItem>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::TextManipulationItemIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto tokens = decoder.decode<Vector<WebCore::TextManipulationToken>>();
    if (!tokens)
        return std::nullopt;

    return {
        WebCore::TextManipulationItem {
            WTFMove(*identifier),
            WTFMove(*tokens)
        }
    };
}


void ArgumentCoder<WebCore::TextManipulationToken>::encode(Encoder& encoder, const WebCore::TextManipulationToken& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::TextManipulationTokenIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.content)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.info)>, std::optional<WebCore::TextManipulationTokenInfo>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isExcluded)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextManipulationToken, identifier)
        , offsetof(WebCore::TextManipulationToken, content)
        , offsetof(WebCore::TextManipulationToken, info)
        , offsetof(WebCore::TextManipulationToken, isExcluded)
    >::value);
    encoder << instance.identifier;
    encoder << instance.content;
    encoder << instance.info;
    encoder << instance.isExcluded;
}

std::optional<WebCore::TextManipulationToken> ArgumentCoder<WebCore::TextManipulationToken>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::TextManipulationTokenIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto content = decoder.decode<String>();
    if (!content)
        return std::nullopt;

    auto info = decoder.decode<std::optional<WebCore::TextManipulationTokenInfo>>();
    if (!info)
        return std::nullopt;

    auto isExcluded = decoder.decode<bool>();
    if (!isExcluded)
        return std::nullopt;

    return {
        WebCore::TextManipulationToken {
            WTFMove(*identifier),
            WTFMove(*content),
            WTFMove(*info),
            WTFMove(*isExcluded)
        }
    };
}


void ArgumentCoder<WebCore::TextManipulationTokenInfo>::encode(Encoder& encoder, const WebCore::TextManipulationTokenInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tagName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.roleAttribute)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.documentURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isVisible)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextManipulationTokenInfo, tagName)
        , offsetof(WebCore::TextManipulationTokenInfo, roleAttribute)
        , offsetof(WebCore::TextManipulationTokenInfo, documentURL)
        , offsetof(WebCore::TextManipulationTokenInfo, isVisible)
    >::value);
    encoder << instance.tagName;
    encoder << instance.roleAttribute;
    encoder << instance.documentURL;
    encoder << instance.isVisible;
}

std::optional<WebCore::TextManipulationTokenInfo> ArgumentCoder<WebCore::TextManipulationTokenInfo>::decode(Decoder& decoder)
{
    auto tagName = decoder.decode<String>();
    if (!tagName)
        return std::nullopt;

    auto roleAttribute = decoder.decode<String>();
    if (!roleAttribute)
        return std::nullopt;

    auto documentURL = decoder.decode<URL>();
    if (!documentURL)
        return std::nullopt;

    auto isVisible = decoder.decode<bool>();
    if (!isVisible)
        return std::nullopt;

    return {
        WebCore::TextManipulationTokenInfo {
            WTFMove(*tagName),
            WTFMove(*roleAttribute),
            WTFMove(*documentURL),
            WTFMove(*isVisible)
        }
    };
}


void ArgumentCoder<WebCore::VelocityData>::encode(Encoder& encoder, const WebCore::VelocityData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.horizontalVelocity)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.verticalVelocity)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scaleChangeRate)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lastUpdateTime)>, MonotonicTime>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::VelocityData, horizontalVelocity)
        , offsetof(WebCore::VelocityData, verticalVelocity)
        , offsetof(WebCore::VelocityData, scaleChangeRate)
        , offsetof(WebCore::VelocityData, lastUpdateTime)
    >::value);
    encoder << instance.horizontalVelocity;
    encoder << instance.verticalVelocity;
    encoder << instance.scaleChangeRate;
    encoder << instance.lastUpdateTime;
}

std::optional<WebCore::VelocityData> ArgumentCoder<WebCore::VelocityData>::decode(Decoder& decoder)
{
    auto horizontalVelocity = decoder.decode<float>();
    if (!horizontalVelocity)
        return std::nullopt;

    auto verticalVelocity = decoder.decode<float>();
    if (!verticalVelocity)
        return std::nullopt;

    auto scaleChangeRate = decoder.decode<float>();
    if (!scaleChangeRate)
        return std::nullopt;

    auto lastUpdateTime = decoder.decode<MonotonicTime>();
    if (!lastUpdateTime)
        return std::nullopt;

    return {
        WebCore::VelocityData {
            WTFMove(*horizontalVelocity),
            WTFMove(*verticalVelocity),
            WTFMove(*scaleChangeRate),
            WTFMove(*lastUpdateTime)
        }
    };
}


void ArgumentCoder<WebCore::MimeClassInfo>::encode(Encoder& encoder, const WebCore::MimeClassInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.desc)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.extensions)>, Vector<String>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MimeClassInfo, type)
        , offsetof(WebCore::MimeClassInfo, desc)
        , offsetof(WebCore::MimeClassInfo, extensions)
    >::value);
    encoder << instance.type;
    encoder << instance.desc;
    encoder << instance.extensions;
}

std::optional<WebCore::MimeClassInfo> ArgumentCoder<WebCore::MimeClassInfo>::decode(Decoder& decoder)
{
    auto type = decoder.decode<AtomString>();
    if (!type)
        return std::nullopt;

    auto desc = decoder.decode<String>();
    if (!desc)
        return std::nullopt;

    auto extensions = decoder.decode<Vector<String>>();
    if (!extensions)
        return std::nullopt;

    return {
        WebCore::MimeClassInfo {
            WTFMove(*type),
            WTFMove(*desc),
            WTFMove(*extensions)
        }
    };
}


void ArgumentCoder<WebCore::AuthenticationChallenge>::encode(Encoder& encoder, const WebCore::AuthenticationChallenge& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.protectionSpace())>, WebCore::ProtectionSpace>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.proposedCredential())>, WebCore::Credential>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.previousFailureCount())>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.failureResponse())>, WebCore::ResourceResponse>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.error())>, WebCore::ResourceError>);
#if USE(SOUP)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tlsPasswordFlags())>, uint32_t>);
#endif
    encoder << instance.protectionSpace();
    encoder << instance.proposedCredential();
    encoder << instance.previousFailureCount();
    encoder << instance.failureResponse();
    encoder << instance.error();
#if USE(SOUP)
    encoder << instance.tlsPasswordFlags();
#endif
}

std::optional<WebCore::AuthenticationChallenge> ArgumentCoder<WebCore::AuthenticationChallenge>::decode(Decoder& decoder)
{
    auto protectionSpace = decoder.decode<WebCore::ProtectionSpace>();
    if (!protectionSpace)
        return std::nullopt;

    auto proposedCredential = decoder.decode<WebCore::Credential>();
    if (!proposedCredential)
        return std::nullopt;

    auto previousFailureCount = decoder.decode<unsigned>();
    if (!previousFailureCount)
        return std::nullopt;

    auto failureResponse = decoder.decode<WebCore::ResourceResponse>();
    if (!failureResponse)
        return std::nullopt;

    auto error = decoder.decode<WebCore::ResourceError>();
    if (!error)
        return std::nullopt;

#if USE(SOUP)
    auto tlsPasswordFlags = decoder.decode<uint32_t>();
    if (!tlsPasswordFlags)
        return std::nullopt;
#endif

    return {
        WebCore::AuthenticationChallenge {
            WTFMove(*protectionSpace),
            WTFMove(*proposedCredential),
            WTFMove(*previousFailureCount),
            WTFMove(*failureResponse),
            WTFMove(*error),
#if USE(SOUP)
            WTFMove(*tlsPasswordFlags)
#endif
        }
    };
}

#if ENABLE(DRAG_SUPPORT)

void ArgumentCoder<WebCore::DragData>::encode(Encoder& encoder, const WebCore::DragData& instance)
{
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pasteboardName())>, String>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientPosition())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.globalPosition())>, WebCore::IntPoint>);
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fileNames())>, Vector<String>>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.draggingSourceOperationMask())>, OptionSet<WebCore::DragOperation>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.flags())>, OptionSet<WebCore::DragApplicationFlags>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dragDestinationActionMask())>, OptionSet<WebCore::DragDestinationAction>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageID())>, std::optional<WebCore::PageIdentifier>>);
#if PLATFORM(COCOA)
    encoder << instance.pasteboardName();
#endif
    encoder << instance.clientPosition();
    encoder << instance.globalPosition();
#if PLATFORM(COCOA)
    encoder << instance.fileNames();
#endif
    encoder << instance.draggingSourceOperationMask();
    encoder << instance.flags();
    encoder << instance.dragDestinationActionMask();
    encoder << instance.pageID();
}

std::optional<WebCore::DragData> ArgumentCoder<WebCore::DragData>::decode(Decoder& decoder)
{
#if PLATFORM(COCOA)
    auto pasteboardName = decoder.decode<String>();
    if (!pasteboardName)
        return std::nullopt;
#endif

    auto clientPosition = decoder.decode<WebCore::IntPoint>();
    if (!clientPosition)
        return std::nullopt;

    auto globalPosition = decoder.decode<WebCore::IntPoint>();
    if (!globalPosition)
        return std::nullopt;

#if PLATFORM(COCOA)
    auto fileNames = decoder.decode<Vector<String>>();
    if (!fileNames)
        return std::nullopt;
#endif

    auto draggingSourceOperationMask = decoder.decode<OptionSet<WebCore::DragOperation>>();
    if (!draggingSourceOperationMask)
        return std::nullopt;

    auto flags = decoder.decode<OptionSet<WebCore::DragApplicationFlags>>();
    if (!flags)
        return std::nullopt;

    auto dragDestinationActionMask = decoder.decode<OptionSet<WebCore::DragDestinationAction>>();
    if (!dragDestinationActionMask)
        return std::nullopt;

    auto pageID = decoder.decode<std::optional<WebCore::PageIdentifier>>();
    if (!pageID)
        return std::nullopt;

    return {
        WebCore::DragData {
#if PLATFORM(COCOA)
            WTFMove(*pasteboardName),
#endif
            WTFMove(*clientPosition),
            WTFMove(*globalPosition),
#if PLATFORM(COCOA)
            WTFMove(*fileNames),
#endif
            WTFMove(*draggingSourceOperationMask),
            WTFMove(*flags),
            WTFMove(*dragDestinationActionMask),
            WTFMove(*pageID)
        }
    };
}

#endif


void ArgumentCoder<WebCore::DictationAlternative>::encode(Encoder& encoder, const WebCore::DictationAlternative& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.range)>, WebCore::CharacterRange>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.context)>, WebCore::DictationContext>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DictationAlternative, range)
        , offsetof(WebCore::DictationAlternative, context)
    >::value);
    encoder << instance.range;
    encoder << instance.context;
}

std::optional<WebCore::DictationAlternative> ArgumentCoder<WebCore::DictationAlternative>::decode(Decoder& decoder)
{
    auto range = decoder.decode<WebCore::CharacterRange>();
    if (!range)
        return std::nullopt;

    auto context = decoder.decode<WebCore::DictationContext>();
    if (!context)
        return std::nullopt;

    return {
        WebCore::DictationAlternative {
            WTFMove(*range),
            WTFMove(*context)
        }
    };
}


void ArgumentCoder<WebCore::UserStyleSheet>::encode(Encoder& encoder, const WebCore::UserStyleSheet& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.source())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url())>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowlist())>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blocklist())>, Vector<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.injectedFrames())>, WebCore::UserContentInjectedFrames>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.level())>, WebCore::UserStyleLevel>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageID())>, std::optional<WebCore::PageIdentifier>>);
    encoder << instance.source();
    encoder << instance.url();
    encoder << instance.allowlist();
    encoder << instance.blocklist();
    encoder << instance.injectedFrames();
    encoder << instance.level();
    encoder << instance.pageID();
}

std::optional<WebCore::UserStyleSheet> ArgumentCoder<WebCore::UserStyleSheet>::decode(Decoder& decoder)
{
    auto source = decoder.decode<String>();
    if (!source)
        return std::nullopt;

    auto url = decoder.decode<URL>();
    if (!url)
        return std::nullopt;

    auto allowlist = decoder.decode<Vector<String>>();
    if (!allowlist)
        return std::nullopt;

    auto blocklist = decoder.decode<Vector<String>>();
    if (!blocklist)
        return std::nullopt;

    auto injectedFrames = decoder.decode<WebCore::UserContentInjectedFrames>();
    if (!injectedFrames)
        return std::nullopt;

    auto level = decoder.decode<WebCore::UserStyleLevel>();
    if (!level)
        return std::nullopt;

    auto pageID = decoder.decode<std::optional<WebCore::PageIdentifier>>();
    if (!pageID)
        return std::nullopt;

    return {
        WebCore::UserStyleSheet {
            WTFMove(*source),
            WTFMove(*url),
            WTFMove(*allowlist),
            WTFMove(*blocklist),
            WTFMove(*injectedFrames),
            WTFMove(*level),
            WTFMove(*pageID)
        }
    };
}


void ArgumentCoder<WebCore::ScrollableAreaParameters>::encode(Encoder& encoder, const WebCore::ScrollableAreaParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.horizontalScrollElasticity)>, WebCore::ScrollElasticity>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.verticalScrollElasticity)>, WebCore::ScrollElasticity>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.horizontalScrollbarMode)>, WebCore::ScrollbarMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.verticalScrollbarMode)>, WebCore::ScrollbarMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.horizontalOverscrollBehavior)>, WebCore::OverscrollBehavior>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.verticalOverscrollBehavior)>, WebCore::OverscrollBehavior>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowsHorizontalScrolling)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowsVerticalScrolling)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.horizontalNativeScrollbarVisibility)>, WebCore::NativeScrollbarVisibility>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.verticalNativeScrollbarVisibility)>, WebCore::NativeScrollbarVisibility>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.useDarkAppearanceForScrollbars)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ScrollableAreaParameters, horizontalScrollElasticity)
        , offsetof(WebCore::ScrollableAreaParameters, verticalScrollElasticity)
        , offsetof(WebCore::ScrollableAreaParameters, horizontalScrollbarMode)
        , offsetof(WebCore::ScrollableAreaParameters, verticalScrollbarMode)
        , offsetof(WebCore::ScrollableAreaParameters, horizontalOverscrollBehavior)
        , offsetof(WebCore::ScrollableAreaParameters, verticalOverscrollBehavior)
        , offsetof(WebCore::ScrollableAreaParameters, allowsHorizontalScrolling)
        , offsetof(WebCore::ScrollableAreaParameters, allowsVerticalScrolling)
        , offsetof(WebCore::ScrollableAreaParameters, horizontalNativeScrollbarVisibility)
        , offsetof(WebCore::ScrollableAreaParameters, verticalNativeScrollbarVisibility)
        , offsetof(WebCore::ScrollableAreaParameters, useDarkAppearanceForScrollbars)
    >::value);
    encoder << instance.horizontalScrollElasticity;
    encoder << instance.verticalScrollElasticity;
    encoder << instance.horizontalScrollbarMode;
    encoder << instance.verticalScrollbarMode;
    encoder << instance.horizontalOverscrollBehavior;
    encoder << instance.verticalOverscrollBehavior;
    encoder << instance.allowsHorizontalScrolling;
    encoder << instance.allowsVerticalScrolling;
    encoder << instance.horizontalNativeScrollbarVisibility;
    encoder << instance.verticalNativeScrollbarVisibility;
    encoder << instance.useDarkAppearanceForScrollbars;
}

std::optional<WebCore::ScrollableAreaParameters> ArgumentCoder<WebCore::ScrollableAreaParameters>::decode(Decoder& decoder)
{
    auto horizontalScrollElasticity = decoder.decode<WebCore::ScrollElasticity>();
    if (!horizontalScrollElasticity)
        return std::nullopt;

    auto verticalScrollElasticity = decoder.decode<WebCore::ScrollElasticity>();
    if (!verticalScrollElasticity)
        return std::nullopt;

    auto horizontalScrollbarMode = decoder.decode<WebCore::ScrollbarMode>();
    if (!horizontalScrollbarMode)
        return std::nullopt;

    auto verticalScrollbarMode = decoder.decode<WebCore::ScrollbarMode>();
    if (!verticalScrollbarMode)
        return std::nullopt;

    auto horizontalOverscrollBehavior = decoder.decode<WebCore::OverscrollBehavior>();
    if (!horizontalOverscrollBehavior)
        return std::nullopt;

    auto verticalOverscrollBehavior = decoder.decode<WebCore::OverscrollBehavior>();
    if (!verticalOverscrollBehavior)
        return std::nullopt;

    auto allowsHorizontalScrolling = decoder.decode<bool>();
    if (!allowsHorizontalScrolling)
        return std::nullopt;

    auto allowsVerticalScrolling = decoder.decode<bool>();
    if (!allowsVerticalScrolling)
        return std::nullopt;

    auto horizontalNativeScrollbarVisibility = decoder.decode<WebCore::NativeScrollbarVisibility>();
    if (!horizontalNativeScrollbarVisibility)
        return std::nullopt;

    auto verticalNativeScrollbarVisibility = decoder.decode<WebCore::NativeScrollbarVisibility>();
    if (!verticalNativeScrollbarVisibility)
        return std::nullopt;

    auto useDarkAppearanceForScrollbars = decoder.decode<bool>();
    if (!useDarkAppearanceForScrollbars)
        return std::nullopt;

    return {
        WebCore::ScrollableAreaParameters {
            WTFMove(*horizontalScrollElasticity),
            WTFMove(*verticalScrollElasticity),
            WTFMove(*horizontalScrollbarMode),
            WTFMove(*verticalScrollbarMode),
            WTFMove(*horizontalOverscrollBehavior),
            WTFMove(*verticalOverscrollBehavior),
            WTFMove(*allowsHorizontalScrolling),
            WTFMove(*allowsVerticalScrolling),
            WTFMove(*horizontalNativeScrollbarVisibility),
            WTFMove(*verticalNativeScrollbarVisibility),
            WTFMove(*useDarkAppearanceForScrollbars)
        }
    };
}


void ArgumentCoder<WebCore::RequestedKeyboardScrollData>::encode(Encoder& encoder, const WebCore::RequestedKeyboardScrollData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.action)>, WebCore::KeyboardScrollAction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyboardScroll)>, std::optional<WebCore::KeyboardScroll>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::RequestedKeyboardScrollData, action)
        , offsetof(WebCore::RequestedKeyboardScrollData, keyboardScroll)
    >::value);
    encoder << instance.action;
    encoder << instance.keyboardScroll;
}

std::optional<WebCore::RequestedKeyboardScrollData> ArgumentCoder<WebCore::RequestedKeyboardScrollData>::decode(Decoder& decoder)
{
    auto action = decoder.decode<WebCore::KeyboardScrollAction>();
    if (!action)
        return std::nullopt;

    auto keyboardScroll = decoder.decode<std::optional<WebCore::KeyboardScroll>>();
    if (!keyboardScroll)
        return std::nullopt;

    return {
        WebCore::RequestedKeyboardScrollData {
            WTFMove(*action),
            WTFMove(*keyboardScroll)
        }
    };
}


void ArgumentCoder<WebCore::AbsolutePositionConstraints>::encode(Encoder& encoder, const WebCore::AbsolutePositionConstraints& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alignmentOffset())>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.layerPositionAtLastLayout())>, WebCore::FloatPoint>);
    encoder << instance.alignmentOffset();
    encoder << instance.layerPositionAtLastLayout();
}

std::optional<WebCore::AbsolutePositionConstraints> ArgumentCoder<WebCore::AbsolutePositionConstraints>::decode(Decoder& decoder)
{
    auto alignmentOffset = decoder.decode<WebCore::FloatSize>();
    if (!alignmentOffset)
        return std::nullopt;

    auto layerPositionAtLastLayout = decoder.decode<WebCore::FloatPoint>();
    if (!layerPositionAtLastLayout)
        return std::nullopt;

    return {
        WebCore::AbsolutePositionConstraints {
            WTFMove(*alignmentOffset),
            WTFMove(*layerPositionAtLastLayout)
        }
    };
}


void ArgumentCoder<WebCore::KeyboardScroll>::encode(Encoder& encoder, const WebCore::KeyboardScroll& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maximumVelocity)>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.force)>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.granularity)>, WebCore::ScrollGranularity>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.direction)>, WebCore::ScrollDirection>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::KeyboardScroll, offset)
        , offsetof(WebCore::KeyboardScroll, maximumVelocity)
        , offsetof(WebCore::KeyboardScroll, force)
        , offsetof(WebCore::KeyboardScroll, granularity)
        , offsetof(WebCore::KeyboardScroll, direction)
    >::value);
    encoder << instance.offset;
    encoder << instance.maximumVelocity;
    encoder << instance.force;
    encoder << instance.granularity;
    encoder << instance.direction;
}

std::optional<WebCore::KeyboardScroll> ArgumentCoder<WebCore::KeyboardScroll>::decode(Decoder& decoder)
{
    auto offset = decoder.decode<WebCore::FloatSize>();
    if (!offset)
        return std::nullopt;

    auto maximumVelocity = decoder.decode<WebCore::FloatSize>();
    if (!maximumVelocity)
        return std::nullopt;

    auto force = decoder.decode<WebCore::FloatSize>();
    if (!force)
        return std::nullopt;

    auto granularity = decoder.decode<WebCore::ScrollGranularity>();
    if (!granularity)
        return std::nullopt;

    auto direction = decoder.decode<WebCore::ScrollDirection>();
    if (!direction)
        return std::nullopt;

    return {
        WebCore::KeyboardScroll {
            WTFMove(*offset),
            WTFMove(*maximumVelocity),
            WTFMove(*force),
            WTFMove(*granularity),
            WTFMove(*direction)
        }
    };
}


void ArgumentCoder<WebCore::NotificationResources>::encode(Encoder& encoder, const WebCore::NotificationResources& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.icon())>, RefPtr<WebCore::Image>>);
    encoder << instance.icon();
}

std::optional<Ref<WebCore::NotificationResources>> ArgumentCoder<WebCore::NotificationResources>::decode(Decoder& decoder)
{
    auto icon = decoder.decode<RefPtr<WebCore::Image>>();
    if (!icon)
        return std::nullopt;

    return {
        WebCore::NotificationResources::create(
            WTFMove(*icon)
        )
    };
}


void ArgumentCoder<WebCore::IdentityTransformOperation>::encode(Encoder& encoder, const WebCore::IdentityTransformOperation& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<Ref<WebCore::IdentityTransformOperation>> ArgumentCoder<WebCore::IdentityTransformOperation>::decode(Decoder& decoder)
{
    return {
        WebCore::IdentityTransformOperation::create(
        )
    };
}


void ArgumentCoder<WebCore::TranslateTransformOperation>::encode(Encoder& encoder, const WebCore::TranslateTransformOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, WebCore::Length>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, WebCore::Length>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.z())>, WebCore::Length>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::TransformOperation::Type>);
    encoder << instance.x();
    encoder << instance.y();
    encoder << instance.z();
    encoder << instance.type();
}

std::optional<Ref<WebCore::TranslateTransformOperation>> ArgumentCoder<WebCore::TranslateTransformOperation>::decode(Decoder& decoder)
{
    auto x = decoder.decode<WebCore::Length>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<WebCore::Length>();
    if (!y)
        return std::nullopt;

    auto z = decoder.decode<WebCore::Length>();
    if (!z)
        return std::nullopt;

    auto type = decoder.decode<WebCore::TransformOperation::Type>();
    if (!type)
        return std::nullopt;

    if (!(WebCore::TransformOperation::isTranslateTransformOperationType(*type)))
        return std::nullopt;

    return {
        WebCore::TranslateTransformOperation::create(
            WTFMove(*x),
            WTFMove(*y),
            WTFMove(*z),
            WTFMove(*type)
        )
    };
}


void ArgumentCoder<WebCore::RotateTransformOperation>::encode(Encoder& encoder, const WebCore::RotateTransformOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.z())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.angle())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::TransformOperation::Type>);
    encoder << instance.x();
    encoder << instance.y();
    encoder << instance.z();
    encoder << instance.angle();
    encoder << instance.type();
}

std::optional<Ref<WebCore::RotateTransformOperation>> ArgumentCoder<WebCore::RotateTransformOperation>::decode(Decoder& decoder)
{
    auto x = decoder.decode<double>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<double>();
    if (!y)
        return std::nullopt;

    auto z = decoder.decode<double>();
    if (!z)
        return std::nullopt;

    auto angle = decoder.decode<double>();
    if (!angle)
        return std::nullopt;

    auto type = decoder.decode<WebCore::TransformOperation::Type>();
    if (!type)
        return std::nullopt;

    if (!(WebCore::TransformOperation::isRotateTransformOperationType(*type)))
        return std::nullopt;

    return {
        WebCore::RotateTransformOperation::create(
            WTFMove(*x),
            WTFMove(*y),
            WTFMove(*z),
            WTFMove(*angle),
            WTFMove(*type)
        )
    };
}


void ArgumentCoder<WebCore::ScaleTransformOperation>::encode(Encoder& encoder, const WebCore::ScaleTransformOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.z())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::TransformOperation::Type>);
    encoder << instance.x();
    encoder << instance.y();
    encoder << instance.z();
    encoder << instance.type();
}

std::optional<Ref<WebCore::ScaleTransformOperation>> ArgumentCoder<WebCore::ScaleTransformOperation>::decode(Decoder& decoder)
{
    auto x = decoder.decode<double>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<double>();
    if (!y)
        return std::nullopt;

    auto z = decoder.decode<double>();
    if (!z)
        return std::nullopt;

    auto type = decoder.decode<WebCore::TransformOperation::Type>();
    if (!type)
        return std::nullopt;

    if (!(WebCore::TransformOperation::isScaleTransformOperationType(*type)))
        return std::nullopt;

    return {
        WebCore::ScaleTransformOperation::create(
            WTFMove(*x),
            WTFMove(*y),
            WTFMove(*z),
            WTFMove(*type)
        )
    };
}


void ArgumentCoder<WebCore::SkewTransformOperation>::encode(Encoder& encoder, const WebCore::SkewTransformOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.angleX())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.angleY())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::TransformOperation::Type>);
    encoder << instance.angleX();
    encoder << instance.angleY();
    encoder << instance.type();
}

std::optional<Ref<WebCore::SkewTransformOperation>> ArgumentCoder<WebCore::SkewTransformOperation>::decode(Decoder& decoder)
{
    auto angleX = decoder.decode<double>();
    if (!angleX)
        return std::nullopt;

    auto angleY = decoder.decode<double>();
    if (!angleY)
        return std::nullopt;

    auto type = decoder.decode<WebCore::TransformOperation::Type>();
    if (!type)
        return std::nullopt;

    if (!(WebCore::TransformOperation::isSkewTransformOperationType(*type)))
        return std::nullopt;

    return {
        WebCore::SkewTransformOperation::create(
            WTFMove(*angleX),
            WTFMove(*angleY),
            WTFMove(*type)
        )
    };
}


void ArgumentCoder<WebCore::PerspectiveTransformOperation>::encode(Encoder& encoder, const WebCore::PerspectiveTransformOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.perspective())>, std::optional<WebCore::Length>>);
    encoder << instance.perspective();
}

std::optional<Ref<WebCore::PerspectiveTransformOperation>> ArgumentCoder<WebCore::PerspectiveTransformOperation>::decode(Decoder& decoder)
{
    auto perspective = decoder.decode<std::optional<WebCore::Length>>();
    if (!perspective)
        return std::nullopt;

    return {
        WebCore::PerspectiveTransformOperation::create(
            WTFMove(*perspective)
        )
    };
}


void ArgumentCoder<WebCore::MatrixTransformOperation>::encode(Encoder& encoder, const WebCore::MatrixTransformOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.matrix())>, WebCore::TransformationMatrix>);
    encoder << instance.matrix();
}

std::optional<Ref<WebCore::MatrixTransformOperation>> ArgumentCoder<WebCore::MatrixTransformOperation>::decode(Decoder& decoder)
{
    auto matrix = decoder.decode<WebCore::TransformationMatrix>();
    if (!matrix)
        return std::nullopt;

    return {
        WebCore::MatrixTransformOperation::create(
            WTFMove(*matrix)
        )
    };
}


void ArgumentCoder<WebCore::Matrix3DTransformOperation>::encode(Encoder& encoder, const WebCore::Matrix3DTransformOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.matrix())>, WebCore::TransformationMatrix>);
    encoder << instance.matrix();
}

std::optional<Ref<WebCore::Matrix3DTransformOperation>> ArgumentCoder<WebCore::Matrix3DTransformOperation>::decode(Decoder& decoder)
{
    auto matrix = decoder.decode<WebCore::TransformationMatrix>();
    if (!matrix)
        return std::nullopt;

    return {
        WebCore::Matrix3DTransformOperation::create(
            WTFMove(*matrix)
        )
    };
}


void ArgumentCoder<WebCore::TransformOperations>::encode(Encoder& encoder, const WebCore::TransformOperations& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.operations())>, Vector<RefPtr<WebCore::TransformOperation>>>);
    encoder << instance.operations();
}

std::optional<WebCore::TransformOperations> ArgumentCoder<WebCore::TransformOperations>::decode(Decoder& decoder)
{
    auto operations = decoder.decode<Vector<RefPtr<WebCore::TransformOperation>>>();
    if (!operations)
        return std::nullopt;

    return {
        WebCore::TransformOperations {
            WTFMove(*operations)
        }
    };
}


void ArgumentCoder<WebCore::Gradient::LinearData>::encode(Encoder& encoder, const WebCore::Gradient::LinearData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point0)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point1)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::Gradient::LinearData, point0)
        , offsetof(WebCore::Gradient::LinearData, point1)
    >::value);
    encoder << instance.point0;
    encoder << instance.point1;
}

void ArgumentCoder<WebCore::Gradient::LinearData>::encode(StreamConnectionEncoder& encoder, const WebCore::Gradient::LinearData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point0)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point1)>, WebCore::FloatPoint>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::Gradient::LinearData, point0)
        , offsetof(WebCore::Gradient::LinearData, point1)
    >::value);
    encoder << instance.point0;
    encoder << instance.point1;
}

std::optional<WebCore::Gradient::LinearData> ArgumentCoder<WebCore::Gradient::LinearData>::decode(Decoder& decoder)
{
    auto point0 = decoder.decode<WebCore::FloatPoint>();
    if (!point0)
        return std::nullopt;

    auto point1 = decoder.decode<WebCore::FloatPoint>();
    if (!point1)
        return std::nullopt;

    return {
        WebCore::Gradient::LinearData {
            WTFMove(*point0),
            WTFMove(*point1)
        }
    };
}


void ArgumentCoder<WebCore::Gradient::RadialData>::encode(Encoder& encoder, const WebCore::Gradient::RadialData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point0)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point1)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startRadius)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endRadius)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.aspectRatio)>, float>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::Gradient::RadialData, point0)
        , offsetof(WebCore::Gradient::RadialData, point1)
        , offsetof(WebCore::Gradient::RadialData, startRadius)
        , offsetof(WebCore::Gradient::RadialData, endRadius)
        , offsetof(WebCore::Gradient::RadialData, aspectRatio)
    >::value);
    encoder << instance.point0;
    encoder << instance.point1;
    encoder << instance.startRadius;
    encoder << instance.endRadius;
    encoder << instance.aspectRatio;
}

void ArgumentCoder<WebCore::Gradient::RadialData>::encode(StreamConnectionEncoder& encoder, const WebCore::Gradient::RadialData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point0)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point1)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startRadius)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endRadius)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.aspectRatio)>, float>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::Gradient::RadialData, point0)
        , offsetof(WebCore::Gradient::RadialData, point1)
        , offsetof(WebCore::Gradient::RadialData, startRadius)
        , offsetof(WebCore::Gradient::RadialData, endRadius)
        , offsetof(WebCore::Gradient::RadialData, aspectRatio)
    >::value);
    encoder << instance.point0;
    encoder << instance.point1;
    encoder << instance.startRadius;
    encoder << instance.endRadius;
    encoder << instance.aspectRatio;
}

std::optional<WebCore::Gradient::RadialData> ArgumentCoder<WebCore::Gradient::RadialData>::decode(Decoder& decoder)
{
    auto point0 = decoder.decode<WebCore::FloatPoint>();
    if (!point0)
        return std::nullopt;

    auto point1 = decoder.decode<WebCore::FloatPoint>();
    if (!point1)
        return std::nullopt;

    auto startRadius = decoder.decode<float>();
    if (!startRadius)
        return std::nullopt;

    auto endRadius = decoder.decode<float>();
    if (!endRadius)
        return std::nullopt;

    auto aspectRatio = decoder.decode<float>();
    if (!aspectRatio)
        return std::nullopt;

    return {
        WebCore::Gradient::RadialData {
            WTFMove(*point0),
            WTFMove(*point1),
            WTFMove(*startRadius),
            WTFMove(*endRadius),
            WTFMove(*aspectRatio)
        }
    };
}


void ArgumentCoder<WebCore::Gradient::ConicData>::encode(Encoder& encoder, const WebCore::Gradient::ConicData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point0)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.angleRadians)>, float>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::Gradient::ConicData, point0)
        , offsetof(WebCore::Gradient::ConicData, angleRadians)
    >::value);
    encoder << instance.point0;
    encoder << instance.angleRadians;
}

void ArgumentCoder<WebCore::Gradient::ConicData>::encode(StreamConnectionEncoder& encoder, const WebCore::Gradient::ConicData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point0)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.angleRadians)>, float>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::Gradient::ConicData, point0)
        , offsetof(WebCore::Gradient::ConicData, angleRadians)
    >::value);
    encoder << instance.point0;
    encoder << instance.angleRadians;
}

std::optional<WebCore::Gradient::ConicData> ArgumentCoder<WebCore::Gradient::ConicData>::decode(Decoder& decoder)
{
    auto point0 = decoder.decode<WebCore::FloatPoint>();
    if (!point0)
        return std::nullopt;

    auto angleRadians = decoder.decode<float>();
    if (!angleRadians)
        return std::nullopt;

    return {
        WebCore::Gradient::ConicData {
            WTFMove(*point0),
            WTFMove(*angleRadians)
        }
    };
}


void ArgumentCoder<WebCore::Gradient>::encode(Encoder& encoder, const WebCore::Gradient& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data())>, std::variant<WebCore::Gradient::LinearData, WebCore::Gradient::RadialData, WebCore::Gradient::ConicData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorInterpolationMethod())>, WebCore::ColorInterpolationMethod>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.spreadMethod())>, WebCore::GradientSpreadMethod>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stops())>, WebCore::GradientColorStops>);
    encoder << instance.data();
    encoder << instance.colorInterpolationMethod();
    encoder << instance.spreadMethod();
    encoder << instance.stops();
}

void ArgumentCoder<WebCore::Gradient>::encode(StreamConnectionEncoder& encoder, const WebCore::Gradient& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data())>, std::variant<WebCore::Gradient::LinearData, WebCore::Gradient::RadialData, WebCore::Gradient::ConicData>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorInterpolationMethod())>, WebCore::ColorInterpolationMethod>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.spreadMethod())>, WebCore::GradientSpreadMethod>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stops())>, WebCore::GradientColorStops>);
    encoder << instance.data();
    encoder << instance.colorInterpolationMethod();
    encoder << instance.spreadMethod();
    encoder << instance.stops();
}

std::optional<Ref<WebCore::Gradient>> ArgumentCoder<WebCore::Gradient>::decode(Decoder& decoder)
{
    auto data = decoder.decode<std::variant<WebCore::Gradient::LinearData, WebCore::Gradient::RadialData, WebCore::Gradient::ConicData>>();
    if (!data)
        return std::nullopt;

    auto colorInterpolationMethod = decoder.decode<WebCore::ColorInterpolationMethod>();
    if (!colorInterpolationMethod)
        return std::nullopt;

    auto spreadMethod = decoder.decode<WebCore::GradientSpreadMethod>();
    if (!spreadMethod)
        return std::nullopt;

    auto stops = decoder.decode<WebCore::GradientColorStops>();
    if (!stops)
        return std::nullopt;

    return {
        WebCore::Gradient::create(
            WTFMove(*data),
            WTFMove(*colorInterpolationMethod),
            WTFMove(*spreadMethod),
            WTFMove(*stops)
        )
    };
}


void ArgumentCoder<WebCore::SourceBrush::Brush::LogicalGradient>::encode(Encoder& encoder, const WebCore::SourceBrush::Brush::LogicalGradient& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gradient)>, Ref<WebCore::Gradient>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.spaceTransform)>, WebCore::AffineTransform>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SourceBrush::Brush::LogicalGradient, gradient)
        , offsetof(WebCore::SourceBrush::Brush::LogicalGradient, spaceTransform)
    >::value);
    encoder << instance.gradient;
    encoder << instance.spaceTransform;
}

void ArgumentCoder<WebCore::SourceBrush::Brush::LogicalGradient>::encode(StreamConnectionEncoder& encoder, const WebCore::SourceBrush::Brush::LogicalGradient& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gradient)>, Ref<WebCore::Gradient>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.spaceTransform)>, WebCore::AffineTransform>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SourceBrush::Brush::LogicalGradient, gradient)
        , offsetof(WebCore::SourceBrush::Brush::LogicalGradient, spaceTransform)
    >::value);
    encoder << instance.gradient;
    encoder << instance.spaceTransform;
}

std::optional<WebCore::SourceBrush::Brush::LogicalGradient> ArgumentCoder<WebCore::SourceBrush::Brush::LogicalGradient>::decode(Decoder& decoder)
{
    auto gradient = decoder.decode<Ref<WebCore::Gradient>>();
    if (!gradient)
        return std::nullopt;

    auto spaceTransform = decoder.decode<WebCore::AffineTransform>();
    if (!spaceTransform)
        return std::nullopt;

    return {
        WebCore::SourceBrush::Brush::LogicalGradient {
            WTFMove(*gradient),
            WTFMove(*spaceTransform)
        }
    };
}


void ArgumentCoder<WebCore::Pattern::Parameters>::encode(Encoder& encoder, const WebCore::Pattern::Parameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.repeatX)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.repeatY)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.patternSpaceTransform)>, WebCore::AffineTransform>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::Pattern::Parameters, repeatX)
        , offsetof(WebCore::Pattern::Parameters, repeatY)
        , offsetof(WebCore::Pattern::Parameters, patternSpaceTransform)
    >::value);
    encoder << instance.repeatX;
    encoder << instance.repeatY;
    encoder << instance.patternSpaceTransform;
}

void ArgumentCoder<WebCore::Pattern::Parameters>::encode(StreamConnectionEncoder& encoder, const WebCore::Pattern::Parameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.repeatX)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.repeatY)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.patternSpaceTransform)>, WebCore::AffineTransform>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::Pattern::Parameters, repeatX)
        , offsetof(WebCore::Pattern::Parameters, repeatY)
        , offsetof(WebCore::Pattern::Parameters, patternSpaceTransform)
    >::value);
    encoder << instance.repeatX;
    encoder << instance.repeatY;
    encoder << instance.patternSpaceTransform;
}

std::optional<WebCore::Pattern::Parameters> ArgumentCoder<WebCore::Pattern::Parameters>::decode(Decoder& decoder)
{
    auto repeatX = decoder.decode<bool>();
    if (!repeatX)
        return std::nullopt;

    auto repeatY = decoder.decode<bool>();
    if (!repeatY)
        return std::nullopt;

    auto patternSpaceTransform = decoder.decode<WebCore::AffineTransform>();
    if (!patternSpaceTransform)
        return std::nullopt;

    return {
        WebCore::Pattern::Parameters {
            WTFMove(*repeatX),
            WTFMove(*repeatY),
            WTFMove(*patternSpaceTransform)
        }
    };
}


void ArgumentCoder<WebCore::Pattern>::encode(Encoder& encoder, const WebCore::Pattern& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tileImage())>, WebCore::SourceImage>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parameters())>, WebCore::Pattern::Parameters>);
    encoder << instance.tileImage();
    encoder << instance.parameters();
}

void ArgumentCoder<WebCore::Pattern>::encode(StreamConnectionEncoder& encoder, const WebCore::Pattern& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tileImage())>, WebCore::SourceImage>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parameters())>, WebCore::Pattern::Parameters>);
    encoder << instance.tileImage();
    encoder << instance.parameters();
}

std::optional<Ref<WebCore::Pattern>> ArgumentCoder<WebCore::Pattern>::decode(Decoder& decoder)
{
    auto tileImage = decoder.decode<WebCore::SourceImage>();
    if (!tileImage)
        return std::nullopt;

    auto parameters = decoder.decode<WebCore::Pattern::Parameters>();
    if (!parameters)
        return std::nullopt;

    return {
        WebCore::Pattern::create(
            WTFMove(*tileImage),
            WTFMove(*parameters)
        )
    };
}


void ArgumentCoder<WebCore::SourceBrush::Brush>::encode(Encoder& encoder, const WebCore::SourceBrush::Brush& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.brush)>, std::variant<WebCore::SourceBrush::Brush::LogicalGradient, Ref<WebCore::Pattern>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SourceBrush::Brush, brush)
    >::value);
    encoder << instance.brush;
}

void ArgumentCoder<WebCore::SourceBrush::Brush>::encode(StreamConnectionEncoder& encoder, const WebCore::SourceBrush::Brush& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.brush)>, std::variant<WebCore::SourceBrush::Brush::LogicalGradient, Ref<WebCore::Pattern>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SourceBrush::Brush, brush)
    >::value);
    encoder << instance.brush;
}

std::optional<WebCore::SourceBrush::Brush> ArgumentCoder<WebCore::SourceBrush::Brush>::decode(Decoder& decoder)
{
    auto brush = decoder.decode<std::variant<WebCore::SourceBrush::Brush::LogicalGradient, Ref<WebCore::Pattern>>>();
    if (!brush)
        return std::nullopt;

    return {
        WebCore::SourceBrush::Brush {
            WTFMove(*brush)
        }
    };
}


void ArgumentCoder<WebCore::SourceBrush>::encode(Encoder& encoder, const WebCore::SourceBrush& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.brush())>, std::optional<WebCore::SourceBrush::Brush>>);
    encoder << instance.color();
    encoder << instance.brush();
}

void ArgumentCoder<WebCore::SourceBrush>::encode(StreamConnectionEncoder& encoder, const WebCore::SourceBrush& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.brush())>, std::optional<WebCore::SourceBrush::Brush>>);
    encoder << instance.color();
    encoder << instance.brush();
}

std::optional<WebCore::SourceBrush> ArgumentCoder<WebCore::SourceBrush>::decode(Decoder& decoder)
{
    auto color = decoder.decode<WebCore::Color>();
    if (!color)
        return std::nullopt;

    auto brush = decoder.decode<std::optional<WebCore::SourceBrush::Brush>>();
    if (!brush)
        return std::nullopt;

    return {
        WebCore::SourceBrush {
            WTFMove(*color),
            WTFMove(*brush)
        }
    };
}

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebCore::GraphicsContextGLAttributes>::encode(Encoder& encoder, const WebCore::GraphicsContextGLAttributes& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alpha)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depth)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencil)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.antialias)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.premultipliedAlpha)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preserveDrawingBuffer)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.failIfMajorPerformanceCaveat)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.powerPreference)>, WebCore::GraphicsContextGLPowerPreference>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.failPlatformContextCreationForTesting)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shareResources)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.noExtensions)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.devicePixelRatio)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.initialPowerPreference)>, WebCore::GraphicsContextGLPowerPreference>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webGLVersion)>, WebCore::GraphicsContextGLWebGLVersion>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.forceRequestForHighPerformanceGPU)>, bool>);
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.windowGPUID)>, uint64_t>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.useMetal)>, bool>);
#endif
#if ENABLE(WEBXR)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.xrCompatible)>, bool>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GraphicsContextGLAttributes, alpha)
        , offsetof(WebCore::GraphicsContextGLAttributes, depth)
        , offsetof(WebCore::GraphicsContextGLAttributes, stencil)
        , offsetof(WebCore::GraphicsContextGLAttributes, antialias)
        , offsetof(WebCore::GraphicsContextGLAttributes, premultipliedAlpha)
        , offsetof(WebCore::GraphicsContextGLAttributes, preserveDrawingBuffer)
        , offsetof(WebCore::GraphicsContextGLAttributes, failIfMajorPerformanceCaveat)
        , offsetof(WebCore::GraphicsContextGLAttributes, powerPreference)
        , offsetof(WebCore::GraphicsContextGLAttributes, failPlatformContextCreationForTesting)
        , offsetof(WebCore::GraphicsContextGLAttributes, shareResources)
        , offsetof(WebCore::GraphicsContextGLAttributes, noExtensions)
        , offsetof(WebCore::GraphicsContextGLAttributes, devicePixelRatio)
        , offsetof(WebCore::GraphicsContextGLAttributes, initialPowerPreference)
        , offsetof(WebCore::GraphicsContextGLAttributes, webGLVersion)
        , offsetof(WebCore::GraphicsContextGLAttributes, forceRequestForHighPerformanceGPU)
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
        , offsetof(WebCore::GraphicsContextGLAttributes, windowGPUID)
#endif
#if PLATFORM(COCOA)
        , offsetof(WebCore::GraphicsContextGLAttributes, useMetal)
#endif
#if ENABLE(WEBXR)
        , offsetof(WebCore::GraphicsContextGLAttributes, xrCompatible)
#endif
    >::value);
    encoder << instance.alpha;
    encoder << instance.depth;
    encoder << instance.stencil;
    encoder << instance.antialias;
    encoder << instance.premultipliedAlpha;
    encoder << instance.preserveDrawingBuffer;
    encoder << instance.failIfMajorPerformanceCaveat;
    encoder << instance.powerPreference;
    encoder << instance.failPlatformContextCreationForTesting;
    encoder << instance.shareResources;
    encoder << instance.noExtensions;
    encoder << instance.devicePixelRatio;
    encoder << instance.initialPowerPreference;
    encoder << instance.webGLVersion;
    encoder << instance.forceRequestForHighPerformanceGPU;
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
    encoder << instance.windowGPUID;
#endif
#if PLATFORM(COCOA)
    encoder << instance.useMetal;
#endif
#if ENABLE(WEBXR)
    encoder << instance.xrCompatible;
#endif
}

std::optional<WebCore::GraphicsContextGLAttributes> ArgumentCoder<WebCore::GraphicsContextGLAttributes>::decode(Decoder& decoder)
{
    auto alpha = decoder.decode<bool>();
    if (!alpha)
        return std::nullopt;

    auto depth = decoder.decode<bool>();
    if (!depth)
        return std::nullopt;

    auto stencil = decoder.decode<bool>();
    if (!stencil)
        return std::nullopt;

    auto antialias = decoder.decode<bool>();
    if (!antialias)
        return std::nullopt;

    auto premultipliedAlpha = decoder.decode<bool>();
    if (!premultipliedAlpha)
        return std::nullopt;

    auto preserveDrawingBuffer = decoder.decode<bool>();
    if (!preserveDrawingBuffer)
        return std::nullopt;

    auto failIfMajorPerformanceCaveat = decoder.decode<bool>();
    if (!failIfMajorPerformanceCaveat)
        return std::nullopt;

    auto powerPreference = decoder.decode<WebCore::GraphicsContextGLPowerPreference>();
    if (!powerPreference)
        return std::nullopt;

    auto failPlatformContextCreationForTesting = decoder.decode<bool>();
    if (!failPlatformContextCreationForTesting)
        return std::nullopt;

    auto shareResources = decoder.decode<bool>();
    if (!shareResources)
        return std::nullopt;

    auto noExtensions = decoder.decode<bool>();
    if (!noExtensions)
        return std::nullopt;

    auto devicePixelRatio = decoder.decode<float>();
    if (!devicePixelRatio)
        return std::nullopt;

    auto initialPowerPreference = decoder.decode<WebCore::GraphicsContextGLPowerPreference>();
    if (!initialPowerPreference)
        return std::nullopt;

    auto webGLVersion = decoder.decode<WebCore::GraphicsContextGLWebGLVersion>();
    if (!webGLVersion)
        return std::nullopt;

    auto forceRequestForHighPerformanceGPU = decoder.decode<bool>();
    if (!forceRequestForHighPerformanceGPU)
        return std::nullopt;

#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
    auto windowGPUID = decoder.decode<uint64_t>();
    if (!windowGPUID)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto useMetal = decoder.decode<bool>();
    if (!useMetal)
        return std::nullopt;
#endif

#if ENABLE(WEBXR)
    auto xrCompatible = decoder.decode<bool>();
    if (!xrCompatible)
        return std::nullopt;
#endif

    return {
        WebCore::GraphicsContextGLAttributes {
            WTFMove(*alpha),
            WTFMove(*depth),
            WTFMove(*stencil),
            WTFMove(*antialias),
            WTFMove(*premultipliedAlpha),
            WTFMove(*preserveDrawingBuffer),
            WTFMove(*failIfMajorPerformanceCaveat),
            WTFMove(*powerPreference),
            WTFMove(*failPlatformContextCreationForTesting),
            WTFMove(*shareResources),
            WTFMove(*noExtensions),
            WTFMove(*devicePixelRatio),
            WTFMove(*initialPowerPreference),
            WTFMove(*webGLVersion),
            WTFMove(*forceRequestForHighPerformanceGPU),
#if PLATFORM(MAC) || PLATFORM(MACCATALYST)
            WTFMove(*windowGPUID),
#endif
#if PLATFORM(COCOA)
            WTFMove(*useMetal),
#endif
#if ENABLE(WEBXR)
            WTFMove(*xrCompatible)
#endif
        }
    };
}

#endif

enum class WebCore_TimingFunction_Subclass : uint8_t {
    LinearTimingFunction,
    CubicBezierTimingFunction,
    StepsTimingFunction,
    SpringTimingFunction
};

void ArgumentCoder<WebCore::TimingFunction>::encode(Encoder& encoder, const WebCore::TimingFunction& instance)
{
    if (auto* subclass = dynamicDowncast<WebCore::LinearTimingFunction>(instance)) {
        encoder << WebCore_TimingFunction_Subclass::LinearTimingFunction;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::CubicBezierTimingFunction>(instance)) {
        encoder << WebCore_TimingFunction_Subclass::CubicBezierTimingFunction;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::StepsTimingFunction>(instance)) {
        encoder << WebCore_TimingFunction_Subclass::StepsTimingFunction;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::SpringTimingFunction>(instance)) {
        encoder << WebCore_TimingFunction_Subclass::SpringTimingFunction;
        encoder << *subclass;
    }
}

std::optional<Ref<WebCore::TimingFunction>> ArgumentCoder<WebCore::TimingFunction>::decode(Decoder& decoder)
{
    std::optional<WebCore_TimingFunction_Subclass> type;
    decoder >> type;
    if (!type)
        return std::nullopt;

    if (type == WebCore_TimingFunction_Subclass::LinearTimingFunction) {
        std::optional<Ref<WebCore::LinearTimingFunction>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TimingFunction_Subclass::CubicBezierTimingFunction) {
        std::optional<Ref<WebCore::CubicBezierTimingFunction>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TimingFunction_Subclass::StepsTimingFunction) {
        std::optional<Ref<WebCore::StepsTimingFunction>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TimingFunction_Subclass::SpringTimingFunction) {
        std::optional<Ref<WebCore::SpringTimingFunction>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    ASSERT_NOT_REACHED();
    return std::nullopt;
}

enum class WebCore_TransformOperation_Subclass : uint8_t {
    TranslateTransformOperation,
    ScaleTransformOperation,
    RotateTransformOperation,
    SkewTransformOperation,
    MatrixTransformOperation,
    Matrix3DTransformOperation,
    PerspectiveTransformOperation,
    IdentityTransformOperation
};

void ArgumentCoder<WebCore::TransformOperation>::encode(Encoder& encoder, const WebCore::TransformOperation& instance)
{
    if (auto* subclass = dynamicDowncast<WebCore::TranslateTransformOperation>(instance)) {
        encoder << WebCore_TransformOperation_Subclass::TranslateTransformOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::ScaleTransformOperation>(instance)) {
        encoder << WebCore_TransformOperation_Subclass::ScaleTransformOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::RotateTransformOperation>(instance)) {
        encoder << WebCore_TransformOperation_Subclass::RotateTransformOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::SkewTransformOperation>(instance)) {
        encoder << WebCore_TransformOperation_Subclass::SkewTransformOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::MatrixTransformOperation>(instance)) {
        encoder << WebCore_TransformOperation_Subclass::MatrixTransformOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::Matrix3DTransformOperation>(instance)) {
        encoder << WebCore_TransformOperation_Subclass::Matrix3DTransformOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::PerspectiveTransformOperation>(instance)) {
        encoder << WebCore_TransformOperation_Subclass::PerspectiveTransformOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::IdentityTransformOperation>(instance)) {
        encoder << WebCore_TransformOperation_Subclass::IdentityTransformOperation;
        encoder << *subclass;
    }
}

std::optional<Ref<WebCore::TransformOperation>> ArgumentCoder<WebCore::TransformOperation>::decode(Decoder& decoder)
{
    std::optional<WebCore_TransformOperation_Subclass> type;
    decoder >> type;
    if (!type)
        return std::nullopt;

    if (type == WebCore_TransformOperation_Subclass::TranslateTransformOperation) {
        std::optional<Ref<WebCore::TranslateTransformOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TransformOperation_Subclass::ScaleTransformOperation) {
        std::optional<Ref<WebCore::ScaleTransformOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TransformOperation_Subclass::RotateTransformOperation) {
        std::optional<Ref<WebCore::RotateTransformOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TransformOperation_Subclass::SkewTransformOperation) {
        std::optional<Ref<WebCore::SkewTransformOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TransformOperation_Subclass::MatrixTransformOperation) {
        std::optional<Ref<WebCore::MatrixTransformOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TransformOperation_Subclass::Matrix3DTransformOperation) {
        std::optional<Ref<WebCore::Matrix3DTransformOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TransformOperation_Subclass::PerspectiveTransformOperation) {
        std::optional<Ref<WebCore::PerspectiveTransformOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_TransformOperation_Subclass::IdentityTransformOperation) {
        std::optional<Ref<WebCore::IdentityTransformOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    ASSERT_NOT_REACHED();
    return std::nullopt;
}


void ArgumentCoder<WebCore::LengthSize>::encode(Encoder& encoder, const WebCore::LengthSize& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width)>, WebCore::Length>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height)>, WebCore::Length>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::LengthSize, width)
        , offsetof(WebCore::LengthSize, height)
    >::value);
    encoder << instance.width;
    encoder << instance.height;
}

std::optional<WebCore::LengthSize> ArgumentCoder<WebCore::LengthSize>::decode(Decoder& decoder)
{
    auto width = decoder.decode<WebCore::Length>();
    if (!width)
        return std::nullopt;

    auto height = decoder.decode<WebCore::Length>();
    if (!height)
        return std::nullopt;

    return {
        WebCore::LengthSize {
            WTFMove(*width),
            WTFMove(*height)
        }
    };
}


void ArgumentCoder<WebCore::SVGPathByteStream>::encode(Encoder& encoder, const WebCore::SVGPathByteStream& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data())>, Vector<unsigned char>>);
    encoder << instance.data();
}

std::optional<WebCore::SVGPathByteStream> ArgumentCoder<WebCore::SVGPathByteStream>::decode(Decoder& decoder)
{
    auto data = decoder.decode<Vector<unsigned char>>();
    if (!data)
        return std::nullopt;

    return {
        WebCore::SVGPathByteStream {
            WTFMove(*data)
        }
    };
}


void ArgumentCoder<WebCore::BasicShapeCenterCoordinate>::encode(Encoder& encoder, const WebCore::BasicShapeCenterCoordinate& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.direction())>, WebCore::BasicShapeCenterCoordinate::Direction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.length())>, WebCore::Length>);
    encoder << instance.direction();
    encoder << instance.length();
}

std::optional<WebCore::BasicShapeCenterCoordinate> ArgumentCoder<WebCore::BasicShapeCenterCoordinate>::decode(Decoder& decoder)
{
    auto direction = decoder.decode<WebCore::BasicShapeCenterCoordinate::Direction>();
    if (!direction)
        return std::nullopt;

    auto length = decoder.decode<WebCore::Length>();
    if (!length)
        return std::nullopt;

    return {
        WebCore::BasicShapeCenterCoordinate {
            WTFMove(*direction),
            WTFMove(*length)
        }
    };
}


void ArgumentCoder<WebCore::BasicShapeRadius>::encode(Encoder& encoder, const WebCore::BasicShapeRadius& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value())>, WebCore::Length>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::BasicShapeRadius::Type>);
    encoder << instance.value();
    encoder << instance.type();
}

std::optional<WebCore::BasicShapeRadius> ArgumentCoder<WebCore::BasicShapeRadius>::decode(Decoder& decoder)
{
    auto value = decoder.decode<WebCore::Length>();
    if (!value)
        return std::nullopt;

    auto type = decoder.decode<WebCore::BasicShapeRadius::Type>();
    if (!type)
        return std::nullopt;

    return {
        WebCore::BasicShapeRadius {
            WTFMove(*value),
            WTFMove(*type)
        }
    };
}


void ArgumentCoder<WebCore::BasicShapeCircle>::encode(Encoder& encoder, const WebCore::BasicShapeCircle& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.centerX())>, WebCore::BasicShapeCenterCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.centerY())>, WebCore::BasicShapeCenterCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radius())>, WebCore::BasicShapeRadius>);
    encoder << instance.centerX();
    encoder << instance.centerY();
    encoder << instance.radius();
}

std::optional<Ref<WebCore::BasicShapeCircle>> ArgumentCoder<WebCore::BasicShapeCircle>::decode(Decoder& decoder)
{
    auto centerX = decoder.decode<WebCore::BasicShapeCenterCoordinate>();
    if (!centerX)
        return std::nullopt;

    auto centerY = decoder.decode<WebCore::BasicShapeCenterCoordinate>();
    if (!centerY)
        return std::nullopt;

    auto radius = decoder.decode<WebCore::BasicShapeRadius>();
    if (!radius)
        return std::nullopt;

    return {
        WebCore::BasicShapeCircle::create(
            WTFMove(*centerX),
            WTFMove(*centerY),
            WTFMove(*radius)
        )
    };
}


void ArgumentCoder<WebCore::BasicShapeEllipse>::encode(Encoder& encoder, const WebCore::BasicShapeEllipse& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.centerX())>, WebCore::BasicShapeCenterCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.centerY())>, WebCore::BasicShapeCenterCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radiusX())>, WebCore::BasicShapeRadius>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radiusY())>, WebCore::BasicShapeRadius>);
    encoder << instance.centerX();
    encoder << instance.centerY();
    encoder << instance.radiusX();
    encoder << instance.radiusY();
}

std::optional<Ref<WebCore::BasicShapeEllipse>> ArgumentCoder<WebCore::BasicShapeEllipse>::decode(Decoder& decoder)
{
    auto centerX = decoder.decode<WebCore::BasicShapeCenterCoordinate>();
    if (!centerX)
        return std::nullopt;

    auto centerY = decoder.decode<WebCore::BasicShapeCenterCoordinate>();
    if (!centerY)
        return std::nullopt;

    auto radiusX = decoder.decode<WebCore::BasicShapeRadius>();
    if (!radiusX)
        return std::nullopt;

    auto radiusY = decoder.decode<WebCore::BasicShapeRadius>();
    if (!radiusY)
        return std::nullopt;

    return {
        WebCore::BasicShapeEllipse::create(
            WTFMove(*centerX),
            WTFMove(*centerY),
            WTFMove(*radiusX),
            WTFMove(*radiusY)
        )
    };
}


void ArgumentCoder<WebCore::BasicShapePolygon>::encode(Encoder& encoder, const WebCore::BasicShapePolygon& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.windRule())>, WebCore::WindRule>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.values())>, Vector<WebCore::Length>>);
    encoder << instance.windRule();
    encoder << instance.values();
}

std::optional<Ref<WebCore::BasicShapePolygon>> ArgumentCoder<WebCore::BasicShapePolygon>::decode(Decoder& decoder)
{
    auto windRule = decoder.decode<WebCore::WindRule>();
    if (!windRule)
        return std::nullopt;

    auto values = decoder.decode<Vector<WebCore::Length>>();
    if (!values)
        return std::nullopt;

    return {
        WebCore::BasicShapePolygon::create(
            WTFMove(*windRule),
            WTFMove(*values)
        )
    };
}


void ArgumentCoder<WebCore::BasicShapePath>::encode(Encoder& encoder, const WebCore::BasicShapePath& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.byteStream())>, std::unique_ptr<WebCore::SVGPathByteStream>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.zoom())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.windRule())>, WebCore::WindRule>);
    encoder << instance.byteStream();
    encoder << instance.zoom();
    encoder << instance.windRule();
}

std::optional<Ref<WebCore::BasicShapePath>> ArgumentCoder<WebCore::BasicShapePath>::decode(Decoder& decoder)
{
    auto byteStream = decoder.decode<std::unique_ptr<WebCore::SVGPathByteStream>>();
    if (!byteStream)
        return std::nullopt;

    auto zoom = decoder.decode<float>();
    if (!zoom)
        return std::nullopt;

    auto windRule = decoder.decode<WebCore::WindRule>();
    if (!windRule)
        return std::nullopt;

    return {
        WebCore::BasicShapePath::create(
            WTFMove(*byteStream),
            WTFMove(*zoom),
            WTFMove(*windRule)
        )
    };
}


void ArgumentCoder<WebCore::BasicShapeInset>::encode(Encoder& encoder, const WebCore::BasicShapeInset& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.right())>, WebCore::Length>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.top())>, WebCore::Length>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bottom())>, WebCore::Length>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.left())>, WebCore::Length>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topLeftRadius())>, WebCore::LengthSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topRightRadius())>, WebCore::LengthSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bottomRightRadius())>, WebCore::LengthSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bottomLeftRadius())>, WebCore::LengthSize>);
    encoder << instance.right();
    encoder << instance.top();
    encoder << instance.bottom();
    encoder << instance.left();
    encoder << instance.topLeftRadius();
    encoder << instance.topRightRadius();
    encoder << instance.bottomRightRadius();
    encoder << instance.bottomLeftRadius();
}

std::optional<Ref<WebCore::BasicShapeInset>> ArgumentCoder<WebCore::BasicShapeInset>::decode(Decoder& decoder)
{
    auto right = decoder.decode<WebCore::Length>();
    if (!right)
        return std::nullopt;

    auto top = decoder.decode<WebCore::Length>();
    if (!top)
        return std::nullopt;

    auto bottom = decoder.decode<WebCore::Length>();
    if (!bottom)
        return std::nullopt;

    auto left = decoder.decode<WebCore::Length>();
    if (!left)
        return std::nullopt;

    auto topLeftRadius = decoder.decode<WebCore::LengthSize>();
    if (!topLeftRadius)
        return std::nullopt;

    auto topRightRadius = decoder.decode<WebCore::LengthSize>();
    if (!topRightRadius)
        return std::nullopt;

    auto bottomRightRadius = decoder.decode<WebCore::LengthSize>();
    if (!bottomRightRadius)
        return std::nullopt;

    auto bottomLeftRadius = decoder.decode<WebCore::LengthSize>();
    if (!bottomLeftRadius)
        return std::nullopt;

    return {
        WebCore::BasicShapeInset::create(
            WTFMove(*right),
            WTFMove(*top),
            WTFMove(*bottom),
            WTFMove(*left),
            WTFMove(*topLeftRadius),
            WTFMove(*topRightRadius),
            WTFMove(*bottomRightRadius),
            WTFMove(*bottomLeftRadius)
        )
    };
}

enum class WebCore_BasicShape_Subclass : uint8_t {
    BasicShapeCircle,
    BasicShapeEllipse,
    BasicShapePolygon,
    BasicShapePath,
    BasicShapeInset
};

void ArgumentCoder<WebCore::BasicShape>::encode(Encoder& encoder, const WebCore::BasicShape& instance)
{
    if (auto* subclass = dynamicDowncast<WebCore::BasicShapeCircle>(instance)) {
        encoder << WebCore_BasicShape_Subclass::BasicShapeCircle;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::BasicShapeEllipse>(instance)) {
        encoder << WebCore_BasicShape_Subclass::BasicShapeEllipse;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::BasicShapePolygon>(instance)) {
        encoder << WebCore_BasicShape_Subclass::BasicShapePolygon;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::BasicShapePath>(instance)) {
        encoder << WebCore_BasicShape_Subclass::BasicShapePath;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::BasicShapeInset>(instance)) {
        encoder << WebCore_BasicShape_Subclass::BasicShapeInset;
        encoder << *subclass;
    }
}

std::optional<Ref<WebCore::BasicShape>> ArgumentCoder<WebCore::BasicShape>::decode(Decoder& decoder)
{
    std::optional<WebCore_BasicShape_Subclass> type;
    decoder >> type;
    if (!type)
        return std::nullopt;

    if (type == WebCore_BasicShape_Subclass::BasicShapeCircle) {
        std::optional<Ref<WebCore::BasicShapeCircle>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_BasicShape_Subclass::BasicShapeEllipse) {
        std::optional<Ref<WebCore::BasicShapeEllipse>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_BasicShape_Subclass::BasicShapePolygon) {
        std::optional<Ref<WebCore::BasicShapePolygon>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_BasicShape_Subclass::BasicShapePath) {
        std::optional<Ref<WebCore::BasicShapePath>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_BasicShape_Subclass::BasicShapeInset) {
        std::optional<Ref<WebCore::BasicShapeInset>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    ASSERT_NOT_REACHED();
    return std::nullopt;
}


void ArgumentCoder<WebCore::ReferencePathOperation>::encode(Encoder& encoder, const WebCore::ReferencePathOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.path())>, std::optional<WebCore::Path>>);
    encoder << instance.path();
}

std::optional<Ref<WebCore::ReferencePathOperation>> ArgumentCoder<WebCore::ReferencePathOperation>::decode(Decoder& decoder)
{
    auto path = decoder.decode<std::optional<WebCore::Path>>();
    if (!path)
        return std::nullopt;

    return {
        WebCore::ReferencePathOperation::create(
            WTFMove(*path)
        )
    };
}


void ArgumentCoder<WebCore::ShapePathOperation>::encode(Encoder& encoder, const WebCore::ShapePathOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shape())>, Ref<WebCore::BasicShape>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.referenceBox())>, WebCore::CSSBoxType>);
    encoder << instance.shape();
    encoder << instance.referenceBox();
}

std::optional<Ref<WebCore::ShapePathOperation>> ArgumentCoder<WebCore::ShapePathOperation>::decode(Decoder& decoder)
{
    auto shape = decoder.decode<Ref<WebCore::BasicShape>>();
    if (!shape)
        return std::nullopt;

    auto referenceBox = decoder.decode<WebCore::CSSBoxType>();
    if (!referenceBox)
        return std::nullopt;

    return {
        WebCore::ShapePathOperation::create(
            WTFMove(*shape),
            WTFMove(*referenceBox)
        )
    };
}


void ArgumentCoder<WebCore::BoxPathOperation>::encode(Encoder& encoder, const WebCore::BoxPathOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.path())>, WebCore::Path>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.referenceBox())>, WebCore::CSSBoxType>);
    encoder << instance.path();
    encoder << instance.referenceBox();
}

std::optional<Ref<WebCore::BoxPathOperation>> ArgumentCoder<WebCore::BoxPathOperation>::decode(Decoder& decoder)
{
    auto path = decoder.decode<WebCore::Path>();
    if (!path)
        return std::nullopt;

    auto referenceBox = decoder.decode<WebCore::CSSBoxType>();
    if (!referenceBox)
        return std::nullopt;

    return {
        WebCore::BoxPathOperation::create(
            WTFMove(*path),
            WTFMove(*referenceBox)
        )
    };
}


void ArgumentCoder<WebCore::RayPathOperation>::encode(Encoder& encoder, const WebCore::RayPathOperation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.angle())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size())>, WebCore::RayPathOperation::Size>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isContaining())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.containingBlockBoundingRect())>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, WebCore::FloatPoint>);
    encoder << instance.angle();
    encoder << instance.size();
    encoder << instance.isContaining();
    encoder << instance.containingBlockBoundingRect();
    encoder << instance.position();
}

std::optional<Ref<WebCore::RayPathOperation>> ArgumentCoder<WebCore::RayPathOperation>::decode(Decoder& decoder)
{
    auto angle = decoder.decode<float>();
    if (!angle)
        return std::nullopt;

    auto size = decoder.decode<WebCore::RayPathOperation::Size>();
    if (!size)
        return std::nullopt;

    auto isContaining = decoder.decode<bool>();
    if (!isContaining)
        return std::nullopt;

    auto containingBlockBoundingRect = decoder.decode<WebCore::FloatRect>();
    if (!containingBlockBoundingRect)
        return std::nullopt;

    auto position = decoder.decode<WebCore::FloatPoint>();
    if (!position)
        return std::nullopt;

    return {
        WebCore::RayPathOperation::create(
            WTFMove(*angle),
            WTFMove(*size),
            WTFMove(*isContaining),
            WTFMove(*containingBlockBoundingRect),
            WTFMove(*position)
        )
    };
}

enum class WebCore_PathOperation_Subclass : uint8_t {
    ReferencePathOperation,
    ShapePathOperation,
    BoxPathOperation,
    RayPathOperation
};

void ArgumentCoder<WebCore::PathOperation>::encode(Encoder& encoder, const WebCore::PathOperation& instance)
{
    if (auto* subclass = dynamicDowncast<WebCore::ReferencePathOperation>(instance)) {
        encoder << WebCore_PathOperation_Subclass::ReferencePathOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::ShapePathOperation>(instance)) {
        encoder << WebCore_PathOperation_Subclass::ShapePathOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::BoxPathOperation>(instance)) {
        encoder << WebCore_PathOperation_Subclass::BoxPathOperation;
        encoder << *subclass;
    }
    if (auto* subclass = dynamicDowncast<WebCore::RayPathOperation>(instance)) {
        encoder << WebCore_PathOperation_Subclass::RayPathOperation;
        encoder << *subclass;
    }
}

std::optional<Ref<WebCore::PathOperation>> ArgumentCoder<WebCore::PathOperation>::decode(Decoder& decoder)
{
    std::optional<WebCore_PathOperation_Subclass> type;
    decoder >> type;
    if (!type)
        return std::nullopt;

    if (type == WebCore_PathOperation_Subclass::ReferencePathOperation) {
        std::optional<Ref<WebCore::ReferencePathOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_PathOperation_Subclass::ShapePathOperation) {
        std::optional<Ref<WebCore::ShapePathOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_PathOperation_Subclass::BoxPathOperation) {
        std::optional<Ref<WebCore::BoxPathOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    if (type == WebCore_PathOperation_Subclass::RayPathOperation) {
        std::optional<Ref<WebCore::RayPathOperation>> result;
        decoder >> result;
        if (!result)
            return std::nullopt;
        return WTFMove(*result);
    }

    ASSERT_NOT_REACHED();
    return std::nullopt;
}

#if ENABLE(ENCRYPTED_MEDIA)

void ArgumentCoder<WebCore::CDMKeySystemConfiguration>::encode(Encoder& encoder, const WebCore::CDMKeySystemConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.initDataTypes)>, Vector<AtomString>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.audioCapabilities)>, Vector<WebCore::CDMMediaCapability>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.videoCapabilities)>, Vector<WebCore::CDMMediaCapability>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.distinctiveIdentifier)>, WebCore::CDMRequirement>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.persistentState)>, WebCore::CDMRequirement>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sessionTypes)>, Vector<WebCore::CDMSessionType>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CDMKeySystemConfiguration, label)
        , offsetof(WebCore::CDMKeySystemConfiguration, initDataTypes)
        , offsetof(WebCore::CDMKeySystemConfiguration, audioCapabilities)
        , offsetof(WebCore::CDMKeySystemConfiguration, videoCapabilities)
        , offsetof(WebCore::CDMKeySystemConfiguration, distinctiveIdentifier)
        , offsetof(WebCore::CDMKeySystemConfiguration, persistentState)
        , offsetof(WebCore::CDMKeySystemConfiguration, sessionTypes)
    >::value);
    encoder << instance.label;
    encoder << instance.initDataTypes;
    encoder << instance.audioCapabilities;
    encoder << instance.videoCapabilities;
    encoder << instance.distinctiveIdentifier;
    encoder << instance.persistentState;
    encoder << instance.sessionTypes;
}

std::optional<WebCore::CDMKeySystemConfiguration> ArgumentCoder<WebCore::CDMKeySystemConfiguration>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto initDataTypes = decoder.decode<Vector<AtomString>>();
    if (!initDataTypes)
        return std::nullopt;

    auto audioCapabilities = decoder.decode<Vector<WebCore::CDMMediaCapability>>();
    if (!audioCapabilities)
        return std::nullopt;

    auto videoCapabilities = decoder.decode<Vector<WebCore::CDMMediaCapability>>();
    if (!videoCapabilities)
        return std::nullopt;

    auto distinctiveIdentifier = decoder.decode<WebCore::CDMRequirement>();
    if (!distinctiveIdentifier)
        return std::nullopt;

    auto persistentState = decoder.decode<WebCore::CDMRequirement>();
    if (!persistentState)
        return std::nullopt;

    auto sessionTypes = decoder.decode<Vector<WebCore::CDMSessionType>>();
    if (!sessionTypes)
        return std::nullopt;

    return {
        WebCore::CDMKeySystemConfiguration {
            WTFMove(*label),
            WTFMove(*initDataTypes),
            WTFMove(*audioCapabilities),
            WTFMove(*videoCapabilities),
            WTFMove(*distinctiveIdentifier),
            WTFMove(*persistentState),
            WTFMove(*sessionTypes)
        }
    };
}

#endif


void ArgumentCoder<WebCore::MediaConfiguration>::encode(Encoder& encoder, const WebCore::MediaConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.video)>, std::optional<WebCore::VideoConfiguration>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.audio)>, std::optional<WebCore::AudioConfiguration>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaContainerTypes)>, std::optional<Vector<String>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaCodecTypes)>, std::optional<Vector<String>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaConfiguration, video)
        , offsetof(WebCore::MediaConfiguration, audio)
        , offsetof(WebCore::MediaConfiguration, allowedMediaContainerTypes)
        , offsetof(WebCore::MediaConfiguration, allowedMediaCodecTypes)
    >::value);
    encoder << instance.video;
    encoder << instance.audio;
    encoder << instance.allowedMediaContainerTypes;
    encoder << instance.allowedMediaCodecTypes;
}

std::optional<WebCore::MediaConfiguration> ArgumentCoder<WebCore::MediaConfiguration>::decode(Decoder& decoder)
{
    auto video = decoder.decode<std::optional<WebCore::VideoConfiguration>>();
    if (!video)
        return std::nullopt;

    auto audio = decoder.decode<std::optional<WebCore::AudioConfiguration>>();
    if (!audio)
        return std::nullopt;

    auto allowedMediaContainerTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaContainerTypes)
        return std::nullopt;

    auto allowedMediaCodecTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaCodecTypes)
        return std::nullopt;

    return {
        WebCore::MediaConfiguration {
            WTFMove(*video),
            WTFMove(*audio),
            WTFMove(*allowedMediaContainerTypes),
            WTFMove(*allowedMediaCodecTypes)
        }
    };
}


void ArgumentCoder<WebCore::MediaEncodingConfiguration>::encode(Encoder& encoder, const WebCore::MediaEncodingConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.video)>, std::optional<WebCore::VideoConfiguration>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.audio)>, std::optional<WebCore::AudioConfiguration>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaContainerTypes)>, std::optional<Vector<String>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaCodecTypes)>, std::optional<Vector<String>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaConfiguration, video)
        , offsetof(WebCore::MediaConfiguration, audio)
        , offsetof(WebCore::MediaConfiguration, allowedMediaContainerTypes)
        , offsetof(WebCore::MediaConfiguration, allowedMediaCodecTypes)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::MediaEncodingType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaEncodingConfiguration, type)
    >::value);
    encoder << instance.video;
    encoder << instance.audio;
    encoder << instance.allowedMediaContainerTypes;
    encoder << instance.allowedMediaCodecTypes;
    encoder << instance.type;
}

std::optional<WebCore::MediaEncodingConfiguration> ArgumentCoder<WebCore::MediaEncodingConfiguration>::decode(Decoder& decoder)
{
    auto video = decoder.decode<std::optional<WebCore::VideoConfiguration>>();
    if (!video)
        return std::nullopt;

    auto audio = decoder.decode<std::optional<WebCore::AudioConfiguration>>();
    if (!audio)
        return std::nullopt;

    auto allowedMediaContainerTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaContainerTypes)
        return std::nullopt;

    auto allowedMediaCodecTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaCodecTypes)
        return std::nullopt;

    auto type = decoder.decode<WebCore::MediaEncodingType>();
    if (!type)
        return std::nullopt;

    return {
        WebCore::MediaEncodingConfiguration {
            WebCore::MediaConfiguration {
                WTFMove(*video),
                WTFMove(*audio),
                WTFMove(*allowedMediaContainerTypes),
                WTFMove(*allowedMediaCodecTypes)
            },
            WTFMove(*type)
        }
    };
}


void ArgumentCoder<WebCore::MediaDecodingConfiguration>::encode(Encoder& encoder, const WebCore::MediaDecodingConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.video)>, std::optional<WebCore::VideoConfiguration>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.audio)>, std::optional<WebCore::AudioConfiguration>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaContainerTypes)>, std::optional<Vector<String>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaCodecTypes)>, std::optional<Vector<String>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaConfiguration, video)
        , offsetof(WebCore::MediaConfiguration, audio)
        , offsetof(WebCore::MediaConfiguration, allowedMediaContainerTypes)
        , offsetof(WebCore::MediaConfiguration, allowedMediaCodecTypes)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::MediaDecodingType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canExposeVP9)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaDecodingConfiguration, type)
        , offsetof(WebCore::MediaDecodingConfiguration, canExposeVP9)
    >::value);
    encoder << instance.video;
    encoder << instance.audio;
    encoder << instance.allowedMediaContainerTypes;
    encoder << instance.allowedMediaCodecTypes;
    encoder << instance.type;
    encoder << instance.canExposeVP9;
}

std::optional<WebCore::MediaDecodingConfiguration> ArgumentCoder<WebCore::MediaDecodingConfiguration>::decode(Decoder& decoder)
{
    auto video = decoder.decode<std::optional<WebCore::VideoConfiguration>>();
    if (!video)
        return std::nullopt;

    auto audio = decoder.decode<std::optional<WebCore::AudioConfiguration>>();
    if (!audio)
        return std::nullopt;

    auto allowedMediaContainerTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaContainerTypes)
        return std::nullopt;

    auto allowedMediaCodecTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaCodecTypes)
        return std::nullopt;

    auto type = decoder.decode<WebCore::MediaDecodingType>();
    if (!type)
        return std::nullopt;

    auto canExposeVP9 = decoder.decode<bool>();
    if (!canExposeVP9)
        return std::nullopt;

    return {
        WebCore::MediaDecodingConfiguration {
            WebCore::MediaConfiguration {
                WTFMove(*video),
                WTFMove(*audio),
                WTFMove(*allowedMediaContainerTypes),
                WTFMove(*allowedMediaCodecTypes)
            },
            WTFMove(*type),
            WTFMove(*canExposeVP9)
        }
    };
}


void ArgumentCoder<WebCore::ResourceResponseBase::ResponseData>::encode(Encoder& encoder, const WebCore::ResourceResponseBase::ResponseData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_url)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_mimeType)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_expectedContentLength)>, long long>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_textEncodingName)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_httpStatusText)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_httpVersion)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_httpHeaderFields)>, WebCore::HTTPHeaderMap>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_networkLoadMetrics)>, Box<WebCore::NetworkLoadMetrics>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_httpStatusCode)>, short>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_certificateInfo)>, std::optional<WebCore::CertificateInfo>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_source)>, WebCore::ResourceResponseBase::Source>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_type)>, WebCore::ResourceResponseBase::Type>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_tainting)>, WebCore::ResourceResponseBase::Tainting>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isRedirected)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_usedLegacyTLS)>, WebCore::UsedLegacyTLS>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_wasPrivateRelayed)>, WebCore::WasPrivateRelayed>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isRangeRequested)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_url)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_mimeType)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_expectedContentLength)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_textEncodingName)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_httpStatusText)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_httpVersion)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_httpHeaderFields)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_networkLoadMetrics)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_httpStatusCode)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_certificateInfo)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_source)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_type)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_tainting)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_isRedirected)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_usedLegacyTLS)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_wasPrivateRelayed)
        , offsetof(WebCore::ResourceResponseBase::ResponseData, m_isRangeRequested)
    >::value);
    encoder << instance.m_url;
    encoder << instance.m_mimeType;
    encoder << instance.m_expectedContentLength;
    encoder << instance.m_textEncodingName;
    encoder << instance.m_httpStatusText;
    encoder << instance.m_httpVersion;
    encoder << instance.m_httpHeaderFields;
    encoder << instance.m_networkLoadMetrics;
    encoder << instance.m_httpStatusCode;
    encoder << instance.m_certificateInfo;
    encoder << instance.m_source;
    encoder << instance.m_type;
    encoder << instance.m_tainting;
    encoder << instance.m_isRedirected;
    encoder << instance.m_usedLegacyTLS;
    encoder << instance.m_wasPrivateRelayed;
    encoder << instance.m_isRangeRequested;
}

std::optional<WebCore::ResourceResponseBase::ResponseData> ArgumentCoder<WebCore::ResourceResponseBase::ResponseData>::decode(Decoder& decoder)
{
    auto m_url = decoder.decode<URL>();
    if (!m_url)
        return std::nullopt;

    auto m_mimeType = decoder.decode<AtomString>();
    if (!m_mimeType)
        return std::nullopt;

    auto m_expectedContentLength = decoder.decode<long long>();
    if (!m_expectedContentLength)
        return std::nullopt;

    auto m_textEncodingName = decoder.decode<AtomString>();
    if (!m_textEncodingName)
        return std::nullopt;

    auto m_httpStatusText = decoder.decode<AtomString>();
    if (!m_httpStatusText)
        return std::nullopt;

    auto m_httpVersion = decoder.decode<AtomString>();
    if (!m_httpVersion)
        return std::nullopt;

    auto m_httpHeaderFields = decoder.decode<WebCore::HTTPHeaderMap>();
    if (!m_httpHeaderFields)
        return std::nullopt;

    auto m_networkLoadMetrics = decoder.decode<Box<WebCore::NetworkLoadMetrics>>();
    if (!m_networkLoadMetrics)
        return std::nullopt;

    auto m_httpStatusCode = decoder.decode<short>();
    if (!m_httpStatusCode)
        return std::nullopt;

    auto m_certificateInfo = decoder.decode<std::optional<WebCore::CertificateInfo>>();
    if (!m_certificateInfo)
        return std::nullopt;

    auto m_source = decoder.decode<WebCore::ResourceResponseBase::Source>();
    if (!m_source)
        return std::nullopt;

    auto m_type = decoder.decode<WebCore::ResourceResponseBase::Type>();
    if (!m_type)
        return std::nullopt;

    auto m_tainting = decoder.decode<WebCore::ResourceResponseBase::Tainting>();
    if (!m_tainting)
        return std::nullopt;

    auto m_isRedirected = decoder.decode<bool>();
    if (!m_isRedirected)
        return std::nullopt;

    auto m_usedLegacyTLS = decoder.decode<WebCore::UsedLegacyTLS>();
    if (!m_usedLegacyTLS)
        return std::nullopt;

    auto m_wasPrivateRelayed = decoder.decode<WebCore::WasPrivateRelayed>();
    if (!m_wasPrivateRelayed)
        return std::nullopt;

    auto m_isRangeRequested = decoder.decode<bool>();
    if (!m_isRangeRequested)
        return std::nullopt;

    return {
        WebCore::ResourceResponseBase::ResponseData {
            WTFMove(*m_url),
            WTFMove(*m_mimeType),
            WTFMove(*m_expectedContentLength),
            WTFMove(*m_textEncodingName),
            WTFMove(*m_httpStatusText),
            WTFMove(*m_httpVersion),
            WTFMove(*m_httpHeaderFields),
            WTFMove(*m_networkLoadMetrics),
            WTFMove(*m_httpStatusCode),
            WTFMove(*m_certificateInfo),
            WTFMove(*m_source),
            WTFMove(*m_type),
            WTFMove(*m_tainting),
            WTFMove(*m_isRedirected),
            WTFMove(*m_usedLegacyTLS),
            WTFMove(*m_wasPrivateRelayed),
            WTFMove(*m_isRangeRequested)
        }
    };
}


void ArgumentCoder<WebCore::ResourceResponseBase>::encode(Encoder& encoder, const WebCore::ResourceResponseBase& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.getResponseData())>, std::optional<WebCore::ResourceResponseBase::ResponseData>>);
    encoder << instance.getResponseData();
}

std::optional<WebCore::ResourceResponseBase> ArgumentCoder<WebCore::ResourceResponseBase>::decode(Decoder& decoder)
{
    auto getResponseData = decoder.decode<std::optional<WebCore::ResourceResponseBase::ResponseData>>();
    if (!getResponseData)
        return std::nullopt;

    return {
        WebCore::ResourceResponseBase {
            WTFMove(*getResponseData)
        }
    };
}


void ArgumentCoder<WebCore::ResourceResponse>::encode(Encoder& encoder, const WebCore::ResourceResponse& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.getResponseData())>, std::optional<WebCore::ResourceResponseBase::ResponseData>>);
    static_assert(MembersInCorrectOrder<0
    >::value);
    encoder << instance.getResponseData();
}

std::optional<WebCore::ResourceResponse> ArgumentCoder<WebCore::ResourceResponse>::decode(Decoder& decoder)
{
    auto getResponseData = decoder.decode<std::optional<WebCore::ResourceResponseBase::ResponseData>>();
    if (!getResponseData)
        return std::nullopt;

    return {
        WebCore::ResourceResponse {
            WebCore::ResourceResponseBase {
                WTFMove(*getResponseData)
            }
        }
    };
}


void ArgumentCoder<WebCore::FetchOptions>::encode(Encoder& encoder, const WebCore::FetchOptions& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.destination)>, WebCore::FetchOptionsDestination>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mode)>, WebCore::FetchOptionsMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.credentials)>, WebCore::FetchOptionsCredentials>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cache)>, WebCore::FetchOptionsCache>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.redirect)>, WebCore::FetchOptionsRedirect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.referrerPolicy)>, WebCore::ReferrerPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keepAlive)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.integrity)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientIdentifier)>, Markable<UUID>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.resultingClientIdentifier)>, Markable<UUID>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FetchOptions, destination)
        , offsetof(WebCore::FetchOptions, mode)
        , offsetof(WebCore::FetchOptions, credentials)
        , offsetof(WebCore::FetchOptions, cache)
        , offsetof(WebCore::FetchOptions, redirect)
        , offsetof(WebCore::FetchOptions, referrerPolicy)
        , offsetof(WebCore::FetchOptions, keepAlive)
        , offsetof(WebCore::FetchOptions, integrity)
        , offsetof(WebCore::FetchOptions, clientIdentifier)
        , offsetof(WebCore::FetchOptions, resultingClientIdentifier)
    >::value);
    encoder << instance.destination;
    encoder << instance.mode;
    encoder << instance.credentials;
    encoder << instance.cache;
    encoder << instance.redirect;
    encoder << instance.referrerPolicy;
    encoder << instance.keepAlive;
    encoder << instance.integrity;
    encoder << instance.clientIdentifier;
    encoder << instance.resultingClientIdentifier;
}

std::optional<WebCore::FetchOptions> ArgumentCoder<WebCore::FetchOptions>::decode(Decoder& decoder)
{
    auto destination = decoder.decode<WebCore::FetchOptionsDestination>();
    if (!destination)
        return std::nullopt;

    auto mode = decoder.decode<WebCore::FetchOptionsMode>();
    if (!mode)
        return std::nullopt;

    auto credentials = decoder.decode<WebCore::FetchOptionsCredentials>();
    if (!credentials)
        return std::nullopt;

    auto cache = decoder.decode<WebCore::FetchOptionsCache>();
    if (!cache)
        return std::nullopt;

    auto redirect = decoder.decode<WebCore::FetchOptionsRedirect>();
    if (!redirect)
        return std::nullopt;

    auto referrerPolicy = decoder.decode<WebCore::ReferrerPolicy>();
    if (!referrerPolicy)
        return std::nullopt;

    auto keepAlive = decoder.decode<bool>();
    if (!keepAlive)
        return std::nullopt;

    auto integrity = decoder.decode<String>();
    if (!integrity)
        return std::nullopt;

    auto clientIdentifier = decoder.decode<Markable<UUID>>();
    if (!clientIdentifier)
        return std::nullopt;

    auto resultingClientIdentifier = decoder.decode<Markable<UUID>>();
    if (!resultingClientIdentifier)
        return std::nullopt;

    return {
        WebCore::FetchOptions {
            WTFMove(*destination),
            WTFMove(*mode),
            WTFMove(*credentials),
            WTFMove(*cache),
            WTFMove(*redirect),
            WTFMove(*referrerPolicy),
            WTFMove(*keepAlive),
            WTFMove(*integrity),
            WTFMove(*clientIdentifier),
            WTFMove(*resultingClientIdentifier)
        }
    };
}


void ArgumentCoder<WebCore::ControlStyle>::encode(Encoder& encoder, const WebCore::ControlStyle& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.states)>, OptionSet<WebCore::ControlStyle::State>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fontSize)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.zoomFactor)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.accentColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.borderWidth)>, WebCore::FloatBoxExtent>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ControlStyle, states)
        , offsetof(WebCore::ControlStyle, fontSize)
        , offsetof(WebCore::ControlStyle, zoomFactor)
        , offsetof(WebCore::ControlStyle, accentColor)
        , offsetof(WebCore::ControlStyle, textColor)
        , offsetof(WebCore::ControlStyle, borderWidth)
    >::value);
    encoder << instance.states;
    encoder << instance.fontSize;
    encoder << instance.zoomFactor;
    encoder << instance.accentColor;
    encoder << instance.textColor;
    encoder << instance.borderWidth;
}

void ArgumentCoder<WebCore::ControlStyle>::encode(StreamConnectionEncoder& encoder, const WebCore::ControlStyle& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.states)>, OptionSet<WebCore::ControlStyle::State>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fontSize)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.zoomFactor)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.accentColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.borderWidth)>, WebCore::FloatBoxExtent>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ControlStyle, states)
        , offsetof(WebCore::ControlStyle, fontSize)
        , offsetof(WebCore::ControlStyle, zoomFactor)
        , offsetof(WebCore::ControlStyle, accentColor)
        , offsetof(WebCore::ControlStyle, textColor)
        , offsetof(WebCore::ControlStyle, borderWidth)
    >::value);
    encoder << instance.states;
    encoder << instance.fontSize;
    encoder << instance.zoomFactor;
    encoder << instance.accentColor;
    encoder << instance.textColor;
    encoder << instance.borderWidth;
}

std::optional<WebCore::ControlStyle> ArgumentCoder<WebCore::ControlStyle>::decode(Decoder& decoder)
{
    auto states = decoder.decode<OptionSet<WebCore::ControlStyle::State>>();
    if (!states)
        return std::nullopt;

    auto fontSize = decoder.decode<unsigned>();
    if (!fontSize)
        return std::nullopt;

    auto zoomFactor = decoder.decode<float>();
    if (!zoomFactor)
        return std::nullopt;

    auto accentColor = decoder.decode<WebCore::Color>();
    if (!accentColor)
        return std::nullopt;

    auto textColor = decoder.decode<WebCore::Color>();
    if (!textColor)
        return std::nullopt;

    auto borderWidth = decoder.decode<WebCore::FloatBoxExtent>();
    if (!borderWidth)
        return std::nullopt;

    return {
        WebCore::ControlStyle {
            WTFMove(*states),
            WTFMove(*fontSize),
            WTFMove(*zoomFactor),
            WTFMove(*accentColor),
            WTFMove(*textColor),
            WTFMove(*borderWidth)
        }
    };
}

#if ENABLE(APPLE_PAY)

void ArgumentCoder<WebCore::ApplePayButtonPart>::encode(Encoder& encoder, const WebCore::ApplePayButtonPart& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buttonType())>, WebCore::ApplePayButtonType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buttonStyle())>, WebCore::ApplePayButtonStyle>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.locale())>, String>);
    encoder << instance.buttonType();
    encoder << instance.buttonStyle();
    encoder << instance.locale();
}

void ArgumentCoder<WebCore::ApplePayButtonPart>::encode(StreamConnectionEncoder& encoder, const WebCore::ApplePayButtonPart& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buttonType())>, WebCore::ApplePayButtonType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buttonStyle())>, WebCore::ApplePayButtonStyle>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.locale())>, String>);
    encoder << instance.buttonType();
    encoder << instance.buttonStyle();
    encoder << instance.locale();
}

std::optional<Ref<WebCore::ApplePayButtonPart>> ArgumentCoder<WebCore::ApplePayButtonPart>::decode(Decoder& decoder)
{
    auto buttonType = decoder.decode<WebCore::ApplePayButtonType>();
    if (!buttonType)
        return std::nullopt;

    auto buttonStyle = decoder.decode<WebCore::ApplePayButtonStyle>();
    if (!buttonStyle)
        return std::nullopt;

    auto locale = decoder.decode<String>();
    if (!locale)
        return std::nullopt;

    return {
        WebCore::ApplePayButtonPart::create(
            WTFMove(*buttonType),
            WTFMove(*buttonStyle),
            WTFMove(*locale)
        )
    };
}

#endif


void ArgumentCoder<WebCore::MeterPart>::encode(Encoder& encoder, const WebCore::MeterPart& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gaugeRegion())>, WebCore::MeterPart::GaugeRegion>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minimum())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maximum())>, double>);
    encoder << instance.gaugeRegion();
    encoder << instance.value();
    encoder << instance.minimum();
    encoder << instance.maximum();
}

void ArgumentCoder<WebCore::MeterPart>::encode(StreamConnectionEncoder& encoder, const WebCore::MeterPart& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gaugeRegion())>, WebCore::MeterPart::GaugeRegion>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minimum())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maximum())>, double>);
    encoder << instance.gaugeRegion();
    encoder << instance.value();
    encoder << instance.minimum();
    encoder << instance.maximum();
}

std::optional<Ref<WebCore::MeterPart>> ArgumentCoder<WebCore::MeterPart>::decode(Decoder& decoder)
{
    auto gaugeRegion = decoder.decode<WebCore::MeterPart::GaugeRegion>();
    if (!gaugeRegion)
        return std::nullopt;

    auto value = decoder.decode<double>();
    if (!value)
        return std::nullopt;

    auto minimum = decoder.decode<double>();
    if (!minimum)
        return std::nullopt;

    auto maximum = decoder.decode<double>();
    if (!maximum)
        return std::nullopt;

    return {
        WebCore::MeterPart::create(
            WTFMove(*gaugeRegion),
            WTFMove(*value),
            WTFMove(*minimum),
            WTFMove(*maximum)
        )
    };
}


void ArgumentCoder<WebCore::ProgressBarPart>::encode(Encoder& encoder, const WebCore::ProgressBarPart& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.animationStartTime())>, Seconds>);
    encoder << instance.position();
    encoder << instance.animationStartTime();
}

void ArgumentCoder<WebCore::ProgressBarPart>::encode(StreamConnectionEncoder& encoder, const WebCore::ProgressBarPart& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.animationStartTime())>, Seconds>);
    encoder << instance.position();
    encoder << instance.animationStartTime();
}

std::optional<Ref<WebCore::ProgressBarPart>> ArgumentCoder<WebCore::ProgressBarPart>::decode(Decoder& decoder)
{
    auto position = decoder.decode<double>();
    if (!position)
        return std::nullopt;

    auto animationStartTime = decoder.decode<Seconds>();
    if (!animationStartTime)
        return std::nullopt;

    return {
        WebCore::ProgressBarPart::create(
            WTFMove(*position),
            WTFMove(*animationStartTime)
        )
    };
}


void ArgumentCoder<WebCore::SliderTrackPart>::encode(Encoder& encoder, const WebCore::SliderTrackPart& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::StyleAppearance>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.thumbSize())>, WebCore::IntSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.trackBounds())>, WebCore::IntRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tickRatios())>, Vector<double>>);
    encoder << instance.type();
    encoder << instance.thumbSize();
    encoder << instance.trackBounds();
    encoder << instance.tickRatios();
}

void ArgumentCoder<WebCore::SliderTrackPart>::encode(StreamConnectionEncoder& encoder, const WebCore::SliderTrackPart& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::StyleAppearance>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.thumbSize())>, WebCore::IntSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.trackBounds())>, WebCore::IntRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tickRatios())>, Vector<double>>);
    encoder << instance.type();
    encoder << instance.thumbSize();
    encoder << instance.trackBounds();
    encoder << instance.tickRatios();
}

std::optional<Ref<WebCore::SliderTrackPart>> ArgumentCoder<WebCore::SliderTrackPart>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::StyleAppearance>();
    if (!type)
        return std::nullopt;

    auto thumbSize = decoder.decode<WebCore::IntSize>();
    if (!thumbSize)
        return std::nullopt;

    auto trackBounds = decoder.decode<WebCore::IntRect>();
    if (!trackBounds)
        return std::nullopt;

    auto tickRatios = decoder.decode<Vector<double>>();
    if (!tickRatios)
        return std::nullopt;

    return {
        WebCore::SliderTrackPart::create(
            WTFMove(*type),
            WTFMove(*thumbSize),
            WTFMove(*trackBounds),
            WTFMove(*tickRatios)
        )
    };
}


void ArgumentCoder<WebCore::DistantLightSource>::encode(Encoder& encoder, const WebCore::DistantLightSource& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.azimuth())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.elevation())>, float>);
    encoder << instance.azimuth();
    encoder << instance.elevation();
}

void ArgumentCoder<WebCore::DistantLightSource>::encode(StreamConnectionEncoder& encoder, const WebCore::DistantLightSource& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.azimuth())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.elevation())>, float>);
    encoder << instance.azimuth();
    encoder << instance.elevation();
}

std::optional<Ref<WebCore::DistantLightSource>> ArgumentCoder<WebCore::DistantLightSource>::decode(Decoder& decoder)
{
    auto azimuth = decoder.decode<float>();
    if (!azimuth)
        return std::nullopt;

    auto elevation = decoder.decode<float>();
    if (!elevation)
        return std::nullopt;

    return {
        WebCore::DistantLightSource::create(
            WTFMove(*azimuth),
            WTFMove(*elevation)
        )
    };
}


void ArgumentCoder<WebCore::PointLightSource>::encode(Encoder& encoder, const WebCore::PointLightSource& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, WebCore::FloatPoint3D>);
    encoder << instance.position();
}

void ArgumentCoder<WebCore::PointLightSource>::encode(StreamConnectionEncoder& encoder, const WebCore::PointLightSource& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, WebCore::FloatPoint3D>);
    encoder << instance.position();
}

std::optional<Ref<WebCore::PointLightSource>> ArgumentCoder<WebCore::PointLightSource>::decode(Decoder& decoder)
{
    auto position = decoder.decode<WebCore::FloatPoint3D>();
    if (!position)
        return std::nullopt;

    return {
        WebCore::PointLightSource::create(
            WTFMove(*position)
        )
    };
}


void ArgumentCoder<WebCore::SpotLightSource>::encode(Encoder& encoder, const WebCore::SpotLightSource& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, WebCore::FloatPoint3D>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.direction())>, WebCore::FloatPoint3D>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.specularExponent())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.limitingConeAngle())>, float>);
    encoder << instance.position();
    encoder << instance.direction();
    encoder << instance.specularExponent();
    encoder << instance.limitingConeAngle();
}

void ArgumentCoder<WebCore::SpotLightSource>::encode(StreamConnectionEncoder& encoder, const WebCore::SpotLightSource& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, WebCore::FloatPoint3D>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.direction())>, WebCore::FloatPoint3D>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.specularExponent())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.limitingConeAngle())>, float>);
    encoder << instance.position();
    encoder << instance.direction();
    encoder << instance.specularExponent();
    encoder << instance.limitingConeAngle();
}

std::optional<Ref<WebCore::SpotLightSource>> ArgumentCoder<WebCore::SpotLightSource>::decode(Decoder& decoder)
{
    auto position = decoder.decode<WebCore::FloatPoint3D>();
    if (!position)
        return std::nullopt;

    auto direction = decoder.decode<WebCore::FloatPoint3D>();
    if (!direction)
        return std::nullopt;

    auto specularExponent = decoder.decode<float>();
    if (!specularExponent)
        return std::nullopt;

    auto limitingConeAngle = decoder.decode<float>();
    if (!limitingConeAngle)
        return std::nullopt;

    return {
        WebCore::SpotLightSource::create(
            WTFMove(*position),
            WTFMove(*direction),
            WTFMove(*specularExponent),
            WTFMove(*limitingConeAngle)
        )
    };
}


void ArgumentCoder<WebCore::FEBlend>::encode(Encoder& encoder, const WebCore::FEBlend& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blendMode())>, WebCore::BlendMode>);
    encoder << instance.blendMode();
}

void ArgumentCoder<WebCore::FEBlend>::encode(StreamConnectionEncoder& encoder, const WebCore::FEBlend& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blendMode())>, WebCore::BlendMode>);
    encoder << instance.blendMode();
}

std::optional<Ref<WebCore::FEBlend>> ArgumentCoder<WebCore::FEBlend>::decode(Decoder& decoder)
{
    auto blendMode = decoder.decode<WebCore::BlendMode>();
    if (!blendMode)
        return std::nullopt;

    return {
        WebCore::FEBlend::create(
            WTFMove(*blendMode)
        )
    };
}


void ArgumentCoder<WebCore::FEColorMatrix>::encode(Encoder& encoder, const WebCore::FEColorMatrix& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::ColorMatrixType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.values())>, Vector<float>>);
    encoder << instance.type();
    encoder << instance.values();
}

void ArgumentCoder<WebCore::FEColorMatrix>::encode(StreamConnectionEncoder& encoder, const WebCore::FEColorMatrix& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::ColorMatrixType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.values())>, Vector<float>>);
    encoder << instance.type();
    encoder << instance.values();
}

std::optional<Ref<WebCore::FEColorMatrix>> ArgumentCoder<WebCore::FEColorMatrix>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::ColorMatrixType>();
    if (!type)
        return std::nullopt;

    auto values = decoder.decode<Vector<float>>();
    if (!values)
        return std::nullopt;

    return {
        WebCore::FEColorMatrix::create(
            WTFMove(*type),
            WTFMove(*values)
        )
    };
}


void ArgumentCoder<WebCore::ComponentTransferFunction>::encode(Encoder& encoder, const WebCore::ComponentTransferFunction& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ComponentTransferType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.slope)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.intercept)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.amplitude)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.exponent)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tableValues)>, Vector<float>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ComponentTransferFunction, type)
        , offsetof(WebCore::ComponentTransferFunction, slope)
        , offsetof(WebCore::ComponentTransferFunction, intercept)
        , offsetof(WebCore::ComponentTransferFunction, amplitude)
        , offsetof(WebCore::ComponentTransferFunction, exponent)
        , offsetof(WebCore::ComponentTransferFunction, offset)
        , offsetof(WebCore::ComponentTransferFunction, tableValues)
    >::value);
    encoder << instance.type;
    encoder << instance.slope;
    encoder << instance.intercept;
    encoder << instance.amplitude;
    encoder << instance.exponent;
    encoder << instance.offset;
    encoder << instance.tableValues;
}

void ArgumentCoder<WebCore::ComponentTransferFunction>::encode(StreamConnectionEncoder& encoder, const WebCore::ComponentTransferFunction& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ComponentTransferType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.slope)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.intercept)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.amplitude)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.exponent)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tableValues)>, Vector<float>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ComponentTransferFunction, type)
        , offsetof(WebCore::ComponentTransferFunction, slope)
        , offsetof(WebCore::ComponentTransferFunction, intercept)
        , offsetof(WebCore::ComponentTransferFunction, amplitude)
        , offsetof(WebCore::ComponentTransferFunction, exponent)
        , offsetof(WebCore::ComponentTransferFunction, offset)
        , offsetof(WebCore::ComponentTransferFunction, tableValues)
    >::value);
    encoder << instance.type;
    encoder << instance.slope;
    encoder << instance.intercept;
    encoder << instance.amplitude;
    encoder << instance.exponent;
    encoder << instance.offset;
    encoder << instance.tableValues;
}

std::optional<WebCore::ComponentTransferFunction> ArgumentCoder<WebCore::ComponentTransferFunction>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::ComponentTransferType>();
    if (!type)
        return std::nullopt;

    auto slope = decoder.decode<float>();
    if (!slope)
        return std::nullopt;

    auto intercept = decoder.decode<float>();
    if (!intercept)
        return std::nullopt;

    auto amplitude = decoder.decode<float>();
    if (!amplitude)
        return std::nullopt;

    auto exponent = decoder.decode<float>();
    if (!exponent)
        return std::nullopt;

    auto offset = decoder.decode<float>();
    if (!offset)
        return std::nullopt;

    auto tableValues = decoder.decode<Vector<float>>();
    if (!tableValues)
        return std::nullopt;

    return {
        WebCore::ComponentTransferFunction {
            WTFMove(*type),
            WTFMove(*slope),
            WTFMove(*intercept),
            WTFMove(*amplitude),
            WTFMove(*exponent),
            WTFMove(*offset),
            WTFMove(*tableValues)
        }
    };
}


void ArgumentCoder<WebCore::FEComponentTransfer>::encode(Encoder& encoder, const WebCore::FEComponentTransfer& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.redFunction())>, WebCore::ComponentTransferFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.greenFunction())>, WebCore::ComponentTransferFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blueFunction())>, WebCore::ComponentTransferFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alphaFunction())>, WebCore::ComponentTransferFunction>);
    encoder << instance.redFunction();
    encoder << instance.greenFunction();
    encoder << instance.blueFunction();
    encoder << instance.alphaFunction();
}

void ArgumentCoder<WebCore::FEComponentTransfer>::encode(StreamConnectionEncoder& encoder, const WebCore::FEComponentTransfer& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.redFunction())>, WebCore::ComponentTransferFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.greenFunction())>, WebCore::ComponentTransferFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blueFunction())>, WebCore::ComponentTransferFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alphaFunction())>, WebCore::ComponentTransferFunction>);
    encoder << instance.redFunction();
    encoder << instance.greenFunction();
    encoder << instance.blueFunction();
    encoder << instance.alphaFunction();
}

std::optional<Ref<WebCore::FEComponentTransfer>> ArgumentCoder<WebCore::FEComponentTransfer>::decode(Decoder& decoder)
{
    auto redFunction = decoder.decode<WebCore::ComponentTransferFunction>();
    if (!redFunction)
        return std::nullopt;

    auto greenFunction = decoder.decode<WebCore::ComponentTransferFunction>();
    if (!greenFunction)
        return std::nullopt;

    auto blueFunction = decoder.decode<WebCore::ComponentTransferFunction>();
    if (!blueFunction)
        return std::nullopt;

    auto alphaFunction = decoder.decode<WebCore::ComponentTransferFunction>();
    if (!alphaFunction)
        return std::nullopt;

    return {
        WebCore::FEComponentTransfer::create(
            WTFMove(*redFunction),
            WTFMove(*greenFunction),
            WTFMove(*blueFunction),
            WTFMove(*alphaFunction)
        )
    };
}


void ArgumentCoder<WebCore::FEComposite>::encode(Encoder& encoder, const WebCore::FEComposite& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.operation())>, WebCore::CompositeOperationType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.k1())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.k2())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.k3())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.k4())>, float>);
    encoder << instance.operation();
    encoder << instance.k1();
    encoder << instance.k2();
    encoder << instance.k3();
    encoder << instance.k4();
}

void ArgumentCoder<WebCore::FEComposite>::encode(StreamConnectionEncoder& encoder, const WebCore::FEComposite& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.operation())>, WebCore::CompositeOperationType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.k1())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.k2())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.k3())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.k4())>, float>);
    encoder << instance.operation();
    encoder << instance.k1();
    encoder << instance.k2();
    encoder << instance.k3();
    encoder << instance.k4();
}

std::optional<Ref<WebCore::FEComposite>> ArgumentCoder<WebCore::FEComposite>::decode(Decoder& decoder)
{
    auto operation = decoder.decode<WebCore::CompositeOperationType>();
    if (!operation)
        return std::nullopt;

    auto k1 = decoder.decode<float>();
    if (!k1)
        return std::nullopt;

    auto k2 = decoder.decode<float>();
    if (!k2)
        return std::nullopt;

    auto k3 = decoder.decode<float>();
    if (!k3)
        return std::nullopt;

    auto k4 = decoder.decode<float>();
    if (!k4)
        return std::nullopt;

    return {
        WebCore::FEComposite::create(
            WTFMove(*operation),
            WTFMove(*k1),
            WTFMove(*k2),
            WTFMove(*k3),
            WTFMove(*k4)
        )
    };
}


void ArgumentCoder<WebCore::FEConvolveMatrix>::encode(Encoder& encoder, const WebCore::FEConvolveMatrix& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelSize())>, WebCore::IntSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.divisor())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bias())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.targetOffset())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.edgeMode())>, WebCore::EdgeModeType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLength())>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preserveAlpha())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernel())>, Vector<float>>);
    encoder << instance.kernelSize();
    encoder << instance.divisor();
    encoder << instance.bias();
    encoder << instance.targetOffset();
    encoder << instance.edgeMode();
    encoder << instance.kernelUnitLength();
    encoder << instance.preserveAlpha();
    encoder << instance.kernel();
}

void ArgumentCoder<WebCore::FEConvolveMatrix>::encode(StreamConnectionEncoder& encoder, const WebCore::FEConvolveMatrix& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelSize())>, WebCore::IntSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.divisor())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bias())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.targetOffset())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.edgeMode())>, WebCore::EdgeModeType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLength())>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preserveAlpha())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernel())>, Vector<float>>);
    encoder << instance.kernelSize();
    encoder << instance.divisor();
    encoder << instance.bias();
    encoder << instance.targetOffset();
    encoder << instance.edgeMode();
    encoder << instance.kernelUnitLength();
    encoder << instance.preserveAlpha();
    encoder << instance.kernel();
}

std::optional<Ref<WebCore::FEConvolveMatrix>> ArgumentCoder<WebCore::FEConvolveMatrix>::decode(Decoder& decoder)
{
    auto kernelSize = decoder.decode<WebCore::IntSize>();
    if (!kernelSize)
        return std::nullopt;

    auto divisor = decoder.decode<float>();
    if (!divisor)
        return std::nullopt;

    auto bias = decoder.decode<float>();
    if (!bias)
        return std::nullopt;

    auto targetOffset = decoder.decode<WebCore::IntPoint>();
    if (!targetOffset)
        return std::nullopt;

    auto edgeMode = decoder.decode<WebCore::EdgeModeType>();
    if (!edgeMode)
        return std::nullopt;

    auto kernelUnitLength = decoder.decode<WebCore::FloatPoint>();
    if (!kernelUnitLength)
        return std::nullopt;

    auto preserveAlpha = decoder.decode<bool>();
    if (!preserveAlpha)
        return std::nullopt;

    auto kernel = decoder.decode<Vector<float>>();
    if (!kernel)
        return std::nullopt;

    return {
        WebCore::FEConvolveMatrix::create(
            WTFMove(*kernelSize),
            WTFMove(*divisor),
            WTFMove(*bias),
            WTFMove(*targetOffset),
            WTFMove(*edgeMode),
            WTFMove(*kernelUnitLength),
            WTFMove(*preserveAlpha),
            WTFMove(*kernel)
        )
    };
}


void ArgumentCoder<WebCore::FEDiffuseLighting>::encode(Encoder& encoder, const WebCore::FEDiffuseLighting& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lightingColor())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.surfaceScale())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.diffuseConstant())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLengthX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLengthY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lightSource())>, Ref<WebCore::LightSource>>);
    encoder << instance.lightingColor();
    encoder << instance.surfaceScale();
    encoder << instance.diffuseConstant();
    encoder << instance.kernelUnitLengthX();
    encoder << instance.kernelUnitLengthY();
    encoder << instance.lightSource();
}

void ArgumentCoder<WebCore::FEDiffuseLighting>::encode(StreamConnectionEncoder& encoder, const WebCore::FEDiffuseLighting& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lightingColor())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.surfaceScale())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.diffuseConstant())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLengthX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLengthY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lightSource())>, Ref<WebCore::LightSource>>);
    encoder << instance.lightingColor();
    encoder << instance.surfaceScale();
    encoder << instance.diffuseConstant();
    encoder << instance.kernelUnitLengthX();
    encoder << instance.kernelUnitLengthY();
    encoder << instance.lightSource();
}

std::optional<Ref<WebCore::FEDiffuseLighting>> ArgumentCoder<WebCore::FEDiffuseLighting>::decode(Decoder& decoder)
{
    auto lightingColor = decoder.decode<WebCore::Color>();
    if (!lightingColor)
        return std::nullopt;

    auto surfaceScale = decoder.decode<float>();
    if (!surfaceScale)
        return std::nullopt;

    auto diffuseConstant = decoder.decode<float>();
    if (!diffuseConstant)
        return std::nullopt;

    auto kernelUnitLengthX = decoder.decode<float>();
    if (!kernelUnitLengthX)
        return std::nullopt;

    auto kernelUnitLengthY = decoder.decode<float>();
    if (!kernelUnitLengthY)
        return std::nullopt;

    auto lightSource = decoder.decode<Ref<WebCore::LightSource>>();
    if (!lightSource)
        return std::nullopt;

    return {
        WebCore::FEDiffuseLighting::create(
            WTFMove(*lightingColor),
            WTFMove(*surfaceScale),
            WTFMove(*diffuseConstant),
            WTFMove(*kernelUnitLengthX),
            WTFMove(*kernelUnitLengthY),
            WTFMove(*lightSource)
        )
    };
}


void ArgumentCoder<WebCore::FEDisplacementMap>::encode(Encoder& encoder, const WebCore::FEDisplacementMap& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.xChannelSelector())>, WebCore::ChannelSelectorType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.yChannelSelector())>, WebCore::ChannelSelectorType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scale())>, float>);
    encoder << instance.xChannelSelector();
    encoder << instance.yChannelSelector();
    encoder << instance.scale();
}

void ArgumentCoder<WebCore::FEDisplacementMap>::encode(StreamConnectionEncoder& encoder, const WebCore::FEDisplacementMap& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.xChannelSelector())>, WebCore::ChannelSelectorType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.yChannelSelector())>, WebCore::ChannelSelectorType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scale())>, float>);
    encoder << instance.xChannelSelector();
    encoder << instance.yChannelSelector();
    encoder << instance.scale();
}

std::optional<Ref<WebCore::FEDisplacementMap>> ArgumentCoder<WebCore::FEDisplacementMap>::decode(Decoder& decoder)
{
    auto xChannelSelector = decoder.decode<WebCore::ChannelSelectorType>();
    if (!xChannelSelector)
        return std::nullopt;

    auto yChannelSelector = decoder.decode<WebCore::ChannelSelectorType>();
    if (!yChannelSelector)
        return std::nullopt;

    auto scale = decoder.decode<float>();
    if (!scale)
        return std::nullopt;

    return {
        WebCore::FEDisplacementMap::create(
            WTFMove(*xChannelSelector),
            WTFMove(*yChannelSelector),
            WTFMove(*scale)
        )
    };
}


void ArgumentCoder<WebCore::FEDropShadow>::encode(Encoder& encoder, const WebCore::FEDropShadow& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stdDeviationX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stdDeviationY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dx())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dy())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shadowColor())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shadowOpacity())>, float>);
    encoder << instance.stdDeviationX();
    encoder << instance.stdDeviationY();
    encoder << instance.dx();
    encoder << instance.dy();
    encoder << instance.shadowColor();
    encoder << instance.shadowOpacity();
}

void ArgumentCoder<WebCore::FEDropShadow>::encode(StreamConnectionEncoder& encoder, const WebCore::FEDropShadow& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stdDeviationX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stdDeviationY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dx())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dy())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shadowColor())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shadowOpacity())>, float>);
    encoder << instance.stdDeviationX();
    encoder << instance.stdDeviationY();
    encoder << instance.dx();
    encoder << instance.dy();
    encoder << instance.shadowColor();
    encoder << instance.shadowOpacity();
}

std::optional<Ref<WebCore::FEDropShadow>> ArgumentCoder<WebCore::FEDropShadow>::decode(Decoder& decoder)
{
    auto stdDeviationX = decoder.decode<float>();
    if (!stdDeviationX)
        return std::nullopt;

    auto stdDeviationY = decoder.decode<float>();
    if (!stdDeviationY)
        return std::nullopt;

    auto dx = decoder.decode<float>();
    if (!dx)
        return std::nullopt;

    auto dy = decoder.decode<float>();
    if (!dy)
        return std::nullopt;

    auto shadowColor = decoder.decode<WebCore::Color>();
    if (!shadowColor)
        return std::nullopt;

    auto shadowOpacity = decoder.decode<float>();
    if (!shadowOpacity)
        return std::nullopt;

    return {
        WebCore::FEDropShadow::create(
            WTFMove(*stdDeviationX),
            WTFMove(*stdDeviationY),
            WTFMove(*dx),
            WTFMove(*dy),
            WTFMove(*shadowColor),
            WTFMove(*shadowOpacity)
        )
    };
}


void ArgumentCoder<WebCore::FEFlood>::encode(Encoder& encoder, const WebCore::FEFlood& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.floodColor())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.floodOpacity())>, float>);
    encoder << instance.floodColor();
    encoder << instance.floodOpacity();
}

void ArgumentCoder<WebCore::FEFlood>::encode(StreamConnectionEncoder& encoder, const WebCore::FEFlood& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.floodColor())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.floodOpacity())>, float>);
    encoder << instance.floodColor();
    encoder << instance.floodOpacity();
}

std::optional<Ref<WebCore::FEFlood>> ArgumentCoder<WebCore::FEFlood>::decode(Decoder& decoder)
{
    auto floodColor = decoder.decode<WebCore::Color>();
    if (!floodColor)
        return std::nullopt;

    auto floodOpacity = decoder.decode<float>();
    if (!floodOpacity)
        return std::nullopt;

    return {
        WebCore::FEFlood::create(
            WTFMove(*floodColor),
            WTFMove(*floodOpacity)
        )
    };
}


void ArgumentCoder<WebCore::FEGaussianBlur>::encode(Encoder& encoder, const WebCore::FEGaussianBlur& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stdDeviationX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stdDeviationY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.edgeMode())>, WebCore::EdgeModeType>);
    encoder << instance.stdDeviationX();
    encoder << instance.stdDeviationY();
    encoder << instance.edgeMode();
}

void ArgumentCoder<WebCore::FEGaussianBlur>::encode(StreamConnectionEncoder& encoder, const WebCore::FEGaussianBlur& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stdDeviationX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stdDeviationY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.edgeMode())>, WebCore::EdgeModeType>);
    encoder << instance.stdDeviationX();
    encoder << instance.stdDeviationY();
    encoder << instance.edgeMode();
}

std::optional<Ref<WebCore::FEGaussianBlur>> ArgumentCoder<WebCore::FEGaussianBlur>::decode(Decoder& decoder)
{
    auto stdDeviationX = decoder.decode<float>();
    if (!stdDeviationX)
        return std::nullopt;

    auto stdDeviationY = decoder.decode<float>();
    if (!stdDeviationY)
        return std::nullopt;

    auto edgeMode = decoder.decode<WebCore::EdgeModeType>();
    if (!edgeMode)
        return std::nullopt;

    return {
        WebCore::FEGaussianBlur::create(
            WTFMove(*stdDeviationX),
            WTFMove(*stdDeviationY),
            WTFMove(*edgeMode)
        )
    };
}


void ArgumentCoder<WebCore::FEImage>::encode(Encoder& encoder, const WebCore::FEImage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceImage())>, WebCore::SourceImage>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceImageRect())>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preserveAspectRatio())>, WebCore::SVGPreserveAspectRatioValue>);
    encoder << instance.sourceImage();
    encoder << instance.sourceImageRect();
    encoder << instance.preserveAspectRatio();
}

void ArgumentCoder<WebCore::FEImage>::encode(StreamConnectionEncoder& encoder, const WebCore::FEImage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceImage())>, WebCore::SourceImage>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceImageRect())>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preserveAspectRatio())>, WebCore::SVGPreserveAspectRatioValue>);
    encoder << instance.sourceImage();
    encoder << instance.sourceImageRect();
    encoder << instance.preserveAspectRatio();
}

std::optional<Ref<WebCore::FEImage>> ArgumentCoder<WebCore::FEImage>::decode(Decoder& decoder)
{
    auto sourceImage = decoder.decode<WebCore::SourceImage>();
    if (!sourceImage)
        return std::nullopt;

    auto sourceImageRect = decoder.decode<WebCore::FloatRect>();
    if (!sourceImageRect)
        return std::nullopt;

    auto preserveAspectRatio = decoder.decode<WebCore::SVGPreserveAspectRatioValue>();
    if (!preserveAspectRatio)
        return std::nullopt;

    return {
        WebCore::FEImage::create(
            WTFMove(*sourceImage),
            WTFMove(*sourceImageRect),
            WTFMove(*preserveAspectRatio)
        )
    };
}


void ArgumentCoder<WebCore::FEMerge>::encode(Encoder& encoder, const WebCore::FEMerge& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.numberOfEffectInputs())>, unsigned>);
    encoder << instance.numberOfEffectInputs();
}

void ArgumentCoder<WebCore::FEMerge>::encode(StreamConnectionEncoder& encoder, const WebCore::FEMerge& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.numberOfEffectInputs())>, unsigned>);
    encoder << instance.numberOfEffectInputs();
}

std::optional<Ref<WebCore::FEMerge>> ArgumentCoder<WebCore::FEMerge>::decode(Decoder& decoder)
{
    auto numberOfEffectInputs = decoder.decode<unsigned>();
    if (!numberOfEffectInputs)
        return std::nullopt;

    return {
        WebCore::FEMerge::create(
            WTFMove(*numberOfEffectInputs)
        )
    };
}


void ArgumentCoder<WebCore::FEMorphology>::encode(Encoder& encoder, const WebCore::FEMorphology& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.morphologyOperator())>, WebCore::MorphologyOperatorType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radiusX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radiusY())>, float>);
    encoder << instance.morphologyOperator();
    encoder << instance.radiusX();
    encoder << instance.radiusY();
}

void ArgumentCoder<WebCore::FEMorphology>::encode(StreamConnectionEncoder& encoder, const WebCore::FEMorphology& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.morphologyOperator())>, WebCore::MorphologyOperatorType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radiusX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radiusY())>, float>);
    encoder << instance.morphologyOperator();
    encoder << instance.radiusX();
    encoder << instance.radiusY();
}

std::optional<Ref<WebCore::FEMorphology>> ArgumentCoder<WebCore::FEMorphology>::decode(Decoder& decoder)
{
    auto morphologyOperator = decoder.decode<WebCore::MorphologyOperatorType>();
    if (!morphologyOperator)
        return std::nullopt;

    auto radiusX = decoder.decode<float>();
    if (!radiusX)
        return std::nullopt;

    auto radiusY = decoder.decode<float>();
    if (!radiusY)
        return std::nullopt;

    return {
        WebCore::FEMorphology::create(
            WTFMove(*morphologyOperator),
            WTFMove(*radiusX),
            WTFMove(*radiusY)
        )
    };
}


void ArgumentCoder<WebCore::FEOffset>::encode(Encoder& encoder, const WebCore::FEOffset& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dx())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dy())>, float>);
    encoder << instance.dx();
    encoder << instance.dy();
}

void ArgumentCoder<WebCore::FEOffset>::encode(StreamConnectionEncoder& encoder, const WebCore::FEOffset& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dx())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dy())>, float>);
    encoder << instance.dx();
    encoder << instance.dy();
}

std::optional<Ref<WebCore::FEOffset>> ArgumentCoder<WebCore::FEOffset>::decode(Decoder& decoder)
{
    auto dx = decoder.decode<float>();
    if (!dx)
        return std::nullopt;

    auto dy = decoder.decode<float>();
    if (!dy)
        return std::nullopt;

    return {
        WebCore::FEOffset::create(
            WTFMove(*dx),
            WTFMove(*dy)
        )
    };
}


void ArgumentCoder<WebCore::FESpecularLighting>::encode(Encoder& encoder, const WebCore::FESpecularLighting& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lightingColor())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.surfaceScale())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.specularConstant())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.specularExponent())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLengthX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLengthY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lightSource())>, Ref<WebCore::LightSource>>);
    encoder << instance.lightingColor();
    encoder << instance.surfaceScale();
    encoder << instance.specularConstant();
    encoder << instance.specularExponent();
    encoder << instance.kernelUnitLengthX();
    encoder << instance.kernelUnitLengthY();
    encoder << instance.lightSource();
}

void ArgumentCoder<WebCore::FESpecularLighting>::encode(StreamConnectionEncoder& encoder, const WebCore::FESpecularLighting& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lightingColor())>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.surfaceScale())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.specularConstant())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.specularExponent())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLengthX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.kernelUnitLengthY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lightSource())>, Ref<WebCore::LightSource>>);
    encoder << instance.lightingColor();
    encoder << instance.surfaceScale();
    encoder << instance.specularConstant();
    encoder << instance.specularExponent();
    encoder << instance.kernelUnitLengthX();
    encoder << instance.kernelUnitLengthY();
    encoder << instance.lightSource();
}

std::optional<Ref<WebCore::FESpecularLighting>> ArgumentCoder<WebCore::FESpecularLighting>::decode(Decoder& decoder)
{
    auto lightingColor = decoder.decode<WebCore::Color>();
    if (!lightingColor)
        return std::nullopt;

    auto surfaceScale = decoder.decode<float>();
    if (!surfaceScale)
        return std::nullopt;

    auto specularConstant = decoder.decode<float>();
    if (!specularConstant)
        return std::nullopt;

    auto specularExponent = decoder.decode<float>();
    if (!specularExponent)
        return std::nullopt;

    auto kernelUnitLengthX = decoder.decode<float>();
    if (!kernelUnitLengthX)
        return std::nullopt;

    auto kernelUnitLengthY = decoder.decode<float>();
    if (!kernelUnitLengthY)
        return std::nullopt;

    auto lightSource = decoder.decode<Ref<WebCore::LightSource>>();
    if (!lightSource)
        return std::nullopt;

    return {
        WebCore::FESpecularLighting::create(
            WTFMove(*lightingColor),
            WTFMove(*surfaceScale),
            WTFMove(*specularConstant),
            WTFMove(*specularExponent),
            WTFMove(*kernelUnitLengthX),
            WTFMove(*kernelUnitLengthY),
            WTFMove(*lightSource)
        )
    };
}


void ArgumentCoder<WebCore::FETurbulence>::encode(Encoder& encoder, const WebCore::FETurbulence& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::TurbulenceType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.baseFrequencyX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.baseFrequencyY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.numOctaves())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.seed())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stitchTiles())>, bool>);
    encoder << instance.type();
    encoder << instance.baseFrequencyX();
    encoder << instance.baseFrequencyY();
    encoder << instance.numOctaves();
    encoder << instance.seed();
    encoder << instance.stitchTiles();
}

void ArgumentCoder<WebCore::FETurbulence>::encode(StreamConnectionEncoder& encoder, const WebCore::FETurbulence& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebCore::TurbulenceType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.baseFrequencyX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.baseFrequencyY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.numOctaves())>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.seed())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stitchTiles())>, bool>);
    encoder << instance.type();
    encoder << instance.baseFrequencyX();
    encoder << instance.baseFrequencyY();
    encoder << instance.numOctaves();
    encoder << instance.seed();
    encoder << instance.stitchTiles();
}

std::optional<Ref<WebCore::FETurbulence>> ArgumentCoder<WebCore::FETurbulence>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::TurbulenceType>();
    if (!type)
        return std::nullopt;

    auto baseFrequencyX = decoder.decode<float>();
    if (!baseFrequencyX)
        return std::nullopt;

    auto baseFrequencyY = decoder.decode<float>();
    if (!baseFrequencyY)
        return std::nullopt;

    auto numOctaves = decoder.decode<int>();
    if (!numOctaves)
        return std::nullopt;

    auto seed = decoder.decode<float>();
    if (!seed)
        return std::nullopt;

    auto stitchTiles = decoder.decode<bool>();
    if (!stitchTiles)
        return std::nullopt;

    return {
        WebCore::FETurbulence::create(
            WTFMove(*type),
            WTFMove(*baseFrequencyX),
            WTFMove(*baseFrequencyY),
            WTFMove(*numOctaves),
            WTFMove(*seed),
            WTFMove(*stitchTiles)
        )
    };
}

#if ENABLE(GAMEPAD)

void ArgumentCoder<WebCore::GamepadEffectParameters>::encode(Encoder& encoder, const WebCore::GamepadEffectParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.duration)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startDelay)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.strongMagnitude)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.weakMagnitude)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.leftTrigger)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rightTrigger)>, double>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GamepadEffectParameters, duration)
        , offsetof(WebCore::GamepadEffectParameters, startDelay)
        , offsetof(WebCore::GamepadEffectParameters, strongMagnitude)
        , offsetof(WebCore::GamepadEffectParameters, weakMagnitude)
        , offsetof(WebCore::GamepadEffectParameters, leftTrigger)
        , offsetof(WebCore::GamepadEffectParameters, rightTrigger)
    >::value);
    encoder << instance.duration;
    encoder << instance.startDelay;
    encoder << instance.strongMagnitude;
    encoder << instance.weakMagnitude;
    encoder << instance.leftTrigger;
    encoder << instance.rightTrigger;
}

std::optional<WebCore::GamepadEffectParameters> ArgumentCoder<WebCore::GamepadEffectParameters>::decode(Decoder& decoder)
{
    auto duration = decoder.decode<double>();
    if (!duration)
        return std::nullopt;

    auto startDelay = decoder.decode<double>();
    if (!startDelay)
        return std::nullopt;

    auto strongMagnitude = decoder.decode<double>();
    if (!strongMagnitude)
        return std::nullopt;

    auto weakMagnitude = decoder.decode<double>();
    if (!weakMagnitude)
        return std::nullopt;

    auto leftTrigger = decoder.decode<double>();
    if (!leftTrigger)
        return std::nullopt;

    auto rightTrigger = decoder.decode<double>();
    if (!rightTrigger)
        return std::nullopt;

    return {
        WebCore::GamepadEffectParameters {
            WTFMove(*duration),
            WTFMove(*startDelay),
            WTFMove(*strongMagnitude),
            WTFMove(*weakMagnitude),
            WTFMove(*leftTrigger),
            WTFMove(*rightTrigger)
        }
    };
}

#endif


void ArgumentCoder<WebCore::StorageEstimate>::encode(Encoder& encoder, const WebCore::StorageEstimate& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.usage)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.quota)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::StorageEstimate, usage)
        , offsetof(WebCore::StorageEstimate, quota)
    >::value);
    encoder << instance.usage;
    encoder << instance.quota;
}

std::optional<WebCore::StorageEstimate> ArgumentCoder<WebCore::StorageEstimate>::decode(Decoder& decoder)
{
    auto usage = decoder.decode<uint64_t>();
    if (!usage)
        return std::nullopt;

    auto quota = decoder.decode<uint64_t>();
    if (!quota)
        return std::nullopt;

    return {
        WebCore::StorageEstimate {
            WTFMove(*usage),
            WTFMove(*quota)
        }
    };
}


void ArgumentCoder<WebCore::TextList>::encode(Encoder& encoder, const WebCore::TextList& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.style)>, WebCore::ListStyleType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startingItemNumber)>, int>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ordered)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextList, style)
        , offsetof(WebCore::TextList, startingItemNumber)
        , offsetof(WebCore::TextList, ordered)
    >::value);
    encoder << instance.style;
    encoder << instance.startingItemNumber;
    encoder << instance.ordered;
}

std::optional<WebCore::TextList> ArgumentCoder<WebCore::TextList>::decode(Decoder& decoder)
{
    auto style = decoder.decode<WebCore::ListStyleType>();
    if (!style)
        return std::nullopt;

    auto startingItemNumber = decoder.decode<int>();
    if (!startingItemNumber)
        return std::nullopt;

    auto ordered = decoder.decode<bool>();
    if (!ordered)
        return std::nullopt;

    return {
        WebCore::TextList {
            WTFMove(*style),
            WTFMove(*startingItemNumber),
            WTFMove(*ordered)
        }
    };
}


void ArgumentCoder<WebCore::FontAttributes>::encode(Encoder& encoder, const WebCore::FontAttributes& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.font)>, RefPtr<WebCore::Font>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.backgroundColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.foregroundColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fontShadow)>, WebCore::FontShadow>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.subscriptOrSuperscript)>, WebCore::FontAttributes::SubscriptOrSuperscript>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.horizontalAlignment)>, WebCore::FontAttributes::HorizontalAlignment>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textLists)>, Vector<WebCore::TextList>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasUnderline)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasStrikeThrough)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasMultipleFonts)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FontAttributes, font)
        , offsetof(WebCore::FontAttributes, backgroundColor)
        , offsetof(WebCore::FontAttributes, foregroundColor)
        , offsetof(WebCore::FontAttributes, fontShadow)
        , offsetof(WebCore::FontAttributes, subscriptOrSuperscript)
        , offsetof(WebCore::FontAttributes, horizontalAlignment)
        , offsetof(WebCore::FontAttributes, textLists)
        , offsetof(WebCore::FontAttributes, hasUnderline)
        , offsetof(WebCore::FontAttributes, hasStrikeThrough)
        , offsetof(WebCore::FontAttributes, hasMultipleFonts)
    >::value);
    encoder << instance.font;
    encoder << instance.backgroundColor;
    encoder << instance.foregroundColor;
    encoder << instance.fontShadow;
    encoder << instance.subscriptOrSuperscript;
    encoder << instance.horizontalAlignment;
    encoder << instance.textLists;
    encoder << instance.hasUnderline;
    encoder << instance.hasStrikeThrough;
    encoder << instance.hasMultipleFonts;
}

std::optional<WebCore::FontAttributes> ArgumentCoder<WebCore::FontAttributes>::decode(Decoder& decoder)
{
    auto font = decoder.decode<RefPtr<WebCore::Font>>();
    if (!font)
        return std::nullopt;

    auto backgroundColor = decoder.decode<WebCore::Color>();
    if (!backgroundColor)
        return std::nullopt;

    auto foregroundColor = decoder.decode<WebCore::Color>();
    if (!foregroundColor)
        return std::nullopt;

    auto fontShadow = decoder.decode<WebCore::FontShadow>();
    if (!fontShadow)
        return std::nullopt;

    auto subscriptOrSuperscript = decoder.decode<WebCore::FontAttributes::SubscriptOrSuperscript>();
    if (!subscriptOrSuperscript)
        return std::nullopt;

    auto horizontalAlignment = decoder.decode<WebCore::FontAttributes::HorizontalAlignment>();
    if (!horizontalAlignment)
        return std::nullopt;

    auto textLists = decoder.decode<Vector<WebCore::TextList>>();
    if (!textLists)
        return std::nullopt;

    auto hasUnderline = decoder.decode<bool>();
    if (!hasUnderline)
        return std::nullopt;

    auto hasStrikeThrough = decoder.decode<bool>();
    if (!hasStrikeThrough)
        return std::nullopt;

    auto hasMultipleFonts = decoder.decode<bool>();
    if (!hasMultipleFonts)
        return std::nullopt;

    return {
        WebCore::FontAttributes {
            WTFMove(*font),
            WTFMove(*backgroundColor),
            WTFMove(*foregroundColor),
            WTFMove(*fontShadow),
            WTFMove(*subscriptOrSuperscript),
            WTFMove(*horizontalAlignment),
            WTFMove(*textLists),
            WTFMove(*hasUnderline),
            WTFMove(*hasStrikeThrough),
            WTFMove(*hasMultipleFonts)
        }
    };
}


void ArgumentCoder<WebCore::CrossOriginEmbedderPolicy>::encode(Encoder& encoder, const WebCore::CrossOriginEmbedderPolicy& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, WebCore::CrossOriginEmbedderPolicyValue>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.reportOnlyValue)>, WebCore::CrossOriginEmbedderPolicyValue>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.reportingEndpoint)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.reportOnlyReportingEndpoint)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CrossOriginEmbedderPolicy, value)
        , offsetof(WebCore::CrossOriginEmbedderPolicy, reportOnlyValue)
        , offsetof(WebCore::CrossOriginEmbedderPolicy, reportingEndpoint)
        , offsetof(WebCore::CrossOriginEmbedderPolicy, reportOnlyReportingEndpoint)
    >::value);
    encoder << instance.value;
    encoder << instance.reportOnlyValue;
    encoder << instance.reportingEndpoint;
    encoder << instance.reportOnlyReportingEndpoint;
}

std::optional<WebCore::CrossOriginEmbedderPolicy> ArgumentCoder<WebCore::CrossOriginEmbedderPolicy>::decode(Decoder& decoder)
{
    auto value = decoder.decode<WebCore::CrossOriginEmbedderPolicyValue>();
    if (!value)
        return std::nullopt;

    auto reportOnlyValue = decoder.decode<WebCore::CrossOriginEmbedderPolicyValue>();
    if (!reportOnlyValue)
        return std::nullopt;

    auto reportingEndpoint = decoder.decode<String>();
    if (!reportingEndpoint)
        return std::nullopt;

    auto reportOnlyReportingEndpoint = decoder.decode<String>();
    if (!reportOnlyReportingEndpoint)
        return std::nullopt;

    return {
        WebCore::CrossOriginEmbedderPolicy {
            WTFMove(*value),
            WTFMove(*reportOnlyValue),
            WTFMove(*reportingEndpoint),
            WTFMove(*reportOnlyReportingEndpoint)
        }
    };
}


void ArgumentCoder<WebCore::SameSiteInfo>::encode(Encoder& encoder, const WebCore::SameSiteInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isSameSite)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isTopSite)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isSafeHTTPMethod)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SameSiteInfo, isSameSite)
        , offsetof(WebCore::SameSiteInfo, isTopSite)
        , offsetof(WebCore::SameSiteInfo, isSafeHTTPMethod)
    >::value);
    encoder << instance.isSameSite;
    encoder << instance.isTopSite;
    encoder << instance.isSafeHTTPMethod;
}

std::optional<WebCore::SameSiteInfo> ArgumentCoder<WebCore::SameSiteInfo>::decode(Decoder& decoder)
{
    auto isSameSite = decoder.decode<bool>();
    if (!isSameSite)
        return std::nullopt;

    auto isTopSite = decoder.decode<bool>();
    if (!isTopSite)
        return std::nullopt;

    auto isSafeHTTPMethod = decoder.decode<bool>();
    if (!isSafeHTTPMethod)
        return std::nullopt;

    return {
        WebCore::SameSiteInfo {
            WTFMove(*isSameSite),
            WTFMove(*isTopSite),
            WTFMove(*isSafeHTTPMethod)
        }
    };
}


void ArgumentCoder<WebCore::SecurityOrigin>::encode(Encoder& encoder, const WebCore::SecurityOrigin& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_data)>, WebCore::SecurityOriginData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_domain)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_filePath)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_universalAccess)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_domainWasSetInDOM)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_canLoadLocalResources)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_enforcesFilePathSeparation)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_needsStorageAccessFromFileURLsQuirk)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isPotentiallyTrustworthy)>, std::optional<bool>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isLocal)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SecurityOrigin, m_data)
        , offsetof(WebCore::SecurityOrigin, m_domain)
        , offsetof(WebCore::SecurityOrigin, m_filePath)
        , offsetof(WebCore::SecurityOrigin, m_universalAccess)
        , offsetof(WebCore::SecurityOrigin, m_domainWasSetInDOM)
        , offsetof(WebCore::SecurityOrigin, m_canLoadLocalResources)
        , offsetof(WebCore::SecurityOrigin, m_enforcesFilePathSeparation)
        , offsetof(WebCore::SecurityOrigin, m_needsStorageAccessFromFileURLsQuirk)
        , offsetof(WebCore::SecurityOrigin, m_isPotentiallyTrustworthy)
        , offsetof(WebCore::SecurityOrigin, m_isLocal)
    >::value);
    encoder << instance.m_data;
    encoder << instance.m_domain;
    encoder << instance.m_filePath;
    encoder << instance.m_universalAccess;
    encoder << instance.m_domainWasSetInDOM;
    encoder << instance.m_canLoadLocalResources;
    encoder << instance.m_enforcesFilePathSeparation;
    encoder << instance.m_needsStorageAccessFromFileURLsQuirk;
    encoder << instance.m_isPotentiallyTrustworthy;
    encoder << instance.m_isLocal;
}

std::optional<Ref<WebCore::SecurityOrigin>> ArgumentCoder<WebCore::SecurityOrigin>::decode(Decoder& decoder)
{
    auto m_data = decoder.decode<WebCore::SecurityOriginData>();
    if (!m_data)
        return std::nullopt;

    auto m_domain = decoder.decode<String>();
    if (!m_domain)
        return std::nullopt;

    auto m_filePath = decoder.decode<String>();
    if (!m_filePath)
        return std::nullopt;

    auto m_universalAccess = decoder.decode<bool>();
    if (!m_universalAccess)
        return std::nullopt;

    auto m_domainWasSetInDOM = decoder.decode<bool>();
    if (!m_domainWasSetInDOM)
        return std::nullopt;

    auto m_canLoadLocalResources = decoder.decode<bool>();
    if (!m_canLoadLocalResources)
        return std::nullopt;

    auto m_enforcesFilePathSeparation = decoder.decode<bool>();
    if (!m_enforcesFilePathSeparation)
        return std::nullopt;

    auto m_needsStorageAccessFromFileURLsQuirk = decoder.decode<bool>();
    if (!m_needsStorageAccessFromFileURLsQuirk)
        return std::nullopt;

    auto m_isPotentiallyTrustworthy = decoder.decode<std::optional<bool>>();
    if (!m_isPotentiallyTrustworthy)
        return std::nullopt;

    auto m_isLocal = decoder.decode<bool>();
    if (!m_isLocal)
        return std::nullopt;

    return {
        WebCore::SecurityOrigin::create(
            WTFMove(*m_data),
            WTFMove(*m_domain),
            WTFMove(*m_filePath),
            WTFMove(*m_universalAccess),
            WTFMove(*m_domainWasSetInDOM),
            WTFMove(*m_canLoadLocalResources),
            WTFMove(*m_enforcesFilePathSeparation),
            WTFMove(*m_needsStorageAccessFromFileURLsQuirk),
            WTFMove(*m_isPotentiallyTrustworthy),
            WTFMove(*m_isLocal)
        )
    };
}


void ArgumentCoder<WebCore::CookieRequestHeaderFieldProxy>::encode(Encoder& encoder, const WebCore::CookieRequestHeaderFieldProxy& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.firstParty)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sameSiteInfo)>, WebCore::SameSiteInfo>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameID)>, std::optional<WebCore::FrameIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageID)>, std::optional<WebCore::PageIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.includeSecureCookies)>, WebCore::IncludeSecureCookies>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CookieRequestHeaderFieldProxy, firstParty)
        , offsetof(WebCore::CookieRequestHeaderFieldProxy, sameSiteInfo)
        , offsetof(WebCore::CookieRequestHeaderFieldProxy, url)
        , offsetof(WebCore::CookieRequestHeaderFieldProxy, frameID)
        , offsetof(WebCore::CookieRequestHeaderFieldProxy, pageID)
        , offsetof(WebCore::CookieRequestHeaderFieldProxy, includeSecureCookies)
    >::value);
    encoder << instance.firstParty;
    encoder << instance.sameSiteInfo;
    encoder << instance.url;
    encoder << instance.frameID;
    encoder << instance.pageID;
    encoder << instance.includeSecureCookies;
}

std::optional<WebCore::CookieRequestHeaderFieldProxy> ArgumentCoder<WebCore::CookieRequestHeaderFieldProxy>::decode(Decoder& decoder)
{
    auto firstParty = decoder.decode<URL>();
    if (!firstParty)
        return std::nullopt;

    auto sameSiteInfo = decoder.decode<WebCore::SameSiteInfo>();
    if (!sameSiteInfo)
        return std::nullopt;

    auto url = decoder.decode<URL>();
    if (!url)
        return std::nullopt;

    auto frameID = decoder.decode<std::optional<WebCore::FrameIdentifier>>();
    if (!frameID)
        return std::nullopt;

    auto pageID = decoder.decode<std::optional<WebCore::PageIdentifier>>();
    if (!pageID)
        return std::nullopt;

    auto includeSecureCookies = decoder.decode<WebCore::IncludeSecureCookies>();
    if (!includeSecureCookies)
        return std::nullopt;

    return {
        WebCore::CookieRequestHeaderFieldProxy {
            WTFMove(*firstParty),
            WTFMove(*sameSiteInfo),
            WTFMove(*url),
            WTFMove(*frameID),
            WTFMove(*pageID),
            WTFMove(*includeSecureCookies)
        }
    };
}


void ArgumentCoder<WebCore::FormData>::encode(Encoder& encoder, const WebCore::FormData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_alwaysStream)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_boundary)>, Vector<char>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_elements)>, Vector<WebCore::FormDataElement>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_identifier)>, int64_t>);
    encoder << instance.m_alwaysStream;
    encoder << instance.m_boundary;
    encoder << instance.m_elements;
    encoder << instance.m_identifier;
}

std::optional<Ref<WebCore::FormData>> ArgumentCoder<WebCore::FormData>::decode(Decoder& decoder)
{
    auto m_alwaysStream = decoder.decode<bool>();
    if (!m_alwaysStream)
        return std::nullopt;

    auto m_boundary = decoder.decode<Vector<char>>();
    if (!m_boundary)
        return std::nullopt;

    auto m_elements = decoder.decode<Vector<WebCore::FormDataElement>>();
    if (!m_elements)
        return std::nullopt;

    auto m_identifier = decoder.decode<int64_t>();
    if (!m_identifier)
        return std::nullopt;

    return {
        WebCore::FormData::create(
            WTFMove(*m_alwaysStream),
            WTFMove(*m_boundary),
            WTFMove(*m_elements),
            WTFMove(*m_identifier)
        )
    };
}


void ArgumentCoder<WebCore::RequestedScrollData>::encode(Encoder& encoder, const WebCore::RequestedScrollData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.requestType)>, WebCore::ScrollRequestType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scrollPosition)>, WebCore::FloatPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scrollType)>, WebCore::ScrollType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clamping)>, WebCore::ScrollClamping>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.animated)>, WebCore::ScrollIsAnimated>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::RequestedScrollData, requestType)
        , offsetof(WebCore::RequestedScrollData, scrollPosition)
        , offsetof(WebCore::RequestedScrollData, scrollType)
        , offsetof(WebCore::RequestedScrollData, clamping)
        , offsetof(WebCore::RequestedScrollData, animated)
    >::value);
    encoder << instance.requestType;
    encoder << instance.scrollPosition;
    encoder << instance.scrollType;
    encoder << instance.clamping;
    encoder << instance.animated;
}

std::optional<WebCore::RequestedScrollData> ArgumentCoder<WebCore::RequestedScrollData>::decode(Decoder& decoder)
{
    auto requestType = decoder.decode<WebCore::ScrollRequestType>();
    if (!requestType)
        return std::nullopt;

    auto scrollPosition = decoder.decode<WebCore::FloatPoint>();
    if (!scrollPosition)
        return std::nullopt;

    auto scrollType = decoder.decode<WebCore::ScrollType>();
    if (!scrollType)
        return std::nullopt;

    auto clamping = decoder.decode<WebCore::ScrollClamping>();
    if (!clamping)
        return std::nullopt;

    auto animated = decoder.decode<WebCore::ScrollIsAnimated>();
    if (!animated)
        return std::nullopt;

    return {
        WebCore::RequestedScrollData {
            WTFMove(*requestType),
            WTFMove(*scrollPosition),
            WTFMove(*scrollType),
            WTFMove(*clamping),
            WTFMove(*animated)
        }
    };
}


void ArgumentCoder<WebCore::FloatScrollSnapOffsetsInfo>::encode(Encoder& encoder, const WebCore::FloatScrollSnapOffsetsInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.strictness)>, WebCore::ScrollSnapStrictness>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.horizontalSnapOffsets)>, Vector<WebCore::FloatSnapOffset>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.verticalSnapOffsets)>, Vector<WebCore::FloatSnapOffset>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.snapAreas)>, Vector<WebCore::FloatRect>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.snapAreasIDs)>, Vector<WebCore::ElementIdentifier>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FloatScrollSnapOffsetsInfo, strictness)
        , offsetof(WebCore::FloatScrollSnapOffsetsInfo, horizontalSnapOffsets)
        , offsetof(WebCore::FloatScrollSnapOffsetsInfo, verticalSnapOffsets)
        , offsetof(WebCore::FloatScrollSnapOffsetsInfo, snapAreas)
        , offsetof(WebCore::FloatScrollSnapOffsetsInfo, snapAreasIDs)
    >::value);
    encoder << instance.strictness;
    encoder << instance.horizontalSnapOffsets;
    encoder << instance.verticalSnapOffsets;
    encoder << instance.snapAreas;
    encoder << instance.snapAreasIDs;
}

std::optional<WebCore::FloatScrollSnapOffsetsInfo> ArgumentCoder<WebCore::FloatScrollSnapOffsetsInfo>::decode(Decoder& decoder)
{
    auto strictness = decoder.decode<WebCore::ScrollSnapStrictness>();
    if (!strictness)
        return std::nullopt;

    auto horizontalSnapOffsets = decoder.decode<Vector<WebCore::FloatSnapOffset>>();
    if (!horizontalSnapOffsets)
        return std::nullopt;

    auto verticalSnapOffsets = decoder.decode<Vector<WebCore::FloatSnapOffset>>();
    if (!verticalSnapOffsets)
        return std::nullopt;

    auto snapAreas = decoder.decode<Vector<WebCore::FloatRect>>();
    if (!snapAreas)
        return std::nullopt;

    auto snapAreasIDs = decoder.decode<Vector<WebCore::ElementIdentifier>>();
    if (!snapAreasIDs)
        return std::nullopt;

    return {
        WebCore::FloatScrollSnapOffsetsInfo {
            WTFMove(*strictness),
            WTFMove(*horizontalSnapOffsets),
            WTFMove(*verticalSnapOffsets),
            WTFMove(*snapAreas),
            WTFMove(*snapAreasIDs)
        }
    };
}


void ArgumentCoder<WebCore::FloatSnapOffset>::encode(Encoder& encoder, const WebCore::FloatSnapOffset& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stop)>, WebCore::ScrollSnapStop>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasSnapAreaLargerThanViewport)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.snapTargetID)>, WebCore::ElementIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isFocused)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.snapAreaIndices)>, Vector<size_t>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FloatSnapOffset, offset)
        , offsetof(WebCore::FloatSnapOffset, stop)
        , offsetof(WebCore::FloatSnapOffset, hasSnapAreaLargerThanViewport)
        , offsetof(WebCore::FloatSnapOffset, snapTargetID)
        , offsetof(WebCore::FloatSnapOffset, isFocused)
        , offsetof(WebCore::FloatSnapOffset, snapAreaIndices)
    >::value);
    encoder << instance.offset;
    encoder << instance.stop;
    encoder << instance.hasSnapAreaLargerThanViewport;
    encoder << instance.snapTargetID;
    encoder << instance.isFocused;
    encoder << instance.snapAreaIndices;
}

std::optional<WebCore::FloatSnapOffset> ArgumentCoder<WebCore::FloatSnapOffset>::decode(Decoder& decoder)
{
    auto offset = decoder.decode<float>();
    if (!offset)
        return std::nullopt;

    auto stop = decoder.decode<WebCore::ScrollSnapStop>();
    if (!stop)
        return std::nullopt;

    auto hasSnapAreaLargerThanViewport = decoder.decode<bool>();
    if (!hasSnapAreaLargerThanViewport)
        return std::nullopt;

    auto snapTargetID = decoder.decode<WebCore::ElementIdentifier>();
    if (!snapTargetID)
        return std::nullopt;

    auto isFocused = decoder.decode<bool>();
    if (!isFocused)
        return std::nullopt;

    auto snapAreaIndices = decoder.decode<Vector<size_t>>();
    if (!snapAreaIndices)
        return std::nullopt;

    return {
        WebCore::FloatSnapOffset {
            WTFMove(*offset),
            WTFMove(*stop),
            WTFMove(*hasSnapAreaLargerThanViewport),
            WTFMove(*snapTargetID),
            WTFMove(*isFocused),
            WTFMove(*snapAreaIndices)
        }
    };
}

#if ENABLE(ENCRYPTED_MEDIA)

void ArgumentCoder<WebCore::CDMMediaCapability>::encode(Encoder& encoder, const WebCore::CDMMediaCapability& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentType)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.robustness)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.encryptionScheme)>, std::optional<WebCore::CDMEncryptionScheme>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CDMMediaCapability, contentType)
        , offsetof(WebCore::CDMMediaCapability, robustness)
        , offsetof(WebCore::CDMMediaCapability, encryptionScheme)
    >::value);
    encoder << instance.contentType;
    encoder << instance.robustness;
    encoder << instance.encryptionScheme;
}

std::optional<WebCore::CDMMediaCapability> ArgumentCoder<WebCore::CDMMediaCapability>::decode(Decoder& decoder)
{
    auto contentType = decoder.decode<String>();
    if (!contentType)
        return std::nullopt;

    auto robustness = decoder.decode<String>();
    if (!robustness)
        return std::nullopt;

    auto encryptionScheme = decoder.decode<std::optional<WebCore::CDMEncryptionScheme>>();
    if (!encryptionScheme)
        return std::nullopt;

    return {
        WebCore::CDMMediaCapability {
            WTFMove(*contentType),
            WTFMove(*robustness),
            WTFMove(*encryptionScheme)
        }
    };
}

#endif


void ArgumentCoder<WebCore::MediaSelectionOption>::encode(Encoder& encoder, const WebCore::MediaSelectionOption& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mediaType)>, WebCore::MediaSelectionOption::MediaType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.displayName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.legibleType)>, WebCore::MediaSelectionOption::LegibleType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaSelectionOption, mediaType)
        , offsetof(WebCore::MediaSelectionOption, displayName)
        , offsetof(WebCore::MediaSelectionOption, legibleType)
    >::value);
    encoder << instance.mediaType;
    encoder << instance.displayName;
    encoder << instance.legibleType;
}

std::optional<WebCore::MediaSelectionOption> ArgumentCoder<WebCore::MediaSelectionOption>::decode(Decoder& decoder)
{
    auto mediaType = decoder.decode<WebCore::MediaSelectionOption::MediaType>();
    if (!mediaType)
        return std::nullopt;

    auto displayName = decoder.decode<String>();
    if (!displayName)
        return std::nullopt;

    auto legibleType = decoder.decode<WebCore::MediaSelectionOption::LegibleType>();
    if (!legibleType)
        return std::nullopt;

    return {
        WebCore::MediaSelectionOption {
            WTFMove(*mediaType),
            WTFMove(*displayName),
            WTFMove(*legibleType)
        }
    };
}


void ArgumentCoder<WebCore::BufferSource>::encode(Encoder& encoder, const WebCore::BufferSource& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.span())>, Span<const uint8_t>>);
    encoder << instance.span();
}

std::optional<WebCore::BufferSource> ArgumentCoder<WebCore::BufferSource>::decode(Decoder& decoder)
{
    auto span = decoder.decode<Span<const uint8_t>>();
    if (!span)
        return std::nullopt;

    return {
        WebCore::BufferSource {
            WTFMove(*span)
        }
    };
}


void ArgumentCoder<WebCore::FontShadow>::encode(Encoder& encoder, const WebCore::FontShadow& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blurRadius)>, double>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FontShadow, color)
        , offsetof(WebCore::FontShadow, offset)
        , offsetof(WebCore::FontShadow, blurRadius)
    >::value);
    encoder << instance.color;
    encoder << instance.offset;
    encoder << instance.blurRadius;
}

std::optional<WebCore::FontShadow> ArgumentCoder<WebCore::FontShadow>::decode(Decoder& decoder)
{
    auto color = decoder.decode<WebCore::Color>();
    if (!color)
        return std::nullopt;

    auto offset = decoder.decode<WebCore::FloatSize>();
    if (!offset)
        return std::nullopt;

    auto blurRadius = decoder.decode<double>();
    if (!blurRadius)
        return std::nullopt;

    return {
        WebCore::FontShadow {
            WTFMove(*color),
            WTFMove(*offset),
            WTFMove(*blurRadius)
        }
    };
}


void ArgumentCoder<WebCore::CompositionHighlight>::encode(Encoder& encoder, const WebCore::CompositionHighlight& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startOffset)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.endOffset)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color)>, WebCore::Color>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CompositionHighlight, startOffset)
        , offsetof(WebCore::CompositionHighlight, endOffset)
        , offsetof(WebCore::CompositionHighlight, color)
    >::value);
    encoder << instance.startOffset;
    encoder << instance.endOffset;
    encoder << instance.color;
}

std::optional<WebCore::CompositionHighlight> ArgumentCoder<WebCore::CompositionHighlight>::decode(Decoder& decoder)
{
    auto startOffset = decoder.decode<unsigned>();
    if (!startOffset)
        return std::nullopt;

    auto endOffset = decoder.decode<unsigned>();
    if (!endOffset)
        return std::nullopt;

    auto color = decoder.decode<WebCore::Color>();
    if (!color)
        return std::nullopt;

    return {
        WebCore::CompositionHighlight {
            WTFMove(*startOffset),
            WTFMove(*endOffset),
            WTFMove(*color)
        }
    };
}


void ArgumentCoder<WebCore::FontChanges>::encode(Encoder& encoder, const WebCore::FontChanges& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_fontName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_fontFamily)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_fontSize)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_fontSizeDelta)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_bold)>, std::optional<bool>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_italic)>, std::optional<bool>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FontChanges, m_fontName)
        , offsetof(WebCore::FontChanges, m_fontFamily)
        , offsetof(WebCore::FontChanges, m_fontSize)
        , offsetof(WebCore::FontChanges, m_fontSizeDelta)
        , offsetof(WebCore::FontChanges, m_bold)
        , offsetof(WebCore::FontChanges, m_italic)
    >::value);
    encoder << instance.m_fontName;
    encoder << instance.m_fontFamily;
    encoder << instance.m_fontSize;
    encoder << instance.m_fontSizeDelta;
    encoder << instance.m_bold;
    encoder << instance.m_italic;
}

std::optional<WebCore::FontChanges> ArgumentCoder<WebCore::FontChanges>::decode(Decoder& decoder)
{
    auto m_fontName = decoder.decode<String>();
    if (!m_fontName)
        return std::nullopt;

    auto m_fontFamily = decoder.decode<String>();
    if (!m_fontFamily)
        return std::nullopt;

    auto m_fontSize = decoder.decode<std::optional<double>>();
    if (!m_fontSize)
        return std::nullopt;

    auto m_fontSizeDelta = decoder.decode<std::optional<double>>();
    if (!m_fontSizeDelta)
        return std::nullopt;

    if (!(!*m_fontSize || !*m_fontSizeDelta))
        return std::nullopt;

    auto m_bold = decoder.decode<std::optional<bool>>();
    if (!m_bold)
        return std::nullopt;

    auto m_italic = decoder.decode<std::optional<bool>>();
    if (!m_italic)
        return std::nullopt;

    return {
        WebCore::FontChanges {
            WTFMove(*m_fontName),
            WTFMove(*m_fontFamily),
            WTFMove(*m_fontSize),
            WTFMove(*m_fontSizeDelta),
            WTFMove(*m_bold),
            WTFMove(*m_italic)
        }
    };
}


void ArgumentCoder<WebCore::FontAttributeChanges>::encode(Encoder& encoder, const WebCore::FontAttributeChanges& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_verticalAlign)>, std::optional<WebCore::VerticalAlignChange>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_backgroundColor)>, std::optional<WebCore::Color>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_foregroundColor)>, std::optional<WebCore::Color>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_shadow)>, std::optional<WebCore::FontShadow>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_strikeThrough)>, std::optional<bool>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_underline)>, std::optional<bool>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_fontChanges)>, WebCore::FontChanges>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FontAttributeChanges, m_verticalAlign)
        , offsetof(WebCore::FontAttributeChanges, m_backgroundColor)
        , offsetof(WebCore::FontAttributeChanges, m_foregroundColor)
        , offsetof(WebCore::FontAttributeChanges, m_shadow)
        , offsetof(WebCore::FontAttributeChanges, m_strikeThrough)
        , offsetof(WebCore::FontAttributeChanges, m_underline)
        , offsetof(WebCore::FontAttributeChanges, m_fontChanges)
    >::value);
    encoder << instance.m_verticalAlign;
    encoder << instance.m_backgroundColor;
    encoder << instance.m_foregroundColor;
    encoder << instance.m_shadow;
    encoder << instance.m_strikeThrough;
    encoder << instance.m_underline;
    encoder << instance.m_fontChanges;
}

std::optional<WebCore::FontAttributeChanges> ArgumentCoder<WebCore::FontAttributeChanges>::decode(Decoder& decoder)
{
    auto m_verticalAlign = decoder.decode<std::optional<WebCore::VerticalAlignChange>>();
    if (!m_verticalAlign)
        return std::nullopt;

    auto m_backgroundColor = decoder.decode<std::optional<WebCore::Color>>();
    if (!m_backgroundColor)
        return std::nullopt;

    auto m_foregroundColor = decoder.decode<std::optional<WebCore::Color>>();
    if (!m_foregroundColor)
        return std::nullopt;

    auto m_shadow = decoder.decode<std::optional<WebCore::FontShadow>>();
    if (!m_shadow)
        return std::nullopt;

    auto m_strikeThrough = decoder.decode<std::optional<bool>>();
    if (!m_strikeThrough)
        return std::nullopt;

    auto m_underline = decoder.decode<std::optional<bool>>();
    if (!m_underline)
        return std::nullopt;

    auto m_fontChanges = decoder.decode<WebCore::FontChanges>();
    if (!m_fontChanges)
        return std::nullopt;

    return {
        WebCore::FontAttributeChanges {
            WTFMove(*m_verticalAlign),
            WTFMove(*m_backgroundColor),
            WTFMove(*m_foregroundColor),
            WTFMove(*m_shadow),
            WTFMove(*m_strikeThrough),
            WTFMove(*m_underline),
            WTFMove(*m_fontChanges)
        }
    };
}


void ArgumentCoder<WebCore::TextManipulationControllerExclusionRule::ElementRule>::encode(Encoder& encoder, const WebCore::TextManipulationControllerExclusionRule::ElementRule& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.localName)>, AtomString>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextManipulationControllerExclusionRule::ElementRule, localName)
    >::value);
    encoder << instance.localName;
}

std::optional<WebCore::TextManipulationControllerExclusionRule::ElementRule> ArgumentCoder<WebCore::TextManipulationControllerExclusionRule::ElementRule>::decode(Decoder& decoder)
{
    auto localName = decoder.decode<AtomString>();
    if (!localName)
        return std::nullopt;

    return {
        WebCore::TextManipulationControllerExclusionRule::ElementRule {
            WTFMove(*localName)
        }
    };
}


void ArgumentCoder<WebCore::TextManipulationControllerExclusionRule::AttributeRule>::encode(Encoder& encoder, const WebCore::TextManipulationControllerExclusionRule::AttributeRule& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextManipulationControllerExclusionRule::AttributeRule, name)
        , offsetof(WebCore::TextManipulationControllerExclusionRule::AttributeRule, value)
    >::value);
    encoder << instance.name;
    encoder << instance.value;
}

std::optional<WebCore::TextManipulationControllerExclusionRule::AttributeRule> ArgumentCoder<WebCore::TextManipulationControllerExclusionRule::AttributeRule>::decode(Decoder& decoder)
{
    auto name = decoder.decode<AtomString>();
    if (!name)
        return std::nullopt;

    auto value = decoder.decode<String>();
    if (!value)
        return std::nullopt;

    return {
        WebCore::TextManipulationControllerExclusionRule::AttributeRule {
            WTFMove(*name),
            WTFMove(*value)
        }
    };
}


void ArgumentCoder<WebCore::TextManipulationControllerExclusionRule::ClassRule>::encode(Encoder& encoder, const WebCore::TextManipulationControllerExclusionRule::ClassRule& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.className)>, AtomString>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextManipulationControllerExclusionRule::ClassRule, className)
    >::value);
    encoder << instance.className;
}

std::optional<WebCore::TextManipulationControllerExclusionRule::ClassRule> ArgumentCoder<WebCore::TextManipulationControllerExclusionRule::ClassRule>::decode(Decoder& decoder)
{
    auto className = decoder.decode<AtomString>();
    if (!className)
        return std::nullopt;

    return {
        WebCore::TextManipulationControllerExclusionRule::ClassRule {
            WTFMove(*className)
        }
    };
}


void ArgumentCoder<WebCore::TextManipulationControllerExclusionRule>::encode(Encoder& encoder, const WebCore::TextManipulationControllerExclusionRule& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::TextManipulationControllerExclusionRule::Type>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rule)>, std::variant<WebCore::TextManipulationControllerExclusionRule::ElementRule, WebCore::TextManipulationControllerExclusionRule::AttributeRule, WebCore::TextManipulationControllerExclusionRule::ClassRule>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextManipulationControllerExclusionRule, type)
        , offsetof(WebCore::TextManipulationControllerExclusionRule, rule)
    >::value);
    encoder << instance.type;
    encoder << instance.rule;
}

std::optional<WebCore::TextManipulationControllerExclusionRule> ArgumentCoder<WebCore::TextManipulationControllerExclusionRule>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::TextManipulationControllerExclusionRule::Type>();
    if (!type)
        return std::nullopt;

    auto rule = decoder.decode<std::variant<WebCore::TextManipulationControllerExclusionRule::ElementRule, WebCore::TextManipulationControllerExclusionRule::AttributeRule, WebCore::TextManipulationControllerExclusionRule::ClassRule>>();
    if (!rule)
        return std::nullopt;

    return {
        WebCore::TextManipulationControllerExclusionRule {
            WTFMove(*type),
            WTFMove(*rule)
        }
    };
}


void ArgumentCoder<WebCore::TextManipulationControllerManipulationFailure>::encode(Encoder& encoder, const WebCore::TextManipulationControllerManipulationFailure& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::TextManipulationItemIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.index)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::TextManipulationControllerManipulationFailure::Type>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::TextManipulationControllerManipulationFailure, identifier)
        , offsetof(WebCore::TextManipulationControllerManipulationFailure, index)
        , offsetof(WebCore::TextManipulationControllerManipulationFailure, type)
    >::value);
    encoder << instance.identifier;
    encoder << instance.index;
    encoder << instance.type;
}

std::optional<WebCore::TextManipulationControllerManipulationFailure> ArgumentCoder<WebCore::TextManipulationControllerManipulationFailure>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::TextManipulationItemIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto index = decoder.decode<uint64_t>();
    if (!index)
        return std::nullopt;

    auto type = decoder.decode<WebCore::TextManipulationControllerManipulationFailure::Type>();
    if (!type)
        return std::nullopt;

    return {
        WebCore::TextManipulationControllerManipulationFailure {
            WTFMove(*identifier),
            WTFMove(*index),
            WTFMove(*type)
        }
    };
}


void ArgumentCoder<WebCore::FourCC>::encode(Encoder& encoder, const WebCore::FourCC& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, uint32_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::FourCC, value)
    >::value);
    encoder << instance.value;
}

std::optional<WebCore::FourCC> ArgumentCoder<WebCore::FourCC>::decode(Decoder& decoder)
{
    auto value = decoder.decode<uint32_t>();
    if (!value)
        return std::nullopt;

    return {
        WebCore::FourCC {
            WTFMove(*value)
        }
    };
}

#if ENABLE(VIDEO)

void ArgumentCoder<WebCore::MediaEngineSupportParameters>::encode(Encoder& encoder, const WebCore::MediaEngineSupportParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ContentType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMediaSource)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMediaStream)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.requiresRemotePlayback)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentTypesRequiringHardwareSupport)>, Vector<WebCore::ContentType>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaContainerTypes)>, std::optional<Vector<String>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaCodecTypes)>, std::optional<Vector<String>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaVideoCodecIDs)>, std::optional<Vector<WebCore::FourCC>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaAudioCodecIDs)>, std::optional<Vector<WebCore::FourCC>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.allowedMediaCaptionFormatTypes)>, std::optional<Vector<WebCore::FourCC>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaEngineSupportParameters, type)
        , offsetof(WebCore::MediaEngineSupportParameters, url)
        , offsetof(WebCore::MediaEngineSupportParameters, isMediaSource)
        , offsetof(WebCore::MediaEngineSupportParameters, isMediaStream)
        , offsetof(WebCore::MediaEngineSupportParameters, requiresRemotePlayback)
        , offsetof(WebCore::MediaEngineSupportParameters, contentTypesRequiringHardwareSupport)
        , offsetof(WebCore::MediaEngineSupportParameters, allowedMediaContainerTypes)
        , offsetof(WebCore::MediaEngineSupportParameters, allowedMediaCodecTypes)
        , offsetof(WebCore::MediaEngineSupportParameters, allowedMediaVideoCodecIDs)
        , offsetof(WebCore::MediaEngineSupportParameters, allowedMediaAudioCodecIDs)
        , offsetof(WebCore::MediaEngineSupportParameters, allowedMediaCaptionFormatTypes)
    >::value);
    encoder << instance.type;
    encoder << instance.url;
    encoder << instance.isMediaSource;
    encoder << instance.isMediaStream;
    encoder << instance.requiresRemotePlayback;
    encoder << instance.contentTypesRequiringHardwareSupport;
    encoder << instance.allowedMediaContainerTypes;
    encoder << instance.allowedMediaCodecTypes;
    encoder << instance.allowedMediaVideoCodecIDs;
    encoder << instance.allowedMediaAudioCodecIDs;
    encoder << instance.allowedMediaCaptionFormatTypes;
}

std::optional<WebCore::MediaEngineSupportParameters> ArgumentCoder<WebCore::MediaEngineSupportParameters>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebCore::ContentType>();
    if (!type)
        return std::nullopt;

    auto url = decoder.decode<URL>();
    if (!url)
        return std::nullopt;

    auto isMediaSource = decoder.decode<bool>();
    if (!isMediaSource)
        return std::nullopt;

    auto isMediaStream = decoder.decode<bool>();
    if (!isMediaStream)
        return std::nullopt;

    auto requiresRemotePlayback = decoder.decode<bool>();
    if (!requiresRemotePlayback)
        return std::nullopt;

    auto contentTypesRequiringHardwareSupport = decoder.decode<Vector<WebCore::ContentType>>();
    if (!contentTypesRequiringHardwareSupport)
        return std::nullopt;

    auto allowedMediaContainerTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaContainerTypes)
        return std::nullopt;

    auto allowedMediaCodecTypes = decoder.decode<std::optional<Vector<String>>>();
    if (!allowedMediaCodecTypes)
        return std::nullopt;

    auto allowedMediaVideoCodecIDs = decoder.decode<std::optional<Vector<WebCore::FourCC>>>();
    if (!allowedMediaVideoCodecIDs)
        return std::nullopt;

    auto allowedMediaAudioCodecIDs = decoder.decode<std::optional<Vector<WebCore::FourCC>>>();
    if (!allowedMediaAudioCodecIDs)
        return std::nullopt;

    auto allowedMediaCaptionFormatTypes = decoder.decode<std::optional<Vector<WebCore::FourCC>>>();
    if (!allowedMediaCaptionFormatTypes)
        return std::nullopt;

    return {
        WebCore::MediaEngineSupportParameters {
            WTFMove(*type),
            WTFMove(*url),
            WTFMove(*isMediaSource),
            WTFMove(*isMediaStream),
            WTFMove(*requiresRemotePlayback),
            WTFMove(*contentTypesRequiringHardwareSupport),
            WTFMove(*allowedMediaContainerTypes),
            WTFMove(*allowedMediaCodecTypes),
            WTFMove(*allowedMediaVideoCodecIDs),
            WTFMove(*allowedMediaAudioCodecIDs),
            WTFMove(*allowedMediaCaptionFormatTypes)
        }
    };
}

#endif


void ArgumentCoder<WebCore::GeolocationPositionData>::encode(Encoder& encoder, const WebCore::GeolocationPositionData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestamp)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.latitude)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.longitude)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.accuracy)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.altitude)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.altitudeAccuracy)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.heading)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.speed)>, std::optional<double>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.floorLevel)>, std::optional<double>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GeolocationPositionData, timestamp)
        , offsetof(WebCore::GeolocationPositionData, latitude)
        , offsetof(WebCore::GeolocationPositionData, longitude)
        , offsetof(WebCore::GeolocationPositionData, accuracy)
        , offsetof(WebCore::GeolocationPositionData, altitude)
        , offsetof(WebCore::GeolocationPositionData, altitudeAccuracy)
        , offsetof(WebCore::GeolocationPositionData, heading)
        , offsetof(WebCore::GeolocationPositionData, speed)
        , offsetof(WebCore::GeolocationPositionData, floorLevel)
    >::value);
    encoder << instance.timestamp;
    encoder << instance.latitude;
    encoder << instance.longitude;
    encoder << instance.accuracy;
    encoder << instance.altitude;
    encoder << instance.altitudeAccuracy;
    encoder << instance.heading;
    encoder << instance.speed;
    encoder << instance.floorLevel;
}

std::optional<WebCore::GeolocationPositionData> ArgumentCoder<WebCore::GeolocationPositionData>::decode(Decoder& decoder)
{
    auto timestamp = decoder.decode<double>();
    if (!timestamp)
        return std::nullopt;

    auto latitude = decoder.decode<double>();
    if (!latitude)
        return std::nullopt;

    auto longitude = decoder.decode<double>();
    if (!longitude)
        return std::nullopt;

    auto accuracy = decoder.decode<double>();
    if (!accuracy)
        return std::nullopt;

    auto altitude = decoder.decode<std::optional<double>>();
    if (!altitude)
        return std::nullopt;

    auto altitudeAccuracy = decoder.decode<std::optional<double>>();
    if (!altitudeAccuracy)
        return std::nullopt;

    auto heading = decoder.decode<std::optional<double>>();
    if (!heading)
        return std::nullopt;

    auto speed = decoder.decode<std::optional<double>>();
    if (!speed)
        return std::nullopt;

    auto floorLevel = decoder.decode<std::optional<double>>();
    if (!floorLevel)
        return std::nullopt;

    return {
        WebCore::GeolocationPositionData {
            WTFMove(*timestamp),
            WTFMove(*latitude),
            WTFMove(*longitude),
            WTFMove(*accuracy),
            WTFMove(*altitude),
            WTFMove(*altitudeAccuracy),
            WTFMove(*heading),
            WTFMove(*speed),
            WTFMove(*floorLevel)
        }
    };
}

#if ENABLE(APP_HIGHLIGHTS)

void ArgumentCoder<WebCore::AppHighlight>::encode(Encoder& encoder, const WebCore::AppHighlight& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.highlight)>, Ref<WebCore::FragmentedSharedBuffer>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.text)>, std::optional<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isNewGroup)>, WebCore::CreateNewGroupForHighlight>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.requestOriginatedInApp)>, WebCore::HighlightRequestOriginatedInApp>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::AppHighlight, highlight)
        , offsetof(WebCore::AppHighlight, text)
        , offsetof(WebCore::AppHighlight, isNewGroup)
        , offsetof(WebCore::AppHighlight, requestOriginatedInApp)
    >::value);
    encoder << instance.highlight;
    encoder << instance.text;
    encoder << instance.isNewGroup;
    encoder << instance.requestOriginatedInApp;
}

std::optional<WebCore::AppHighlight> ArgumentCoder<WebCore::AppHighlight>::decode(Decoder& decoder)
{
    auto highlight = decoder.decode<Ref<WebCore::FragmentedSharedBuffer>>();
    if (!highlight)
        return std::nullopt;

    auto text = decoder.decode<std::optional<String>>();
    if (!text)
        return std::nullopt;

    auto isNewGroup = decoder.decode<WebCore::CreateNewGroupForHighlight>();
    if (!isNewGroup)
        return std::nullopt;

    auto requestOriginatedInApp = decoder.decode<WebCore::HighlightRequestOriginatedInApp>();
    if (!requestOriginatedInApp)
        return std::nullopt;

    return {
        WebCore::AppHighlight {
            WTFMove(*highlight),
            WTFMove(*text),
            WTFMove(*isNewGroup),
            WTFMove(*requestOriginatedInApp)
        }
    };
}

#endif


void ArgumentCoder<WebCore::MediaDeviceHashSalts>::encode(Encoder& encoder, const WebCore::MediaDeviceHashSalts& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.persistentDeviceSalt)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ephemeralDeviceSalt)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MediaDeviceHashSalts, persistentDeviceSalt)
        , offsetof(WebCore::MediaDeviceHashSalts, ephemeralDeviceSalt)
    >::value);
    encoder << instance.persistentDeviceSalt;
    encoder << instance.ephemeralDeviceSalt;
}

std::optional<WebCore::MediaDeviceHashSalts> ArgumentCoder<WebCore::MediaDeviceHashSalts>::decode(Decoder& decoder)
{
    auto persistentDeviceSalt = decoder.decode<String>();
    if (!persistentDeviceSalt)
        return std::nullopt;

    auto ephemeralDeviceSalt = decoder.decode<String>();
    if (!ephemeralDeviceSalt)
        return std::nullopt;

    return {
        WebCore::MediaDeviceHashSalts {
            WTFMove(*persistentDeviceSalt),
            WTFMove(*ephemeralDeviceSalt)
        }
    };
}


void ArgumentCoder<WebCore::SpeechRecognitionUpdate>::encode(Encoder& encoder, const WebCore::SpeechRecognitionUpdate& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_clientIdentifier)>, WebCore::SpeechRecognitionConnectionClientIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_type)>, WebCore::SpeechRecognitionUpdateType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_content)>, std::variant<std::monostate, WebCore::SpeechRecognitionError, Vector<WebCore::SpeechRecognitionResultData>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SpeechRecognitionUpdate, m_clientIdentifier)
        , offsetof(WebCore::SpeechRecognitionUpdate, m_type)
        , offsetof(WebCore::SpeechRecognitionUpdate, m_content)
    >::value);
    encoder << instance.m_clientIdentifier;
    encoder << instance.m_type;
    encoder << instance.m_content;
}

std::optional<WebCore::SpeechRecognitionUpdate> ArgumentCoder<WebCore::SpeechRecognitionUpdate>::decode(Decoder& decoder)
{
    auto m_clientIdentifier = decoder.decode<WebCore::SpeechRecognitionConnectionClientIdentifier>();
    if (!m_clientIdentifier)
        return std::nullopt;

    auto m_type = decoder.decode<WebCore::SpeechRecognitionUpdateType>();
    if (!m_type)
        return std::nullopt;

    auto m_content = decoder.decode<std::variant<std::monostate, WebCore::SpeechRecognitionError, Vector<WebCore::SpeechRecognitionResultData>>>();
    if (!m_content)
        return std::nullopt;

    return {
        WebCore::SpeechRecognitionUpdate {
            WTFMove(*m_clientIdentifier),
            WTFMove(*m_type),
            WTFMove(*m_content)
        }
    };
}

#if USE(SYSTEM_PREVIEW)

void ArgumentCoder<WebCore::ARKitBadgeSystemImage>::encode(Encoder& encoder, const WebCore::ARKitBadgeSystemImage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.imageIdentifier())>, WebCore::RenderingResourceIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_imageSize)>, WebCore::FloatSize>);
    encoder << instance.imageIdentifier();
    encoder << instance.m_imageSize;
}

void ArgumentCoder<WebCore::ARKitBadgeSystemImage>::encode(StreamConnectionEncoder& encoder, const WebCore::ARKitBadgeSystemImage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.imageIdentifier())>, WebCore::RenderingResourceIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_imageSize)>, WebCore::FloatSize>);
    encoder << instance.imageIdentifier();
    encoder << instance.m_imageSize;
}

std::optional<Ref<WebCore::ARKitBadgeSystemImage>> ArgumentCoder<WebCore::ARKitBadgeSystemImage>::decode(Decoder& decoder)
{
    auto imageIdentifier = decoder.decode<WebCore::RenderingResourceIdentifier>();
    if (!imageIdentifier)
        return std::nullopt;

    auto m_imageSize = decoder.decode<WebCore::FloatSize>();
    if (!m_imageSize)
        return std::nullopt;

    return {
        WebCore::ARKitBadgeSystemImage::create(
            WTFMove(*imageIdentifier),
            WTFMove(*m_imageSize)
        )
    };
}

#endif


void ArgumentCoder<WebCore::AudioIOPosition>::encode(Encoder& encoder, const WebCore::AudioIOPosition& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position)>, Seconds>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestamp)>, MonotonicTime>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::AudioIOPosition, position)
        , offsetof(WebCore::AudioIOPosition, timestamp)
    >::value);
    encoder << instance.position;
    encoder << instance.timestamp;
}

std::optional<WebCore::AudioIOPosition> ArgumentCoder<WebCore::AudioIOPosition>::decode(Decoder& decoder)
{
    auto position = decoder.decode<Seconds>();
    if (!position)
        return std::nullopt;

    auto timestamp = decoder.decode<MonotonicTime>();
    if (!timestamp)
        return std::nullopt;

    return {
        WebCore::AudioIOPosition {
            WTFMove(*position),
            WTFMove(*timestamp)
        }
    };
}

#if ENABLE(VIDEO) && USE(AVFOUNDATION)

void ArgumentCoder<WebCore::VideoFrameCV>::encode(Encoder& encoder, const WebCore::VideoFrameCV& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.presentationTime())>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isMirrored())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rotation())>, WebCore::VideoFrameRotation>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_pixelBuffer)>, RetainPtr<CVPixelBufferRef>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace())>, WebCore::PlatformVideoColorSpace>);
    encoder << instance.presentationTime();
    encoder << instance.isMirrored();
    encoder << instance.rotation();
    encoder << instance.m_pixelBuffer;
    encoder << instance.colorSpace();
}

std::optional<Ref<WebCore::VideoFrameCV>> ArgumentCoder<WebCore::VideoFrameCV>::decode(Decoder& decoder)
{
    auto presentationTime = decoder.decode<MediaTime>();
    if (!presentationTime)
        return std::nullopt;

    auto isMirrored = decoder.decode<bool>();
    if (!isMirrored)
        return std::nullopt;

    auto rotation = decoder.decode<WebCore::VideoFrameRotation>();
    if (!rotation)
        return std::nullopt;

    auto m_pixelBuffer = decoder.decode<RetainPtr<CVPixelBufferRef>>();
    if (!m_pixelBuffer)
        return std::nullopt;

    auto colorSpace = decoder.decode<WebCore::PlatformVideoColorSpace>();
    if (!colorSpace)
        return std::nullopt;

    return {
        WebCore::VideoFrameCV::create(
            WTFMove(*presentationTime),
            WTFMove(*isMirrored),
            WTFMove(*rotation),
            WTFMove(*m_pixelBuffer),
            WTFMove(*colorSpace)
        )
    };
}

#endif


void ArgumentCoder<WebCore::GradientColorStop>::encode(Encoder& encoder, const WebCore::GradientColorStop& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color)>, WebCore::Color>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GradientColorStop, offset)
        , offsetof(WebCore::GradientColorStop, color)
    >::value);
    encoder << instance.offset;
    encoder << instance.color;
}

void ArgumentCoder<WebCore::GradientColorStop>::encode(StreamConnectionEncoder& encoder, const WebCore::GradientColorStop& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color)>, WebCore::Color>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GradientColorStop, offset)
        , offsetof(WebCore::GradientColorStop, color)
    >::value);
    encoder << instance.offset;
    encoder << instance.color;
}

std::optional<WebCore::GradientColorStop> ArgumentCoder<WebCore::GradientColorStop>::decode(Decoder& decoder)
{
    auto offset = decoder.decode<float>();
    if (!offset)
        return std::nullopt;

    auto color = decoder.decode<WebCore::Color>();
    if (!color)
        return std::nullopt;

    return {
        WebCore::GradientColorStop {
            WTFMove(*offset),
            WTFMove(*color)
        }
    };
}


void ArgumentCoder<WebCore::GradientColorStops>::encode(Encoder& encoder, const WebCore::GradientColorStops& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stops())>, Vector<WebCore::GradientColorStop, 2>>);
    encoder << instance.stops();
}

void ArgumentCoder<WebCore::GradientColorStops>::encode(StreamConnectionEncoder& encoder, const WebCore::GradientColorStops& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stops())>, Vector<WebCore::GradientColorStop, 2>>);
    encoder << instance.stops();
}

std::optional<WebCore::GradientColorStops> ArgumentCoder<WebCore::GradientColorStops>::decode(Decoder& decoder)
{
    auto stops = decoder.decode<Vector<WebCore::GradientColorStop, 2>>();
    if (!stops)
        return std::nullopt;

    return {
        WebCore::GradientColorStops {
            WTFMove(*stops)
        }
    };
}


void ArgumentCoder<WebCore::ImageBufferBackendParameters>::encode(Encoder& encoder, const WebCore::ImageBufferBackendParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.logicalSize)>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.resolutionScale)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, WebCore::DestinationColorSpace>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pixelFormat)>, WebCore::PixelFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.purpose)>, WebCore::RenderingPurpose>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ImageBufferBackendParameters, logicalSize)
        , offsetof(WebCore::ImageBufferBackendParameters, resolutionScale)
        , offsetof(WebCore::ImageBufferBackendParameters, colorSpace)
        , offsetof(WebCore::ImageBufferBackendParameters, pixelFormat)
        , offsetof(WebCore::ImageBufferBackendParameters, purpose)
    >::value);
    encoder << instance.logicalSize;
    encoder << instance.resolutionScale;
    encoder << instance.colorSpace;
    encoder << instance.pixelFormat;
    encoder << instance.purpose;
}

std::optional<WebCore::ImageBufferBackendParameters> ArgumentCoder<WebCore::ImageBufferBackendParameters>::decode(Decoder& decoder)
{
    auto logicalSize = decoder.decode<WebCore::FloatSize>();
    if (!logicalSize)
        return std::nullopt;

    auto resolutionScale = decoder.decode<float>();
    if (!resolutionScale)
        return std::nullopt;

    auto colorSpace = decoder.decode<WebCore::DestinationColorSpace>();
    if (!colorSpace)
        return std::nullopt;

    auto pixelFormat = decoder.decode<WebCore::PixelFormat>();
    if (!pixelFormat)
        return std::nullopt;

    auto purpose = decoder.decode<WebCore::RenderingPurpose>();
    if (!purpose)
        return std::nullopt;

    return {
        WebCore::ImageBufferBackendParameters {
            WTFMove(*logicalSize),
            WTFMove(*resolutionScale),
            WTFMove(*colorSpace),
            WTFMove(*pixelFormat),
            WTFMove(*purpose)
        }
    };
}


void ArgumentCoder<WebCore::EncodedPathElementType>::encode(Encoder& encoder, const WebCore::EncodedPathElementType& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_type)>, std::optional<WebCore::PathElementType>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::EncodedPathElementType, m_type)
    >::value);
    encoder << instance.m_type;
}

void ArgumentCoder<WebCore::EncodedPathElementType>::encode(StreamConnectionEncoder& encoder, const WebCore::EncodedPathElementType& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_type)>, std::optional<WebCore::PathElementType>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::EncodedPathElementType, m_type)
    >::value);
    encoder << instance.m_type;
}

std::optional<WebCore::EncodedPathElementType> ArgumentCoder<WebCore::EncodedPathElementType>::decode(Decoder& decoder)
{
    auto m_type = decoder.decode<std::optional<WebCore::PathElementType>>();
    if (!m_type)
        return std::nullopt;

    return {
        WebCore::EncodedPathElementType {
            WTFMove(*m_type)
        }
    };
}


void ArgumentCoder<WebCore::ProcessIdentity>::encode(Encoder& encoder, const WebCore::ProcessIdentity& instance)
{
#if HAVE(TASK_IDENTITY_TOKEN)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_taskIdToken)>, MachSendRight>);
#endif
    static_assert(MembersInCorrectOrder<0
#if HAVE(TASK_IDENTITY_TOKEN)
        , offsetof(WebCore::ProcessIdentity, m_taskIdToken)
#endif
    >::value);
#if HAVE(TASK_IDENTITY_TOKEN)
    encoder << instance.m_taskIdToken;
#endif
}

std::optional<WebCore::ProcessIdentity> ArgumentCoder<WebCore::ProcessIdentity>::decode(Decoder& decoder)
{
#if HAVE(TASK_IDENTITY_TOKEN)
    auto m_taskIdToken = decoder.decode<MachSendRight>();
    if (!m_taskIdToken)
        return std::nullopt;
#endif

    return {
        WebCore::ProcessIdentity {
#if HAVE(TASK_IDENTITY_TOKEN)
            WTFMove(*m_taskIdToken)
#endif
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::HSL>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::HSL& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hueInterpolationMethod)>, WebCore::HueInterpolationMethod>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod::HSL, hueInterpolationMethod)
    >::value);
    encoder << instance.hueInterpolationMethod;
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::HSL>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::HSL& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hueInterpolationMethod)>, WebCore::HueInterpolationMethod>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod::HSL, hueInterpolationMethod)
    >::value);
    encoder << instance.hueInterpolationMethod;
}

std::optional<WebCore::ColorInterpolationMethod::HSL> ArgumentCoder<WebCore::ColorInterpolationMethod::HSL>::decode(Decoder& decoder)
{
    auto hueInterpolationMethod = decoder.decode<WebCore::HueInterpolationMethod>();
    if (!hueInterpolationMethod)
        return std::nullopt;

    return {
        WebCore::ColorInterpolationMethod::HSL {
            WTFMove(*hueInterpolationMethod)
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::HWB>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::HWB& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hueInterpolationMethod)>, WebCore::HueInterpolationMethod>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod::HWB, hueInterpolationMethod)
    >::value);
    encoder << instance.hueInterpolationMethod;
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::HWB>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::HWB& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hueInterpolationMethod)>, WebCore::HueInterpolationMethod>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod::HWB, hueInterpolationMethod)
    >::value);
    encoder << instance.hueInterpolationMethod;
}

std::optional<WebCore::ColorInterpolationMethod::HWB> ArgumentCoder<WebCore::ColorInterpolationMethod::HWB>::decode(Decoder& decoder)
{
    auto hueInterpolationMethod = decoder.decode<WebCore::HueInterpolationMethod>();
    if (!hueInterpolationMethod)
        return std::nullopt;

    return {
        WebCore::ColorInterpolationMethod::HWB {
            WTFMove(*hueInterpolationMethod)
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::LCH>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::LCH& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hueInterpolationMethod)>, WebCore::HueInterpolationMethod>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod::LCH, hueInterpolationMethod)
    >::value);
    encoder << instance.hueInterpolationMethod;
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::LCH>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::LCH& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hueInterpolationMethod)>, WebCore::HueInterpolationMethod>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod::LCH, hueInterpolationMethod)
    >::value);
    encoder << instance.hueInterpolationMethod;
}

std::optional<WebCore::ColorInterpolationMethod::LCH> ArgumentCoder<WebCore::ColorInterpolationMethod::LCH>::decode(Decoder& decoder)
{
    auto hueInterpolationMethod = decoder.decode<WebCore::HueInterpolationMethod>();
    if (!hueInterpolationMethod)
        return std::nullopt;

    return {
        WebCore::ColorInterpolationMethod::LCH {
            WTFMove(*hueInterpolationMethod)
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::Lab>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::Lab& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::Lab>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::Lab& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<WebCore::ColorInterpolationMethod::Lab> ArgumentCoder<WebCore::ColorInterpolationMethod::Lab>::decode(Decoder& decoder)
{
    return {
        WebCore::ColorInterpolationMethod::Lab {
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::OKLCH>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::OKLCH& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hueInterpolationMethod)>, WebCore::HueInterpolationMethod>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod::OKLCH, hueInterpolationMethod)
    >::value);
    encoder << instance.hueInterpolationMethod;
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::OKLCH>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::OKLCH& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hueInterpolationMethod)>, WebCore::HueInterpolationMethod>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod::OKLCH, hueInterpolationMethod)
    >::value);
    encoder << instance.hueInterpolationMethod;
}

std::optional<WebCore::ColorInterpolationMethod::OKLCH> ArgumentCoder<WebCore::ColorInterpolationMethod::OKLCH>::decode(Decoder& decoder)
{
    auto hueInterpolationMethod = decoder.decode<WebCore::HueInterpolationMethod>();
    if (!hueInterpolationMethod)
        return std::nullopt;

    return {
        WebCore::ColorInterpolationMethod::OKLCH {
            WTFMove(*hueInterpolationMethod)
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::OKLab>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::OKLab& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::OKLab>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::OKLab& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<WebCore::ColorInterpolationMethod::OKLab> ArgumentCoder<WebCore::ColorInterpolationMethod::OKLab>::decode(Decoder& decoder)
{
    return {
        WebCore::ColorInterpolationMethod::OKLab {
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::SRGB>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::SRGB& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::SRGB>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::SRGB& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<WebCore::ColorInterpolationMethod::SRGB> ArgumentCoder<WebCore::ColorInterpolationMethod::SRGB>::decode(Decoder& decoder)
{
    return {
        WebCore::ColorInterpolationMethod::SRGB {
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::SRGBLinear>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::SRGBLinear& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::SRGBLinear>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::SRGBLinear& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<WebCore::ColorInterpolationMethod::SRGBLinear> ArgumentCoder<WebCore::ColorInterpolationMethod::SRGBLinear>::decode(Decoder& decoder)
{
    return {
        WebCore::ColorInterpolationMethod::SRGBLinear {
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::XYZD50>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::XYZD50& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::XYZD50>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::XYZD50& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<WebCore::ColorInterpolationMethod::XYZD50> ArgumentCoder<WebCore::ColorInterpolationMethod::XYZD50>::decode(Decoder& decoder)
{
    return {
        WebCore::ColorInterpolationMethod::XYZD50 {
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod::XYZD65>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod::XYZD65& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

void ArgumentCoder<WebCore::ColorInterpolationMethod::XYZD65>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod::XYZD65& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<WebCore::ColorInterpolationMethod::XYZD65> ArgumentCoder<WebCore::ColorInterpolationMethod::XYZD65>::decode(Decoder& decoder)
{
    return {
        WebCore::ColorInterpolationMethod::XYZD65 {
        }
    };
}


void ArgumentCoder<WebCore::ColorInterpolationMethod>::encode(Encoder& encoder, const WebCore::ColorInterpolationMethod& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, std::variant<WebCore::ColorInterpolationMethod::HSL, WebCore::ColorInterpolationMethod::HWB, WebCore::ColorInterpolationMethod::LCH, WebCore::ColorInterpolationMethod::Lab, WebCore::ColorInterpolationMethod::OKLCH, WebCore::ColorInterpolationMethod::OKLab, WebCore::ColorInterpolationMethod::SRGB, WebCore::ColorInterpolationMethod::SRGBLinear, WebCore::ColorInterpolationMethod::XYZD50, WebCore::ColorInterpolationMethod::XYZD65>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alphaPremultiplication)>, WebCore::AlphaPremultiplication>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod, colorSpace)
        , offsetof(WebCore::ColorInterpolationMethod, alphaPremultiplication)
    >::value);
    encoder << instance.colorSpace;
    encoder << instance.alphaPremultiplication;
}

void ArgumentCoder<WebCore::ColorInterpolationMethod>::encode(StreamConnectionEncoder& encoder, const WebCore::ColorInterpolationMethod& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, std::variant<WebCore::ColorInterpolationMethod::HSL, WebCore::ColorInterpolationMethod::HWB, WebCore::ColorInterpolationMethod::LCH, WebCore::ColorInterpolationMethod::Lab, WebCore::ColorInterpolationMethod::OKLCH, WebCore::ColorInterpolationMethod::OKLab, WebCore::ColorInterpolationMethod::SRGB, WebCore::ColorInterpolationMethod::SRGBLinear, WebCore::ColorInterpolationMethod::XYZD50, WebCore::ColorInterpolationMethod::XYZD65>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alphaPremultiplication)>, WebCore::AlphaPremultiplication>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ColorInterpolationMethod, colorSpace)
        , offsetof(WebCore::ColorInterpolationMethod, alphaPremultiplication)
    >::value);
    encoder << instance.colorSpace;
    encoder << instance.alphaPremultiplication;
}

std::optional<WebCore::ColorInterpolationMethod> ArgumentCoder<WebCore::ColorInterpolationMethod>::decode(Decoder& decoder)
{
    auto colorSpace = decoder.decode<std::variant<WebCore::ColorInterpolationMethod::HSL, WebCore::ColorInterpolationMethod::HWB, WebCore::ColorInterpolationMethod::LCH, WebCore::ColorInterpolationMethod::Lab, WebCore::ColorInterpolationMethod::OKLCH, WebCore::ColorInterpolationMethod::OKLab, WebCore::ColorInterpolationMethod::SRGB, WebCore::ColorInterpolationMethod::SRGBLinear, WebCore::ColorInterpolationMethod::XYZD50, WebCore::ColorInterpolationMethod::XYZD65>>();
    if (!colorSpace)
        return std::nullopt;

    auto alphaPremultiplication = decoder.decode<WebCore::AlphaPremultiplication>();
    if (!alphaPremultiplication)
        return std::nullopt;

    return {
        WebCore::ColorInterpolationMethod {
            WTFMove(*colorSpace),
            WTFMove(*alphaPremultiplication)
        }
    };
}


void ArgumentCoder<WebCore::CompositeMode>::encode(Encoder& encoder, const WebCore::CompositeMode& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.operation)>, WebCore::CompositeOperator>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blendMode)>, WebCore::BlendMode>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CompositeMode, operation)
        , offsetof(WebCore::CompositeMode, blendMode)
    >::value);
    encoder << instance.operation;
    encoder << instance.blendMode;
}

void ArgumentCoder<WebCore::CompositeMode>::encode(StreamConnectionEncoder& encoder, const WebCore::CompositeMode& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.operation)>, WebCore::CompositeOperator>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blendMode)>, WebCore::BlendMode>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CompositeMode, operation)
        , offsetof(WebCore::CompositeMode, blendMode)
    >::value);
    encoder << instance.operation;
    encoder << instance.blendMode;
}

std::optional<WebCore::CompositeMode> ArgumentCoder<WebCore::CompositeMode>::decode(Decoder& decoder)
{
    auto operation = decoder.decode<WebCore::CompositeOperator>();
    if (!operation)
        return std::nullopt;

    auto blendMode = decoder.decode<WebCore::BlendMode>();
    if (!blendMode)
        return std::nullopt;

    return {
        WebCore::CompositeMode {
            WTFMove(*operation),
            WTFMove(*blendMode)
        }
    };
}


void ArgumentCoder<WebCore::DocumentMarkerLineStyle>::encode(Encoder& encoder, const WebCore::DocumentMarkerLineStyle& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mode)>, WebCore::DocumentMarkerLineStyleMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldUseDarkAppearance)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DocumentMarkerLineStyle, mode)
        , offsetof(WebCore::DocumentMarkerLineStyle, shouldUseDarkAppearance)
    >::value);
    encoder << instance.mode;
    encoder << instance.shouldUseDarkAppearance;
}

void ArgumentCoder<WebCore::DocumentMarkerLineStyle>::encode(StreamConnectionEncoder& encoder, const WebCore::DocumentMarkerLineStyle& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mode)>, WebCore::DocumentMarkerLineStyleMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldUseDarkAppearance)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DocumentMarkerLineStyle, mode)
        , offsetof(WebCore::DocumentMarkerLineStyle, shouldUseDarkAppearance)
    >::value);
    encoder << instance.mode;
    encoder << instance.shouldUseDarkAppearance;
}

std::optional<WebCore::DocumentMarkerLineStyle> ArgumentCoder<WebCore::DocumentMarkerLineStyle>::decode(Decoder& decoder)
{
    auto mode = decoder.decode<WebCore::DocumentMarkerLineStyleMode>();
    if (!mode)
        return std::nullopt;

    auto shouldUseDarkAppearance = decoder.decode<bool>();
    if (!shouldUseDarkAppearance)
        return std::nullopt;

    return {
        WebCore::DocumentMarkerLineStyle {
            WTFMove(*mode),
            WTFMove(*shouldUseDarkAppearance)
        }
    };
}


void ArgumentCoder<WebCore::DropShadow>::encode(Encoder& encoder, const WebCore::DropShadow& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blurRadius)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radiusMode)>, WebCore::ShadowRadiusMode>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DropShadow, offset)
        , offsetof(WebCore::DropShadow, blurRadius)
        , offsetof(WebCore::DropShadow, color)
        , offsetof(WebCore::DropShadow, radiusMode)
    >::value);
    encoder << instance.offset;
    encoder << instance.blurRadius;
    encoder << instance.color;
    encoder << instance.radiusMode;
}

void ArgumentCoder<WebCore::DropShadow>::encode(StreamConnectionEncoder& encoder, const WebCore::DropShadow& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blurRadius)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.radiusMode)>, WebCore::ShadowRadiusMode>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DropShadow, offset)
        , offsetof(WebCore::DropShadow, blurRadius)
        , offsetof(WebCore::DropShadow, color)
        , offsetof(WebCore::DropShadow, radiusMode)
    >::value);
    encoder << instance.offset;
    encoder << instance.blurRadius;
    encoder << instance.color;
    encoder << instance.radiusMode;
}

std::optional<WebCore::DropShadow> ArgumentCoder<WebCore::DropShadow>::decode(Decoder& decoder)
{
    auto offset = decoder.decode<WebCore::FloatSize>();
    if (!offset)
        return std::nullopt;

    auto blurRadius = decoder.decode<float>();
    if (!blurRadius)
        return std::nullopt;

    auto color = decoder.decode<WebCore::Color>();
    if (!color)
        return std::nullopt;

    auto radiusMode = decoder.decode<WebCore::ShadowRadiusMode>();
    if (!radiusMode)
        return std::nullopt;

    return {
        WebCore::DropShadow {
            WTFMove(*offset),
            WTFMove(*blurRadius),
            WTFMove(*color),
            WTFMove(*radiusMode)
        }
    };
}

#if ENABLE(VIDEO)

void ArgumentCoder<WebCore::GenericCueData>::encode(Encoder& encoder, const WebCore::GenericCueData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_uniqueId)>, WebCore::InbandGenericCueIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_startTime)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_endTime)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_id)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_content)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_fontName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_line)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_position)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_size)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_baseFontSize)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_relativeFontSize)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_foregroundColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_backgroundColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_highlightColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_align)>, WebCore::GenericCueData::Alignment>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_status)>, WebCore::GenericCueData::Status>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GenericCueData, m_uniqueId)
        , offsetof(WebCore::GenericCueData, m_startTime)
        , offsetof(WebCore::GenericCueData, m_endTime)
        , offsetof(WebCore::GenericCueData, m_id)
        , offsetof(WebCore::GenericCueData, m_content)
        , offsetof(WebCore::GenericCueData, m_fontName)
        , offsetof(WebCore::GenericCueData, m_line)
        , offsetof(WebCore::GenericCueData, m_position)
        , offsetof(WebCore::GenericCueData, m_size)
        , offsetof(WebCore::GenericCueData, m_baseFontSize)
        , offsetof(WebCore::GenericCueData, m_relativeFontSize)
        , offsetof(WebCore::GenericCueData, m_foregroundColor)
        , offsetof(WebCore::GenericCueData, m_backgroundColor)
        , offsetof(WebCore::GenericCueData, m_highlightColor)
        , offsetof(WebCore::GenericCueData, m_align)
        , offsetof(WebCore::GenericCueData, m_status)
    >::value);
    encoder << instance.m_uniqueId;
    encoder << instance.m_startTime;
    encoder << instance.m_endTime;
    encoder << instance.m_id;
    encoder << instance.m_content;
    encoder << instance.m_fontName;
    encoder << instance.m_line;
    encoder << instance.m_position;
    encoder << instance.m_size;
    encoder << instance.m_baseFontSize;
    encoder << instance.m_relativeFontSize;
    encoder << instance.m_foregroundColor;
    encoder << instance.m_backgroundColor;
    encoder << instance.m_highlightColor;
    encoder << instance.m_align;
    encoder << instance.m_status;
}

void ArgumentCoder<WebCore::GenericCueData>::encode(StreamConnectionEncoder& encoder, const WebCore::GenericCueData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_uniqueId)>, WebCore::InbandGenericCueIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_startTime)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_endTime)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_id)>, AtomString>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_content)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_fontName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_line)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_position)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_size)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_baseFontSize)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_relativeFontSize)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_foregroundColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_backgroundColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_highlightColor)>, WebCore::Color>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_align)>, WebCore::GenericCueData::Alignment>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_status)>, WebCore::GenericCueData::Status>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::GenericCueData, m_uniqueId)
        , offsetof(WebCore::GenericCueData, m_startTime)
        , offsetof(WebCore::GenericCueData, m_endTime)
        , offsetof(WebCore::GenericCueData, m_id)
        , offsetof(WebCore::GenericCueData, m_content)
        , offsetof(WebCore::GenericCueData, m_fontName)
        , offsetof(WebCore::GenericCueData, m_line)
        , offsetof(WebCore::GenericCueData, m_position)
        , offsetof(WebCore::GenericCueData, m_size)
        , offsetof(WebCore::GenericCueData, m_baseFontSize)
        , offsetof(WebCore::GenericCueData, m_relativeFontSize)
        , offsetof(WebCore::GenericCueData, m_foregroundColor)
        , offsetof(WebCore::GenericCueData, m_backgroundColor)
        , offsetof(WebCore::GenericCueData, m_highlightColor)
        , offsetof(WebCore::GenericCueData, m_align)
        , offsetof(WebCore::GenericCueData, m_status)
    >::value);
    encoder << instance.m_uniqueId;
    encoder << instance.m_startTime;
    encoder << instance.m_endTime;
    encoder << instance.m_id;
    encoder << instance.m_content;
    encoder << instance.m_fontName;
    encoder << instance.m_line;
    encoder << instance.m_position;
    encoder << instance.m_size;
    encoder << instance.m_baseFontSize;
    encoder << instance.m_relativeFontSize;
    encoder << instance.m_foregroundColor;
    encoder << instance.m_backgroundColor;
    encoder << instance.m_highlightColor;
    encoder << instance.m_align;
    encoder << instance.m_status;
}

std::optional<WebCore::GenericCueData> ArgumentCoder<WebCore::GenericCueData>::decode(Decoder& decoder)
{
    auto m_uniqueId = decoder.decode<WebCore::InbandGenericCueIdentifier>();
    if (!m_uniqueId)
        return std::nullopt;

    auto m_startTime = decoder.decode<MediaTime>();
    if (!m_startTime)
        return std::nullopt;

    auto m_endTime = decoder.decode<MediaTime>();
    if (!m_endTime)
        return std::nullopt;

    auto m_id = decoder.decode<AtomString>();
    if (!m_id)
        return std::nullopt;

    auto m_content = decoder.decode<String>();
    if (!m_content)
        return std::nullopt;

    auto m_fontName = decoder.decode<String>();
    if (!m_fontName)
        return std::nullopt;

    auto m_line = decoder.decode<double>();
    if (!m_line)
        return std::nullopt;

    auto m_position = decoder.decode<double>();
    if (!m_position)
        return std::nullopt;

    auto m_size = decoder.decode<double>();
    if (!m_size)
        return std::nullopt;

    auto m_baseFontSize = decoder.decode<double>();
    if (!m_baseFontSize)
        return std::nullopt;

    auto m_relativeFontSize = decoder.decode<double>();
    if (!m_relativeFontSize)
        return std::nullopt;

    auto m_foregroundColor = decoder.decode<WebCore::Color>();
    if (!m_foregroundColor)
        return std::nullopt;

    auto m_backgroundColor = decoder.decode<WebCore::Color>();
    if (!m_backgroundColor)
        return std::nullopt;

    auto m_highlightColor = decoder.decode<WebCore::Color>();
    if (!m_highlightColor)
        return std::nullopt;

    auto m_align = decoder.decode<WebCore::GenericCueData::Alignment>();
    if (!m_align)
        return std::nullopt;

    auto m_status = decoder.decode<WebCore::GenericCueData::Status>();
    if (!m_status)
        return std::nullopt;

    return {
        WebCore::GenericCueData {
            WTFMove(*m_uniqueId),
            WTFMove(*m_startTime),
            WTFMove(*m_endTime),
            WTFMove(*m_id),
            WTFMove(*m_content),
            WTFMove(*m_fontName),
            WTFMove(*m_line),
            WTFMove(*m_position),
            WTFMove(*m_size),
            WTFMove(*m_baseFontSize),
            WTFMove(*m_relativeFontSize),
            WTFMove(*m_foregroundColor),
            WTFMove(*m_backgroundColor),
            WTFMove(*m_highlightColor),
            WTFMove(*m_align),
            WTFMove(*m_status)
        }
    };
}

#endif


void ArgumentCoder<WebCore::ImageDecoderFrameInfo>::encode(Encoder& encoder, const WebCore::ImageDecoderFrameInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasAlpha)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.duration)>, Seconds>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ImageDecoderFrameInfo, hasAlpha)
        , offsetof(WebCore::ImageDecoderFrameInfo, duration)
    >::value);
    encoder << instance.hasAlpha;
    encoder << instance.duration;
}

void ArgumentCoder<WebCore::ImageDecoderFrameInfo>::encode(StreamConnectionEncoder& encoder, const WebCore::ImageDecoderFrameInfo& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasAlpha)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.duration)>, Seconds>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ImageDecoderFrameInfo, hasAlpha)
        , offsetof(WebCore::ImageDecoderFrameInfo, duration)
    >::value);
    encoder << instance.hasAlpha;
    encoder << instance.duration;
}

std::optional<WebCore::ImageDecoderFrameInfo> ArgumentCoder<WebCore::ImageDecoderFrameInfo>::decode(Decoder& decoder)
{
    auto hasAlpha = decoder.decode<bool>();
    if (!hasAlpha)
        return std::nullopt;

    auto duration = decoder.decode<Seconds>();
    if (!duration)
        return std::nullopt;

    return {
        WebCore::ImageDecoderFrameInfo {
            WTFMove(*hasAlpha),
            WTFMove(*duration)
        }
    };
}


void ArgumentCoder<WebCore::DisplayList::DrawDotsForDocumentMarker>::encode(Encoder& encoder, const WebCore::DisplayList::DrawDotsForDocumentMarker& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_rect)>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_styleMode)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_styleShouldUseDarkAppearance)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DisplayList::DrawDotsForDocumentMarker, m_rect)
        , offsetof(WebCore::DisplayList::DrawDotsForDocumentMarker, m_styleMode)
        , offsetof(WebCore::DisplayList::DrawDotsForDocumentMarker, m_styleShouldUseDarkAppearance)
    >::value);
    encoder << instance.m_rect;
    encoder << instance.m_styleMode;
    encoder << instance.m_styleShouldUseDarkAppearance;
}

void ArgumentCoder<WebCore::DisplayList::DrawDotsForDocumentMarker>::encode(StreamConnectionEncoder& encoder, const WebCore::DisplayList::DrawDotsForDocumentMarker& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_rect)>, WebCore::FloatRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_styleMode)>, uint8_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_styleShouldUseDarkAppearance)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::DisplayList::DrawDotsForDocumentMarker, m_rect)
        , offsetof(WebCore::DisplayList::DrawDotsForDocumentMarker, m_styleMode)
        , offsetof(WebCore::DisplayList::DrawDotsForDocumentMarker, m_styleShouldUseDarkAppearance)
    >::value);
    encoder << instance.m_rect;
    encoder << instance.m_styleMode;
    encoder << instance.m_styleShouldUseDarkAppearance;
}

std::optional<WebCore::DisplayList::DrawDotsForDocumentMarker> ArgumentCoder<WebCore::DisplayList::DrawDotsForDocumentMarker>::decode(Decoder& decoder)
{
    auto m_rect = decoder.decode<WebCore::FloatRect>();
    if (!m_rect)
        return std::nullopt;

    auto m_styleMode = decoder.decode<uint8_t>();
    if (!m_styleMode)
        return std::nullopt;

    auto m_styleShouldUseDarkAppearance = decoder.decode<bool>();
    if (!m_styleShouldUseDarkAppearance)
        return std::nullopt;

    return {
        WebCore::DisplayList::DrawDotsForDocumentMarker {
            WTFMove(*m_rect),
            WTFMove(*m_styleMode),
            WTFMove(*m_styleShouldUseDarkAppearance)
        }
    };
}


void ArgumentCoder<WebCore::ImageOrientation>::encode(Encoder& encoder, const WebCore::ImageOrientation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.orientation())>, WebCore::ImageOrientation::Orientation>);
    encoder << instance.orientation();
}

void ArgumentCoder<WebCore::ImageOrientation>::encode(StreamConnectionEncoder& encoder, const WebCore::ImageOrientation& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.orientation())>, WebCore::ImageOrientation::Orientation>);
    encoder << instance.orientation();
}

std::optional<WebCore::ImageOrientation> ArgumentCoder<WebCore::ImageOrientation>::decode(Decoder& decoder)
{
    auto orientation = decoder.decode<WebCore::ImageOrientation::Orientation>();
    if (!orientation)
        return std::nullopt;

    return {
        WebCore::ImageOrientation {
            WTFMove(*orientation)
        }
    };
}


void ArgumentCoder<WebCore::ImagePaintingOptions>::encode(Encoder& encoder, const WebCore::ImagePaintingOptions& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_compositeOperator)>, WebCore::CompositeOperator>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_blendMode)>, WebCore::BlendMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_decodingMode)>, WebCore::DecodingMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_orientation)>, WebCore::ImageOrientation>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_interpolationQuality)>, WebCore::InterpolationQuality>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ImagePaintingOptions, m_compositeOperator)
        , offsetof(WebCore::ImagePaintingOptions, m_blendMode)
        , offsetof(WebCore::ImagePaintingOptions, m_decodingMode)
        , offsetof(WebCore::ImagePaintingOptions, m_orientation)
        , offsetof(WebCore::ImagePaintingOptions, m_interpolationQuality)
    >::value);
    encoder << instance.m_compositeOperator;
    encoder << instance.m_blendMode;
    encoder << instance.m_decodingMode;
    encoder << instance.m_orientation;
    encoder << instance.m_interpolationQuality;
}

void ArgumentCoder<WebCore::ImagePaintingOptions>::encode(StreamConnectionEncoder& encoder, const WebCore::ImagePaintingOptions& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_compositeOperator)>, WebCore::CompositeOperator>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_blendMode)>, WebCore::BlendMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_decodingMode)>, WebCore::DecodingMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_orientation)>, WebCore::ImageOrientation>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_interpolationQuality)>, WebCore::InterpolationQuality>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ImagePaintingOptions, m_compositeOperator)
        , offsetof(WebCore::ImagePaintingOptions, m_blendMode)
        , offsetof(WebCore::ImagePaintingOptions, m_decodingMode)
        , offsetof(WebCore::ImagePaintingOptions, m_orientation)
        , offsetof(WebCore::ImagePaintingOptions, m_interpolationQuality)
    >::value);
    encoder << instance.m_compositeOperator;
    encoder << instance.m_blendMode;
    encoder << instance.m_decodingMode;
    encoder << instance.m_orientation;
    encoder << instance.m_interpolationQuality;
}

std::optional<WebCore::ImagePaintingOptions> ArgumentCoder<WebCore::ImagePaintingOptions>::decode(Decoder& decoder)
{
    auto m_compositeOperator = decoder.decode<WebCore::CompositeOperator>();
    if (!m_compositeOperator)
        return std::nullopt;

    auto m_blendMode = decoder.decode<WebCore::BlendMode>();
    if (!m_blendMode)
        return std::nullopt;

    auto m_decodingMode = decoder.decode<WebCore::DecodingMode>();
    if (!m_decodingMode)
        return std::nullopt;

    auto m_orientation = decoder.decode<WebCore::ImageOrientation>();
    if (!m_orientation)
        return std::nullopt;

    auto m_interpolationQuality = decoder.decode<WebCore::InterpolationQuality>();
    if (!m_interpolationQuality)
        return std::nullopt;

    return {
        WebCore::ImagePaintingOptions {
            WTFMove(*m_compositeOperator),
            WTFMove(*m_blendMode),
            WTFMove(*m_decodingMode),
            WTFMove(*m_orientation),
            WTFMove(*m_interpolationQuality)
        }
    };
}


void ArgumentCoder<WebCore::CanvasActivityRecord>::encode(Encoder& encoder, const WebCore::CanvasActivityRecord& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.textWritten)>, HashSet<String>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.wasDataRead)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CanvasActivityRecord, textWritten)
        , offsetof(WebCore::CanvasActivityRecord, wasDataRead)
    >::value);
    encoder << instance.textWritten;
    encoder << instance.wasDataRead;
}

std::optional<WebCore::CanvasActivityRecord> ArgumentCoder<WebCore::CanvasActivityRecord>::decode(Decoder& decoder)
{
    auto textWritten = decoder.decode<HashSet<String>>();
    if (!textWritten)
        return std::nullopt;

    auto wasDataRead = decoder.decode<bool>();
    if (!wasDataRead)
        return std::nullopt;

    return {
        WebCore::CanvasActivityRecord {
            WTFMove(*textWritten),
            WTFMove(*wasDataRead)
        }
    };
}


void ArgumentCoder<WebCore::PCM::AttributionSecondsUntilSendData>::encode(Encoder& encoder, const WebCore::PCM::AttributionSecondsUntilSendData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceSeconds)>, std::optional<Seconds>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.destinationSeconds)>, std::optional<Seconds>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PCM::AttributionSecondsUntilSendData, sourceSeconds)
        , offsetof(WebCore::PCM::AttributionSecondsUntilSendData, destinationSeconds)
    >::value);
    encoder << instance.sourceSeconds;
    encoder << instance.destinationSeconds;
}

std::optional<WebCore::PCM::AttributionSecondsUntilSendData> ArgumentCoder<WebCore::PCM::AttributionSecondsUntilSendData>::decode(Decoder& decoder)
{
    auto sourceSeconds = decoder.decode<std::optional<Seconds>>();
    if (!sourceSeconds)
        return std::nullopt;

    auto destinationSeconds = decoder.decode<std::optional<Seconds>>();
    if (!destinationSeconds)
        return std::nullopt;

    return {
        WebCore::PCM::AttributionSecondsUntilSendData {
            WTFMove(*sourceSeconds),
            WTFMove(*destinationSeconds)
        }
    };
}


void ArgumentCoder<WebCore::CrossOriginOpenerPolicy>::encode(Encoder& encoder, const WebCore::CrossOriginOpenerPolicy& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value)>, WebCore::CrossOriginOpenerPolicyValue>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.reportOnlyValue)>, WebCore::CrossOriginOpenerPolicyValue>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.reportingEndpoint)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.reportOnlyReportingEndpoint)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CrossOriginOpenerPolicy, value)
        , offsetof(WebCore::CrossOriginOpenerPolicy, reportOnlyValue)
        , offsetof(WebCore::CrossOriginOpenerPolicy, reportingEndpoint)
        , offsetof(WebCore::CrossOriginOpenerPolicy, reportOnlyReportingEndpoint)
    >::value);
    encoder << instance.value;
    encoder << instance.reportOnlyValue;
    encoder << instance.reportingEndpoint;
    encoder << instance.reportOnlyReportingEndpoint;
}

std::optional<WebCore::CrossOriginOpenerPolicy> ArgumentCoder<WebCore::CrossOriginOpenerPolicy>::decode(Decoder& decoder)
{
    auto value = decoder.decode<WebCore::CrossOriginOpenerPolicyValue>();
    if (!value)
        return std::nullopt;

    auto reportOnlyValue = decoder.decode<WebCore::CrossOriginOpenerPolicyValue>();
    if (!reportOnlyValue)
        return std::nullopt;

    auto reportingEndpoint = decoder.decode<String>();
    if (!reportingEndpoint)
        return std::nullopt;

    auto reportOnlyReportingEndpoint = decoder.decode<String>();
    if (!reportOnlyReportingEndpoint)
        return std::nullopt;

    return {
        WebCore::CrossOriginOpenerPolicy {
            WTFMove(*value),
            WTFMove(*reportOnlyValue),
            WTFMove(*reportingEndpoint),
            WTFMove(*reportOnlyReportingEndpoint)
        }
    };
}


void ArgumentCoder<WebCore::CustomHeaderFields>::encode(Encoder& encoder, const WebCore::CustomHeaderFields& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fields)>, Vector<WebCore::HTTPHeaderField>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.thirdPartyDomains)>, Vector<String>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::CustomHeaderFields, fields)
        , offsetof(WebCore::CustomHeaderFields, thirdPartyDomains)
    >::value);
    encoder << instance.fields;
    encoder << instance.thirdPartyDomains;
}

std::optional<WebCore::CustomHeaderFields> ArgumentCoder<WebCore::CustomHeaderFields>::decode(Decoder& decoder)
{
    auto fields = decoder.decode<Vector<WebCore::HTTPHeaderField>>();
    if (!fields)
        return std::nullopt;

    auto thirdPartyDomains = decoder.decode<Vector<String>>();
    if (!thirdPartyDomains)
        return std::nullopt;

    return {
        WebCore::CustomHeaderFields {
            WTFMove(*fields),
            WTFMove(*thirdPartyDomains)
        }
    };
}


void ArgumentCoder<WebCore::HTTPHeaderField>::encode(Encoder& encoder, const WebCore::HTTPHeaderField& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.name())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.value())>, String>);
    encoder << instance.name();
    encoder << instance.value();
}

std::optional<WebCore::HTTPHeaderField> ArgumentCoder<WebCore::HTTPHeaderField>::decode(Decoder& decoder)
{
    auto name = decoder.decode<String>();
    if (!name)
        return std::nullopt;

    auto value = decoder.decode<String>();
    if (!value)
        return std::nullopt;

    return {
        WebCore::HTTPHeaderField::create(
            WTFMove(*name),
            WTFMove(*value)
        )
    };
}


void ArgumentCoder<WebCore::NavigationRequester>::encode(Encoder& encoder, const WebCore::NavigationRequester& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.securityOrigin)>, Ref<WebCore::SecurityOrigin>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topOrigin)>, Ref<WebCore::SecurityOrigin>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.policyContainer)>, WebCore::PolicyContainer>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.documentIdentifier)>, WebCore::ScriptExecutionContextIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.globalFrameIdentifier)>, std::optional<WebCore::GlobalFrameIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sandboxFlags)>, WebCore::SandboxFlags>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::NavigationRequester, url)
        , offsetof(WebCore::NavigationRequester, securityOrigin)
        , offsetof(WebCore::NavigationRequester, topOrigin)
        , offsetof(WebCore::NavigationRequester, policyContainer)
        , offsetof(WebCore::NavigationRequester, documentIdentifier)
        , offsetof(WebCore::NavigationRequester, globalFrameIdentifier)
        , offsetof(WebCore::NavigationRequester, sandboxFlags)
    >::value);
    encoder << instance.url;
    encoder << instance.securityOrigin;
    encoder << instance.topOrigin;
    encoder << instance.policyContainer;
    encoder << instance.documentIdentifier;
    encoder << instance.globalFrameIdentifier;
    encoder << instance.sandboxFlags;
}

std::optional<WebCore::NavigationRequester> ArgumentCoder<WebCore::NavigationRequester>::decode(Decoder& decoder)
{
    auto url = decoder.decode<URL>();
    if (!url)
        return std::nullopt;

    auto securityOrigin = decoder.decode<Ref<WebCore::SecurityOrigin>>();
    if (!securityOrigin)
        return std::nullopt;

    auto topOrigin = decoder.decode<Ref<WebCore::SecurityOrigin>>();
    if (!topOrigin)
        return std::nullopt;

    auto policyContainer = decoder.decode<WebCore::PolicyContainer>();
    if (!policyContainer)
        return std::nullopt;

    auto documentIdentifier = decoder.decode<WebCore::ScriptExecutionContextIdentifier>();
    if (!documentIdentifier)
        return std::nullopt;

    auto globalFrameIdentifier = decoder.decode<std::optional<WebCore::GlobalFrameIdentifier>>();
    if (!globalFrameIdentifier)
        return std::nullopt;

    auto sandboxFlags = decoder.decode<WebCore::SandboxFlags>();
    if (!sandboxFlags)
        return std::nullopt;

    return {
        WebCore::NavigationRequester {
            WTFMove(*url),
            WTFMove(*securityOrigin),
            WTFMove(*topOrigin),
            WTFMove(*policyContainer),
            WTFMove(*documentIdentifier),
            WTFMove(*globalFrameIdentifier),
            WTFMove(*sandboxFlags)
        }
    };
}


void ArgumentCoder<WebCore::PolicyContainer>::encode(Encoder& encoder, const WebCore::PolicyContainer& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.contentSecurityPolicyResponseHeaders)>, WebCore::ContentSecurityPolicyResponseHeaders>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.crossOriginEmbedderPolicy)>, WebCore::CrossOriginEmbedderPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.crossOriginOpenerPolicy)>, WebCore::CrossOriginOpenerPolicy>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.referrerPolicy)>, WebCore::ReferrerPolicy>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::PolicyContainer, contentSecurityPolicyResponseHeaders)
        , offsetof(WebCore::PolicyContainer, crossOriginEmbedderPolicy)
        , offsetof(WebCore::PolicyContainer, crossOriginOpenerPolicy)
        , offsetof(WebCore::PolicyContainer, referrerPolicy)
    >::value);
    encoder << instance.contentSecurityPolicyResponseHeaders;
    encoder << instance.crossOriginEmbedderPolicy;
    encoder << instance.crossOriginOpenerPolicy;
    encoder << instance.referrerPolicy;
}

std::optional<WebCore::PolicyContainer> ArgumentCoder<WebCore::PolicyContainer>::decode(Decoder& decoder)
{
    auto contentSecurityPolicyResponseHeaders = decoder.decode<WebCore::ContentSecurityPolicyResponseHeaders>();
    if (!contentSecurityPolicyResponseHeaders)
        return std::nullopt;

    auto crossOriginEmbedderPolicy = decoder.decode<WebCore::CrossOriginEmbedderPolicy>();
    if (!crossOriginEmbedderPolicy)
        return std::nullopt;

    auto crossOriginOpenerPolicy = decoder.decode<WebCore::CrossOriginOpenerPolicy>();
    if (!crossOriginOpenerPolicy)
        return std::nullopt;

    auto referrerPolicy = decoder.decode<WebCore::ReferrerPolicy>();
    if (!referrerPolicy)
        return std::nullopt;

    return {
        WebCore::PolicyContainer {
            WTFMove(*contentSecurityPolicyResponseHeaders),
            WTFMove(*crossOriginEmbedderPolicy),
            WTFMove(*crossOriginOpenerPolicy),
            WTFMove(*referrerPolicy)
        }
    };
}


void ArgumentCoder<WebCore::SubstituteData>::encode(Encoder& encoder, const WebCore::SubstituteData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.content())>, RefPtr<WebCore::FragmentedSharedBuffer>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.failingURL())>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.response())>, WebCore::ResourceResponse>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldRevealToSessionHistory())>, WebCore::SubstituteData::SessionHistoryVisibility>);
    encoder << instance.content();
    encoder << instance.failingURL();
    encoder << instance.response();
    encoder << instance.shouldRevealToSessionHistory();
}

std::optional<WebCore::SubstituteData> ArgumentCoder<WebCore::SubstituteData>::decode(Decoder& decoder)
{
    auto content = decoder.decode<RefPtr<WebCore::FragmentedSharedBuffer>>();
    if (!content)
        return std::nullopt;

    auto failingURL = decoder.decode<URL>();
    if (!failingURL)
        return std::nullopt;

    auto response = decoder.decode<WebCore::ResourceResponse>();
    if (!response)
        return std::nullopt;

    auto shouldRevealToSessionHistory = decoder.decode<WebCore::SubstituteData::SessionHistoryVisibility>();
    if (!shouldRevealToSessionHistory)
        return std::nullopt;

    return {
        WebCore::SubstituteData {
            WTFMove(*content),
            WTFMove(*failingURL),
            WTFMove(*response),
            WTFMove(*shouldRevealToSessionHistory)
        }
    };
}

#if ENABLE(SERVICE_WORKER)

void ArgumentCoder<WebCore::ServiceWorkerClientData>::encode(Encoder& encoder, const WebCore::ServiceWorkerClientData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::ScriptExecutionContextIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ServiceWorkerClientType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameType)>, WebCore::ServiceWorkerClientFrameType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.url)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ownerURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageIdentifier)>, std::optional<WebCore::PageIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameIdentifier)>, std::optional<WebCore::FrameIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lastNavigationWasAppInitiated)>, WebCore::LastNavigationWasAppInitiated>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isVisible)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isFocused)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.focusOrder)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ancestorOrigins)>, Vector<String>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ServiceWorkerClientData, identifier)
        , offsetof(WebCore::ServiceWorkerClientData, type)
        , offsetof(WebCore::ServiceWorkerClientData, frameType)
        , offsetof(WebCore::ServiceWorkerClientData, url)
        , offsetof(WebCore::ServiceWorkerClientData, ownerURL)
        , offsetof(WebCore::ServiceWorkerClientData, pageIdentifier)
        , offsetof(WebCore::ServiceWorkerClientData, frameIdentifier)
        , offsetof(WebCore::ServiceWorkerClientData, lastNavigationWasAppInitiated)
        , offsetof(WebCore::ServiceWorkerClientData, isVisible)
        , offsetof(WebCore::ServiceWorkerClientData, isFocused)
        , offsetof(WebCore::ServiceWorkerClientData, focusOrder)
        , offsetof(WebCore::ServiceWorkerClientData, ancestorOrigins)
    >::value);
    encoder << instance.identifier;
    encoder << instance.type;
    encoder << instance.frameType;
    encoder << instance.url;
    encoder << instance.ownerURL;
    encoder << instance.pageIdentifier;
    encoder << instance.frameIdentifier;
    encoder << instance.lastNavigationWasAppInitiated;
    encoder << instance.isVisible;
    encoder << instance.isFocused;
    encoder << instance.focusOrder;
    encoder << instance.ancestorOrigins;
}

std::optional<WebCore::ServiceWorkerClientData> ArgumentCoder<WebCore::ServiceWorkerClientData>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::ScriptExecutionContextIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto type = decoder.decode<WebCore::ServiceWorkerClientType>();
    if (!type)
        return std::nullopt;

    auto frameType = decoder.decode<WebCore::ServiceWorkerClientFrameType>();
    if (!frameType)
        return std::nullopt;

    auto url = decoder.decode<URL>();
    if (!url)
        return std::nullopt;

    auto ownerURL = decoder.decode<URL>();
    if (!ownerURL)
        return std::nullopt;

    auto pageIdentifier = decoder.decode<std::optional<WebCore::PageIdentifier>>();
    if (!pageIdentifier)
        return std::nullopt;

    auto frameIdentifier = decoder.decode<std::optional<WebCore::FrameIdentifier>>();
    if (!frameIdentifier)
        return std::nullopt;

    auto lastNavigationWasAppInitiated = decoder.decode<WebCore::LastNavigationWasAppInitiated>();
    if (!lastNavigationWasAppInitiated)
        return std::nullopt;

    auto isVisible = decoder.decode<bool>();
    if (!isVisible)
        return std::nullopt;

    auto isFocused = decoder.decode<bool>();
    if (!isFocused)
        return std::nullopt;

    auto focusOrder = decoder.decode<uint64_t>();
    if (!focusOrder)
        return std::nullopt;

    auto ancestorOrigins = decoder.decode<Vector<String>>();
    if (!ancestorOrigins)
        return std::nullopt;

    return {
        WebCore::ServiceWorkerClientData {
            WTFMove(*identifier),
            WTFMove(*type),
            WTFMove(*frameType),
            WTFMove(*url),
            WTFMove(*ownerURL),
            WTFMove(*pageIdentifier),
            WTFMove(*frameIdentifier),
            WTFMove(*lastNavigationWasAppInitiated),
            WTFMove(*isVisible),
            WTFMove(*isFocused),
            WTFMove(*focusOrder),
            WTFMove(*ancestorOrigins)
        }
    };
}

#endif

#if ENABLE(SERVICE_WORKER)

void ArgumentCoder<WebCore::ServiceWorkerClientQueryOptions>::encode(Encoder& encoder, const WebCore::ServiceWorkerClientQueryOptions& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.includeUncontrolled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ServiceWorkerClientType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ServiceWorkerClientQueryOptions, includeUncontrolled)
        , offsetof(WebCore::ServiceWorkerClientQueryOptions, type)
    >::value);
    encoder << instance.includeUncontrolled;
    encoder << instance.type;
}

std::optional<WebCore::ServiceWorkerClientQueryOptions> ArgumentCoder<WebCore::ServiceWorkerClientQueryOptions>::decode(Decoder& decoder)
{
    auto includeUncontrolled = decoder.decode<bool>();
    if (!includeUncontrolled)
        return std::nullopt;

    auto type = decoder.decode<WebCore::ServiceWorkerClientType>();
    if (!type)
        return std::nullopt;

    return {
        WebCore::ServiceWorkerClientQueryOptions {
            WTFMove(*includeUncontrolled),
            WTFMove(*type)
        }
    };
}

#endif

#if ENABLE(SERVICE_WORKER)

void ArgumentCoder<WebCore::ServiceWorkerData>::encode(Encoder& encoder, const WebCore::ServiceWorkerData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebCore::ServiceWorkerIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.registrationIdentifier)>, WebCore::ServiceWorkerRegistrationIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scriptURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.state)>, WebCore::ServiceWorkerState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::WorkerType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ServiceWorkerData, identifier)
        , offsetof(WebCore::ServiceWorkerData, registrationIdentifier)
        , offsetof(WebCore::ServiceWorkerData, scriptURL)
        , offsetof(WebCore::ServiceWorkerData, state)
        , offsetof(WebCore::ServiceWorkerData, type)
    >::value);
    encoder << instance.identifier;
    encoder << instance.registrationIdentifier;
    encoder << instance.scriptURL;
    encoder << instance.state;
    encoder << instance.type;
}

std::optional<WebCore::ServiceWorkerData> ArgumentCoder<WebCore::ServiceWorkerData>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::ServiceWorkerIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto registrationIdentifier = decoder.decode<WebCore::ServiceWorkerRegistrationIdentifier>();
    if (!registrationIdentifier)
        return std::nullopt;

    auto scriptURL = decoder.decode<URL>();
    if (!scriptURL)
        return std::nullopt;

    auto state = decoder.decode<WebCore::ServiceWorkerState>();
    if (!state)
        return std::nullopt;

    auto type = decoder.decode<WebCore::WorkerType>();
    if (!type)
        return std::nullopt;

    return {
        WebCore::ServiceWorkerData {
            WTFMove(*identifier),
            WTFMove(*registrationIdentifier),
            WTFMove(*scriptURL),
            WTFMove(*state),
            WTFMove(*type)
        }
    };
}

#endif

#if ENABLE(SERVICE_WORKER)

void ArgumentCoder<WebCore::ServiceWorkerJobData>::encode(Encoder& encoder, const WebCore::ServiceWorkerJobData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier())>, WebCore::ServiceWorkerJobDataIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scriptURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clientCreationURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topOrigin)>, WebCore::SecurityOriginData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scopeURL)>, URL>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceContext)>, WebCore::ServiceWorkerOrClientIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.workerType)>, WebCore::WorkerType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebCore::ServiceWorkerJobType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.domainForCachePartition)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isFromServiceWorkerPage)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.registrationOptions)>, std::optional<WebCore::ServiceWorkerRegistrationOptions>>);
    encoder << instance.identifier();
    encoder << instance.scriptURL;
    encoder << instance.clientCreationURL;
    encoder << instance.topOrigin;
    encoder << instance.scopeURL;
    encoder << instance.sourceContext;
    encoder << instance.workerType;
    encoder << instance.type;
    encoder << instance.domainForCachePartition;
    encoder << instance.isFromServiceWorkerPage;
    encoder << instance.registrationOptions;
}

std::optional<WebCore::ServiceWorkerJobData> ArgumentCoder<WebCore::ServiceWorkerJobData>::decode(Decoder& decoder)
{
    auto identifier = decoder.decode<WebCore::ServiceWorkerJobDataIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto scriptURL = decoder.decode<URL>();
    if (!scriptURL)
        return std::nullopt;

    auto clientCreationURL = decoder.decode<URL>();
    if (!clientCreationURL)
        return std::nullopt;

    auto topOrigin = decoder.decode<WebCore::SecurityOriginData>();
    if (!topOrigin)
        return std::nullopt;

    auto scopeURL = decoder.decode<URL>();
    if (!scopeURL)
        return std::nullopt;

    auto sourceContext = decoder.decode<WebCore::ServiceWorkerOrClientIdentifier>();
    if (!sourceContext)
        return std::nullopt;

    auto workerType = decoder.decode<WebCore::WorkerType>();
    if (!workerType)
        return std::nullopt;

    auto type = decoder.decode<WebCore::ServiceWorkerJobType>();
    if (!type)
        return std::nullopt;

    auto domainForCachePartition = decoder.decode<String>();
    if (!domainForCachePartition)
        return std::nullopt;

    auto isFromServiceWorkerPage = decoder.decode<bool>();
    if (!isFromServiceWorkerPage)
        return std::nullopt;

    auto registrationOptions = decoder.decode<std::optional<WebCore::ServiceWorkerRegistrationOptions>>();
    if (!registrationOptions)
        return std::nullopt;

    if (!(( type == WebCore::ServiceWorkerJobType::Register && registrationOptions->has_value()) || (type != WebCore::ServiceWorkerJobType::Register && !registrationOptions->has_value() )))
        return std::nullopt;

    return {
        WebCore::ServiceWorkerJobData {
            WTFMove(*identifier),
            WTFMove(*scriptURL),
            WTFMove(*clientCreationURL),
            WTFMove(*topOrigin),
            WTFMove(*scopeURL),
            WTFMove(*sourceContext),
            WTFMove(*workerType),
            WTFMove(*type),
            WTFMove(*domainForCachePartition),
            WTFMove(*isFromServiceWorkerPage),
            WTFMove(*registrationOptions)
        }
    };
}

#endif


void ArgumentCoder<WebCore::EventInit>::encode(Encoder& encoder, const WebCore::EventInit& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bubbles)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cancelable)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.composed)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::EventInit, bubbles)
        , offsetof(WebCore::EventInit, cancelable)
        , offsetof(WebCore::EventInit, composed)
    >::value);
    encoder << instance.bubbles;
    encoder << instance.cancelable;
    encoder << instance.composed;
}

std::optional<WebCore::EventInit> ArgumentCoder<WebCore::EventInit>::decode(Decoder& decoder)
{
    auto bubbles = decoder.decode<bool>();
    if (!bubbles)
        return std::nullopt;

    auto cancelable = decoder.decode<bool>();
    if (!cancelable)
        return std::nullopt;

    auto composed = decoder.decode<bool>();
    if (!composed)
        return std::nullopt;

    return {
        WebCore::EventInit {
            WTFMove(*bubbles),
            WTFMove(*cancelable),
            WTFMove(*composed)
        }
    };
}


void ArgumentCoder<WebCore::MessageWithMessagePorts>::encode(Encoder& encoder, const WebCore::MessageWithMessagePorts& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message)>, RefPtr<WebCore::SerializedScriptValue>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.transferredPorts)>, Vector<WebCore::TransferredMessagePort>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MessageWithMessagePorts, message)
        , offsetof(WebCore::MessageWithMessagePorts, transferredPorts)
    >::value);
    encoder << instance.message;
    encoder << instance.transferredPorts;
}

std::optional<WebCore::MessageWithMessagePorts> ArgumentCoder<WebCore::MessageWithMessagePorts>::decode(Decoder& decoder)
{
    auto message = decoder.decode<RefPtr<WebCore::SerializedScriptValue>>();
    if (!message)
        return std::nullopt;

    auto transferredPorts = decoder.decode<Vector<WebCore::TransferredMessagePort>>();
    if (!transferredPorts)
        return std::nullopt;

    return {
        WebCore::MessageWithMessagePorts {
            WTFMove(*message),
            WTFMove(*transferredPorts)
        }
    };
}


void ArgumentCoder<WebCore::RequestStorageAccessResult>::encode(Encoder& encoder, const WebCore::RequestStorageAccessResult& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.wasGranted)>, WebCore::StorageAccessWasGranted>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.promptWasShown)>, WebCore::StorageAccessPromptWasShown>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scope)>, WebCore::StorageAccessScope>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topFrameDomain)>, WebCore::RegistrableDomain>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.subFrameDomain)>, WebCore::RegistrableDomain>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::RequestStorageAccessResult, wasGranted)
        , offsetof(WebCore::RequestStorageAccessResult, promptWasShown)
        , offsetof(WebCore::RequestStorageAccessResult, scope)
        , offsetof(WebCore::RequestStorageAccessResult, topFrameDomain)
        , offsetof(WebCore::RequestStorageAccessResult, subFrameDomain)
    >::value);
    encoder << instance.wasGranted;
    encoder << instance.promptWasShown;
    encoder << instance.scope;
    encoder << instance.topFrameDomain;
    encoder << instance.subFrameDomain;
}

std::optional<WebCore::RequestStorageAccessResult> ArgumentCoder<WebCore::RequestStorageAccessResult>::decode(Decoder& decoder)
{
    auto wasGranted = decoder.decode<WebCore::StorageAccessWasGranted>();
    if (!wasGranted)
        return std::nullopt;

    auto promptWasShown = decoder.decode<WebCore::StorageAccessPromptWasShown>();
    if (!promptWasShown)
        return std::nullopt;

    auto scope = decoder.decode<WebCore::StorageAccessScope>();
    if (!scope)
        return std::nullopt;

    auto topFrameDomain = decoder.decode<WebCore::RegistrableDomain>();
    if (!topFrameDomain)
        return std::nullopt;

    auto subFrameDomain = decoder.decode<WebCore::RegistrableDomain>();
    if (!subFrameDomain)
        return std::nullopt;

    return {
        WebCore::RequestStorageAccessResult {
            WTFMove(*wasGranted),
            WTFMove(*promptWasShown),
            WTFMove(*scope),
            WTFMove(*topFrameDomain),
            WTFMove(*subFrameDomain)
        }
    };
}


void ArgumentCoder<WebCore::Exception>::encode(Encoder& encoder, const WebCore::Exception& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.code())>, WebCore::ExceptionCode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message())>, String>);
    encoder << instance.code();
    encoder << instance.message();
}

std::optional<WebCore::Exception> ArgumentCoder<WebCore::Exception>::decode(Decoder& decoder)
{
    auto code = decoder.decode<WebCore::ExceptionCode>();
    if (!code)
        return std::nullopt;

    auto message = decoder.decode<String>();
    if (!message)
        return std::nullopt;

    return {
        WebCore::Exception {
            WTFMove(*code),
            WTFMove(*message)
        }
    };
}


void ArgumentCoder<WebCore::ExceptionData>::encode(Encoder& encoder, const WebCore::ExceptionData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.code)>, WebCore::ExceptionCode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::ExceptionData, code)
        , offsetof(WebCore::ExceptionData, message)
    >::value);
    encoder << instance.code;
    encoder << instance.message;
}

std::optional<WebCore::ExceptionData> ArgumentCoder<WebCore::ExceptionData>::decode(Decoder& decoder)
{
    auto code = decoder.decode<WebCore::ExceptionCode>();
    if (!code)
        return std::nullopt;

    auto message = decoder.decode<String>();
    if (!message)
        return std::nullopt;

    return {
        WebCore::ExceptionData {
            WTFMove(*code),
            WTFMove(*message)
        }
    };
}


void ArgumentCoder<WebCore::MessagePortIdentifier>::encode(Encoder& encoder, const WebCore::MessagePortIdentifier& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.processIdentifier)>, WebCore::ProcessIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.portIdentifier)>, WebCore::PortIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::MessagePortIdentifier, processIdentifier)
        , offsetof(WebCore::MessagePortIdentifier, portIdentifier)
    >::value);
    encoder << instance.processIdentifier;
    encoder << instance.portIdentifier;
}

std::optional<WebCore::MessagePortIdentifier> ArgumentCoder<WebCore::MessagePortIdentifier>::decode(Decoder& decoder)
{
    auto processIdentifier = decoder.decode<WebCore::ProcessIdentifier>();
    if (!processIdentifier)
        return std::nullopt;

    auto portIdentifier = decoder.decode<WebCore::PortIdentifier>();
    if (!portIdentifier)
        return std::nullopt;

    return {
        WebCore::MessagePortIdentifier {
            WTFMove(*processIdentifier),
            WTFMove(*portIdentifier)
        }
    };
}


void ArgumentCoder<WebCore::SecurityPolicyViolationEventInit>::encode(Encoder& encoder, const WebCore::SecurityPolicyViolationEventInit& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bubbles)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cancelable)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.composed)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::EventInit, bubbles)
        , offsetof(WebCore::EventInit, cancelable)
        , offsetof(WebCore::EventInit, composed)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.documentURI)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.referrer)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blockedURI)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.violatedDirective)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.effectiveDirective)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.originalPolicy)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceFile)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sample)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.disposition)>, WebCore::SecurityPolicyViolationEventDisposition>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.statusCode)>, unsigned short>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lineNumber)>, unsigned>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.columnNumber)>, unsigned>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SecurityPolicyViolationEventInit, documentURI)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, referrer)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, blockedURI)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, violatedDirective)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, effectiveDirective)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, originalPolicy)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, sourceFile)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, sample)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, disposition)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, statusCode)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, lineNumber)
        , offsetof(WebCore::SecurityPolicyViolationEventInit, columnNumber)
    >::value);
    encoder << instance.bubbles;
    encoder << instance.cancelable;
    encoder << instance.composed;
    encoder << instance.documentURI;
    encoder << instance.referrer;
    encoder << instance.blockedURI;
    encoder << instance.violatedDirective;
    encoder << instance.effectiveDirective;
    encoder << instance.originalPolicy;
    encoder << instance.sourceFile;
    encoder << instance.sample;
    encoder << instance.disposition;
    encoder << instance.statusCode;
    encoder << instance.lineNumber;
    encoder << instance.columnNumber;
}

std::optional<WebCore::SecurityPolicyViolationEventInit> ArgumentCoder<WebCore::SecurityPolicyViolationEventInit>::decode(Decoder& decoder)
{
    auto bubbles = decoder.decode<bool>();
    if (!bubbles)
        return std::nullopt;

    auto cancelable = decoder.decode<bool>();
    if (!cancelable)
        return std::nullopt;

    auto composed = decoder.decode<bool>();
    if (!composed)
        return std::nullopt;

    auto documentURI = decoder.decode<String>();
    if (!documentURI)
        return std::nullopt;

    auto referrer = decoder.decode<String>();
    if (!referrer)
        return std::nullopt;

    auto blockedURI = decoder.decode<String>();
    if (!blockedURI)
        return std::nullopt;

    auto violatedDirective = decoder.decode<String>();
    if (!violatedDirective)
        return std::nullopt;

    auto effectiveDirective = decoder.decode<String>();
    if (!effectiveDirective)
        return std::nullopt;

    auto originalPolicy = decoder.decode<String>();
    if (!originalPolicy)
        return std::nullopt;

    auto sourceFile = decoder.decode<String>();
    if (!sourceFile)
        return std::nullopt;

    auto sample = decoder.decode<String>();
    if (!sample)
        return std::nullopt;

    auto disposition = decoder.decode<WebCore::SecurityPolicyViolationEventDisposition>();
    if (!disposition)
        return std::nullopt;

    auto statusCode = decoder.decode<unsigned short>();
    if (!statusCode)
        return std::nullopt;

    auto lineNumber = decoder.decode<unsigned>();
    if (!lineNumber)
        return std::nullopt;

    auto columnNumber = decoder.decode<unsigned>();
    if (!columnNumber)
        return std::nullopt;

    return {
        WebCore::SecurityPolicyViolationEventInit {
            WebCore::EventInit {
                WTFMove(*bubbles),
                WTFMove(*cancelable),
                WTFMove(*composed)
            },
            WTFMove(*documentURI),
            WTFMove(*referrer),
            WTFMove(*blockedURI),
            WTFMove(*violatedDirective),
            WTFMove(*effectiveDirective),
            WTFMove(*originalPolicy),
            WTFMove(*sourceFile),
            WTFMove(*sample),
            WTFMove(*disposition),
            WTFMove(*statusCode),
            WTFMove(*lineNumber),
            WTFMove(*columnNumber)
        }
    };
}


void ArgumentCoder<WebCore::CSPViolationReportBody>::encode(Encoder& encoder, const WebCore::CSPViolationReportBody& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.documentURL())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.referrer())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blockedURL())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.effectiveDirective())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.originalPolicy())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceFile())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sample())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.disposition())>, WebCore::SecurityPolicyViolationEventDisposition>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.statusCode())>, unsigned short>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lineNumber())>, unsigned long>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.columnNumber())>, unsigned long>);
    encoder << instance.documentURL();
    encoder << instance.referrer();
    encoder << instance.blockedURL();
    encoder << instance.effectiveDirective();
    encoder << instance.originalPolicy();
    encoder << instance.sourceFile();
    encoder << instance.sample();
    encoder << instance.disposition();
    encoder << instance.statusCode();
    encoder << instance.lineNumber();
    encoder << instance.columnNumber();
}

std::optional<Ref<WebCore::CSPViolationReportBody>> ArgumentCoder<WebCore::CSPViolationReportBody>::decode(Decoder& decoder)
{
    auto documentURL = decoder.decode<String>();
    if (!documentURL)
        return std::nullopt;

    auto referrer = decoder.decode<String>();
    if (!referrer)
        return std::nullopt;

    auto blockedURL = decoder.decode<String>();
    if (!blockedURL)
        return std::nullopt;

    auto effectiveDirective = decoder.decode<String>();
    if (!effectiveDirective)
        return std::nullopt;

    auto originalPolicy = decoder.decode<String>();
    if (!originalPolicy)
        return std::nullopt;

    auto sourceFile = decoder.decode<String>();
    if (!sourceFile)
        return std::nullopt;

    auto sample = decoder.decode<String>();
    if (!sample)
        return std::nullopt;

    auto disposition = decoder.decode<WebCore::SecurityPolicyViolationEventDisposition>();
    if (!disposition)
        return std::nullopt;

    auto statusCode = decoder.decode<unsigned short>();
    if (!statusCode)
        return std::nullopt;

    auto lineNumber = decoder.decode<unsigned long>();
    if (!lineNumber)
        return std::nullopt;

    auto columnNumber = decoder.decode<unsigned long>();
    if (!columnNumber)
        return std::nullopt;

    return {
        WebCore::CSPViolationReportBody::create(
            WTFMove(*documentURL),
            WTFMove(*referrer),
            WTFMove(*blockedURL),
            WTFMove(*effectiveDirective),
            WTFMove(*originalPolicy),
            WTFMove(*sourceFile),
            WTFMove(*sample),
            WTFMove(*disposition),
            WTFMove(*statusCode),
            WTFMove(*lineNumber),
            WTFMove(*columnNumber)
        )
    };
}


void ArgumentCoder<WebCore::SecurityOriginData>::encode(Encoder& encoder, const WebCore::SecurityOriginData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.data())>, std::variant<WebCore::SecurityOriginData::Tuple, WebCore::ProcessQualified<WebCore::OpaqueOriginIdentifier>>>);
    encoder << instance.data();
}

std::optional<WebCore::SecurityOriginData> ArgumentCoder<WebCore::SecurityOriginData>::decode(Decoder& decoder)
{
    auto data = decoder.decode<std::variant<WebCore::SecurityOriginData::Tuple, WebCore::ProcessQualified<WebCore::OpaqueOriginIdentifier>>>();
    if (!data)
        return std::nullopt;

    return {
        WebCore::SecurityOriginData {
            WTFMove(*data)
        }
    };
}


void ArgumentCoder<WebCore::SecurityOriginData::Tuple>::encode(Encoder& encoder, const WebCore::SecurityOriginData::Tuple& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.protocol)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.host)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.port)>, std::optional<uint16_t>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebCore::SecurityOriginData::Tuple, protocol)
        , offsetof(WebCore::SecurityOriginData::Tuple, host)
        , offsetof(WebCore::SecurityOriginData::Tuple, port)
    >::value);
    encoder << instance.protocol;
    encoder << instance.host;
    encoder << instance.port;
}

std::optional<WebCore::SecurityOriginData::Tuple> ArgumentCoder<WebCore::SecurityOriginData::Tuple>::decode(Decoder& decoder)
{
    auto protocol = decoder.decode<String>();
    if (!protocol)
        return std::nullopt;

    if (!(!protocol->isHashTableDeletedValue()))
        return std::nullopt;

    auto host = decoder.decode<String>();
    if (!host)
        return std::nullopt;

    auto port = decoder.decode<std::optional<uint16_t>>();
    if (!port)
        return std::nullopt;

    return {
        WebCore::SecurityOriginData::Tuple {
            WTFMove(*protocol),
            WTFMove(*host),
            WTFMove(*port)
        }
    };
}


void ArgumentCoder<WebKit::WebEvent>::encode(Encoder& encoder, const WebKit::WebEvent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebKit::WebEventType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.modifiers())>, OptionSet<WebKit::WebEventModifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestamp())>, WallTime>);
    encoder << instance.type();
    encoder << instance.modifiers();
    encoder << instance.timestamp();
}

std::optional<WebKit::WebEvent> ArgumentCoder<WebKit::WebEvent>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebKit::WebEventType>();
    if (!type)
        return std::nullopt;

    auto modifiers = decoder.decode<OptionSet<WebKit::WebEventModifier>>();
    if (!modifiers)
        return std::nullopt;

    auto timestamp = decoder.decode<WallTime>();
    if (!timestamp)
        return std::nullopt;

    return {
        WebKit::WebEvent {
            WTFMove(*type),
            WTFMove(*modifiers),
            WTFMove(*timestamp)
        }
    };
}


void ArgumentCoder<WebKit::WebKeyboardEvent>::encode(Encoder& encoder, const WebKit::WebKeyboardEvent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebKit::WebEventType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.modifiers())>, OptionSet<WebKit::WebEventModifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestamp())>, WallTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.text())>, String>);
#if !PLATFORM(GTK) && !USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.unmodifiedText())>, String>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.key())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.code())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.keyIdentifier())>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.windowsVirtualKeyCode())>, int32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.nativeVirtualKeyCode())>, int32_t>);
#if !PLATFORM(GTK) && !USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.macCharCode())>, int32_t>);
#endif
#if USE(APPKIT) || PLATFORM(IOS_FAMILY) || PLATFORM(GTK) || USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.handledByInputMethod())>, bool>);
#endif
#if PLATFORM(GTK) || USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preeditUnderlines())>, std::optional<Vector<WebCore::CompositionUnderline>>>);
#endif
#if PLATFORM(GTK) || USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.preeditSelectionRange())>, std::optional<WebKit::EditingRange>>);
#endif
#if USE(APPKIT)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.commands())>, Vector<WebCore::KeypressCommand>>);
#endif
#if !USE(APPKIT) && PLATFORM(GTK)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.commands())>, Vector<String>>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isAutoRepeat())>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isKeypad())>, bool>);
#if !PLATFORM(GTK) && !USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isSystemKey())>, bool>);
#endif
    encoder << instance.type();
    encoder << instance.modifiers();
    encoder << instance.timestamp();
    encoder << instance.text();
#if !PLATFORM(GTK) && !USE(LIBWPE)
    encoder << instance.unmodifiedText();
#endif
    encoder << instance.key();
    encoder << instance.code();
    encoder << instance.keyIdentifier();
    encoder << instance.windowsVirtualKeyCode();
    encoder << instance.nativeVirtualKeyCode();
#if !PLATFORM(GTK) && !USE(LIBWPE)
    encoder << instance.macCharCode();
#endif
#if USE(APPKIT) || PLATFORM(IOS_FAMILY) || PLATFORM(GTK) || USE(LIBWPE)
    encoder << instance.handledByInputMethod();
#endif
#if PLATFORM(GTK) || USE(LIBWPE)
    encoder << instance.preeditUnderlines();
#endif
#if PLATFORM(GTK) || USE(LIBWPE)
    encoder << instance.preeditSelectionRange();
#endif
#if USE(APPKIT)
    encoder << instance.commands();
#endif
#if !USE(APPKIT) && PLATFORM(GTK)
    encoder << instance.commands();
#endif
    encoder << instance.isAutoRepeat();
    encoder << instance.isKeypad();
#if !PLATFORM(GTK) && !USE(LIBWPE)
    encoder << instance.isSystemKey();
#endif
}

std::optional<WebKit::WebKeyboardEvent> ArgumentCoder<WebKit::WebKeyboardEvent>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebKit::WebEventType>();
    if (!type)
        return std::nullopt;

    auto modifiers = decoder.decode<OptionSet<WebKit::WebEventModifier>>();
    if (!modifiers)
        return std::nullopt;

    auto timestamp = decoder.decode<WallTime>();
    if (!timestamp)
        return std::nullopt;

    auto text = decoder.decode<String>();
    if (!text)
        return std::nullopt;

#if !PLATFORM(GTK) && !USE(LIBWPE)
    auto unmodifiedText = decoder.decode<String>();
    if (!unmodifiedText)
        return std::nullopt;
#endif

    auto key = decoder.decode<String>();
    if (!key)
        return std::nullopt;

    auto code = decoder.decode<String>();
    if (!code)
        return std::nullopt;

    auto keyIdentifier = decoder.decode<String>();
    if (!keyIdentifier)
        return std::nullopt;

    auto windowsVirtualKeyCode = decoder.decode<int32_t>();
    if (!windowsVirtualKeyCode)
        return std::nullopt;

    auto nativeVirtualKeyCode = decoder.decode<int32_t>();
    if (!nativeVirtualKeyCode)
        return std::nullopt;

#if !PLATFORM(GTK) && !USE(LIBWPE)
    auto macCharCode = decoder.decode<int32_t>();
    if (!macCharCode)
        return std::nullopt;
#endif

#if USE(APPKIT) || PLATFORM(IOS_FAMILY) || PLATFORM(GTK) || USE(LIBWPE)
    auto handledByInputMethod = decoder.decode<bool>();
    if (!handledByInputMethod)
        return std::nullopt;
#endif

#if PLATFORM(GTK) || USE(LIBWPE)
    auto preeditUnderlines = decoder.decode<std::optional<Vector<WebCore::CompositionUnderline>>>();
    if (!preeditUnderlines)
        return std::nullopt;
#endif

#if PLATFORM(GTK) || USE(LIBWPE)
    auto preeditSelectionRange = decoder.decode<std::optional<WebKit::EditingRange>>();
    if (!preeditSelectionRange)
        return std::nullopt;
#endif

#if USE(APPKIT)
    auto commands = decoder.decode<Vector<WebCore::KeypressCommand>>();
    if (!commands)
        return std::nullopt;
#endif

#if !USE(APPKIT) && PLATFORM(GTK)
    auto commands = decoder.decode<Vector<String>>();
    if (!commands)
        return std::nullopt;
#endif

    auto isAutoRepeat = decoder.decode<bool>();
    if (!isAutoRepeat)
        return std::nullopt;

    auto isKeypad = decoder.decode<bool>();
    if (!isKeypad)
        return std::nullopt;

#if !PLATFORM(GTK) && !USE(LIBWPE)
    auto isSystemKey = decoder.decode<bool>();
    if (!isSystemKey)
        return std::nullopt;
#endif

    return {
        WebKit::WebKeyboardEvent {
            WebKit::WebEvent {
                WTFMove(*type),
                WTFMove(*modifiers),
                WTFMove(*timestamp)
            },
            WTFMove(*text),
#if !PLATFORM(GTK) && !USE(LIBWPE)
            WTFMove(*unmodifiedText),
#endif
            WTFMove(*key),
            WTFMove(*code),
            WTFMove(*keyIdentifier),
            WTFMove(*windowsVirtualKeyCode),
            WTFMove(*nativeVirtualKeyCode),
#if !PLATFORM(GTK) && !USE(LIBWPE)
            WTFMove(*macCharCode),
#endif
#if USE(APPKIT) || PLATFORM(IOS_FAMILY) || PLATFORM(GTK) || USE(LIBWPE)
            WTFMove(*handledByInputMethod),
#endif
#if PLATFORM(GTK) || USE(LIBWPE)
            WTFMove(*preeditUnderlines),
#endif
#if PLATFORM(GTK) || USE(LIBWPE)
            WTFMove(*preeditSelectionRange),
#endif
#if USE(APPKIT)
            WTFMove(*commands),
#endif
#if !USE(APPKIT) && PLATFORM(GTK)
            WTFMove(*commands),
#endif
            WTFMove(*isAutoRepeat),
            WTFMove(*isKeypad),
#if !PLATFORM(GTK) && !USE(LIBWPE)
            WTFMove(*isSystemKey)
#endif
        }
    };
}

#if ENABLE(TOUCH_EVENTS)

void ArgumentCoder<WebKit::WebTouchEvent>::encode(Encoder& encoder, const WebKit::WebTouchEvent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebKit::WebEventType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.modifiers())>, OptionSet<WebKit::WebEventModifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestamp())>, WallTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.touchPoints())>, Vector<WebKit::WebPlatformTouchPoint>>);
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, WebCore::IntPoint>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isPotentialTap())>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isGesture())>, bool>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gestureScale())>, float>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gestureRotation())>, float>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canPreventNativeGestures())>, bool>);
#endif
    encoder << instance.type();
    encoder << instance.modifiers();
    encoder << instance.timestamp();
    encoder << instance.touchPoints();
#if PLATFORM(IOS_FAMILY)
    encoder << instance.position();
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.isPotentialTap();
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.isGesture();
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.gestureScale();
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.gestureRotation();
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.canPreventNativeGestures();
#endif
}

std::optional<WebKit::WebTouchEvent> ArgumentCoder<WebKit::WebTouchEvent>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebKit::WebEventType>();
    if (!type)
        return std::nullopt;

    auto modifiers = decoder.decode<OptionSet<WebKit::WebEventModifier>>();
    if (!modifiers)
        return std::nullopt;

    auto timestamp = decoder.decode<WallTime>();
    if (!timestamp)
        return std::nullopt;

    auto touchPoints = decoder.decode<Vector<WebKit::WebPlatformTouchPoint>>();
    if (!touchPoints)
        return std::nullopt;

#if PLATFORM(IOS_FAMILY)
    auto position = decoder.decode<WebCore::IntPoint>();
    if (!position)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto isPotentialTap = decoder.decode<bool>();
    if (!isPotentialTap)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto isGesture = decoder.decode<bool>();
    if (!isGesture)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto gestureScale = decoder.decode<float>();
    if (!gestureScale)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto gestureRotation = decoder.decode<float>();
    if (!gestureRotation)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto canPreventNativeGestures = decoder.decode<bool>();
    if (!canPreventNativeGestures)
        return std::nullopt;
#endif

    return {
        WebKit::WebTouchEvent {
            WebKit::WebEvent {
                WTFMove(*type),
                WTFMove(*modifiers),
                WTFMove(*timestamp)
            },
            WTFMove(*touchPoints),
#if PLATFORM(IOS_FAMILY)
            WTFMove(*position),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*isPotentialTap),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*isGesture),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*gestureScale),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*gestureRotation),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*canPreventNativeGestures)
#endif
        }
    };
}

#endif


void ArgumentCoder<WebKit::WebMouseEvent>::encode(Encoder& encoder, const WebKit::WebMouseEvent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebKit::WebEventType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.modifiers())>, OptionSet<WebKit::WebEventModifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestamp())>, WallTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.button())>, WebKit::WebMouseEventButton>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buttons())>, unsigned short>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.globalPosition())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.deltaX())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.deltaY())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.deltaZ())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clickCount())>, int32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.force())>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.syntheticClickType())>, WebKit::WebMouseEventSyntheticClickType>);
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.eventNumber())>, int32_t>);
#endif
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.menuTypeForEvent())>, int32_t>);
#endif
#if !PLATFORM(MAC) && PLATFORM(GTK)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isTouchEvent())>, WebCore::PlatformMouseEvent::IsTouch>);
#endif
#if !PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pointerId())>, WebCore::PointerID>);
#endif
#if !PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pointerType())>, String>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gestureWasCancelled())>, WebKit::GestureWasCancelled>);
    encoder << instance.type();
    encoder << instance.modifiers();
    encoder << instance.timestamp();
    encoder << instance.button();
    encoder << instance.buttons();
    encoder << instance.position();
    encoder << instance.globalPosition();
    encoder << instance.deltaX();
    encoder << instance.deltaY();
    encoder << instance.deltaZ();
    encoder << instance.clickCount();
    encoder << instance.force();
    encoder << instance.syntheticClickType();
#if PLATFORM(MAC)
    encoder << instance.eventNumber();
#endif
#if PLATFORM(MAC)
    encoder << instance.menuTypeForEvent();
#endif
#if !PLATFORM(MAC) && PLATFORM(GTK)
    encoder << instance.isTouchEvent();
#endif
#if !PLATFORM(MAC)
    encoder << instance.pointerId();
#endif
#if !PLATFORM(MAC)
    encoder << instance.pointerType();
#endif
    encoder << instance.gestureWasCancelled();
}

std::optional<WebKit::WebMouseEvent> ArgumentCoder<WebKit::WebMouseEvent>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebKit::WebEventType>();
    if (!type)
        return std::nullopt;

    auto modifiers = decoder.decode<OptionSet<WebKit::WebEventModifier>>();
    if (!modifiers)
        return std::nullopt;

    auto timestamp = decoder.decode<WallTime>();
    if (!timestamp)
        return std::nullopt;

    auto button = decoder.decode<WebKit::WebMouseEventButton>();
    if (!button)
        return std::nullopt;

    auto buttons = decoder.decode<unsigned short>();
    if (!buttons)
        return std::nullopt;

    auto position = decoder.decode<WebCore::IntPoint>();
    if (!position)
        return std::nullopt;

    auto globalPosition = decoder.decode<WebCore::IntPoint>();
    if (!globalPosition)
        return std::nullopt;

    auto deltaX = decoder.decode<float>();
    if (!deltaX)
        return std::nullopt;

    auto deltaY = decoder.decode<float>();
    if (!deltaY)
        return std::nullopt;

    auto deltaZ = decoder.decode<float>();
    if (!deltaZ)
        return std::nullopt;

    auto clickCount = decoder.decode<int32_t>();
    if (!clickCount)
        return std::nullopt;

    auto force = decoder.decode<double>();
    if (!force)
        return std::nullopt;

    auto syntheticClickType = decoder.decode<WebKit::WebMouseEventSyntheticClickType>();
    if (!syntheticClickType)
        return std::nullopt;

#if PLATFORM(MAC)
    auto eventNumber = decoder.decode<int32_t>();
    if (!eventNumber)
        return std::nullopt;
#endif

#if PLATFORM(MAC)
    auto menuTypeForEvent = decoder.decode<int32_t>();
    if (!menuTypeForEvent)
        return std::nullopt;
#endif

#if !PLATFORM(MAC) && PLATFORM(GTK)
    auto isTouchEvent = decoder.decode<WebCore::PlatformMouseEvent::IsTouch>();
    if (!isTouchEvent)
        return std::nullopt;
#endif

#if !PLATFORM(MAC)
    auto pointerId = decoder.decode<WebCore::PointerID>();
    if (!pointerId)
        return std::nullopt;
#endif

#if !PLATFORM(MAC)
    auto pointerType = decoder.decode<String>();
    if (!pointerType)
        return std::nullopt;
#endif

    auto gestureWasCancelled = decoder.decode<WebKit::GestureWasCancelled>();
    if (!gestureWasCancelled)
        return std::nullopt;

    return {
        WebKit::WebMouseEvent {
            WebKit::WebEvent {
                WTFMove(*type),
                WTFMove(*modifiers),
                WTFMove(*timestamp)
            },
            WTFMove(*button),
            WTFMove(*buttons),
            WTFMove(*position),
            WTFMove(*globalPosition),
            WTFMove(*deltaX),
            WTFMove(*deltaY),
            WTFMove(*deltaZ),
            WTFMove(*clickCount),
            WTFMove(*force),
            WTFMove(*syntheticClickType),
#if PLATFORM(MAC)
            WTFMove(*eventNumber),
#endif
#if PLATFORM(MAC)
            WTFMove(*menuTypeForEvent),
#endif
#if !PLATFORM(MAC) && PLATFORM(GTK)
            WTFMove(*isTouchEvent),
#endif
#if !PLATFORM(MAC)
            WTFMove(*pointerId),
#endif
#if !PLATFORM(MAC)
            WTFMove(*pointerType),
#endif
            WTFMove(*gestureWasCancelled)
        }
    };
}

#if ENABLE(MAC_GESTURE_EVENTS)

void ArgumentCoder<WebKit::WebGestureEvent>::encode(Encoder& encoder, const WebKit::WebGestureEvent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebKit::WebEventType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.modifiers())>, OptionSet<WebKit::WebEventModifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestamp())>, WallTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gestureScale())>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.gestureRotation())>, float>);
    encoder << instance.type();
    encoder << instance.modifiers();
    encoder << instance.timestamp();
    encoder << instance.position();
    encoder << instance.gestureScale();
    encoder << instance.gestureRotation();
}

std::optional<WebKit::WebGestureEvent> ArgumentCoder<WebKit::WebGestureEvent>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebKit::WebEventType>();
    if (!type)
        return std::nullopt;

    auto modifiers = decoder.decode<OptionSet<WebKit::WebEventModifier>>();
    if (!modifiers)
        return std::nullopt;

    auto timestamp = decoder.decode<WallTime>();
    if (!timestamp)
        return std::nullopt;

    auto position = decoder.decode<WebCore::IntPoint>();
    if (!position)
        return std::nullopt;

    auto gestureScale = decoder.decode<float>();
    if (!gestureScale)
        return std::nullopt;

    auto gestureRotation = decoder.decode<float>();
    if (!gestureRotation)
        return std::nullopt;

    return {
        WebKit::WebGestureEvent {
            WebKit::WebEvent {
                WTFMove(*type),
                WTFMove(*modifiers),
                WTFMove(*timestamp)
            },
            WTFMove(*position),
            WTFMove(*gestureScale),
            WTFMove(*gestureRotation)
        }
    };
}

#endif


void ArgumentCoder<WebKit::WebWheelEvent>::encode(Encoder& encoder, const WebKit::WebWheelEvent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type())>, WebKit::WebEventType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.modifiers())>, OptionSet<WebKit::WebEventModifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestamp())>, WallTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.position())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.globalPosition())>, WebCore::IntPoint>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.delta())>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.wheelTicks())>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.granularity())>, WebKit::WebWheelEvent::Granularity>);
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.directionInvertedFromDevice())>, bool>);
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.phase())>, WebKit::WebWheelEvent::Phase>);
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.momentumPhase())>, WebKit::WebWheelEvent::Phase>);
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasPreciseScrollingDeltas())>, bool>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.scrollCount())>, uint32_t>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.unacceleratedScrollingDelta())>, WebCore::FloatSize>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.ioHIDEventTimestamp())>, WallTime>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rawPlatformDelta())>, std::optional<WebCore::FloatSize>>);
#endif
#if PLATFORM(COCOA)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.momentumEndType())>, WebKit::WebWheelEvent::MomentumEndType>);
#endif
    encoder << instance.type();
    encoder << instance.modifiers();
    encoder << instance.timestamp();
    encoder << instance.position();
    encoder << instance.globalPosition();
    encoder << instance.delta();
    encoder << instance.wheelTicks();
    encoder << instance.granularity();
#if PLATFORM(COCOA)
    encoder << instance.directionInvertedFromDevice();
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
    encoder << instance.phase();
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
    encoder << instance.momentumPhase();
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
    encoder << instance.hasPreciseScrollingDeltas();
#endif
#if PLATFORM(COCOA)
    encoder << instance.scrollCount();
#endif
#if PLATFORM(COCOA)
    encoder << instance.unacceleratedScrollingDelta();
#endif
#if PLATFORM(COCOA)
    encoder << instance.ioHIDEventTimestamp();
#endif
#if PLATFORM(COCOA)
    encoder << instance.rawPlatformDelta();
#endif
#if PLATFORM(COCOA)
    encoder << instance.momentumEndType();
#endif
}

std::optional<WebKit::WebWheelEvent> ArgumentCoder<WebKit::WebWheelEvent>::decode(Decoder& decoder)
{
    auto type = decoder.decode<WebKit::WebEventType>();
    if (!type)
        return std::nullopt;

    auto modifiers = decoder.decode<OptionSet<WebKit::WebEventModifier>>();
    if (!modifiers)
        return std::nullopt;

    auto timestamp = decoder.decode<WallTime>();
    if (!timestamp)
        return std::nullopt;

    auto position = decoder.decode<WebCore::IntPoint>();
    if (!position)
        return std::nullopt;

    auto globalPosition = decoder.decode<WebCore::IntPoint>();
    if (!globalPosition)
        return std::nullopt;

    auto delta = decoder.decode<WebCore::FloatSize>();
    if (!delta)
        return std::nullopt;

    auto wheelTicks = decoder.decode<WebCore::FloatSize>();
    if (!wheelTicks)
        return std::nullopt;

    auto granularity = decoder.decode<WebKit::WebWheelEvent::Granularity>();
    if (!granularity)
        return std::nullopt;

#if PLATFORM(COCOA)
    auto directionInvertedFromDevice = decoder.decode<bool>();
    if (!directionInvertedFromDevice)
        return std::nullopt;
#endif

#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
    auto phase = decoder.decode<WebKit::WebWheelEvent::Phase>();
    if (!phase)
        return std::nullopt;
#endif

#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
    auto momentumPhase = decoder.decode<WebKit::WebWheelEvent::Phase>();
    if (!momentumPhase)
        return std::nullopt;
#endif

#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
    auto hasPreciseScrollingDeltas = decoder.decode<bool>();
    if (!hasPreciseScrollingDeltas)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto scrollCount = decoder.decode<uint32_t>();
    if (!scrollCount)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto unacceleratedScrollingDelta = decoder.decode<WebCore::FloatSize>();
    if (!unacceleratedScrollingDelta)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto ioHIDEventTimestamp = decoder.decode<WallTime>();
    if (!ioHIDEventTimestamp)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto rawPlatformDelta = decoder.decode<std::optional<WebCore::FloatSize>>();
    if (!rawPlatformDelta)
        return std::nullopt;
#endif

#if PLATFORM(COCOA)
    auto momentumEndType = decoder.decode<WebKit::WebWheelEvent::MomentumEndType>();
    if (!momentumEndType)
        return std::nullopt;
#endif

    return {
        WebKit::WebWheelEvent {
            WebKit::WebEvent {
                WTFMove(*type),
                WTFMove(*modifiers),
                WTFMove(*timestamp)
            },
            WTFMove(*position),
            WTFMove(*globalPosition),
            WTFMove(*delta),
            WTFMove(*wheelTicks),
            WTFMove(*granularity),
#if PLATFORM(COCOA)
            WTFMove(*directionInvertedFromDevice),
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
            WTFMove(*phase),
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
            WTFMove(*momentumPhase),
#endif
#if PLATFORM(COCOA) || PLATFORM(GTK) || USE(LIBWPE)
            WTFMove(*hasPreciseScrollingDeltas),
#endif
#if PLATFORM(COCOA)
            WTFMove(*scrollCount),
#endif
#if PLATFORM(COCOA)
            WTFMove(*unacceleratedScrollingDelta),
#endif
#if PLATFORM(COCOA)
            WTFMove(*ioHIDEventTimestamp),
#endif
#if PLATFORM(COCOA)
            WTFMove(*rawPlatformDelta),
#endif
#if PLATFORM(COCOA)
            WTFMove(*momentumEndType)
#endif
        }
    };
}


void ArgumentCoder<WebKit::WebHitTestResultData>::encode(Encoder& encoder, const WebKit::WebHitTestResultData& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.absoluteImageURL)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.absolutePDFURL)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.absoluteLinkURL)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.absoluteMediaURL)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.linkLabel)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.linkTitle)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.linkSuggestedFilename)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isContentEditable)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.elementBoundingBox)>, WebCore::IntRect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isScrollbar)>, WebKit::WebHitTestResultData::IsScrollbar>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isSelected)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isTextNode)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isOverTextInsideFormControlElement)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isDownloadableMedia)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lookupText)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.toolTipText)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.imageText)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.getImageSharedMemoryHandle())>, std::optional<WebKit::SharedMemory::Handle>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.imageBitmap)>, RefPtr<WebKit::ShareableBitmap>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sourceImageMIMEType)>, String>);
#if PLATFORM(MAC)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.platformData)>, WebKit::WebHitTestResultPlatformData>);
#endif
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dictionaryPopupInfo)>, WebCore::DictionaryPopupInfo>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.linkTextIndicator)>, RefPtr<WebCore::TextIndicator>>);
    encoder << instance.absoluteImageURL;
    encoder << instance.absolutePDFURL;
    encoder << instance.absoluteLinkURL;
    encoder << instance.absoluteMediaURL;
    encoder << instance.linkLabel;
    encoder << instance.linkTitle;
    encoder << instance.linkSuggestedFilename;
    encoder << instance.isContentEditable;
    encoder << instance.elementBoundingBox;
    encoder << instance.isScrollbar;
    encoder << instance.isSelected;
    encoder << instance.isTextNode;
    encoder << instance.isOverTextInsideFormControlElement;
    encoder << instance.isDownloadableMedia;
    encoder << instance.lookupText;
    encoder << instance.toolTipText;
    encoder << instance.imageText;
    encoder << instance.getImageSharedMemoryHandle();
    encoder << instance.imageBitmap;
    encoder << instance.sourceImageMIMEType;
#if PLATFORM(MAC)
    encoder << instance.platformData;
#endif
    encoder << instance.dictionaryPopupInfo;
    encoder << instance.linkTextIndicator;
}

std::optional<WebKit::WebHitTestResultData> ArgumentCoder<WebKit::WebHitTestResultData>::decode(Decoder& decoder)
{
    auto absoluteImageURL = decoder.decode<String>();
    if (!absoluteImageURL)
        return std::nullopt;

    auto absolutePDFURL = decoder.decode<String>();
    if (!absolutePDFURL)
        return std::nullopt;

    auto absoluteLinkURL = decoder.decode<String>();
    if (!absoluteLinkURL)
        return std::nullopt;

    auto absoluteMediaURL = decoder.decode<String>();
    if (!absoluteMediaURL)
        return std::nullopt;

    auto linkLabel = decoder.decode<String>();
    if (!linkLabel)
        return std::nullopt;

    auto linkTitle = decoder.decode<String>();
    if (!linkTitle)
        return std::nullopt;

    auto linkSuggestedFilename = decoder.decode<String>();
    if (!linkSuggestedFilename)
        return std::nullopt;

    auto isContentEditable = decoder.decode<bool>();
    if (!isContentEditable)
        return std::nullopt;

    auto elementBoundingBox = decoder.decode<WebCore::IntRect>();
    if (!elementBoundingBox)
        return std::nullopt;

    auto isScrollbar = decoder.decode<WebKit::WebHitTestResultData::IsScrollbar>();
    if (!isScrollbar)
        return std::nullopt;

    auto isSelected = decoder.decode<bool>();
    if (!isSelected)
        return std::nullopt;

    auto isTextNode = decoder.decode<bool>();
    if (!isTextNode)
        return std::nullopt;

    auto isOverTextInsideFormControlElement = decoder.decode<bool>();
    if (!isOverTextInsideFormControlElement)
        return std::nullopt;

    auto isDownloadableMedia = decoder.decode<bool>();
    if (!isDownloadableMedia)
        return std::nullopt;

    auto lookupText = decoder.decode<String>();
    if (!lookupText)
        return std::nullopt;

    auto toolTipText = decoder.decode<String>();
    if (!toolTipText)
        return std::nullopt;

    auto imageText = decoder.decode<String>();
    if (!imageText)
        return std::nullopt;

    auto getImageSharedMemoryHandle = decoder.decode<std::optional<WebKit::SharedMemory::Handle>>();
    if (!getImageSharedMemoryHandle)
        return std::nullopt;

    auto imageBitmap = decoder.decode<RefPtr<WebKit::ShareableBitmap>>();
    if (!imageBitmap)
        return std::nullopt;

    auto sourceImageMIMEType = decoder.decode<String>();
    if (!sourceImageMIMEType)
        return std::nullopt;

#if PLATFORM(MAC)
    auto platformData = decoder.decode<WebKit::WebHitTestResultPlatformData>();
    if (!platformData)
        return std::nullopt;
#endif

    auto dictionaryPopupInfo = decoder.decode<WebCore::DictionaryPopupInfo>();
    if (!dictionaryPopupInfo)
        return std::nullopt;

    auto linkTextIndicator = decoder.decode<RefPtr<WebCore::TextIndicator>>();
    if (!linkTextIndicator)
        return std::nullopt;

    return {
        WebKit::WebHitTestResultData {
            WTFMove(*absoluteImageURL),
            WTFMove(*absolutePDFURL),
            WTFMove(*absoluteLinkURL),
            WTFMove(*absoluteMediaURL),
            WTFMove(*linkLabel),
            WTFMove(*linkTitle),
            WTFMove(*linkSuggestedFilename),
            WTFMove(*isContentEditable),
            WTFMove(*elementBoundingBox),
            WTFMove(*isScrollbar),
            WTFMove(*isSelected),
            WTFMove(*isTextNode),
            WTFMove(*isOverTextInsideFormControlElement),
            WTFMove(*isDownloadableMedia),
            WTFMove(*lookupText),
            WTFMove(*toolTipText),
            WTFMove(*imageText),
            WTFMove(*getImageSharedMemoryHandle),
            WTFMove(*imageBitmap),
            WTFMove(*sourceImageMIMEType),
#if PLATFORM(MAC)
            WTFMove(*platformData),
#endif
            WTFMove(*dictionaryPopupInfo),
            WTFMove(*linkTextIndicator)
        }
    };
}


void ArgumentCoder<WebKit::WebPopupItem>::encode(Encoder& encoder, const WebKit::WebPopupItem& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_type)>, WebKit::WebPopupItem::Type>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_text)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_textDirection)>, WebCore::TextDirection>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_hasTextDirectionOverride)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_toolTip)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_accessibilityText)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isEnabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isLabel)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_isSelected)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebPopupItem, m_type)
        , offsetof(WebKit::WebPopupItem, m_text)
        , offsetof(WebKit::WebPopupItem, m_textDirection)
        , offsetof(WebKit::WebPopupItem, m_hasTextDirectionOverride)
        , offsetof(WebKit::WebPopupItem, m_toolTip)
        , offsetof(WebKit::WebPopupItem, m_accessibilityText)
        , offsetof(WebKit::WebPopupItem, m_isEnabled)
        , offsetof(WebKit::WebPopupItem, m_isLabel)
        , offsetof(WebKit::WebPopupItem, m_isSelected)
    >::value);
    encoder << instance.m_type;
    encoder << instance.m_text;
    encoder << instance.m_textDirection;
    encoder << instance.m_hasTextDirectionOverride;
    encoder << instance.m_toolTip;
    encoder << instance.m_accessibilityText;
    encoder << instance.m_isEnabled;
    encoder << instance.m_isLabel;
    encoder << instance.m_isSelected;
}

std::optional<WebKit::WebPopupItem> ArgumentCoder<WebKit::WebPopupItem>::decode(Decoder& decoder)
{
    auto m_type = decoder.decode<WebKit::WebPopupItem::Type>();
    if (!m_type)
        return std::nullopt;

    auto m_text = decoder.decode<String>();
    if (!m_text)
        return std::nullopt;

    auto m_textDirection = decoder.decode<WebCore::TextDirection>();
    if (!m_textDirection)
        return std::nullopt;

    auto m_hasTextDirectionOverride = decoder.decode<bool>();
    if (!m_hasTextDirectionOverride)
        return std::nullopt;

    auto m_toolTip = decoder.decode<String>();
    if (!m_toolTip)
        return std::nullopt;

    auto m_accessibilityText = decoder.decode<String>();
    if (!m_accessibilityText)
        return std::nullopt;

    auto m_isEnabled = decoder.decode<bool>();
    if (!m_isEnabled)
        return std::nullopt;

    auto m_isLabel = decoder.decode<bool>();
    if (!m_isLabel)
        return std::nullopt;

    auto m_isSelected = decoder.decode<bool>();
    if (!m_isSelected)
        return std::nullopt;

    return {
        WebKit::WebPopupItem {
            WTFMove(*m_type),
            WTFMove(*m_text),
            WTFMove(*m_textDirection),
            WTFMove(*m_hasTextDirectionOverride),
            WTFMove(*m_toolTip),
            WTFMove(*m_accessibilityText),
            WTFMove(*m_isEnabled),
            WTFMove(*m_isLabel),
            WTFMove(*m_isSelected)
        }
    };
}


void ArgumentCoder<WebKit::WebPushD::WebPushDaemonConnectionConfiguration>::encode(Encoder& encoder, const WebKit::WebPushD::WebPushDaemonConnectionConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.useMockBundlesForTesting)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hostAppAuditTokenData)>, std::optional<Vector<uint8_t>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pushPartitionString)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dataStoreIdentifier)>, std::optional<UUID>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebPushD::WebPushDaemonConnectionConfiguration, useMockBundlesForTesting)
        , offsetof(WebKit::WebPushD::WebPushDaemonConnectionConfiguration, hostAppAuditTokenData)
        , offsetof(WebKit::WebPushD::WebPushDaemonConnectionConfiguration, pushPartitionString)
        , offsetof(WebKit::WebPushD::WebPushDaemonConnectionConfiguration, dataStoreIdentifier)
    >::value);
    encoder << instance.useMockBundlesForTesting;
    encoder << instance.hostAppAuditTokenData;
    encoder << instance.pushPartitionString;
    encoder << instance.dataStoreIdentifier;
}

std::optional<WebKit::WebPushD::WebPushDaemonConnectionConfiguration> ArgumentCoder<WebKit::WebPushD::WebPushDaemonConnectionConfiguration>::decode(Decoder& decoder)
{
    auto useMockBundlesForTesting = decoder.decode<bool>();
    if (!useMockBundlesForTesting)
        return std::nullopt;

    auto hostAppAuditTokenData = decoder.decode<std::optional<Vector<uint8_t>>>();
    if (!hostAppAuditTokenData)
        return std::nullopt;

    auto pushPartitionString = decoder.decode<String>();
    if (!pushPartitionString)
        return std::nullopt;

    auto dataStoreIdentifier = decoder.decode<std::optional<UUID>>();
    if (!dataStoreIdentifier)
        return std::nullopt;

    return {
        WebKit::WebPushD::WebPushDaemonConnectionConfiguration {
            WTFMove(*useMockBundlesForTesting),
            WTFMove(*hostAppAuditTokenData),
            WTFMove(*pushPartitionString),
            WTFMove(*dataStoreIdentifier)
        }
    };
}


void ArgumentCoder<WebKit::WebPushMessage>::encode(Encoder& encoder, const WebKit::WebPushMessage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pushData)>, std::optional<Vector<uint8_t>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pushPartitionString)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.registrationURL)>, URL>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebPushMessage, pushData)
        , offsetof(WebKit::WebPushMessage, pushPartitionString)
        , offsetof(WebKit::WebPushMessage, registrationURL)
    >::value);
    encoder << instance.pushData;
    encoder << instance.pushPartitionString;
    encoder << instance.registrationURL;
}

std::optional<WebKit::WebPushMessage> ArgumentCoder<WebKit::WebPushMessage>::decode(Decoder& decoder)
{
    auto pushData = decoder.decode<std::optional<Vector<uint8_t>>>();
    if (!pushData)
        return std::nullopt;

    auto pushPartitionString = decoder.decode<String>();
    if (!pushPartitionString)
        return std::nullopt;

    auto registrationURL = decoder.decode<URL>();
    if (!registrationURL)
        return std::nullopt;

    return {
        WebKit::WebPushMessage {
            WTFMove(*pushData),
            WTFMove(*pushPartitionString),
            WTFMove(*registrationURL)
        }
    };
}


void ArgumentCoder<WebKit::WebsiteDataStoreParameters>::encode(Encoder& encoder, const WebKit::WebsiteDataStoreParameters& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.uiProcessCookieStorageIdentifier)>, Vector<uint8_t>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cookieStoragePathExtensionHandle)>, WebKit::SandboxExtension::Handle>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.networkSessionParameters)>, WebKit::NetworkSessionCreationParameters>);
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cookieStorageDirectoryExtensionHandle)>, std::optional<WebKit::SandboxExtension::Handle>>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.containerCachesDirectoryExtensionHandle)>, std::optional<WebKit::SandboxExtension::Handle>>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.parentBundleDirectoryExtensionHandle)>, std::optional<WebKit::SandboxExtension::Handle>>);
#endif
#if PLATFORM(IOS_FAMILY)
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.tempDirectoryExtensionHandle)>, std::optional<WebKit::SandboxExtension::Handle>>);
#endif
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebsiteDataStoreParameters, uiProcessCookieStorageIdentifier)
        , offsetof(WebKit::WebsiteDataStoreParameters, cookieStoragePathExtensionHandle)
        , offsetof(WebKit::WebsiteDataStoreParameters, networkSessionParameters)
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::WebsiteDataStoreParameters, cookieStorageDirectoryExtensionHandle)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::WebsiteDataStoreParameters, containerCachesDirectoryExtensionHandle)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::WebsiteDataStoreParameters, parentBundleDirectoryExtensionHandle)
#endif
#if PLATFORM(IOS_FAMILY)
        , offsetof(WebKit::WebsiteDataStoreParameters, tempDirectoryExtensionHandle)
#endif
    >::value);
    encoder << instance.uiProcessCookieStorageIdentifier;
    encoder << instance.cookieStoragePathExtensionHandle;
    encoder << instance.networkSessionParameters;
#if PLATFORM(IOS_FAMILY)
    encoder << instance.cookieStorageDirectoryExtensionHandle;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.containerCachesDirectoryExtensionHandle;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.parentBundleDirectoryExtensionHandle;
#endif
#if PLATFORM(IOS_FAMILY)
    encoder << instance.tempDirectoryExtensionHandle;
#endif
}

std::optional<WebKit::WebsiteDataStoreParameters> ArgumentCoder<WebKit::WebsiteDataStoreParameters>::decode(Decoder& decoder)
{
    auto uiProcessCookieStorageIdentifier = decoder.decode<Vector<uint8_t>>();
    if (!uiProcessCookieStorageIdentifier)
        return std::nullopt;

    auto cookieStoragePathExtensionHandle = decoder.decode<WebKit::SandboxExtension::Handle>();
    if (!cookieStoragePathExtensionHandle)
        return std::nullopt;

    auto networkSessionParameters = decoder.decode<WebKit::NetworkSessionCreationParameters>();
    if (!networkSessionParameters)
        return std::nullopt;

#if PLATFORM(IOS_FAMILY)
    auto cookieStorageDirectoryExtensionHandle = decoder.decode<std::optional<WebKit::SandboxExtension::Handle>>();
    if (!cookieStorageDirectoryExtensionHandle)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto containerCachesDirectoryExtensionHandle = decoder.decode<std::optional<WebKit::SandboxExtension::Handle>>();
    if (!containerCachesDirectoryExtensionHandle)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto parentBundleDirectoryExtensionHandle = decoder.decode<std::optional<WebKit::SandboxExtension::Handle>>();
    if (!parentBundleDirectoryExtensionHandle)
        return std::nullopt;
#endif

#if PLATFORM(IOS_FAMILY)
    auto tempDirectoryExtensionHandle = decoder.decode<std::optional<WebKit::SandboxExtension::Handle>>();
    if (!tempDirectoryExtensionHandle)
        return std::nullopt;
#endif

    return {
        WebKit::WebsiteDataStoreParameters {
            WTFMove(*uiProcessCookieStorageIdentifier),
            WTFMove(*cookieStoragePathExtensionHandle),
            WTFMove(*networkSessionParameters),
#if PLATFORM(IOS_FAMILY)
            WTFMove(*cookieStorageDirectoryExtensionHandle),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*containerCachesDirectoryExtensionHandle),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*parentBundleDirectoryExtensionHandle),
#endif
#if PLATFORM(IOS_FAMILY)
            WTFMove(*tempDirectoryExtensionHandle)
#endif
        }
    };
}


void ArgumentCoder<API::Error>::encode(Encoder& encoder, const API::Error& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.platformError())>, WebCore::ResourceError>);
    encoder << instance.platformError();
}

std::optional<Ref<API::Error>> ArgumentCoder<API::Error>::decode(Decoder& decoder)
{
    auto platformError = decoder.decode<WebCore::ResourceError>();
    if (!platformError)
        return std::nullopt;

    return {
        API::Error::create(
            WTFMove(*platformError)
        )
    };
}


void ArgumentCoder<API::FrameHandle>::encode(Encoder& encoder, const API::FrameHandle& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frameID())>, WebCore::FrameIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isAutoconverting())>, bool>);
    encoder << instance.frameID();
    encoder << instance.isAutoconverting();
}

std::optional<Ref<API::FrameHandle>> ArgumentCoder<API::FrameHandle>::decode(Decoder& decoder)
{
    auto frameID = decoder.decode<WebCore::FrameIdentifier>();
    if (!frameID)
        return std::nullopt;

    auto isAutoconverting = decoder.decode<bool>();
    if (!isAutoconverting)
        return std::nullopt;

    return {
        API::FrameHandle::create(
            WTFMove(*frameID),
            WTFMove(*isAutoconverting)
        )
    };
}


void ArgumentCoder<API::Size>::encode(Encoder& encoder, const API::Size& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size().width)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size().height)>, double>);
    encoder << instance.size().width;
    encoder << instance.size().height;
}

std::optional<Ref<API::Size>> ArgumentCoder<API::Size>::decode(Decoder& decoder)
{
    auto sizewidth = decoder.decode<double>();
    if (!sizewidth)
        return std::nullopt;

    auto sizeheight = decoder.decode<double>();
    if (!sizeheight)
        return std::nullopt;

    return {
        API::Size::create(
            WTFMove(*sizewidth),
            WTFMove(*sizeheight)
        )
    };
}


void ArgumentCoder<API::Point>::encode(Encoder& encoder, const API::Point& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point().x)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.point().y)>, double>);
    encoder << instance.point().x;
    encoder << instance.point().y;
}

std::optional<Ref<API::Point>> ArgumentCoder<API::Point>::decode(Decoder& decoder)
{
    auto pointx = decoder.decode<double>();
    if (!pointx)
        return std::nullopt;

    auto pointy = decoder.decode<double>();
    if (!pointy)
        return std::nullopt;

    return {
        API::Point::create(
            WTFMove(*pointx),
            WTFMove(*pointy)
        )
    };
}


void ArgumentCoder<API::Rect>::encode(Encoder& encoder, const API::Rect& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rect().origin.x)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rect().origin.y)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rect().size.width)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rect().size.height)>, double>);
    encoder << instance.rect().origin.x;
    encoder << instance.rect().origin.y;
    encoder << instance.rect().size.width;
    encoder << instance.rect().size.height;
}

std::optional<Ref<API::Rect>> ArgumentCoder<API::Rect>::decode(Decoder& decoder)
{
    auto rectoriginx = decoder.decode<double>();
    if (!rectoriginx)
        return std::nullopt;

    auto rectoriginy = decoder.decode<double>();
    if (!rectoriginy)
        return std::nullopt;

    auto rectsizewidth = decoder.decode<double>();
    if (!rectsizewidth)
        return std::nullopt;

    auto rectsizeheight = decoder.decode<double>();
    if (!rectsizeheight)
        return std::nullopt;

    return {
        API::Rect::create(
            WTFMove(*rectoriginx),
            WTFMove(*rectoriginy),
            WTFMove(*rectsizewidth),
            WTFMove(*rectsizeheight)
        )
    };
}


void ArgumentCoder<API::PageHandle>::encode(Encoder& encoder, const API::PageHandle& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pageProxyID())>, WebKit::WebPageProxyIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.webPageID())>, WebCore::PageIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.isAutoconverting())>, bool>);
    encoder << instance.pageProxyID();
    encoder << instance.webPageID();
    encoder << instance.isAutoconverting();
}

std::optional<Ref<API::PageHandle>> ArgumentCoder<API::PageHandle>::decode(Decoder& decoder)
{
    auto pageProxyID = decoder.decode<WebKit::WebPageProxyIdentifier>();
    if (!pageProxyID)
        return std::nullopt;

    auto webPageID = decoder.decode<WebCore::PageIdentifier>();
    if (!webPageID)
        return std::nullopt;

    auto isAutoconverting = decoder.decode<bool>();
    if (!isAutoconverting)
        return std::nullopt;

    return {
        API::PageHandle::create(
            WTFMove(*pageProxyID),
            WTFMove(*webPageID),
            WTFMove(*isAutoconverting)
        )
    };
}


void ArgumentCoder<API::URL>::encode(Encoder& encoder, const API::URL& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.string())>, WTF::String>);
    encoder << instance.string();
}

std::optional<Ref<API::URL>> ArgumentCoder<API::URL>::decode(Decoder& decoder)
{
    auto string = decoder.decode<WTF::String>();
    if (!string)
        return std::nullopt;

    return {
        API::URL::create(
            WTFMove(*string)
        )
    };
}


void ArgumentCoder<API::URLRequest>::encode(Encoder& encoder, const API::URLRequest& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.resourceRequest())>, WebCore::ResourceRequest>);
    encoder << instance.resourceRequest();
}

std::optional<Ref<API::URLRequest>> ArgumentCoder<API::URLRequest>::decode(Decoder& decoder)
{
    auto resourceRequest = decoder.decode<WebCore::ResourceRequest>();
    if (!resourceRequest)
        return std::nullopt;

    return {
        API::URLRequest::create(
            WTFMove(*resourceRequest)
        )
    };
}


void ArgumentCoder<API::URLResponse>::encode(Encoder& encoder, const API::URLResponse& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.resourceResponse())>, WebCore::ResourceResponse>);
    encoder << instance.resourceResponse();
}

std::optional<Ref<API::URLResponse>> ArgumentCoder<API::URLResponse>::decode(Decoder& decoder)
{
    auto resourceResponse = decoder.decode<WebCore::ResourceResponse>();
    if (!resourceResponse)
        return std::nullopt;

    return {
        API::URLResponse::create(
            WTFMove(*resourceResponse)
        )
    };
}


void ArgumentCoder<WebKit::WebIDBResult>::encode(Encoder& encoder, const WebKit::WebIDBResult& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_resultData)>, WebCore::IDBResultData>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.m_handles)>, Vector<WebKit::SandboxExtension::Handle>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebIDBResult, m_resultData)
        , offsetof(WebKit::WebIDBResult, m_handles)
    >::value);
    encoder << instance.m_resultData;
    encoder << instance.m_handles;
}

std::optional<WebKit::WebIDBResult> ArgumentCoder<WebKit::WebIDBResult>::decode(Decoder& decoder)
{
    auto m_resultData = decoder.decode<WebCore::IDBResultData>();
    if (!m_resultData)
        return std::nullopt;

    auto m_handles = decoder.decode<Vector<WebKit::SandboxExtension::Handle>>();
    if (!m_handles)
        return std::nullopt;

    return {
        WebKit::WebIDBResult {
            WTFMove(*m_resultData),
            WTFMove(*m_handles)
        }
    };
}

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::BindGroupDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::BindGroupDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bindGroupLayout)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entries)>, Vector<WebKit::WebGPU::BindGroupEntry>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BindGroupDescriptor, bindGroupLayout)
        , offsetof(WebKit::WebGPU::BindGroupDescriptor, entries)
    >::value);
    encoder << instance.label;
    encoder << instance.bindGroupLayout;
    encoder << instance.entries;
}

void ArgumentCoder<WebKit::WebGPU::BindGroupDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::BindGroupDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bindGroupLayout)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entries)>, Vector<WebKit::WebGPU::BindGroupEntry>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BindGroupDescriptor, bindGroupLayout)
        , offsetof(WebKit::WebGPU::BindGroupDescriptor, entries)
    >::value);
    encoder << instance.label;
    encoder << instance.bindGroupLayout;
    encoder << instance.entries;
}

std::optional<WebKit::WebGPU::BindGroupDescriptor> ArgumentCoder<WebKit::WebGPU::BindGroupDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto bindGroupLayout = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!bindGroupLayout)
        return std::nullopt;

    auto entries = decoder.decode<Vector<WebKit::WebGPU::BindGroupEntry>>();
    if (!entries)
        return std::nullopt;

    return {
        WebKit::WebGPU::BindGroupDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*bindGroupLayout),
            WTFMove(*entries)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::BindGroupEntry>::encode(Encoder& encoder, const WebKit::WebGPU::BindGroupEntry& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.binding)>, PAL::WebGPU::Index32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bufferBinding)>, WebKit::WebGPU::BufferBinding>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebKit::WebGPU::BindingResourceType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BindGroupEntry, binding)
        , offsetof(WebKit::WebGPU::BindGroupEntry, bufferBinding)
        , offsetof(WebKit::WebGPU::BindGroupEntry, identifier)
        , offsetof(WebKit::WebGPU::BindGroupEntry, type)
    >::value);
    encoder << instance.binding;
    encoder << instance.bufferBinding;
    encoder << instance.identifier;
    encoder << instance.type;
}

void ArgumentCoder<WebKit::WebGPU::BindGroupEntry>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::BindGroupEntry& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.binding)>, PAL::WebGPU::Index32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bufferBinding)>, WebKit::WebGPU::BufferBinding>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.identifier)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, WebKit::WebGPU::BindingResourceType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BindGroupEntry, binding)
        , offsetof(WebKit::WebGPU::BindGroupEntry, bufferBinding)
        , offsetof(WebKit::WebGPU::BindGroupEntry, identifier)
        , offsetof(WebKit::WebGPU::BindGroupEntry, type)
    >::value);
    encoder << instance.binding;
    encoder << instance.bufferBinding;
    encoder << instance.identifier;
    encoder << instance.type;
}

std::optional<WebKit::WebGPU::BindGroupEntry> ArgumentCoder<WebKit::WebGPU::BindGroupEntry>::decode(Decoder& decoder)
{
    auto binding = decoder.decode<PAL::WebGPU::Index32>();
    if (!binding)
        return std::nullopt;

    auto bufferBinding = decoder.decode<WebKit::WebGPU::BufferBinding>();
    if (!bufferBinding)
        return std::nullopt;

    auto identifier = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!identifier)
        return std::nullopt;

    auto type = decoder.decode<WebKit::WebGPU::BindingResourceType>();
    if (!type)
        return std::nullopt;

    return {
        WebKit::WebGPU::BindGroupEntry {
            WTFMove(*binding),
            WTFMove(*bufferBinding),
            WTFMove(*identifier),
            WTFMove(*type)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::BindGroupLayoutDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::BindGroupLayoutDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entries)>, Vector<WebKit::WebGPU::BindGroupLayoutEntry>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BindGroupLayoutDescriptor, entries)
    >::value);
    encoder << instance.label;
    encoder << instance.entries;
}

void ArgumentCoder<WebKit::WebGPU::BindGroupLayoutDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::BindGroupLayoutDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entries)>, Vector<WebKit::WebGPU::BindGroupLayoutEntry>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BindGroupLayoutDescriptor, entries)
    >::value);
    encoder << instance.label;
    encoder << instance.entries;
}

std::optional<WebKit::WebGPU::BindGroupLayoutDescriptor> ArgumentCoder<WebKit::WebGPU::BindGroupLayoutDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto entries = decoder.decode<Vector<WebKit::WebGPU::BindGroupLayoutEntry>>();
    if (!entries)
        return std::nullopt;

    return {
        WebKit::WebGPU::BindGroupLayoutDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*entries)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::BindGroupLayoutEntry>::encode(Encoder& encoder, const WebKit::WebGPU::BindGroupLayoutEntry& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.binding)>, PAL::WebGPU::Index32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.visibility)>, PAL::WebGPU::ShaderStageFlags>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buffer)>, std::optional<WebKit::WebGPU::BufferBindingLayout>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampler)>, std::optional<WebKit::WebGPU::SamplerBindingLayout>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.texture)>, std::optional<WebKit::WebGPU::TextureBindingLayout>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.storageTexture)>, std::optional<WebKit::WebGPU::StorageTextureBindingLayout>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.externalTexture)>, std::optional<WebKit::WebGPU::ExternalTextureBindingLayout>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, binding)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, visibility)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, buffer)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, sampler)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, texture)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, storageTexture)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, externalTexture)
    >::value);
    encoder << instance.binding;
    encoder << instance.visibility;
    encoder << instance.buffer;
    encoder << instance.sampler;
    encoder << instance.texture;
    encoder << instance.storageTexture;
    encoder << instance.externalTexture;
}

void ArgumentCoder<WebKit::WebGPU::BindGroupLayoutEntry>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::BindGroupLayoutEntry& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.binding)>, PAL::WebGPU::Index32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.visibility)>, PAL::WebGPU::ShaderStageFlags>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buffer)>, std::optional<WebKit::WebGPU::BufferBindingLayout>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampler)>, std::optional<WebKit::WebGPU::SamplerBindingLayout>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.texture)>, std::optional<WebKit::WebGPU::TextureBindingLayout>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.storageTexture)>, std::optional<WebKit::WebGPU::StorageTextureBindingLayout>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.externalTexture)>, std::optional<WebKit::WebGPU::ExternalTextureBindingLayout>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, binding)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, visibility)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, buffer)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, sampler)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, texture)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, storageTexture)
        , offsetof(WebKit::WebGPU::BindGroupLayoutEntry, externalTexture)
    >::value);
    encoder << instance.binding;
    encoder << instance.visibility;
    encoder << instance.buffer;
    encoder << instance.sampler;
    encoder << instance.texture;
    encoder << instance.storageTexture;
    encoder << instance.externalTexture;
}

std::optional<WebKit::WebGPU::BindGroupLayoutEntry> ArgumentCoder<WebKit::WebGPU::BindGroupLayoutEntry>::decode(Decoder& decoder)
{
    auto binding = decoder.decode<PAL::WebGPU::Index32>();
    if (!binding)
        return std::nullopt;

    auto visibility = decoder.decode<PAL::WebGPU::ShaderStageFlags>();
    if (!visibility)
        return std::nullopt;

    auto buffer = decoder.decode<std::optional<WebKit::WebGPU::BufferBindingLayout>>();
    if (!buffer)
        return std::nullopt;

    auto sampler = decoder.decode<std::optional<WebKit::WebGPU::SamplerBindingLayout>>();
    if (!sampler)
        return std::nullopt;

    auto texture = decoder.decode<std::optional<WebKit::WebGPU::TextureBindingLayout>>();
    if (!texture)
        return std::nullopt;

    auto storageTexture = decoder.decode<std::optional<WebKit::WebGPU::StorageTextureBindingLayout>>();
    if (!storageTexture)
        return std::nullopt;

    auto externalTexture = decoder.decode<std::optional<WebKit::WebGPU::ExternalTextureBindingLayout>>();
    if (!externalTexture)
        return std::nullopt;

    return {
        WebKit::WebGPU::BindGroupLayoutEntry {
            WTFMove(*binding),
            WTFMove(*visibility),
            WTFMove(*buffer),
            WTFMove(*sampler),
            WTFMove(*texture),
            WTFMove(*storageTexture),
            WTFMove(*externalTexture)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::BlendComponent>::encode(Encoder& encoder, const WebKit::WebGPU::BlendComponent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.operation)>, PAL::WebGPU::BlendOperation>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.srcFactor)>, PAL::WebGPU::BlendFactor>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dstFactor)>, PAL::WebGPU::BlendFactor>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BlendComponent, operation)
        , offsetof(WebKit::WebGPU::BlendComponent, srcFactor)
        , offsetof(WebKit::WebGPU::BlendComponent, dstFactor)
    >::value);
    encoder << instance.operation;
    encoder << instance.srcFactor;
    encoder << instance.dstFactor;
}

void ArgumentCoder<WebKit::WebGPU::BlendComponent>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::BlendComponent& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.operation)>, PAL::WebGPU::BlendOperation>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.srcFactor)>, PAL::WebGPU::BlendFactor>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dstFactor)>, PAL::WebGPU::BlendFactor>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BlendComponent, operation)
        , offsetof(WebKit::WebGPU::BlendComponent, srcFactor)
        , offsetof(WebKit::WebGPU::BlendComponent, dstFactor)
    >::value);
    encoder << instance.operation;
    encoder << instance.srcFactor;
    encoder << instance.dstFactor;
}

std::optional<WebKit::WebGPU::BlendComponent> ArgumentCoder<WebKit::WebGPU::BlendComponent>::decode(Decoder& decoder)
{
    auto operation = decoder.decode<PAL::WebGPU::BlendOperation>();
    if (!operation)
        return std::nullopt;

    auto srcFactor = decoder.decode<PAL::WebGPU::BlendFactor>();
    if (!srcFactor)
        return std::nullopt;

    auto dstFactor = decoder.decode<PAL::WebGPU::BlendFactor>();
    if (!dstFactor)
        return std::nullopt;

    return {
        WebKit::WebGPU::BlendComponent {
            WTFMove(*operation),
            WTFMove(*srcFactor),
            WTFMove(*dstFactor)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::BlendState>::encode(Encoder& encoder, const WebKit::WebGPU::BlendState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color)>, WebKit::WebGPU::BlendComponent>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alpha)>, WebKit::WebGPU::BlendComponent>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BlendState, color)
        , offsetof(WebKit::WebGPU::BlendState, alpha)
    >::value);
    encoder << instance.color;
    encoder << instance.alpha;
}

void ArgumentCoder<WebKit::WebGPU::BlendState>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::BlendState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.color)>, WebKit::WebGPU::BlendComponent>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alpha)>, WebKit::WebGPU::BlendComponent>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BlendState, color)
        , offsetof(WebKit::WebGPU::BlendState, alpha)
    >::value);
    encoder << instance.color;
    encoder << instance.alpha;
}

std::optional<WebKit::WebGPU::BlendState> ArgumentCoder<WebKit::WebGPU::BlendState>::decode(Decoder& decoder)
{
    auto color = decoder.decode<WebKit::WebGPU::BlendComponent>();
    if (!color)
        return std::nullopt;

    auto alpha = decoder.decode<WebKit::WebGPU::BlendComponent>();
    if (!alpha)
        return std::nullopt;

    return {
        WebKit::WebGPU::BlendState {
            WTFMove(*color),
            WTFMove(*alpha)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::BufferBinding>::encode(Encoder& encoder, const WebKit::WebGPU::BufferBinding& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buffer)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size)>, std::optional<PAL::WebGPU::Size64>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BufferBinding, buffer)
        , offsetof(WebKit::WebGPU::BufferBinding, offset)
        , offsetof(WebKit::WebGPU::BufferBinding, size)
    >::value);
    encoder << instance.buffer;
    encoder << instance.offset;
    encoder << instance.size;
}

void ArgumentCoder<WebKit::WebGPU::BufferBinding>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::BufferBinding& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buffer)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size)>, std::optional<PAL::WebGPU::Size64>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BufferBinding, buffer)
        , offsetof(WebKit::WebGPU::BufferBinding, offset)
        , offsetof(WebKit::WebGPU::BufferBinding, size)
    >::value);
    encoder << instance.buffer;
    encoder << instance.offset;
    encoder << instance.size;
}

std::optional<WebKit::WebGPU::BufferBinding> ArgumentCoder<WebKit::WebGPU::BufferBinding>::decode(Decoder& decoder)
{
    auto buffer = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!buffer)
        return std::nullopt;

    auto offset = decoder.decode<PAL::WebGPU::Size64>();
    if (!offset)
        return std::nullopt;

    auto size = decoder.decode<std::optional<PAL::WebGPU::Size64>>();
    if (!size)
        return std::nullopt;

    return {
        WebKit::WebGPU::BufferBinding {
            WTFMove(*buffer),
            WTFMove(*offset),
            WTFMove(*size)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::BufferBindingLayout>::encode(Encoder& encoder, const WebKit::WebGPU::BufferBindingLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, PAL::WebGPU::BufferBindingType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasDynamicOffset)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minBindingSize)>, PAL::WebGPU::Size64>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BufferBindingLayout, type)
        , offsetof(WebKit::WebGPU::BufferBindingLayout, hasDynamicOffset)
        , offsetof(WebKit::WebGPU::BufferBindingLayout, minBindingSize)
    >::value);
    encoder << instance.type;
    encoder << instance.hasDynamicOffset;
    encoder << instance.minBindingSize;
}

void ArgumentCoder<WebKit::WebGPU::BufferBindingLayout>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::BufferBindingLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, PAL::WebGPU::BufferBindingType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasDynamicOffset)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minBindingSize)>, PAL::WebGPU::Size64>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BufferBindingLayout, type)
        , offsetof(WebKit::WebGPU::BufferBindingLayout, hasDynamicOffset)
        , offsetof(WebKit::WebGPU::BufferBindingLayout, minBindingSize)
    >::value);
    encoder << instance.type;
    encoder << instance.hasDynamicOffset;
    encoder << instance.minBindingSize;
}

std::optional<WebKit::WebGPU::BufferBindingLayout> ArgumentCoder<WebKit::WebGPU::BufferBindingLayout>::decode(Decoder& decoder)
{
    auto type = decoder.decode<PAL::WebGPU::BufferBindingType>();
    if (!type)
        return std::nullopt;

    auto hasDynamicOffset = decoder.decode<bool>();
    if (!hasDynamicOffset)
        return std::nullopt;

    auto minBindingSize = decoder.decode<PAL::WebGPU::Size64>();
    if (!minBindingSize)
        return std::nullopt;

    return {
        WebKit::WebGPU::BufferBindingLayout {
            WTFMove(*type),
            WTFMove(*hasDynamicOffset),
            WTFMove(*minBindingSize)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::BufferDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::BufferDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.usage)>, PAL::WebGPU::BufferUsageFlags>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mappedAtCreation)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BufferDescriptor, size)
        , offsetof(WebKit::WebGPU::BufferDescriptor, usage)
        , offsetof(WebKit::WebGPU::BufferDescriptor, mappedAtCreation)
    >::value);
    encoder << instance.label;
    encoder << instance.size;
    encoder << instance.usage;
    encoder << instance.mappedAtCreation;
}

void ArgumentCoder<WebKit::WebGPU::BufferDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::BufferDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.usage)>, PAL::WebGPU::BufferUsageFlags>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mappedAtCreation)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::BufferDescriptor, size)
        , offsetof(WebKit::WebGPU::BufferDescriptor, usage)
        , offsetof(WebKit::WebGPU::BufferDescriptor, mappedAtCreation)
    >::value);
    encoder << instance.label;
    encoder << instance.size;
    encoder << instance.usage;
    encoder << instance.mappedAtCreation;
}

std::optional<WebKit::WebGPU::BufferDescriptor> ArgumentCoder<WebKit::WebGPU::BufferDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto size = decoder.decode<PAL::WebGPU::Size64>();
    if (!size)
        return std::nullopt;

    auto usage = decoder.decode<PAL::WebGPU::BufferUsageFlags>();
    if (!usage)
        return std::nullopt;

    auto mappedAtCreation = decoder.decode<bool>();
    if (!mappedAtCreation)
        return std::nullopt;

    return {
        WebKit::WebGPU::BufferDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*size),
            WTFMove(*usage),
            WTFMove(*mappedAtCreation)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::CanvasConfiguration>::encode(Encoder& encoder, const WebKit::WebGPU::CanvasConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.device)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.usage)>, PAL::WebGPU::TextureUsageFlags>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.viewFormats)>, Vector<PAL::WebGPU::TextureFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, PAL::WebGPU::PredefinedColorSpace>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compositingAlphaMode)>, PAL::WebGPU::CanvasCompositingAlphaMode>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::CanvasConfiguration, device)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, format)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, usage)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, viewFormats)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, colorSpace)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, compositingAlphaMode)
    >::value);
    encoder << instance.device;
    encoder << instance.format;
    encoder << instance.usage;
    encoder << instance.viewFormats;
    encoder << instance.colorSpace;
    encoder << instance.compositingAlphaMode;
}

void ArgumentCoder<WebKit::WebGPU::CanvasConfiguration>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::CanvasConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.device)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.usage)>, PAL::WebGPU::TextureUsageFlags>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.viewFormats)>, Vector<PAL::WebGPU::TextureFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, PAL::WebGPU::PredefinedColorSpace>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compositingAlphaMode)>, PAL::WebGPU::CanvasCompositingAlphaMode>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::CanvasConfiguration, device)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, format)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, usage)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, viewFormats)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, colorSpace)
        , offsetof(WebKit::WebGPU::CanvasConfiguration, compositingAlphaMode)
    >::value);
    encoder << instance.device;
    encoder << instance.format;
    encoder << instance.usage;
    encoder << instance.viewFormats;
    encoder << instance.colorSpace;
    encoder << instance.compositingAlphaMode;
}

std::optional<WebKit::WebGPU::CanvasConfiguration> ArgumentCoder<WebKit::WebGPU::CanvasConfiguration>::decode(Decoder& decoder)
{
    auto device = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!device)
        return std::nullopt;

    auto format = decoder.decode<PAL::WebGPU::TextureFormat>();
    if (!format)
        return std::nullopt;

    auto usage = decoder.decode<PAL::WebGPU::TextureUsageFlags>();
    if (!usage)
        return std::nullopt;

    auto viewFormats = decoder.decode<Vector<PAL::WebGPU::TextureFormat>>();
    if (!viewFormats)
        return std::nullopt;

    auto colorSpace = decoder.decode<PAL::WebGPU::PredefinedColorSpace>();
    if (!colorSpace)
        return std::nullopt;

    auto compositingAlphaMode = decoder.decode<PAL::WebGPU::CanvasCompositingAlphaMode>();
    if (!compositingAlphaMode)
        return std::nullopt;

    return {
        WebKit::WebGPU::CanvasConfiguration {
            WTFMove(*device),
            WTFMove(*format),
            WTFMove(*usage),
            WTFMove(*viewFormats),
            WTFMove(*colorSpace),
            WTFMove(*compositingAlphaMode)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ColorDict>::encode(Encoder& encoder, const WebKit::WebGPU::ColorDict& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.r)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.g)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.b)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.a)>, double>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ColorDict, r)
        , offsetof(WebKit::WebGPU::ColorDict, g)
        , offsetof(WebKit::WebGPU::ColorDict, b)
        , offsetof(WebKit::WebGPU::ColorDict, a)
    >::value);
    encoder << instance.r;
    encoder << instance.g;
    encoder << instance.b;
    encoder << instance.a;
}

void ArgumentCoder<WebKit::WebGPU::ColorDict>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ColorDict& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.r)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.g)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.b)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.a)>, double>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ColorDict, r)
        , offsetof(WebKit::WebGPU::ColorDict, g)
        , offsetof(WebKit::WebGPU::ColorDict, b)
        , offsetof(WebKit::WebGPU::ColorDict, a)
    >::value);
    encoder << instance.r;
    encoder << instance.g;
    encoder << instance.b;
    encoder << instance.a;
}

std::optional<WebKit::WebGPU::ColorDict> ArgumentCoder<WebKit::WebGPU::ColorDict>::decode(Decoder& decoder)
{
    auto r = decoder.decode<double>();
    if (!r)
        return std::nullopt;

    auto g = decoder.decode<double>();
    if (!g)
        return std::nullopt;

    auto b = decoder.decode<double>();
    if (!b)
        return std::nullopt;

    auto a = decoder.decode<double>();
    if (!a)
        return std::nullopt;

    return {
        WebKit::WebGPU::ColorDict {
            WTFMove(*r),
            WTFMove(*g),
            WTFMove(*b),
            WTFMove(*a)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ColorTargetState>::encode(Encoder& encoder, const WebKit::WebGPU::ColorTargetState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blend)>, std::optional<WebKit::WebGPU::BlendState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.writeMask)>, PAL::WebGPU::ColorWriteFlags>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ColorTargetState, format)
        , offsetof(WebKit::WebGPU::ColorTargetState, blend)
        , offsetof(WebKit::WebGPU::ColorTargetState, writeMask)
    >::value);
    encoder << instance.format;
    encoder << instance.blend;
    encoder << instance.writeMask;
}

void ArgumentCoder<WebKit::WebGPU::ColorTargetState>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ColorTargetState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.blend)>, std::optional<WebKit::WebGPU::BlendState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.writeMask)>, PAL::WebGPU::ColorWriteFlags>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ColorTargetState, format)
        , offsetof(WebKit::WebGPU::ColorTargetState, blend)
        , offsetof(WebKit::WebGPU::ColorTargetState, writeMask)
    >::value);
    encoder << instance.format;
    encoder << instance.blend;
    encoder << instance.writeMask;
}

std::optional<WebKit::WebGPU::ColorTargetState> ArgumentCoder<WebKit::WebGPU::ColorTargetState>::decode(Decoder& decoder)
{
    auto format = decoder.decode<PAL::WebGPU::TextureFormat>();
    if (!format)
        return std::nullopt;

    auto blend = decoder.decode<std::optional<WebKit::WebGPU::BlendState>>();
    if (!blend)
        return std::nullopt;

    auto writeMask = decoder.decode<PAL::WebGPU::ColorWriteFlags>();
    if (!writeMask)
        return std::nullopt;

    return {
        WebKit::WebGPU::ColorTargetState {
            WTFMove(*format),
            WTFMove(*blend),
            WTFMove(*writeMask)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::CommandBufferDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::CommandBufferDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(MembersInCorrectOrder<0
    >::value);
    encoder << instance.label;
}

void ArgumentCoder<WebKit::WebGPU::CommandBufferDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::CommandBufferDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(MembersInCorrectOrder<0
    >::value);
    encoder << instance.label;
}

std::optional<WebKit::WebGPU::CommandBufferDescriptor> ArgumentCoder<WebKit::WebGPU::CommandBufferDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    return {
        WebKit::WebGPU::CommandBufferDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            }
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::CommandEncoderDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::CommandEncoderDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(MembersInCorrectOrder<0
    >::value);
    encoder << instance.label;
}

void ArgumentCoder<WebKit::WebGPU::CommandEncoderDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::CommandEncoderDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(MembersInCorrectOrder<0
    >::value);
    encoder << instance.label;
}

std::optional<WebKit::WebGPU::CommandEncoderDescriptor> ArgumentCoder<WebKit::WebGPU::CommandEncoderDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    return {
        WebKit::WebGPU::CommandEncoderDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            }
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::CompilationMessage>::encode(Encoder& encoder, const WebKit::WebGPU::CompilationMessage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, PAL::WebGPU::CompilationMessageType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lineNum)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.linePos)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.length)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::CompilationMessage, message)
        , offsetof(WebKit::WebGPU::CompilationMessage, type)
        , offsetof(WebKit::WebGPU::CompilationMessage, lineNum)
        , offsetof(WebKit::WebGPU::CompilationMessage, linePos)
        , offsetof(WebKit::WebGPU::CompilationMessage, offset)
        , offsetof(WebKit::WebGPU::CompilationMessage, length)
    >::value);
    encoder << instance.message;
    encoder << instance.type;
    encoder << instance.lineNum;
    encoder << instance.linePos;
    encoder << instance.offset;
    encoder << instance.length;
}

void ArgumentCoder<WebKit::WebGPU::CompilationMessage>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::CompilationMessage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, PAL::WebGPU::CompilationMessageType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lineNum)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.linePos)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.length)>, uint64_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::CompilationMessage, message)
        , offsetof(WebKit::WebGPU::CompilationMessage, type)
        , offsetof(WebKit::WebGPU::CompilationMessage, lineNum)
        , offsetof(WebKit::WebGPU::CompilationMessage, linePos)
        , offsetof(WebKit::WebGPU::CompilationMessage, offset)
        , offsetof(WebKit::WebGPU::CompilationMessage, length)
    >::value);
    encoder << instance.message;
    encoder << instance.type;
    encoder << instance.lineNum;
    encoder << instance.linePos;
    encoder << instance.offset;
    encoder << instance.length;
}

std::optional<WebKit::WebGPU::CompilationMessage> ArgumentCoder<WebKit::WebGPU::CompilationMessage>::decode(Decoder& decoder)
{
    auto message = decoder.decode<String>();
    if (!message)
        return std::nullopt;

    auto type = decoder.decode<PAL::WebGPU::CompilationMessageType>();
    if (!type)
        return std::nullopt;

    auto lineNum = decoder.decode<uint64_t>();
    if (!lineNum)
        return std::nullopt;

    auto linePos = decoder.decode<uint64_t>();
    if (!linePos)
        return std::nullopt;

    auto offset = decoder.decode<uint64_t>();
    if (!offset)
        return std::nullopt;

    auto length = decoder.decode<uint64_t>();
    if (!length)
        return std::nullopt;

    return {
        WebKit::WebGPU::CompilationMessage {
            WTFMove(*message),
            WTFMove(*type),
            WTFMove(*lineNum),
            WTFMove(*linePos),
            WTFMove(*offset),
            WTFMove(*length)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ComputePassDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::ComputePassDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestampWrites)>, WebKit::WebGPU::ComputePassTimestampWrites>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ComputePassDescriptor, timestampWrites)
    >::value);
    encoder << instance.label;
    encoder << instance.timestampWrites;
}

void ArgumentCoder<WebKit::WebGPU::ComputePassDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ComputePassDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestampWrites)>, WebKit::WebGPU::ComputePassTimestampWrites>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ComputePassDescriptor, timestampWrites)
    >::value);
    encoder << instance.label;
    encoder << instance.timestampWrites;
}

std::optional<WebKit::WebGPU::ComputePassDescriptor> ArgumentCoder<WebKit::WebGPU::ComputePassDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto timestampWrites = decoder.decode<WebKit::WebGPU::ComputePassTimestampWrites>();
    if (!timestampWrites)
        return std::nullopt;

    return {
        WebKit::WebGPU::ComputePassDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*timestampWrites)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ComputePassTimestampWrite>::encode(Encoder& encoder, const WebKit::WebGPU::ComputePassTimestampWrite& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.querySet)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.queryIndex)>, PAL::WebGPU::Size32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location)>, PAL::WebGPU::ComputePassTimestampLocation>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ComputePassTimestampWrite, querySet)
        , offsetof(WebKit::WebGPU::ComputePassTimestampWrite, queryIndex)
        , offsetof(WebKit::WebGPU::ComputePassTimestampWrite, location)
    >::value);
    encoder << instance.querySet;
    encoder << instance.queryIndex;
    encoder << instance.location;
}

void ArgumentCoder<WebKit::WebGPU::ComputePassTimestampWrite>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ComputePassTimestampWrite& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.querySet)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.queryIndex)>, PAL::WebGPU::Size32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location)>, PAL::WebGPU::ComputePassTimestampLocation>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ComputePassTimestampWrite, querySet)
        , offsetof(WebKit::WebGPU::ComputePassTimestampWrite, queryIndex)
        , offsetof(WebKit::WebGPU::ComputePassTimestampWrite, location)
    >::value);
    encoder << instance.querySet;
    encoder << instance.queryIndex;
    encoder << instance.location;
}

std::optional<WebKit::WebGPU::ComputePassTimestampWrite> ArgumentCoder<WebKit::WebGPU::ComputePassTimestampWrite>::decode(Decoder& decoder)
{
    auto querySet = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!querySet)
        return std::nullopt;

    auto queryIndex = decoder.decode<PAL::WebGPU::Size32>();
    if (!queryIndex)
        return std::nullopt;

    auto location = decoder.decode<PAL::WebGPU::ComputePassTimestampLocation>();
    if (!location)
        return std::nullopt;

    return {
        WebKit::WebGPU::ComputePassTimestampWrite {
            WTFMove(*querySet),
            WTFMove(*queryIndex),
            WTFMove(*location)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ComputePipelineDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::ComputePipelineDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.layout)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PipelineDescriptorBase, layout)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compute)>, WebKit::WebGPU::ProgrammableStage>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ComputePipelineDescriptor, compute)
    >::value);
    encoder << instance.label;
    encoder << instance.layout;
    encoder << instance.compute;
}

void ArgumentCoder<WebKit::WebGPU::ComputePipelineDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ComputePipelineDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.layout)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PipelineDescriptorBase, layout)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compute)>, WebKit::WebGPU::ProgrammableStage>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ComputePipelineDescriptor, compute)
    >::value);
    encoder << instance.label;
    encoder << instance.layout;
    encoder << instance.compute;
}

std::optional<WebKit::WebGPU::ComputePipelineDescriptor> ArgumentCoder<WebKit::WebGPU::ComputePipelineDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto layout = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!layout)
        return std::nullopt;

    auto compute = decoder.decode<WebKit::WebGPU::ProgrammableStage>();
    if (!compute)
        return std::nullopt;

    return {
        WebKit::WebGPU::ComputePipelineDescriptor {
            WebKit::WebGPU::PipelineDescriptorBase {
                WebKit::WebGPU::ObjectDescriptorBase {
                    WTFMove(*label)
                },
                WTFMove(*layout)
            },
            WTFMove(*compute)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::DepthStencilState>::encode(Encoder& encoder, const WebKit::WebGPU::DepthStencilState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthWriteEnabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthCompare)>, PAL::WebGPU::CompareFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilFront)>, WebKit::WebGPU::StencilFaceState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilBack)>, WebKit::WebGPU::StencilFaceState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilReadMask)>, std::optional<PAL::WebGPU::StencilValue>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilWriteMask)>, std::optional<PAL::WebGPU::StencilValue>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthBias)>, PAL::WebGPU::DepthBias>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthBiasSlopeScale)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthBiasClamp)>, float>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::DepthStencilState, format)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthWriteEnabled)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthCompare)
        , offsetof(WebKit::WebGPU::DepthStencilState, stencilFront)
        , offsetof(WebKit::WebGPU::DepthStencilState, stencilBack)
        , offsetof(WebKit::WebGPU::DepthStencilState, stencilReadMask)
        , offsetof(WebKit::WebGPU::DepthStencilState, stencilWriteMask)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthBias)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthBiasSlopeScale)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthBiasClamp)
    >::value);
    encoder << instance.format;
    encoder << instance.depthWriteEnabled;
    encoder << instance.depthCompare;
    encoder << instance.stencilFront;
    encoder << instance.stencilBack;
    encoder << instance.stencilReadMask;
    encoder << instance.stencilWriteMask;
    encoder << instance.depthBias;
    encoder << instance.depthBiasSlopeScale;
    encoder << instance.depthBiasClamp;
}

void ArgumentCoder<WebKit::WebGPU::DepthStencilState>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::DepthStencilState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthWriteEnabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthCompare)>, PAL::WebGPU::CompareFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilFront)>, WebKit::WebGPU::StencilFaceState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilBack)>, WebKit::WebGPU::StencilFaceState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilReadMask)>, std::optional<PAL::WebGPU::StencilValue>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilWriteMask)>, std::optional<PAL::WebGPU::StencilValue>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthBias)>, PAL::WebGPU::DepthBias>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthBiasSlopeScale)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthBiasClamp)>, float>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::DepthStencilState, format)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthWriteEnabled)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthCompare)
        , offsetof(WebKit::WebGPU::DepthStencilState, stencilFront)
        , offsetof(WebKit::WebGPU::DepthStencilState, stencilBack)
        , offsetof(WebKit::WebGPU::DepthStencilState, stencilReadMask)
        , offsetof(WebKit::WebGPU::DepthStencilState, stencilWriteMask)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthBias)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthBiasSlopeScale)
        , offsetof(WebKit::WebGPU::DepthStencilState, depthBiasClamp)
    >::value);
    encoder << instance.format;
    encoder << instance.depthWriteEnabled;
    encoder << instance.depthCompare;
    encoder << instance.stencilFront;
    encoder << instance.stencilBack;
    encoder << instance.stencilReadMask;
    encoder << instance.stencilWriteMask;
    encoder << instance.depthBias;
    encoder << instance.depthBiasSlopeScale;
    encoder << instance.depthBiasClamp;
}

std::optional<WebKit::WebGPU::DepthStencilState> ArgumentCoder<WebKit::WebGPU::DepthStencilState>::decode(Decoder& decoder)
{
    auto format = decoder.decode<PAL::WebGPU::TextureFormat>();
    if (!format)
        return std::nullopt;

    auto depthWriteEnabled = decoder.decode<bool>();
    if (!depthWriteEnabled)
        return std::nullopt;

    auto depthCompare = decoder.decode<PAL::WebGPU::CompareFunction>();
    if (!depthCompare)
        return std::nullopt;

    auto stencilFront = decoder.decode<WebKit::WebGPU::StencilFaceState>();
    if (!stencilFront)
        return std::nullopt;

    auto stencilBack = decoder.decode<WebKit::WebGPU::StencilFaceState>();
    if (!stencilBack)
        return std::nullopt;

    auto stencilReadMask = decoder.decode<std::optional<PAL::WebGPU::StencilValue>>();
    if (!stencilReadMask)
        return std::nullopt;

    auto stencilWriteMask = decoder.decode<std::optional<PAL::WebGPU::StencilValue>>();
    if (!stencilWriteMask)
        return std::nullopt;

    auto depthBias = decoder.decode<PAL::WebGPU::DepthBias>();
    if (!depthBias)
        return std::nullopt;

    auto depthBiasSlopeScale = decoder.decode<float>();
    if (!depthBiasSlopeScale)
        return std::nullopt;

    auto depthBiasClamp = decoder.decode<float>();
    if (!depthBiasClamp)
        return std::nullopt;

    return {
        WebKit::WebGPU::DepthStencilState {
            WTFMove(*format),
            WTFMove(*depthWriteEnabled),
            WTFMove(*depthCompare),
            WTFMove(*stencilFront),
            WTFMove(*stencilBack),
            WTFMove(*stencilReadMask),
            WTFMove(*stencilWriteMask),
            WTFMove(*depthBias),
            WTFMove(*depthBiasSlopeScale),
            WTFMove(*depthBiasClamp)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::DeviceDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::DeviceDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.requiredFeatures)>, Vector<PAL::WebGPU::FeatureName>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.requiredLimits)>, Vector<KeyValuePair<String, uint64_t>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::DeviceDescriptor, requiredFeatures)
        , offsetof(WebKit::WebGPU::DeviceDescriptor, requiredLimits)
    >::value);
    encoder << instance.label;
    encoder << instance.requiredFeatures;
    encoder << instance.requiredLimits;
}

void ArgumentCoder<WebKit::WebGPU::DeviceDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::DeviceDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.requiredFeatures)>, Vector<PAL::WebGPU::FeatureName>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.requiredLimits)>, Vector<KeyValuePair<String, uint64_t>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::DeviceDescriptor, requiredFeatures)
        , offsetof(WebKit::WebGPU::DeviceDescriptor, requiredLimits)
    >::value);
    encoder << instance.label;
    encoder << instance.requiredFeatures;
    encoder << instance.requiredLimits;
}

std::optional<WebKit::WebGPU::DeviceDescriptor> ArgumentCoder<WebKit::WebGPU::DeviceDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto requiredFeatures = decoder.decode<Vector<PAL::WebGPU::FeatureName>>();
    if (!requiredFeatures)
        return std::nullopt;

    auto requiredLimits = decoder.decode<Vector<KeyValuePair<String, uint64_t>>>();
    if (!requiredLimits)
        return std::nullopt;

    return {
        WebKit::WebGPU::DeviceDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*requiredFeatures),
            WTFMove(*requiredLimits)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::Extent3DDict>::encode(Encoder& encoder, const WebKit::WebGPU::Extent3DDict& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthOrArrayLayers)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::Extent3DDict, width)
        , offsetof(WebKit::WebGPU::Extent3DDict, height)
        , offsetof(WebKit::WebGPU::Extent3DDict, depthOrArrayLayers)
    >::value);
    encoder << instance.width;
    encoder << instance.height;
    encoder << instance.depthOrArrayLayers;
}

void ArgumentCoder<WebKit::WebGPU::Extent3DDict>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::Extent3DDict& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.width)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.height)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthOrArrayLayers)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::Extent3DDict, width)
        , offsetof(WebKit::WebGPU::Extent3DDict, height)
        , offsetof(WebKit::WebGPU::Extent3DDict, depthOrArrayLayers)
    >::value);
    encoder << instance.width;
    encoder << instance.height;
    encoder << instance.depthOrArrayLayers;
}

std::optional<WebKit::WebGPU::Extent3DDict> ArgumentCoder<WebKit::WebGPU::Extent3DDict>::decode(Decoder& decoder)
{
    auto width = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!width)
        return std::nullopt;

    auto height = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!height)
        return std::nullopt;

    auto depthOrArrayLayers = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!depthOrArrayLayers)
        return std::nullopt;

    return {
        WebKit::WebGPU::Extent3DDict {
            WTFMove(*width),
            WTFMove(*height),
            WTFMove(*depthOrArrayLayers)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ExternalTextureBindingLayout>::encode(Encoder& encoder, const WebKit::WebGPU::ExternalTextureBindingLayout& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

void ArgumentCoder<WebKit::WebGPU::ExternalTextureBindingLayout>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ExternalTextureBindingLayout& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<WebKit::WebGPU::ExternalTextureBindingLayout> ArgumentCoder<WebKit::WebGPU::ExternalTextureBindingLayout>::decode(Decoder& decoder)
{
    return {
        WebKit::WebGPU::ExternalTextureBindingLayout {
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ExternalTextureDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::ExternalTextureDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, PAL::WebGPU::PredefinedColorSpace>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ExternalTextureDescriptor, colorSpace)
    >::value);
    encoder << instance.label;
    encoder << instance.colorSpace;
}

void ArgumentCoder<WebKit::WebGPU::ExternalTextureDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ExternalTextureDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, PAL::WebGPU::PredefinedColorSpace>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ExternalTextureDescriptor, colorSpace)
    >::value);
    encoder << instance.label;
    encoder << instance.colorSpace;
}

std::optional<WebKit::WebGPU::ExternalTextureDescriptor> ArgumentCoder<WebKit::WebGPU::ExternalTextureDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto colorSpace = decoder.decode<PAL::WebGPU::PredefinedColorSpace>();
    if (!colorSpace)
        return std::nullopt;

    return {
        WebKit::WebGPU::ExternalTextureDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*colorSpace)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::FragmentState>::encode(Encoder& encoder, const WebKit::WebGPU::FragmentState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.module)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entryPoint)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.constants)>, Vector<KeyValuePair<String, double>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ProgrammableStage, module)
        , offsetof(WebKit::WebGPU::ProgrammableStage, entryPoint)
        , offsetof(WebKit::WebGPU::ProgrammableStage, constants)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.targets)>, Vector<std::optional<WebKit::WebGPU::ColorTargetState>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::FragmentState, targets)
    >::value);
    encoder << instance.module;
    encoder << instance.entryPoint;
    encoder << instance.constants;
    encoder << instance.targets;
}

void ArgumentCoder<WebKit::WebGPU::FragmentState>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::FragmentState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.module)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entryPoint)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.constants)>, Vector<KeyValuePair<String, double>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ProgrammableStage, module)
        , offsetof(WebKit::WebGPU::ProgrammableStage, entryPoint)
        , offsetof(WebKit::WebGPU::ProgrammableStage, constants)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.targets)>, Vector<std::optional<WebKit::WebGPU::ColorTargetState>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::FragmentState, targets)
    >::value);
    encoder << instance.module;
    encoder << instance.entryPoint;
    encoder << instance.constants;
    encoder << instance.targets;
}

std::optional<WebKit::WebGPU::FragmentState> ArgumentCoder<WebKit::WebGPU::FragmentState>::decode(Decoder& decoder)
{
    auto module = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!module)
        return std::nullopt;

    auto entryPoint = decoder.decode<String>();
    if (!entryPoint)
        return std::nullopt;

    auto constants = decoder.decode<Vector<KeyValuePair<String, double>>>();
    if (!constants)
        return std::nullopt;

    auto targets = decoder.decode<Vector<std::optional<WebKit::WebGPU::ColorTargetState>>>();
    if (!targets)
        return std::nullopt;

    return {
        WebKit::WebGPU::FragmentState {
            WebKit::WebGPU::ProgrammableStage {
                WTFMove(*module),
                WTFMove(*entryPoint),
                WTFMove(*constants)
            },
            WTFMove(*targets)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ImageCopyBuffer>::encode(Encoder& encoder, const WebKit::WebGPU::ImageCopyBuffer& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bytesPerRow)>, std::optional<PAL::WebGPU::Size32>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rowsPerImage)>, std::optional<PAL::WebGPU::Size32>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageDataLayout, offset)
        , offsetof(WebKit::WebGPU::ImageDataLayout, bytesPerRow)
        , offsetof(WebKit::WebGPU::ImageDataLayout, rowsPerImage)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buffer)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyBuffer, buffer)
    >::value);
    encoder << instance.offset;
    encoder << instance.bytesPerRow;
    encoder << instance.rowsPerImage;
    encoder << instance.buffer;
}

void ArgumentCoder<WebKit::WebGPU::ImageCopyBuffer>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ImageCopyBuffer& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bytesPerRow)>, std::optional<PAL::WebGPU::Size32>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rowsPerImage)>, std::optional<PAL::WebGPU::Size32>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageDataLayout, offset)
        , offsetof(WebKit::WebGPU::ImageDataLayout, bytesPerRow)
        , offsetof(WebKit::WebGPU::ImageDataLayout, rowsPerImage)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buffer)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyBuffer, buffer)
    >::value);
    encoder << instance.offset;
    encoder << instance.bytesPerRow;
    encoder << instance.rowsPerImage;
    encoder << instance.buffer;
}

std::optional<WebKit::WebGPU::ImageCopyBuffer> ArgumentCoder<WebKit::WebGPU::ImageCopyBuffer>::decode(Decoder& decoder)
{
    auto offset = decoder.decode<PAL::WebGPU::Size64>();
    if (!offset)
        return std::nullopt;

    auto bytesPerRow = decoder.decode<std::optional<PAL::WebGPU::Size32>>();
    if (!bytesPerRow)
        return std::nullopt;

    auto rowsPerImage = decoder.decode<std::optional<PAL::WebGPU::Size32>>();
    if (!rowsPerImage)
        return std::nullopt;

    auto buffer = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!buffer)
        return std::nullopt;

    return {
        WebKit::WebGPU::ImageCopyBuffer {
            WebKit::WebGPU::ImageDataLayout {
                WTFMove(*offset),
                WTFMove(*bytesPerRow),
                WTFMove(*rowsPerImage)
            },
            WTFMove(*buffer)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ImageCopyExternalImage>::encode(Encoder& encoder, const WebKit::WebGPU::ImageCopyExternalImage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.origin)>, std::optional<WebKit::WebGPU::Origin2D>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.flipY)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyExternalImage, origin)
        , offsetof(WebKit::WebGPU::ImageCopyExternalImage, flipY)
    >::value);
    encoder << instance.origin;
    encoder << instance.flipY;
}

void ArgumentCoder<WebKit::WebGPU::ImageCopyExternalImage>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ImageCopyExternalImage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.origin)>, std::optional<WebKit::WebGPU::Origin2D>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.flipY)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyExternalImage, origin)
        , offsetof(WebKit::WebGPU::ImageCopyExternalImage, flipY)
    >::value);
    encoder << instance.origin;
    encoder << instance.flipY;
}

std::optional<WebKit::WebGPU::ImageCopyExternalImage> ArgumentCoder<WebKit::WebGPU::ImageCopyExternalImage>::decode(Decoder& decoder)
{
    auto origin = decoder.decode<std::optional<WebKit::WebGPU::Origin2D>>();
    if (!origin)
        return std::nullopt;

    auto flipY = decoder.decode<bool>();
    if (!flipY)
        return std::nullopt;

    return {
        WebKit::WebGPU::ImageCopyExternalImage {
            WTFMove(*origin),
            WTFMove(*flipY)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ImageCopyTexture>::encode(Encoder& encoder, const WebKit::WebGPU::ImageCopyTexture& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.texture)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipLevel)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.origin)>, std::optional<WebKit::WebGPU::Origin3D>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.aspect)>, PAL::WebGPU::TextureAspect>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyTexture, texture)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, mipLevel)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, origin)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, aspect)
    >::value);
    encoder << instance.texture;
    encoder << instance.mipLevel;
    encoder << instance.origin;
    encoder << instance.aspect;
}

void ArgumentCoder<WebKit::WebGPU::ImageCopyTexture>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ImageCopyTexture& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.texture)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipLevel)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.origin)>, std::optional<WebKit::WebGPU::Origin3D>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.aspect)>, PAL::WebGPU::TextureAspect>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyTexture, texture)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, mipLevel)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, origin)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, aspect)
    >::value);
    encoder << instance.texture;
    encoder << instance.mipLevel;
    encoder << instance.origin;
    encoder << instance.aspect;
}

std::optional<WebKit::WebGPU::ImageCopyTexture> ArgumentCoder<WebKit::WebGPU::ImageCopyTexture>::decode(Decoder& decoder)
{
    auto texture = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!texture)
        return std::nullopt;

    auto mipLevel = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!mipLevel)
        return std::nullopt;

    auto origin = decoder.decode<std::optional<WebKit::WebGPU::Origin3D>>();
    if (!origin)
        return std::nullopt;

    auto aspect = decoder.decode<PAL::WebGPU::TextureAspect>();
    if (!aspect)
        return std::nullopt;

    return {
        WebKit::WebGPU::ImageCopyTexture {
            WTFMove(*texture),
            WTFMove(*mipLevel),
            WTFMove(*origin),
            WTFMove(*aspect)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ImageCopyTextureTagged>::encode(Encoder& encoder, const WebKit::WebGPU::ImageCopyTextureTagged& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.texture)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipLevel)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.origin)>, std::optional<WebKit::WebGPU::Origin3D>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.aspect)>, PAL::WebGPU::TextureAspect>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyTexture, texture)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, mipLevel)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, origin)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, aspect)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, PAL::WebGPU::PredefinedColorSpace>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.premultipliedAlpha)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyTextureTagged, colorSpace)
        , offsetof(WebKit::WebGPU::ImageCopyTextureTagged, premultipliedAlpha)
    >::value);
    encoder << instance.texture;
    encoder << instance.mipLevel;
    encoder << instance.origin;
    encoder << instance.aspect;
    encoder << instance.colorSpace;
    encoder << instance.premultipliedAlpha;
}

void ArgumentCoder<WebKit::WebGPU::ImageCopyTextureTagged>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ImageCopyTextureTagged& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.texture)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipLevel)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.origin)>, std::optional<WebKit::WebGPU::Origin3D>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.aspect)>, PAL::WebGPU::TextureAspect>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyTexture, texture)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, mipLevel)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, origin)
        , offsetof(WebKit::WebGPU::ImageCopyTexture, aspect)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorSpace)>, PAL::WebGPU::PredefinedColorSpace>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.premultipliedAlpha)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageCopyTextureTagged, colorSpace)
        , offsetof(WebKit::WebGPU::ImageCopyTextureTagged, premultipliedAlpha)
    >::value);
    encoder << instance.texture;
    encoder << instance.mipLevel;
    encoder << instance.origin;
    encoder << instance.aspect;
    encoder << instance.colorSpace;
    encoder << instance.premultipliedAlpha;
}

std::optional<WebKit::WebGPU::ImageCopyTextureTagged> ArgumentCoder<WebKit::WebGPU::ImageCopyTextureTagged>::decode(Decoder& decoder)
{
    auto texture = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!texture)
        return std::nullopt;

    auto mipLevel = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!mipLevel)
        return std::nullopt;

    auto origin = decoder.decode<std::optional<WebKit::WebGPU::Origin3D>>();
    if (!origin)
        return std::nullopt;

    auto aspect = decoder.decode<PAL::WebGPU::TextureAspect>();
    if (!aspect)
        return std::nullopt;

    auto colorSpace = decoder.decode<PAL::WebGPU::PredefinedColorSpace>();
    if (!colorSpace)
        return std::nullopt;

    auto premultipliedAlpha = decoder.decode<bool>();
    if (!premultipliedAlpha)
        return std::nullopt;

    return {
        WebKit::WebGPU::ImageCopyTextureTagged {
            WebKit::WebGPU::ImageCopyTexture {
                WTFMove(*texture),
                WTFMove(*mipLevel),
                WTFMove(*origin),
                WTFMove(*aspect)
            },
            WTFMove(*colorSpace),
            WTFMove(*premultipliedAlpha)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ImageDataLayout>::encode(Encoder& encoder, const WebKit::WebGPU::ImageDataLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bytesPerRow)>, std::optional<PAL::WebGPU::Size32>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rowsPerImage)>, std::optional<PAL::WebGPU::Size32>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageDataLayout, offset)
        , offsetof(WebKit::WebGPU::ImageDataLayout, bytesPerRow)
        , offsetof(WebKit::WebGPU::ImageDataLayout, rowsPerImage)
    >::value);
    encoder << instance.offset;
    encoder << instance.bytesPerRow;
    encoder << instance.rowsPerImage;
}

void ArgumentCoder<WebKit::WebGPU::ImageDataLayout>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ImageDataLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bytesPerRow)>, std::optional<PAL::WebGPU::Size32>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.rowsPerImage)>, std::optional<PAL::WebGPU::Size32>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ImageDataLayout, offset)
        , offsetof(WebKit::WebGPU::ImageDataLayout, bytesPerRow)
        , offsetof(WebKit::WebGPU::ImageDataLayout, rowsPerImage)
    >::value);
    encoder << instance.offset;
    encoder << instance.bytesPerRow;
    encoder << instance.rowsPerImage;
}

std::optional<WebKit::WebGPU::ImageDataLayout> ArgumentCoder<WebKit::WebGPU::ImageDataLayout>::decode(Decoder& decoder)
{
    auto offset = decoder.decode<PAL::WebGPU::Size64>();
    if (!offset)
        return std::nullopt;

    auto bytesPerRow = decoder.decode<std::optional<PAL::WebGPU::Size32>>();
    if (!bytesPerRow)
        return std::nullopt;

    auto rowsPerImage = decoder.decode<std::optional<PAL::WebGPU::Size32>>();
    if (!rowsPerImage)
        return std::nullopt;

    return {
        WebKit::WebGPU::ImageDataLayout {
            WTFMove(*offset),
            WTFMove(*bytesPerRow),
            WTFMove(*rowsPerImage)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::MultisampleState>::encode(Encoder& encoder, const WebKit::WebGPU::MultisampleState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.count)>, PAL::WebGPU::Size32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mask)>, PAL::WebGPU::SampleMask>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alphaToCoverageEnabled)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::MultisampleState, count)
        , offsetof(WebKit::WebGPU::MultisampleState, mask)
        , offsetof(WebKit::WebGPU::MultisampleState, alphaToCoverageEnabled)
    >::value);
    encoder << instance.count;
    encoder << instance.mask;
    encoder << instance.alphaToCoverageEnabled;
}

void ArgumentCoder<WebKit::WebGPU::MultisampleState>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::MultisampleState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.count)>, PAL::WebGPU::Size32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mask)>, PAL::WebGPU::SampleMask>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.alphaToCoverageEnabled)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::MultisampleState, count)
        , offsetof(WebKit::WebGPU::MultisampleState, mask)
        , offsetof(WebKit::WebGPU::MultisampleState, alphaToCoverageEnabled)
    >::value);
    encoder << instance.count;
    encoder << instance.mask;
    encoder << instance.alphaToCoverageEnabled;
}

std::optional<WebKit::WebGPU::MultisampleState> ArgumentCoder<WebKit::WebGPU::MultisampleState>::decode(Decoder& decoder)
{
    auto count = decoder.decode<PAL::WebGPU::Size32>();
    if (!count)
        return std::nullopt;

    auto mask = decoder.decode<PAL::WebGPU::SampleMask>();
    if (!mask)
        return std::nullopt;

    auto alphaToCoverageEnabled = decoder.decode<bool>();
    if (!alphaToCoverageEnabled)
        return std::nullopt;

    return {
        WebKit::WebGPU::MultisampleState {
            WTFMove(*count),
            WTFMove(*mask),
            WTFMove(*alphaToCoverageEnabled)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ObjectDescriptorBase>::encode(Encoder& encoder, const WebKit::WebGPU::ObjectDescriptorBase& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    encoder << instance.label;
}

void ArgumentCoder<WebKit::WebGPU::ObjectDescriptorBase>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ObjectDescriptorBase& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    encoder << instance.label;
}

std::optional<WebKit::WebGPU::ObjectDescriptorBase> ArgumentCoder<WebKit::WebGPU::ObjectDescriptorBase>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    return {
        WebKit::WebGPU::ObjectDescriptorBase {
            WTFMove(*label)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::Origin2DDict>::encode(Encoder& encoder, const WebKit::WebGPU::Origin2DDict& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::Origin2DDict, x)
        , offsetof(WebKit::WebGPU::Origin2DDict, y)
    >::value);
    encoder << instance.x;
    encoder << instance.y;
}

void ArgumentCoder<WebKit::WebGPU::Origin2DDict>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::Origin2DDict& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::Origin2DDict, x)
        , offsetof(WebKit::WebGPU::Origin2DDict, y)
    >::value);
    encoder << instance.x;
    encoder << instance.y;
}

std::optional<WebKit::WebGPU::Origin2DDict> ArgumentCoder<WebKit::WebGPU::Origin2DDict>::decode(Decoder& decoder)
{
    auto x = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!y)
        return std::nullopt;

    return {
        WebKit::WebGPU::Origin2DDict {
            WTFMove(*x),
            WTFMove(*y)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::Origin3DDict>::encode(Encoder& encoder, const WebKit::WebGPU::Origin3DDict& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.z)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::Origin3DDict, x)
        , offsetof(WebKit::WebGPU::Origin3DDict, y)
        , offsetof(WebKit::WebGPU::Origin3DDict, z)
    >::value);
    encoder << instance.x;
    encoder << instance.y;
    encoder << instance.z;
}

void ArgumentCoder<WebKit::WebGPU::Origin3DDict>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::Origin3DDict& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.x)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.y)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.z)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::Origin3DDict, x)
        , offsetof(WebKit::WebGPU::Origin3DDict, y)
        , offsetof(WebKit::WebGPU::Origin3DDict, z)
    >::value);
    encoder << instance.x;
    encoder << instance.y;
    encoder << instance.z;
}

std::optional<WebKit::WebGPU::Origin3DDict> ArgumentCoder<WebKit::WebGPU::Origin3DDict>::decode(Decoder& decoder)
{
    auto x = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!x)
        return std::nullopt;

    auto y = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!y)
        return std::nullopt;

    auto z = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!z)
        return std::nullopt;

    return {
        WebKit::WebGPU::Origin3DDict {
            WTFMove(*x),
            WTFMove(*y),
            WTFMove(*z)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::OutOfMemoryError>::encode(Encoder& encoder, const WebKit::WebGPU::OutOfMemoryError& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

void ArgumentCoder<WebKit::WebGPU::OutOfMemoryError>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::OutOfMemoryError& instance)
{
    static_assert(MembersInCorrectOrder<0
    >::value);
}

std::optional<WebKit::WebGPU::OutOfMemoryError> ArgumentCoder<WebKit::WebGPU::OutOfMemoryError>::decode(Decoder& decoder)
{
    return {
        WebKit::WebGPU::OutOfMemoryError {
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::PipelineDescriptorBase>::encode(Encoder& encoder, const WebKit::WebGPU::PipelineDescriptorBase& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.layout)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PipelineDescriptorBase, layout)
    >::value);
    encoder << instance.label;
    encoder << instance.layout;
}

void ArgumentCoder<WebKit::WebGPU::PipelineDescriptorBase>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::PipelineDescriptorBase& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.layout)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PipelineDescriptorBase, layout)
    >::value);
    encoder << instance.label;
    encoder << instance.layout;
}

std::optional<WebKit::WebGPU::PipelineDescriptorBase> ArgumentCoder<WebKit::WebGPU::PipelineDescriptorBase>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto layout = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!layout)
        return std::nullopt;

    return {
        WebKit::WebGPU::PipelineDescriptorBase {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*layout)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::PipelineLayoutDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::PipelineLayoutDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bindGroupLayouts)>, Vector<WebKit::WebGPUIdentifier>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PipelineLayoutDescriptor, bindGroupLayouts)
    >::value);
    encoder << instance.label;
    encoder << instance.bindGroupLayouts;
}

void ArgumentCoder<WebKit::WebGPU::PipelineLayoutDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::PipelineLayoutDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bindGroupLayouts)>, Vector<WebKit::WebGPUIdentifier>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PipelineLayoutDescriptor, bindGroupLayouts)
    >::value);
    encoder << instance.label;
    encoder << instance.bindGroupLayouts;
}

std::optional<WebKit::WebGPU::PipelineLayoutDescriptor> ArgumentCoder<WebKit::WebGPU::PipelineLayoutDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto bindGroupLayouts = decoder.decode<Vector<WebKit::WebGPUIdentifier>>();
    if (!bindGroupLayouts)
        return std::nullopt;

    return {
        WebKit::WebGPU::PipelineLayoutDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*bindGroupLayouts)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::PresentationContextDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::PresentationContextDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compositorIntegration)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PresentationContextDescriptor, compositorIntegration)
    >::value);
    encoder << instance.compositorIntegration;
}

void ArgumentCoder<WebKit::WebGPU::PresentationContextDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::PresentationContextDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compositorIntegration)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PresentationContextDescriptor, compositorIntegration)
    >::value);
    encoder << instance.compositorIntegration;
}

std::optional<WebKit::WebGPU::PresentationContextDescriptor> ArgumentCoder<WebKit::WebGPU::PresentationContextDescriptor>::decode(Decoder& decoder)
{
    auto compositorIntegration = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!compositorIntegration)
        return std::nullopt;

    return {
        WebKit::WebGPU::PresentationContextDescriptor {
            WTFMove(*compositorIntegration)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::PrimitiveState>::encode(Encoder& encoder, const WebKit::WebGPU::PrimitiveState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topology)>, PAL::WebGPU::PrimitiveTopology>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stripIndexFormat)>, std::optional<PAL::WebGPU::IndexFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frontFace)>, PAL::WebGPU::FrontFace>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cullMode)>, PAL::WebGPU::CullMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.unclippedDepth)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PrimitiveState, topology)
        , offsetof(WebKit::WebGPU::PrimitiveState, stripIndexFormat)
        , offsetof(WebKit::WebGPU::PrimitiveState, frontFace)
        , offsetof(WebKit::WebGPU::PrimitiveState, cullMode)
        , offsetof(WebKit::WebGPU::PrimitiveState, unclippedDepth)
    >::value);
    encoder << instance.topology;
    encoder << instance.stripIndexFormat;
    encoder << instance.frontFace;
    encoder << instance.cullMode;
    encoder << instance.unclippedDepth;
}

void ArgumentCoder<WebKit::WebGPU::PrimitiveState>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::PrimitiveState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.topology)>, PAL::WebGPU::PrimitiveTopology>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stripIndexFormat)>, std::optional<PAL::WebGPU::IndexFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.frontFace)>, PAL::WebGPU::FrontFace>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.cullMode)>, PAL::WebGPU::CullMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.unclippedDepth)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PrimitiveState, topology)
        , offsetof(WebKit::WebGPU::PrimitiveState, stripIndexFormat)
        , offsetof(WebKit::WebGPU::PrimitiveState, frontFace)
        , offsetof(WebKit::WebGPU::PrimitiveState, cullMode)
        , offsetof(WebKit::WebGPU::PrimitiveState, unclippedDepth)
    >::value);
    encoder << instance.topology;
    encoder << instance.stripIndexFormat;
    encoder << instance.frontFace;
    encoder << instance.cullMode;
    encoder << instance.unclippedDepth;
}

std::optional<WebKit::WebGPU::PrimitiveState> ArgumentCoder<WebKit::WebGPU::PrimitiveState>::decode(Decoder& decoder)
{
    auto topology = decoder.decode<PAL::WebGPU::PrimitiveTopology>();
    if (!topology)
        return std::nullopt;

    auto stripIndexFormat = decoder.decode<std::optional<PAL::WebGPU::IndexFormat>>();
    if (!stripIndexFormat)
        return std::nullopt;

    auto frontFace = decoder.decode<PAL::WebGPU::FrontFace>();
    if (!frontFace)
        return std::nullopt;

    auto cullMode = decoder.decode<PAL::WebGPU::CullMode>();
    if (!cullMode)
        return std::nullopt;

    auto unclippedDepth = decoder.decode<bool>();
    if (!unclippedDepth)
        return std::nullopt;

    return {
        WebKit::WebGPU::PrimitiveState {
            WTFMove(*topology),
            WTFMove(*stripIndexFormat),
            WTFMove(*frontFace),
            WTFMove(*cullMode),
            WTFMove(*unclippedDepth)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ProgrammableStage>::encode(Encoder& encoder, const WebKit::WebGPU::ProgrammableStage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.module)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entryPoint)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.constants)>, Vector<KeyValuePair<String, double>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ProgrammableStage, module)
        , offsetof(WebKit::WebGPU::ProgrammableStage, entryPoint)
        , offsetof(WebKit::WebGPU::ProgrammableStage, constants)
    >::value);
    encoder << instance.module;
    encoder << instance.entryPoint;
    encoder << instance.constants;
}

void ArgumentCoder<WebKit::WebGPU::ProgrammableStage>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ProgrammableStage& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.module)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entryPoint)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.constants)>, Vector<KeyValuePair<String, double>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ProgrammableStage, module)
        , offsetof(WebKit::WebGPU::ProgrammableStage, entryPoint)
        , offsetof(WebKit::WebGPU::ProgrammableStage, constants)
    >::value);
    encoder << instance.module;
    encoder << instance.entryPoint;
    encoder << instance.constants;
}

std::optional<WebKit::WebGPU::ProgrammableStage> ArgumentCoder<WebKit::WebGPU::ProgrammableStage>::decode(Decoder& decoder)
{
    auto module = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!module)
        return std::nullopt;

    auto entryPoint = decoder.decode<String>();
    if (!entryPoint)
        return std::nullopt;

    auto constants = decoder.decode<Vector<KeyValuePair<String, double>>>();
    if (!constants)
        return std::nullopt;

    return {
        WebKit::WebGPU::ProgrammableStage {
            WTFMove(*module),
            WTFMove(*entryPoint),
            WTFMove(*constants)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::QuerySetDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::QuerySetDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, PAL::WebGPU::QueryType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.count)>, PAL::WebGPU::Size32>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::QuerySetDescriptor, type)
        , offsetof(WebKit::WebGPU::QuerySetDescriptor, count)
    >::value);
    encoder << instance.label;
    encoder << instance.type;
    encoder << instance.count;
}

void ArgumentCoder<WebKit::WebGPU::QuerySetDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::QuerySetDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, PAL::WebGPU::QueryType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.count)>, PAL::WebGPU::Size32>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::QuerySetDescriptor, type)
        , offsetof(WebKit::WebGPU::QuerySetDescriptor, count)
    >::value);
    encoder << instance.label;
    encoder << instance.type;
    encoder << instance.count;
}

std::optional<WebKit::WebGPU::QuerySetDescriptor> ArgumentCoder<WebKit::WebGPU::QuerySetDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto type = decoder.decode<PAL::WebGPU::QueryType>();
    if (!type)
        return std::nullopt;

    auto count = decoder.decode<PAL::WebGPU::Size32>();
    if (!count)
        return std::nullopt;

    return {
        WebKit::WebGPU::QuerySetDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*type),
            WTFMove(*count)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::RenderBundleDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::RenderBundleDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(MembersInCorrectOrder<0
    >::value);
    encoder << instance.label;
}

void ArgumentCoder<WebKit::WebGPU::RenderBundleDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::RenderBundleDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(MembersInCorrectOrder<0
    >::value);
    encoder << instance.label;
}

std::optional<WebKit::WebGPU::RenderBundleDescriptor> ArgumentCoder<WebKit::WebGPU::RenderBundleDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    return {
        WebKit::WebGPU::RenderBundleDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            }
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::RenderBundleEncoderDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::RenderBundleEncoderDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorFormats)>, Vector<std::optional<PAL::WebGPU::TextureFormat>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStencilFormat)>, std::optional<PAL::WebGPU::TextureFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampleCount)>, PAL::WebGPU::Size32>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassLayout, colorFormats)
        , offsetof(WebKit::WebGPU::RenderPassLayout, depthStencilFormat)
        , offsetof(WebKit::WebGPU::RenderPassLayout, sampleCount)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthReadOnly)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilReadOnly)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderBundleEncoderDescriptor, depthReadOnly)
        , offsetof(WebKit::WebGPU::RenderBundleEncoderDescriptor, stencilReadOnly)
    >::value);
    encoder << instance.label;
    encoder << instance.colorFormats;
    encoder << instance.depthStencilFormat;
    encoder << instance.sampleCount;
    encoder << instance.depthReadOnly;
    encoder << instance.stencilReadOnly;
}

void ArgumentCoder<WebKit::WebGPU::RenderBundleEncoderDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::RenderBundleEncoderDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorFormats)>, Vector<std::optional<PAL::WebGPU::TextureFormat>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStencilFormat)>, std::optional<PAL::WebGPU::TextureFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampleCount)>, PAL::WebGPU::Size32>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassLayout, colorFormats)
        , offsetof(WebKit::WebGPU::RenderPassLayout, depthStencilFormat)
        , offsetof(WebKit::WebGPU::RenderPassLayout, sampleCount)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthReadOnly)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilReadOnly)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderBundleEncoderDescriptor, depthReadOnly)
        , offsetof(WebKit::WebGPU::RenderBundleEncoderDescriptor, stencilReadOnly)
    >::value);
    encoder << instance.label;
    encoder << instance.colorFormats;
    encoder << instance.depthStencilFormat;
    encoder << instance.sampleCount;
    encoder << instance.depthReadOnly;
    encoder << instance.stencilReadOnly;
}

std::optional<WebKit::WebGPU::RenderBundleEncoderDescriptor> ArgumentCoder<WebKit::WebGPU::RenderBundleEncoderDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto colorFormats = decoder.decode<Vector<std::optional<PAL::WebGPU::TextureFormat>>>();
    if (!colorFormats)
        return std::nullopt;

    auto depthStencilFormat = decoder.decode<std::optional<PAL::WebGPU::TextureFormat>>();
    if (!depthStencilFormat)
        return std::nullopt;

    auto sampleCount = decoder.decode<PAL::WebGPU::Size32>();
    if (!sampleCount)
        return std::nullopt;

    auto depthReadOnly = decoder.decode<bool>();
    if (!depthReadOnly)
        return std::nullopt;

    auto stencilReadOnly = decoder.decode<bool>();
    if (!stencilReadOnly)
        return std::nullopt;

    return {
        WebKit::WebGPU::RenderBundleEncoderDescriptor {
            WebKit::WebGPU::RenderPassLayout {
                WebKit::WebGPU::ObjectDescriptorBase {
                    WTFMove(*label)
                },
                WTFMove(*colorFormats),
                WTFMove(*depthStencilFormat),
                WTFMove(*sampleCount)
            },
            WTFMove(*depthReadOnly),
            WTFMove(*stencilReadOnly)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::RenderPassColorAttachment>::encode(Encoder& encoder, const WebKit::WebGPU::RenderPassColorAttachment& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.view)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.resolveTarget)>, std::optional<WebKit::WebGPUIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clearValue)>, std::optional<WebKit::WebGPU::Color>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.loadOp)>, PAL::WebGPU::LoadOp>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.storeOp)>, PAL::WebGPU::StoreOp>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, view)
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, resolveTarget)
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, clearValue)
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, loadOp)
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, storeOp)
    >::value);
    encoder << instance.view;
    encoder << instance.resolveTarget;
    encoder << instance.clearValue;
    encoder << instance.loadOp;
    encoder << instance.storeOp;
}

void ArgumentCoder<WebKit::WebGPU::RenderPassColorAttachment>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::RenderPassColorAttachment& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.view)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.resolveTarget)>, std::optional<WebKit::WebGPUIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.clearValue)>, std::optional<WebKit::WebGPU::Color>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.loadOp)>, PAL::WebGPU::LoadOp>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.storeOp)>, PAL::WebGPU::StoreOp>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, view)
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, resolveTarget)
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, clearValue)
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, loadOp)
        , offsetof(WebKit::WebGPU::RenderPassColorAttachment, storeOp)
    >::value);
    encoder << instance.view;
    encoder << instance.resolveTarget;
    encoder << instance.clearValue;
    encoder << instance.loadOp;
    encoder << instance.storeOp;
}

std::optional<WebKit::WebGPU::RenderPassColorAttachment> ArgumentCoder<WebKit::WebGPU::RenderPassColorAttachment>::decode(Decoder& decoder)
{
    auto view = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!view)
        return std::nullopt;

    auto resolveTarget = decoder.decode<std::optional<WebKit::WebGPUIdentifier>>();
    if (!resolveTarget)
        return std::nullopt;

    auto clearValue = decoder.decode<std::optional<WebKit::WebGPU::Color>>();
    if (!clearValue)
        return std::nullopt;

    auto loadOp = decoder.decode<PAL::WebGPU::LoadOp>();
    if (!loadOp)
        return std::nullopt;

    auto storeOp = decoder.decode<PAL::WebGPU::StoreOp>();
    if (!storeOp)
        return std::nullopt;

    return {
        WebKit::WebGPU::RenderPassColorAttachment {
            WTFMove(*view),
            WTFMove(*resolveTarget),
            WTFMove(*clearValue),
            WTFMove(*loadOp),
            WTFMove(*storeOp)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::RenderPassDepthStencilAttachment>::encode(Encoder& encoder, const WebKit::WebGPU::RenderPassDepthStencilAttachment& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.view)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthClearValue)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthLoadOp)>, std::optional<PAL::WebGPU::LoadOp>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStoreOp)>, std::optional<PAL::WebGPU::StoreOp>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthReadOnly)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilClearValue)>, PAL::WebGPU::StencilValue>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilLoadOp)>, std::optional<PAL::WebGPU::LoadOp>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilStoreOp)>, std::optional<PAL::WebGPU::StoreOp>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilReadOnly)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, view)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, depthClearValue)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, depthLoadOp)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, depthStoreOp)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, depthReadOnly)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, stencilClearValue)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, stencilLoadOp)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, stencilStoreOp)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, stencilReadOnly)
    >::value);
    encoder << instance.view;
    encoder << instance.depthClearValue;
    encoder << instance.depthLoadOp;
    encoder << instance.depthStoreOp;
    encoder << instance.depthReadOnly;
    encoder << instance.stencilClearValue;
    encoder << instance.stencilLoadOp;
    encoder << instance.stencilStoreOp;
    encoder << instance.stencilReadOnly;
}

void ArgumentCoder<WebKit::WebGPU::RenderPassDepthStencilAttachment>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::RenderPassDepthStencilAttachment& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.view)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthClearValue)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthLoadOp)>, std::optional<PAL::WebGPU::LoadOp>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStoreOp)>, std::optional<PAL::WebGPU::StoreOp>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthReadOnly)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilClearValue)>, PAL::WebGPU::StencilValue>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilLoadOp)>, std::optional<PAL::WebGPU::LoadOp>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilStoreOp)>, std::optional<PAL::WebGPU::StoreOp>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stencilReadOnly)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, view)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, depthClearValue)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, depthLoadOp)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, depthStoreOp)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, depthReadOnly)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, stencilClearValue)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, stencilLoadOp)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, stencilStoreOp)
        , offsetof(WebKit::WebGPU::RenderPassDepthStencilAttachment, stencilReadOnly)
    >::value);
    encoder << instance.view;
    encoder << instance.depthClearValue;
    encoder << instance.depthLoadOp;
    encoder << instance.depthStoreOp;
    encoder << instance.depthReadOnly;
    encoder << instance.stencilClearValue;
    encoder << instance.stencilLoadOp;
    encoder << instance.stencilStoreOp;
    encoder << instance.stencilReadOnly;
}

std::optional<WebKit::WebGPU::RenderPassDepthStencilAttachment> ArgumentCoder<WebKit::WebGPU::RenderPassDepthStencilAttachment>::decode(Decoder& decoder)
{
    auto view = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!view)
        return std::nullopt;

    auto depthClearValue = decoder.decode<float>();
    if (!depthClearValue)
        return std::nullopt;

    auto depthLoadOp = decoder.decode<std::optional<PAL::WebGPU::LoadOp>>();
    if (!depthLoadOp)
        return std::nullopt;

    auto depthStoreOp = decoder.decode<std::optional<PAL::WebGPU::StoreOp>>();
    if (!depthStoreOp)
        return std::nullopt;

    auto depthReadOnly = decoder.decode<bool>();
    if (!depthReadOnly)
        return std::nullopt;

    auto stencilClearValue = decoder.decode<PAL::WebGPU::StencilValue>();
    if (!stencilClearValue)
        return std::nullopt;

    auto stencilLoadOp = decoder.decode<std::optional<PAL::WebGPU::LoadOp>>();
    if (!stencilLoadOp)
        return std::nullopt;

    auto stencilStoreOp = decoder.decode<std::optional<PAL::WebGPU::StoreOp>>();
    if (!stencilStoreOp)
        return std::nullopt;

    auto stencilReadOnly = decoder.decode<bool>();
    if (!stencilReadOnly)
        return std::nullopt;

    return {
        WebKit::WebGPU::RenderPassDepthStencilAttachment {
            WTFMove(*view),
            WTFMove(*depthClearValue),
            WTFMove(*depthLoadOp),
            WTFMove(*depthStoreOp),
            WTFMove(*depthReadOnly),
            WTFMove(*stencilClearValue),
            WTFMove(*stencilLoadOp),
            WTFMove(*stencilStoreOp),
            WTFMove(*stencilReadOnly)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::RenderPassDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::RenderPassDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorAttachments)>, Vector<std::optional<WebKit::WebGPU::RenderPassColorAttachment>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStencilAttachment)>, std::optional<WebKit::WebGPU::RenderPassDepthStencilAttachment>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.occlusionQuerySet)>, std::optional<WebKit::WebGPUIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestampWrites)>, WebKit::WebGPU::RenderPassTimestampWrites>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassDescriptor, colorAttachments)
        , offsetof(WebKit::WebGPU::RenderPassDescriptor, depthStencilAttachment)
        , offsetof(WebKit::WebGPU::RenderPassDescriptor, occlusionQuerySet)
        , offsetof(WebKit::WebGPU::RenderPassDescriptor, timestampWrites)
    >::value);
    encoder << instance.label;
    encoder << instance.colorAttachments;
    encoder << instance.depthStencilAttachment;
    encoder << instance.occlusionQuerySet;
    encoder << instance.timestampWrites;
}

void ArgumentCoder<WebKit::WebGPU::RenderPassDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::RenderPassDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorAttachments)>, Vector<std::optional<WebKit::WebGPU::RenderPassColorAttachment>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStencilAttachment)>, std::optional<WebKit::WebGPU::RenderPassDepthStencilAttachment>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.occlusionQuerySet)>, std::optional<WebKit::WebGPUIdentifier>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.timestampWrites)>, WebKit::WebGPU::RenderPassTimestampWrites>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassDescriptor, colorAttachments)
        , offsetof(WebKit::WebGPU::RenderPassDescriptor, depthStencilAttachment)
        , offsetof(WebKit::WebGPU::RenderPassDescriptor, occlusionQuerySet)
        , offsetof(WebKit::WebGPU::RenderPassDescriptor, timestampWrites)
    >::value);
    encoder << instance.label;
    encoder << instance.colorAttachments;
    encoder << instance.depthStencilAttachment;
    encoder << instance.occlusionQuerySet;
    encoder << instance.timestampWrites;
}

std::optional<WebKit::WebGPU::RenderPassDescriptor> ArgumentCoder<WebKit::WebGPU::RenderPassDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto colorAttachments = decoder.decode<Vector<std::optional<WebKit::WebGPU::RenderPassColorAttachment>>>();
    if (!colorAttachments)
        return std::nullopt;

    auto depthStencilAttachment = decoder.decode<std::optional<WebKit::WebGPU::RenderPassDepthStencilAttachment>>();
    if (!depthStencilAttachment)
        return std::nullopt;

    auto occlusionQuerySet = decoder.decode<std::optional<WebKit::WebGPUIdentifier>>();
    if (!occlusionQuerySet)
        return std::nullopt;

    auto timestampWrites = decoder.decode<WebKit::WebGPU::RenderPassTimestampWrites>();
    if (!timestampWrites)
        return std::nullopt;

    return {
        WebKit::WebGPU::RenderPassDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*colorAttachments),
            WTFMove(*depthStencilAttachment),
            WTFMove(*occlusionQuerySet),
            WTFMove(*timestampWrites)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::RenderPassLayout>::encode(Encoder& encoder, const WebKit::WebGPU::RenderPassLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorFormats)>, Vector<std::optional<PAL::WebGPU::TextureFormat>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStencilFormat)>, std::optional<PAL::WebGPU::TextureFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampleCount)>, PAL::WebGPU::Size32>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassLayout, colorFormats)
        , offsetof(WebKit::WebGPU::RenderPassLayout, depthStencilFormat)
        , offsetof(WebKit::WebGPU::RenderPassLayout, sampleCount)
    >::value);
    encoder << instance.label;
    encoder << instance.colorFormats;
    encoder << instance.depthStencilFormat;
    encoder << instance.sampleCount;
}

void ArgumentCoder<WebKit::WebGPU::RenderPassLayout>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::RenderPassLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.colorFormats)>, Vector<std::optional<PAL::WebGPU::TextureFormat>>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStencilFormat)>, std::optional<PAL::WebGPU::TextureFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampleCount)>, PAL::WebGPU::Size32>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassLayout, colorFormats)
        , offsetof(WebKit::WebGPU::RenderPassLayout, depthStencilFormat)
        , offsetof(WebKit::WebGPU::RenderPassLayout, sampleCount)
    >::value);
    encoder << instance.label;
    encoder << instance.colorFormats;
    encoder << instance.depthStencilFormat;
    encoder << instance.sampleCount;
}

std::optional<WebKit::WebGPU::RenderPassLayout> ArgumentCoder<WebKit::WebGPU::RenderPassLayout>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto colorFormats = decoder.decode<Vector<std::optional<PAL::WebGPU::TextureFormat>>>();
    if (!colorFormats)
        return std::nullopt;

    auto depthStencilFormat = decoder.decode<std::optional<PAL::WebGPU::TextureFormat>>();
    if (!depthStencilFormat)
        return std::nullopt;

    auto sampleCount = decoder.decode<PAL::WebGPU::Size32>();
    if (!sampleCount)
        return std::nullopt;

    return {
        WebKit::WebGPU::RenderPassLayout {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*colorFormats),
            WTFMove(*depthStencilFormat),
            WTFMove(*sampleCount)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::RenderPassTimestampWrite>::encode(Encoder& encoder, const WebKit::WebGPU::RenderPassTimestampWrite& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.querySet)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.queryIndex)>, PAL::WebGPU::Size32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location)>, PAL::WebGPU::RenderPassTimestampLocation>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassTimestampWrite, querySet)
        , offsetof(WebKit::WebGPU::RenderPassTimestampWrite, queryIndex)
        , offsetof(WebKit::WebGPU::RenderPassTimestampWrite, location)
    >::value);
    encoder << instance.querySet;
    encoder << instance.queryIndex;
    encoder << instance.location;
}

void ArgumentCoder<WebKit::WebGPU::RenderPassTimestampWrite>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::RenderPassTimestampWrite& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.querySet)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.queryIndex)>, PAL::WebGPU::Size32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.location)>, PAL::WebGPU::RenderPassTimestampLocation>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPassTimestampWrite, querySet)
        , offsetof(WebKit::WebGPU::RenderPassTimestampWrite, queryIndex)
        , offsetof(WebKit::WebGPU::RenderPassTimestampWrite, location)
    >::value);
    encoder << instance.querySet;
    encoder << instance.queryIndex;
    encoder << instance.location;
}

std::optional<WebKit::WebGPU::RenderPassTimestampWrite> ArgumentCoder<WebKit::WebGPU::RenderPassTimestampWrite>::decode(Decoder& decoder)
{
    auto querySet = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!querySet)
        return std::nullopt;

    auto queryIndex = decoder.decode<PAL::WebGPU::Size32>();
    if (!queryIndex)
        return std::nullopt;

    auto location = decoder.decode<PAL::WebGPU::RenderPassTimestampLocation>();
    if (!location)
        return std::nullopt;

    return {
        WebKit::WebGPU::RenderPassTimestampWrite {
            WTFMove(*querySet),
            WTFMove(*queryIndex),
            WTFMove(*location)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::RenderPipelineDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::RenderPipelineDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.layout)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PipelineDescriptorBase, layout)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.vertex)>, WebKit::WebGPU::VertexState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.primitive)>, std::optional<WebKit::WebGPU::PrimitiveState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStencil)>, std::optional<WebKit::WebGPU::DepthStencilState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.multisample)>, std::optional<WebKit::WebGPU::MultisampleState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fragment)>, std::optional<WebKit::WebGPU::FragmentState>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, vertex)
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, primitive)
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, depthStencil)
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, multisample)
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, fragment)
    >::value);
    encoder << instance.label;
    encoder << instance.layout;
    encoder << instance.vertex;
    encoder << instance.primitive;
    encoder << instance.depthStencil;
    encoder << instance.multisample;
    encoder << instance.fragment;
}

void ArgumentCoder<WebKit::WebGPU::RenderPipelineDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::RenderPipelineDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.layout)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::PipelineDescriptorBase, layout)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.vertex)>, WebKit::WebGPU::VertexState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.primitive)>, std::optional<WebKit::WebGPU::PrimitiveState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthStencil)>, std::optional<WebKit::WebGPU::DepthStencilState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.multisample)>, std::optional<WebKit::WebGPU::MultisampleState>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.fragment)>, std::optional<WebKit::WebGPU::FragmentState>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, vertex)
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, primitive)
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, depthStencil)
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, multisample)
        , offsetof(WebKit::WebGPU::RenderPipelineDescriptor, fragment)
    >::value);
    encoder << instance.label;
    encoder << instance.layout;
    encoder << instance.vertex;
    encoder << instance.primitive;
    encoder << instance.depthStencil;
    encoder << instance.multisample;
    encoder << instance.fragment;
}

std::optional<WebKit::WebGPU::RenderPipelineDescriptor> ArgumentCoder<WebKit::WebGPU::RenderPipelineDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto layout = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!layout)
        return std::nullopt;

    auto vertex = decoder.decode<WebKit::WebGPU::VertexState>();
    if (!vertex)
        return std::nullopt;

    auto primitive = decoder.decode<std::optional<WebKit::WebGPU::PrimitiveState>>();
    if (!primitive)
        return std::nullopt;

    auto depthStencil = decoder.decode<std::optional<WebKit::WebGPU::DepthStencilState>>();
    if (!depthStencil)
        return std::nullopt;

    auto multisample = decoder.decode<std::optional<WebKit::WebGPU::MultisampleState>>();
    if (!multisample)
        return std::nullopt;

    auto fragment = decoder.decode<std::optional<WebKit::WebGPU::FragmentState>>();
    if (!fragment)
        return std::nullopt;

    return {
        WebKit::WebGPU::RenderPipelineDescriptor {
            WebKit::WebGPU::PipelineDescriptorBase {
                WebKit::WebGPU::ObjectDescriptorBase {
                    WTFMove(*label)
                },
                WTFMove(*layout)
            },
            WTFMove(*vertex),
            WTFMove(*primitive),
            WTFMove(*depthStencil),
            WTFMove(*multisample),
            WTFMove(*fragment)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::RequestAdapterOptions>::encode(Encoder& encoder, const WebKit::WebGPU::RequestAdapterOptions& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.powerPreference)>, std::optional<PAL::WebGPU::PowerPreference>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.forceFallbackAdapter)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RequestAdapterOptions, powerPreference)
        , offsetof(WebKit::WebGPU::RequestAdapterOptions, forceFallbackAdapter)
    >::value);
    encoder << instance.powerPreference;
    encoder << instance.forceFallbackAdapter;
}

void ArgumentCoder<WebKit::WebGPU::RequestAdapterOptions>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::RequestAdapterOptions& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.powerPreference)>, std::optional<PAL::WebGPU::PowerPreference>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.forceFallbackAdapter)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::RequestAdapterOptions, powerPreference)
        , offsetof(WebKit::WebGPU::RequestAdapterOptions, forceFallbackAdapter)
    >::value);
    encoder << instance.powerPreference;
    encoder << instance.forceFallbackAdapter;
}

std::optional<WebKit::WebGPU::RequestAdapterOptions> ArgumentCoder<WebKit::WebGPU::RequestAdapterOptions>::decode(Decoder& decoder)
{
    auto powerPreference = decoder.decode<std::optional<PAL::WebGPU::PowerPreference>>();
    if (!powerPreference)
        return std::nullopt;

    auto forceFallbackAdapter = decoder.decode<bool>();
    if (!forceFallbackAdapter)
        return std::nullopt;

    return {
        WebKit::WebGPU::RequestAdapterOptions {
            WTFMove(*powerPreference),
            WTFMove(*forceFallbackAdapter)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::SamplerBindingLayout>::encode(Encoder& encoder, const WebKit::WebGPU::SamplerBindingLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, PAL::WebGPU::SamplerBindingType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::SamplerBindingLayout, type)
    >::value);
    encoder << instance.type;
}

void ArgumentCoder<WebKit::WebGPU::SamplerBindingLayout>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::SamplerBindingLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.type)>, PAL::WebGPU::SamplerBindingType>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::SamplerBindingLayout, type)
    >::value);
    encoder << instance.type;
}

std::optional<WebKit::WebGPU::SamplerBindingLayout> ArgumentCoder<WebKit::WebGPU::SamplerBindingLayout>::decode(Decoder& decoder)
{
    auto type = decoder.decode<PAL::WebGPU::SamplerBindingType>();
    if (!type)
        return std::nullopt;

    return {
        WebKit::WebGPU::SamplerBindingLayout {
            WTFMove(*type)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::SamplerDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::SamplerDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.addressModeU)>, PAL::WebGPU::AddressMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.addressModeV)>, PAL::WebGPU::AddressMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.addressModeW)>, PAL::WebGPU::AddressMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.magFilter)>, PAL::WebGPU::FilterMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minFilter)>, PAL::WebGPU::FilterMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipmapFilter)>, PAL::WebGPU::MipmapFilterMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lodMinClamp)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lodMaxClamp)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compare)>, std::optional<PAL::WebGPU::CompareFunction>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxAnisotropy)>, uint16_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::SamplerDescriptor, addressModeU)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, addressModeV)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, addressModeW)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, magFilter)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, minFilter)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, mipmapFilter)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, lodMinClamp)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, lodMaxClamp)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, compare)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, maxAnisotropy)
    >::value);
    encoder << instance.label;
    encoder << instance.addressModeU;
    encoder << instance.addressModeV;
    encoder << instance.addressModeW;
    encoder << instance.magFilter;
    encoder << instance.minFilter;
    encoder << instance.mipmapFilter;
    encoder << instance.lodMinClamp;
    encoder << instance.lodMaxClamp;
    encoder << instance.compare;
    encoder << instance.maxAnisotropy;
}

void ArgumentCoder<WebKit::WebGPU::SamplerDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::SamplerDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.addressModeU)>, PAL::WebGPU::AddressMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.addressModeV)>, PAL::WebGPU::AddressMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.addressModeW)>, PAL::WebGPU::AddressMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.magFilter)>, PAL::WebGPU::FilterMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minFilter)>, PAL::WebGPU::FilterMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipmapFilter)>, PAL::WebGPU::MipmapFilterMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lodMinClamp)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.lodMaxClamp)>, float>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compare)>, std::optional<PAL::WebGPU::CompareFunction>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxAnisotropy)>, uint16_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::SamplerDescriptor, addressModeU)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, addressModeV)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, addressModeW)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, magFilter)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, minFilter)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, mipmapFilter)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, lodMinClamp)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, lodMaxClamp)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, compare)
        , offsetof(WebKit::WebGPU::SamplerDescriptor, maxAnisotropy)
    >::value);
    encoder << instance.label;
    encoder << instance.addressModeU;
    encoder << instance.addressModeV;
    encoder << instance.addressModeW;
    encoder << instance.magFilter;
    encoder << instance.minFilter;
    encoder << instance.mipmapFilter;
    encoder << instance.lodMinClamp;
    encoder << instance.lodMaxClamp;
    encoder << instance.compare;
    encoder << instance.maxAnisotropy;
}

std::optional<WebKit::WebGPU::SamplerDescriptor> ArgumentCoder<WebKit::WebGPU::SamplerDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto addressModeU = decoder.decode<PAL::WebGPU::AddressMode>();
    if (!addressModeU)
        return std::nullopt;

    auto addressModeV = decoder.decode<PAL::WebGPU::AddressMode>();
    if (!addressModeV)
        return std::nullopt;

    auto addressModeW = decoder.decode<PAL::WebGPU::AddressMode>();
    if (!addressModeW)
        return std::nullopt;

    auto magFilter = decoder.decode<PAL::WebGPU::FilterMode>();
    if (!magFilter)
        return std::nullopt;

    auto minFilter = decoder.decode<PAL::WebGPU::FilterMode>();
    if (!minFilter)
        return std::nullopt;

    auto mipmapFilter = decoder.decode<PAL::WebGPU::MipmapFilterMode>();
    if (!mipmapFilter)
        return std::nullopt;

    auto lodMinClamp = decoder.decode<float>();
    if (!lodMinClamp)
        return std::nullopt;

    auto lodMaxClamp = decoder.decode<float>();
    if (!lodMaxClamp)
        return std::nullopt;

    auto compare = decoder.decode<std::optional<PAL::WebGPU::CompareFunction>>();
    if (!compare)
        return std::nullopt;

    auto maxAnisotropy = decoder.decode<uint16_t>();
    if (!maxAnisotropy)
        return std::nullopt;

    return {
        WebKit::WebGPU::SamplerDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*addressModeU),
            WTFMove(*addressModeV),
            WTFMove(*addressModeW),
            WTFMove(*magFilter),
            WTFMove(*minFilter),
            WTFMove(*mipmapFilter),
            WTFMove(*lodMinClamp),
            WTFMove(*lodMaxClamp),
            WTFMove(*compare),
            WTFMove(*maxAnisotropy)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ShaderModuleCompilationHint>::encode(Encoder& encoder, const WebKit::WebGPU::ShaderModuleCompilationHint& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pipelineLayout)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ShaderModuleCompilationHint, pipelineLayout)
    >::value);
    encoder << instance.pipelineLayout;
}

void ArgumentCoder<WebKit::WebGPU::ShaderModuleCompilationHint>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ShaderModuleCompilationHint& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.pipelineLayout)>, WebKit::WebGPUIdentifier>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ShaderModuleCompilationHint, pipelineLayout)
    >::value);
    encoder << instance.pipelineLayout;
}

std::optional<WebKit::WebGPU::ShaderModuleCompilationHint> ArgumentCoder<WebKit::WebGPU::ShaderModuleCompilationHint>::decode(Decoder& decoder)
{
    auto pipelineLayout = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!pipelineLayout)
        return std::nullopt;

    return {
        WebKit::WebGPU::ShaderModuleCompilationHint {
            WTFMove(*pipelineLayout)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ShaderModuleDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::ShaderModuleDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.code)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hints)>, Vector<KeyValuePair<String, WebKit::WebGPU::ShaderModuleCompilationHint>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ShaderModuleDescriptor, code)
        , offsetof(WebKit::WebGPU::ShaderModuleDescriptor, hints)
    >::value);
    encoder << instance.label;
    encoder << instance.code;
    encoder << instance.hints;
}

void ArgumentCoder<WebKit::WebGPU::ShaderModuleDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ShaderModuleDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.code)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hints)>, Vector<KeyValuePair<String, WebKit::WebGPU::ShaderModuleCompilationHint>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ShaderModuleDescriptor, code)
        , offsetof(WebKit::WebGPU::ShaderModuleDescriptor, hints)
    >::value);
    encoder << instance.label;
    encoder << instance.code;
    encoder << instance.hints;
}

std::optional<WebKit::WebGPU::ShaderModuleDescriptor> ArgumentCoder<WebKit::WebGPU::ShaderModuleDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto code = decoder.decode<String>();
    if (!code)
        return std::nullopt;

    auto hints = decoder.decode<Vector<KeyValuePair<String, WebKit::WebGPU::ShaderModuleCompilationHint>>>();
    if (!hints)
        return std::nullopt;

    return {
        WebKit::WebGPU::ShaderModuleDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*code),
            WTFMove(*hints)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::StencilFaceState>::encode(Encoder& encoder, const WebKit::WebGPU::StencilFaceState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compare)>, PAL::WebGPU::CompareFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.failOp)>, PAL::WebGPU::StencilOperation>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthFailOp)>, PAL::WebGPU::StencilOperation>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.passOp)>, PAL::WebGPU::StencilOperation>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::StencilFaceState, compare)
        , offsetof(WebKit::WebGPU::StencilFaceState, failOp)
        , offsetof(WebKit::WebGPU::StencilFaceState, depthFailOp)
        , offsetof(WebKit::WebGPU::StencilFaceState, passOp)
    >::value);
    encoder << instance.compare;
    encoder << instance.failOp;
    encoder << instance.depthFailOp;
    encoder << instance.passOp;
}

void ArgumentCoder<WebKit::WebGPU::StencilFaceState>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::StencilFaceState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.compare)>, PAL::WebGPU::CompareFunction>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.failOp)>, PAL::WebGPU::StencilOperation>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.depthFailOp)>, PAL::WebGPU::StencilOperation>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.passOp)>, PAL::WebGPU::StencilOperation>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::StencilFaceState, compare)
        , offsetof(WebKit::WebGPU::StencilFaceState, failOp)
        , offsetof(WebKit::WebGPU::StencilFaceState, depthFailOp)
        , offsetof(WebKit::WebGPU::StencilFaceState, passOp)
    >::value);
    encoder << instance.compare;
    encoder << instance.failOp;
    encoder << instance.depthFailOp;
    encoder << instance.passOp;
}

std::optional<WebKit::WebGPU::StencilFaceState> ArgumentCoder<WebKit::WebGPU::StencilFaceState>::decode(Decoder& decoder)
{
    auto compare = decoder.decode<PAL::WebGPU::CompareFunction>();
    if (!compare)
        return std::nullopt;

    auto failOp = decoder.decode<PAL::WebGPU::StencilOperation>();
    if (!failOp)
        return std::nullopt;

    auto depthFailOp = decoder.decode<PAL::WebGPU::StencilOperation>();
    if (!depthFailOp)
        return std::nullopt;

    auto passOp = decoder.decode<PAL::WebGPU::StencilOperation>();
    if (!passOp)
        return std::nullopt;

    return {
        WebKit::WebGPU::StencilFaceState {
            WTFMove(*compare),
            WTFMove(*failOp),
            WTFMove(*depthFailOp),
            WTFMove(*passOp)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::StorageTextureBindingLayout>::encode(Encoder& encoder, const WebKit::WebGPU::StorageTextureBindingLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.access)>, PAL::WebGPU::StorageTextureAccess>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.viewDimension)>, PAL::WebGPU::TextureViewDimension>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::StorageTextureBindingLayout, access)
        , offsetof(WebKit::WebGPU::StorageTextureBindingLayout, format)
        , offsetof(WebKit::WebGPU::StorageTextureBindingLayout, viewDimension)
    >::value);
    encoder << instance.access;
    encoder << instance.format;
    encoder << instance.viewDimension;
}

void ArgumentCoder<WebKit::WebGPU::StorageTextureBindingLayout>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::StorageTextureBindingLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.access)>, PAL::WebGPU::StorageTextureAccess>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.viewDimension)>, PAL::WebGPU::TextureViewDimension>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::StorageTextureBindingLayout, access)
        , offsetof(WebKit::WebGPU::StorageTextureBindingLayout, format)
        , offsetof(WebKit::WebGPU::StorageTextureBindingLayout, viewDimension)
    >::value);
    encoder << instance.access;
    encoder << instance.format;
    encoder << instance.viewDimension;
}

std::optional<WebKit::WebGPU::StorageTextureBindingLayout> ArgumentCoder<WebKit::WebGPU::StorageTextureBindingLayout>::decode(Decoder& decoder)
{
    auto access = decoder.decode<PAL::WebGPU::StorageTextureAccess>();
    if (!access)
        return std::nullopt;

    auto format = decoder.decode<PAL::WebGPU::TextureFormat>();
    if (!format)
        return std::nullopt;

    auto viewDimension = decoder.decode<PAL::WebGPU::TextureViewDimension>();
    if (!viewDimension)
        return std::nullopt;

    return {
        WebKit::WebGPU::StorageTextureBindingLayout {
            WTFMove(*access),
            WTFMove(*format),
            WTFMove(*viewDimension)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::SupportedFeatures>::encode(Encoder& encoder, const WebKit::WebGPU::SupportedFeatures& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.features)>, Vector<String>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::SupportedFeatures, features)
    >::value);
    encoder << instance.features;
}

void ArgumentCoder<WebKit::WebGPU::SupportedFeatures>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::SupportedFeatures& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.features)>, Vector<String>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::SupportedFeatures, features)
    >::value);
    encoder << instance.features;
}

std::optional<WebKit::WebGPU::SupportedFeatures> ArgumentCoder<WebKit::WebGPU::SupportedFeatures>::decode(Decoder& decoder)
{
    auto features = decoder.decode<Vector<String>>();
    if (!features)
        return std::nullopt;

    return {
        WebKit::WebGPU::SupportedFeatures {
            WTFMove(*features)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::SupportedLimits>::encode(Encoder& encoder, const WebKit::WebGPU::SupportedLimits& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxTextureDimension1D)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxTextureDimension2D)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxTextureDimension3D)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxTextureArrayLayers)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxBindGroups)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxDynamicUniformBuffersPerPipelineLayout)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxDynamicStorageBuffersPerPipelineLayout)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxSampledTexturesPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxSamplersPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxStorageBuffersPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxStorageTexturesPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxUniformBuffersPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxUniformBufferBindingSize)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxStorageBufferBindingSize)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minUniformBufferOffsetAlignment)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minStorageBufferOffsetAlignment)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxVertexBuffers)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxVertexAttributes)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxVertexBufferArrayStride)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxInterStageShaderComponents)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupStorageSize)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeInvocationsPerWorkgroup)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupSizeX)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupSizeY)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupSizeZ)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupsPerDimension)>, uint32_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::SupportedLimits, maxTextureDimension1D)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxTextureDimension2D)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxTextureDimension3D)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxTextureArrayLayers)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxBindGroups)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxDynamicUniformBuffersPerPipelineLayout)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxDynamicStorageBuffersPerPipelineLayout)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxSampledTexturesPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxSamplersPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxStorageBuffersPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxStorageTexturesPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxUniformBuffersPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxUniformBufferBindingSize)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxStorageBufferBindingSize)
        , offsetof(WebKit::WebGPU::SupportedLimits, minUniformBufferOffsetAlignment)
        , offsetof(WebKit::WebGPU::SupportedLimits, minStorageBufferOffsetAlignment)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxVertexBuffers)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxVertexAttributes)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxVertexBufferArrayStride)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxInterStageShaderComponents)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupStorageSize)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeInvocationsPerWorkgroup)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupSizeX)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupSizeY)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupSizeZ)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupsPerDimension)
    >::value);
    encoder << instance.maxTextureDimension1D;
    encoder << instance.maxTextureDimension2D;
    encoder << instance.maxTextureDimension3D;
    encoder << instance.maxTextureArrayLayers;
    encoder << instance.maxBindGroups;
    encoder << instance.maxDynamicUniformBuffersPerPipelineLayout;
    encoder << instance.maxDynamicStorageBuffersPerPipelineLayout;
    encoder << instance.maxSampledTexturesPerShaderStage;
    encoder << instance.maxSamplersPerShaderStage;
    encoder << instance.maxStorageBuffersPerShaderStage;
    encoder << instance.maxStorageTexturesPerShaderStage;
    encoder << instance.maxUniformBuffersPerShaderStage;
    encoder << instance.maxUniformBufferBindingSize;
    encoder << instance.maxStorageBufferBindingSize;
    encoder << instance.minUniformBufferOffsetAlignment;
    encoder << instance.minStorageBufferOffsetAlignment;
    encoder << instance.maxVertexBuffers;
    encoder << instance.maxVertexAttributes;
    encoder << instance.maxVertexBufferArrayStride;
    encoder << instance.maxInterStageShaderComponents;
    encoder << instance.maxComputeWorkgroupStorageSize;
    encoder << instance.maxComputeInvocationsPerWorkgroup;
    encoder << instance.maxComputeWorkgroupSizeX;
    encoder << instance.maxComputeWorkgroupSizeY;
    encoder << instance.maxComputeWorkgroupSizeZ;
    encoder << instance.maxComputeWorkgroupsPerDimension;
}

void ArgumentCoder<WebKit::WebGPU::SupportedLimits>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::SupportedLimits& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxTextureDimension1D)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxTextureDimension2D)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxTextureDimension3D)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxTextureArrayLayers)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxBindGroups)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxDynamicUniformBuffersPerPipelineLayout)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxDynamicStorageBuffersPerPipelineLayout)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxSampledTexturesPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxSamplersPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxStorageBuffersPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxStorageTexturesPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxUniformBuffersPerShaderStage)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxUniformBufferBindingSize)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxStorageBufferBindingSize)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minUniformBufferOffsetAlignment)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minStorageBufferOffsetAlignment)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxVertexBuffers)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxVertexAttributes)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxVertexBufferArrayStride)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxInterStageShaderComponents)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupStorageSize)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeInvocationsPerWorkgroup)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupSizeX)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupSizeY)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupSizeZ)>, uint32_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxComputeWorkgroupsPerDimension)>, uint32_t>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::SupportedLimits, maxTextureDimension1D)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxTextureDimension2D)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxTextureDimension3D)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxTextureArrayLayers)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxBindGroups)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxDynamicUniformBuffersPerPipelineLayout)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxDynamicStorageBuffersPerPipelineLayout)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxSampledTexturesPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxSamplersPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxStorageBuffersPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxStorageTexturesPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxUniformBuffersPerShaderStage)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxUniformBufferBindingSize)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxStorageBufferBindingSize)
        , offsetof(WebKit::WebGPU::SupportedLimits, minUniformBufferOffsetAlignment)
        , offsetof(WebKit::WebGPU::SupportedLimits, minStorageBufferOffsetAlignment)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxVertexBuffers)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxVertexAttributes)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxVertexBufferArrayStride)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxInterStageShaderComponents)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupStorageSize)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeInvocationsPerWorkgroup)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupSizeX)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupSizeY)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupSizeZ)
        , offsetof(WebKit::WebGPU::SupportedLimits, maxComputeWorkgroupsPerDimension)
    >::value);
    encoder << instance.maxTextureDimension1D;
    encoder << instance.maxTextureDimension2D;
    encoder << instance.maxTextureDimension3D;
    encoder << instance.maxTextureArrayLayers;
    encoder << instance.maxBindGroups;
    encoder << instance.maxDynamicUniformBuffersPerPipelineLayout;
    encoder << instance.maxDynamicStorageBuffersPerPipelineLayout;
    encoder << instance.maxSampledTexturesPerShaderStage;
    encoder << instance.maxSamplersPerShaderStage;
    encoder << instance.maxStorageBuffersPerShaderStage;
    encoder << instance.maxStorageTexturesPerShaderStage;
    encoder << instance.maxUniformBuffersPerShaderStage;
    encoder << instance.maxUniformBufferBindingSize;
    encoder << instance.maxStorageBufferBindingSize;
    encoder << instance.minUniformBufferOffsetAlignment;
    encoder << instance.minStorageBufferOffsetAlignment;
    encoder << instance.maxVertexBuffers;
    encoder << instance.maxVertexAttributes;
    encoder << instance.maxVertexBufferArrayStride;
    encoder << instance.maxInterStageShaderComponents;
    encoder << instance.maxComputeWorkgroupStorageSize;
    encoder << instance.maxComputeInvocationsPerWorkgroup;
    encoder << instance.maxComputeWorkgroupSizeX;
    encoder << instance.maxComputeWorkgroupSizeY;
    encoder << instance.maxComputeWorkgroupSizeZ;
    encoder << instance.maxComputeWorkgroupsPerDimension;
}

std::optional<WebKit::WebGPU::SupportedLimits> ArgumentCoder<WebKit::WebGPU::SupportedLimits>::decode(Decoder& decoder)
{
    auto maxTextureDimension1D = decoder.decode<uint32_t>();
    if (!maxTextureDimension1D)
        return std::nullopt;

    auto maxTextureDimension2D = decoder.decode<uint32_t>();
    if (!maxTextureDimension2D)
        return std::nullopt;

    auto maxTextureDimension3D = decoder.decode<uint32_t>();
    if (!maxTextureDimension3D)
        return std::nullopt;

    auto maxTextureArrayLayers = decoder.decode<uint32_t>();
    if (!maxTextureArrayLayers)
        return std::nullopt;

    auto maxBindGroups = decoder.decode<uint32_t>();
    if (!maxBindGroups)
        return std::nullopt;

    auto maxDynamicUniformBuffersPerPipelineLayout = decoder.decode<uint32_t>();
    if (!maxDynamicUniformBuffersPerPipelineLayout)
        return std::nullopt;

    auto maxDynamicStorageBuffersPerPipelineLayout = decoder.decode<uint32_t>();
    if (!maxDynamicStorageBuffersPerPipelineLayout)
        return std::nullopt;

    auto maxSampledTexturesPerShaderStage = decoder.decode<uint32_t>();
    if (!maxSampledTexturesPerShaderStage)
        return std::nullopt;

    auto maxSamplersPerShaderStage = decoder.decode<uint32_t>();
    if (!maxSamplersPerShaderStage)
        return std::nullopt;

    auto maxStorageBuffersPerShaderStage = decoder.decode<uint32_t>();
    if (!maxStorageBuffersPerShaderStage)
        return std::nullopt;

    auto maxStorageTexturesPerShaderStage = decoder.decode<uint32_t>();
    if (!maxStorageTexturesPerShaderStage)
        return std::nullopt;

    auto maxUniformBuffersPerShaderStage = decoder.decode<uint32_t>();
    if (!maxUniformBuffersPerShaderStage)
        return std::nullopt;

    auto maxUniformBufferBindingSize = decoder.decode<uint64_t>();
    if (!maxUniformBufferBindingSize)
        return std::nullopt;

    auto maxStorageBufferBindingSize = decoder.decode<uint64_t>();
    if (!maxStorageBufferBindingSize)
        return std::nullopt;

    auto minUniformBufferOffsetAlignment = decoder.decode<uint32_t>();
    if (!minUniformBufferOffsetAlignment)
        return std::nullopt;

    auto minStorageBufferOffsetAlignment = decoder.decode<uint32_t>();
    if (!minStorageBufferOffsetAlignment)
        return std::nullopt;

    auto maxVertexBuffers = decoder.decode<uint32_t>();
    if (!maxVertexBuffers)
        return std::nullopt;

    auto maxVertexAttributes = decoder.decode<uint32_t>();
    if (!maxVertexAttributes)
        return std::nullopt;

    auto maxVertexBufferArrayStride = decoder.decode<uint32_t>();
    if (!maxVertexBufferArrayStride)
        return std::nullopt;

    auto maxInterStageShaderComponents = decoder.decode<uint32_t>();
    if (!maxInterStageShaderComponents)
        return std::nullopt;

    auto maxComputeWorkgroupStorageSize = decoder.decode<uint32_t>();
    if (!maxComputeWorkgroupStorageSize)
        return std::nullopt;

    auto maxComputeInvocationsPerWorkgroup = decoder.decode<uint32_t>();
    if (!maxComputeInvocationsPerWorkgroup)
        return std::nullopt;

    auto maxComputeWorkgroupSizeX = decoder.decode<uint32_t>();
    if (!maxComputeWorkgroupSizeX)
        return std::nullopt;

    auto maxComputeWorkgroupSizeY = decoder.decode<uint32_t>();
    if (!maxComputeWorkgroupSizeY)
        return std::nullopt;

    auto maxComputeWorkgroupSizeZ = decoder.decode<uint32_t>();
    if (!maxComputeWorkgroupSizeZ)
        return std::nullopt;

    auto maxComputeWorkgroupsPerDimension = decoder.decode<uint32_t>();
    if (!maxComputeWorkgroupsPerDimension)
        return std::nullopt;

    return {
        WebKit::WebGPU::SupportedLimits {
            WTFMove(*maxTextureDimension1D),
            WTFMove(*maxTextureDimension2D),
            WTFMove(*maxTextureDimension3D),
            WTFMove(*maxTextureArrayLayers),
            WTFMove(*maxBindGroups),
            WTFMove(*maxDynamicUniformBuffersPerPipelineLayout),
            WTFMove(*maxDynamicStorageBuffersPerPipelineLayout),
            WTFMove(*maxSampledTexturesPerShaderStage),
            WTFMove(*maxSamplersPerShaderStage),
            WTFMove(*maxStorageBuffersPerShaderStage),
            WTFMove(*maxStorageTexturesPerShaderStage),
            WTFMove(*maxUniformBuffersPerShaderStage),
            WTFMove(*maxUniformBufferBindingSize),
            WTFMove(*maxStorageBufferBindingSize),
            WTFMove(*minUniformBufferOffsetAlignment),
            WTFMove(*minStorageBufferOffsetAlignment),
            WTFMove(*maxVertexBuffers),
            WTFMove(*maxVertexAttributes),
            WTFMove(*maxVertexBufferArrayStride),
            WTFMove(*maxInterStageShaderComponents),
            WTFMove(*maxComputeWorkgroupStorageSize),
            WTFMove(*maxComputeInvocationsPerWorkgroup),
            WTFMove(*maxComputeWorkgroupSizeX),
            WTFMove(*maxComputeWorkgroupSizeY),
            WTFMove(*maxComputeWorkgroupSizeZ),
            WTFMove(*maxComputeWorkgroupsPerDimension)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::TextureBindingLayout>::encode(Encoder& encoder, const WebKit::WebGPU::TextureBindingLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampleType)>, PAL::WebGPU::TextureSampleType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.viewDimension)>, PAL::WebGPU::TextureViewDimension>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.multisampled)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::TextureBindingLayout, sampleType)
        , offsetof(WebKit::WebGPU::TextureBindingLayout, viewDimension)
        , offsetof(WebKit::WebGPU::TextureBindingLayout, multisampled)
    >::value);
    encoder << instance.sampleType;
    encoder << instance.viewDimension;
    encoder << instance.multisampled;
}

void ArgumentCoder<WebKit::WebGPU::TextureBindingLayout>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::TextureBindingLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampleType)>, PAL::WebGPU::TextureSampleType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.viewDimension)>, PAL::WebGPU::TextureViewDimension>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.multisampled)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::TextureBindingLayout, sampleType)
        , offsetof(WebKit::WebGPU::TextureBindingLayout, viewDimension)
        , offsetof(WebKit::WebGPU::TextureBindingLayout, multisampled)
    >::value);
    encoder << instance.sampleType;
    encoder << instance.viewDimension;
    encoder << instance.multisampled;
}

std::optional<WebKit::WebGPU::TextureBindingLayout> ArgumentCoder<WebKit::WebGPU::TextureBindingLayout>::decode(Decoder& decoder)
{
    auto sampleType = decoder.decode<PAL::WebGPU::TextureSampleType>();
    if (!sampleType)
        return std::nullopt;

    auto viewDimension = decoder.decode<PAL::WebGPU::TextureViewDimension>();
    if (!viewDimension)
        return std::nullopt;

    auto multisampled = decoder.decode<bool>();
    if (!multisampled)
        return std::nullopt;

    return {
        WebKit::WebGPU::TextureBindingLayout {
            WTFMove(*sampleType),
            WTFMove(*viewDimension),
            WTFMove(*multisampled)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::TextureDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::TextureDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size)>, WebKit::WebGPU::Extent3D>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipLevelCount)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampleCount)>, PAL::WebGPU::Size32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dimension)>, PAL::WebGPU::TextureDimension>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.usage)>, PAL::WebGPU::TextureUsageFlags>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.viewFormats)>, Vector<PAL::WebGPU::TextureFormat>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::TextureDescriptor, size)
        , offsetof(WebKit::WebGPU::TextureDescriptor, mipLevelCount)
        , offsetof(WebKit::WebGPU::TextureDescriptor, sampleCount)
        , offsetof(WebKit::WebGPU::TextureDescriptor, dimension)
        , offsetof(WebKit::WebGPU::TextureDescriptor, format)
        , offsetof(WebKit::WebGPU::TextureDescriptor, usage)
        , offsetof(WebKit::WebGPU::TextureDescriptor, viewFormats)
    >::value);
    encoder << instance.label;
    encoder << instance.size;
    encoder << instance.mipLevelCount;
    encoder << instance.sampleCount;
    encoder << instance.dimension;
    encoder << instance.format;
    encoder << instance.usage;
    encoder << instance.viewFormats;
}

void ArgumentCoder<WebKit::WebGPU::TextureDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::TextureDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.size)>, WebKit::WebGPU::Extent3D>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipLevelCount)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.sampleCount)>, PAL::WebGPU::Size32>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dimension)>, PAL::WebGPU::TextureDimension>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::TextureFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.usage)>, PAL::WebGPU::TextureUsageFlags>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.viewFormats)>, Vector<PAL::WebGPU::TextureFormat>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::TextureDescriptor, size)
        , offsetof(WebKit::WebGPU::TextureDescriptor, mipLevelCount)
        , offsetof(WebKit::WebGPU::TextureDescriptor, sampleCount)
        , offsetof(WebKit::WebGPU::TextureDescriptor, dimension)
        , offsetof(WebKit::WebGPU::TextureDescriptor, format)
        , offsetof(WebKit::WebGPU::TextureDescriptor, usage)
        , offsetof(WebKit::WebGPU::TextureDescriptor, viewFormats)
    >::value);
    encoder << instance.label;
    encoder << instance.size;
    encoder << instance.mipLevelCount;
    encoder << instance.sampleCount;
    encoder << instance.dimension;
    encoder << instance.format;
    encoder << instance.usage;
    encoder << instance.viewFormats;
}

std::optional<WebKit::WebGPU::TextureDescriptor> ArgumentCoder<WebKit::WebGPU::TextureDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto size = decoder.decode<WebKit::WebGPU::Extent3D>();
    if (!size)
        return std::nullopt;

    auto mipLevelCount = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!mipLevelCount)
        return std::nullopt;

    auto sampleCount = decoder.decode<PAL::WebGPU::Size32>();
    if (!sampleCount)
        return std::nullopt;

    auto dimension = decoder.decode<PAL::WebGPU::TextureDimension>();
    if (!dimension)
        return std::nullopt;

    auto format = decoder.decode<PAL::WebGPU::TextureFormat>();
    if (!format)
        return std::nullopt;

    auto usage = decoder.decode<PAL::WebGPU::TextureUsageFlags>();
    if (!usage)
        return std::nullopt;

    auto viewFormats = decoder.decode<Vector<PAL::WebGPU::TextureFormat>>();
    if (!viewFormats)
        return std::nullopt;

    return {
        WebKit::WebGPU::TextureDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*size),
            WTFMove(*mipLevelCount),
            WTFMove(*sampleCount),
            WTFMove(*dimension),
            WTFMove(*format),
            WTFMove(*usage),
            WTFMove(*viewFormats)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::TextureViewDescriptor>::encode(Encoder& encoder, const WebKit::WebGPU::TextureViewDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, std::optional<PAL::WebGPU::TextureFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dimension)>, std::optional<PAL::WebGPU::TextureViewDimension>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.aspect)>, PAL::WebGPU::TextureAspect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.baseMipLevel)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipLevelCount)>, std::optional<PAL::WebGPU::IntegerCoordinate>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.baseArrayLayer)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.arrayLayerCount)>, std::optional<PAL::WebGPU::IntegerCoordinate>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, format)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, dimension)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, aspect)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, baseMipLevel)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, mipLevelCount)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, baseArrayLayer)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, arrayLayerCount)
    >::value);
    encoder << instance.label;
    encoder << instance.format;
    encoder << instance.dimension;
    encoder << instance.aspect;
    encoder << instance.baseMipLevel;
    encoder << instance.mipLevelCount;
    encoder << instance.baseArrayLayer;
    encoder << instance.arrayLayerCount;
}

void ArgumentCoder<WebKit::WebGPU::TextureViewDescriptor>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::TextureViewDescriptor& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.label)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ObjectDescriptorBase, label)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, std::optional<PAL::WebGPU::TextureFormat>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.dimension)>, std::optional<PAL::WebGPU::TextureViewDimension>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.aspect)>, PAL::WebGPU::TextureAspect>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.baseMipLevel)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.mipLevelCount)>, std::optional<PAL::WebGPU::IntegerCoordinate>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.baseArrayLayer)>, PAL::WebGPU::IntegerCoordinate>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.arrayLayerCount)>, std::optional<PAL::WebGPU::IntegerCoordinate>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, format)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, dimension)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, aspect)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, baseMipLevel)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, mipLevelCount)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, baseArrayLayer)
        , offsetof(WebKit::WebGPU::TextureViewDescriptor, arrayLayerCount)
    >::value);
    encoder << instance.label;
    encoder << instance.format;
    encoder << instance.dimension;
    encoder << instance.aspect;
    encoder << instance.baseMipLevel;
    encoder << instance.mipLevelCount;
    encoder << instance.baseArrayLayer;
    encoder << instance.arrayLayerCount;
}

std::optional<WebKit::WebGPU::TextureViewDescriptor> ArgumentCoder<WebKit::WebGPU::TextureViewDescriptor>::decode(Decoder& decoder)
{
    auto label = decoder.decode<String>();
    if (!label)
        return std::nullopt;

    auto format = decoder.decode<std::optional<PAL::WebGPU::TextureFormat>>();
    if (!format)
        return std::nullopt;

    auto dimension = decoder.decode<std::optional<PAL::WebGPU::TextureViewDimension>>();
    if (!dimension)
        return std::nullopt;

    auto aspect = decoder.decode<PAL::WebGPU::TextureAspect>();
    if (!aspect)
        return std::nullopt;

    auto baseMipLevel = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!baseMipLevel)
        return std::nullopt;

    auto mipLevelCount = decoder.decode<std::optional<PAL::WebGPU::IntegerCoordinate>>();
    if (!mipLevelCount)
        return std::nullopt;

    auto baseArrayLayer = decoder.decode<PAL::WebGPU::IntegerCoordinate>();
    if (!baseArrayLayer)
        return std::nullopt;

    auto arrayLayerCount = decoder.decode<std::optional<PAL::WebGPU::IntegerCoordinate>>();
    if (!arrayLayerCount)
        return std::nullopt;

    return {
        WebKit::WebGPU::TextureViewDescriptor {
            WebKit::WebGPU::ObjectDescriptorBase {
                WTFMove(*label)
            },
            WTFMove(*format),
            WTFMove(*dimension),
            WTFMove(*aspect),
            WTFMove(*baseMipLevel),
            WTFMove(*mipLevelCount),
            WTFMove(*baseArrayLayer),
            WTFMove(*arrayLayerCount)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::ValidationError>::encode(Encoder& encoder, const WebKit::WebGPU::ValidationError& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ValidationError, message)
    >::value);
    encoder << instance.message;
}

void ArgumentCoder<WebKit::WebGPU::ValidationError>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::ValidationError& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.message)>, String>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ValidationError, message)
    >::value);
    encoder << instance.message;
}

std::optional<WebKit::WebGPU::ValidationError> ArgumentCoder<WebKit::WebGPU::ValidationError>::decode(Decoder& decoder)
{
    auto message = decoder.decode<String>();
    if (!message)
        return std::nullopt;

    return {
        WebKit::WebGPU::ValidationError {
            WTFMove(*message)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::VertexAttribute>::encode(Encoder& encoder, const WebKit::WebGPU::VertexAttribute& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::VertexFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shaderLocation)>, PAL::WebGPU::Index32>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::VertexAttribute, format)
        , offsetof(WebKit::WebGPU::VertexAttribute, offset)
        , offsetof(WebKit::WebGPU::VertexAttribute, shaderLocation)
    >::value);
    encoder << instance.format;
    encoder << instance.offset;
    encoder << instance.shaderLocation;
}

void ArgumentCoder<WebKit::WebGPU::VertexAttribute>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::VertexAttribute& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.format)>, PAL::WebGPU::VertexFormat>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.offset)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shaderLocation)>, PAL::WebGPU::Index32>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::VertexAttribute, format)
        , offsetof(WebKit::WebGPU::VertexAttribute, offset)
        , offsetof(WebKit::WebGPU::VertexAttribute, shaderLocation)
    >::value);
    encoder << instance.format;
    encoder << instance.offset;
    encoder << instance.shaderLocation;
}

std::optional<WebKit::WebGPU::VertexAttribute> ArgumentCoder<WebKit::WebGPU::VertexAttribute>::decode(Decoder& decoder)
{
    auto format = decoder.decode<PAL::WebGPU::VertexFormat>();
    if (!format)
        return std::nullopt;

    auto offset = decoder.decode<PAL::WebGPU::Size64>();
    if (!offset)
        return std::nullopt;

    auto shaderLocation = decoder.decode<PAL::WebGPU::Index32>();
    if (!shaderLocation)
        return std::nullopt;

    return {
        WebKit::WebGPU::VertexAttribute {
            WTFMove(*format),
            WTFMove(*offset),
            WTFMove(*shaderLocation)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::VertexBufferLayout>::encode(Encoder& encoder, const WebKit::WebGPU::VertexBufferLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.arrayStride)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stepMode)>, PAL::WebGPU::VertexStepMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.attributes)>, Vector<WebKit::WebGPU::VertexAttribute>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::VertexBufferLayout, arrayStride)
        , offsetof(WebKit::WebGPU::VertexBufferLayout, stepMode)
        , offsetof(WebKit::WebGPU::VertexBufferLayout, attributes)
    >::value);
    encoder << instance.arrayStride;
    encoder << instance.stepMode;
    encoder << instance.attributes;
}

void ArgumentCoder<WebKit::WebGPU::VertexBufferLayout>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::VertexBufferLayout& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.arrayStride)>, PAL::WebGPU::Size64>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.stepMode)>, PAL::WebGPU::VertexStepMode>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.attributes)>, Vector<WebKit::WebGPU::VertexAttribute>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::VertexBufferLayout, arrayStride)
        , offsetof(WebKit::WebGPU::VertexBufferLayout, stepMode)
        , offsetof(WebKit::WebGPU::VertexBufferLayout, attributes)
    >::value);
    encoder << instance.arrayStride;
    encoder << instance.stepMode;
    encoder << instance.attributes;
}

std::optional<WebKit::WebGPU::VertexBufferLayout> ArgumentCoder<WebKit::WebGPU::VertexBufferLayout>::decode(Decoder& decoder)
{
    auto arrayStride = decoder.decode<PAL::WebGPU::Size64>();
    if (!arrayStride)
        return std::nullopt;

    auto stepMode = decoder.decode<PAL::WebGPU::VertexStepMode>();
    if (!stepMode)
        return std::nullopt;

    auto attributes = decoder.decode<Vector<WebKit::WebGPU::VertexAttribute>>();
    if (!attributes)
        return std::nullopt;

    return {
        WebKit::WebGPU::VertexBufferLayout {
            WTFMove(*arrayStride),
            WTFMove(*stepMode),
            WTFMove(*attributes)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::WebGPU::VertexState>::encode(Encoder& encoder, const WebKit::WebGPU::VertexState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.module)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entryPoint)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.constants)>, Vector<KeyValuePair<String, double>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ProgrammableStage, module)
        , offsetof(WebKit::WebGPU::ProgrammableStage, entryPoint)
        , offsetof(WebKit::WebGPU::ProgrammableStage, constants)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buffers)>, Vector<std::optional<WebKit::WebGPU::VertexBufferLayout>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::VertexState, buffers)
    >::value);
    encoder << instance.module;
    encoder << instance.entryPoint;
    encoder << instance.constants;
    encoder << instance.buffers;
}

void ArgumentCoder<WebKit::WebGPU::VertexState>::encode(StreamConnectionEncoder& encoder, const WebKit::WebGPU::VertexState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.module)>, WebKit::WebGPUIdentifier>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.entryPoint)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.constants)>, Vector<KeyValuePair<String, double>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::ProgrammableStage, module)
        , offsetof(WebKit::WebGPU::ProgrammableStage, entryPoint)
        , offsetof(WebKit::WebGPU::ProgrammableStage, constants)
    >::value);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.buffers)>, Vector<std::optional<WebKit::WebGPU::VertexBufferLayout>>>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::WebGPU::VertexState, buffers)
    >::value);
    encoder << instance.module;
    encoder << instance.entryPoint;
    encoder << instance.constants;
    encoder << instance.buffers;
}

std::optional<WebKit::WebGPU::VertexState> ArgumentCoder<WebKit::WebGPU::VertexState>::decode(Decoder& decoder)
{
    auto module = decoder.decode<WebKit::WebGPUIdentifier>();
    if (!module)
        return std::nullopt;

    auto entryPoint = decoder.decode<String>();
    if (!entryPoint)
        return std::nullopt;

    auto constants = decoder.decode<Vector<KeyValuePair<String, double>>>();
    if (!constants)
        return std::nullopt;

    auto buffers = decoder.decode<Vector<std::optional<WebKit::WebGPU::VertexBufferLayout>>>();
    if (!buffers)
        return std::nullopt;

    return {
        WebKit::WebGPU::VertexState {
            WebKit::WebGPU::ProgrammableStage {
                WTFMove(*module),
                WTFMove(*entryPoint),
                WTFMove(*constants)
            },
            WTFMove(*buffers)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS)

void ArgumentCoder<WebKit::RemoteMediaPlayerConfiguration>::encode(Encoder& encoder, const WebKit::RemoteMediaPlayerConfiguration& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.engineDescription)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maximumDurationToCacheMediaTime)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supportsScanning)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supportsFullscreen)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supportsPictureInPicture)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supportsAcceleratedRendering)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supportsPlayAtHostTime)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.supportsPauseAtHostTime)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canPlayToWirelessPlaybackTarget)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.shouldIgnoreIntrinsicSize)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, engineDescription)
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, maximumDurationToCacheMediaTime)
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, supportsScanning)
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, supportsFullscreen)
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, supportsPictureInPicture)
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, supportsAcceleratedRendering)
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, supportsPlayAtHostTime)
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, supportsPauseAtHostTime)
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, canPlayToWirelessPlaybackTarget)
        , offsetof(WebKit::RemoteMediaPlayerConfiguration, shouldIgnoreIntrinsicSize)
    >::value);
    encoder << instance.engineDescription;
    encoder << instance.maximumDurationToCacheMediaTime;
    encoder << instance.supportsScanning;
    encoder << instance.supportsFullscreen;
    encoder << instance.supportsPictureInPicture;
    encoder << instance.supportsAcceleratedRendering;
    encoder << instance.supportsPlayAtHostTime;
    encoder << instance.supportsPauseAtHostTime;
    encoder << instance.canPlayToWirelessPlaybackTarget;
    encoder << instance.shouldIgnoreIntrinsicSize;
}

std::optional<WebKit::RemoteMediaPlayerConfiguration> ArgumentCoder<WebKit::RemoteMediaPlayerConfiguration>::decode(Decoder& decoder)
{
    auto engineDescription = decoder.decode<String>();
    if (!engineDescription)
        return std::nullopt;

    auto maximumDurationToCacheMediaTime = decoder.decode<double>();
    if (!maximumDurationToCacheMediaTime)
        return std::nullopt;

    auto supportsScanning = decoder.decode<bool>();
    if (!supportsScanning)
        return std::nullopt;

    auto supportsFullscreen = decoder.decode<bool>();
    if (!supportsFullscreen)
        return std::nullopt;

    auto supportsPictureInPicture = decoder.decode<bool>();
    if (!supportsPictureInPicture)
        return std::nullopt;

    auto supportsAcceleratedRendering = decoder.decode<bool>();
    if (!supportsAcceleratedRendering)
        return std::nullopt;

    auto supportsPlayAtHostTime = decoder.decode<bool>();
    if (!supportsPlayAtHostTime)
        return std::nullopt;

    auto supportsPauseAtHostTime = decoder.decode<bool>();
    if (!supportsPauseAtHostTime)
        return std::nullopt;

    auto canPlayToWirelessPlaybackTarget = decoder.decode<bool>();
    if (!canPlayToWirelessPlaybackTarget)
        return std::nullopt;

    auto shouldIgnoreIntrinsicSize = decoder.decode<bool>();
    if (!shouldIgnoreIntrinsicSize)
        return std::nullopt;

    return {
        WebKit::RemoteMediaPlayerConfiguration {
            WTFMove(*engineDescription),
            WTFMove(*maximumDurationToCacheMediaTime),
            WTFMove(*supportsScanning),
            WTFMove(*supportsFullscreen),
            WTFMove(*supportsPictureInPicture),
            WTFMove(*supportsAcceleratedRendering),
            WTFMove(*supportsPlayAtHostTime),
            WTFMove(*supportsPauseAtHostTime),
            WTFMove(*canPlayToWirelessPlaybackTarget),
            WTFMove(*shouldIgnoreIntrinsicSize)
        }
    };
}

#endif

#if ENABLE(GPU_PROCESS) && ENABLE(VIDEO)

void ArgumentCoder<WebKit::RemoteMediaPlayerState>::encode(Encoder& encoder, const WebKit::RemoteMediaPlayerState& instance)
{
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.duration)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minTimeSeekable)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxTimeSeekable)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startDate)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.startTime)>, MediaTime>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.languageOfPrimaryAudioTrack)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.wirelessPlaybackTargetName)>, String>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.bufferedRanges)>, WebCore::PlatformTimeRanges>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.networkState)>, WebCore::MediaPlayerEnums::NetworkState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.readyState)>, WebCore::MediaPlayerEnums::ReadyState>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.movieLoadType)>, WebCore::MediaPlayerEnums::MovieLoadType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.wirelessPlaybackTargetType)>, WebCore::MediaPlayerEnums::WirelessPlaybackTargetType>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.naturalSize)>, WebCore::FloatSize>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.maxFastForwardRate)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.minFastReverseRate)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.seekableTimeRangesLastModifiedTime)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.liveUpdateInterval)>, double>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.totalBytes)>, uint64_t>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.videoMetrics)>, std::optional<WebCore::VideoPlaybackQualityMetrics>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.documentIsCrossOrigin)>, std::optional<bool>>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.paused)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.canSaveMediaData)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasAudio)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasVideo)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasClosedCaptions)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.hasAvailableVideoFrame)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.wirelessVideoPlaybackDisabled)>, bool>);
    static_assert(std::is_same_v<std::remove_cvref_t<decltype(instance.didPassCORSAccessCheck)>, bool>);
    static_assert(MembersInCorrectOrder<0
        , offsetof(WebKit::RemoteMediaPlayerState, duration)
        , offsetof(WebKit::RemoteMediaPlayerState, minTimeSeekable)
        , offsetof(WebKit::RemoteMediaPlayerState, maxTimeSeekable)
        , offsetof(WebKit::RemoteMediaPlayerState, startDate)
        , offsetof(WebKit::RemoteMediaPlayerState, startTime)
        , offsetof(WebKit::RemoteMediaPlayerState, languageOfPrimaryAudioTrack)
        , offsetof(WebKit::RemoteMediaPlayerState, wirelessPlaybackTargetName)
        , offsetof(WebKit::RemoteMediaPlayerState, bufferedRanges)
        , offsetof(WebKit::RemoteMediaPlayerState, networkState)
        , offsetof(WebKit::RemoteMediaPlayerState, readyState)
        , offsetof(WebKit::RemoteMediaPlayerState, movieLoadType)
        , offsetof(WebKit::RemoteMediaPlayerState, wirelessPlaybackTargetType)
        , offsetof(WebKit::RemoteMediaPlayerState, naturalSize)
        , offsetof(WebKit::RemoteMediaPlayerState, maxFastForwardRate)
        , offsetof(WebKit::RemoteMediaPlayerState, minFastReverseRate)
        , offsetof(WebKit::RemoteMediaPlayerState, seekableTimeRangesLastModifiedTime)
        , offsetof(WebKit::RemoteMediaPlayerState, liveUpdateInterval)
        , offsetof(WebKit::RemoteMediaPlayerState, totalBytes)
        , offsetof(WebKit::RemoteMediaPlayerState, videoMetrics)
        , offsetof(WebKit::RemoteMediaPlayerState, documentIsCrossOrigin)
        , offsetof(WebKit::RemoteMediaPlayerState, paused)
        , offsetof(WebKit::RemoteMediaPlayerState, canSaveMediaData)
        , offsetof(WebKit::RemoteMediaPlayerState, hasAudio)
        , offsetof(WebKit::RemoteMediaPlayerState, hasVideo)
        , offsetof(WebKit::RemoteMediaPlayerState, hasClosedCaptions)
        , offsetof(WebKit::RemoteMediaPlayerState, hasAvailableVideoFrame)
        , offsetof(WebKit::RemoteMediaPlayerState, wirelessVideoPlaybackDisabled)
        , offsetof(WebKit::RemoteMediaPlayerState, didPassCORSAccessCheck)
    >::value);
    encoder << instance.duration;
    encoder << instance.minTimeSeekable;
    encoder << instance.maxTimeSeekable;
    encoder << instance.startDate;
    encoder << instance.startTime;
    encoder << instance.languageOfPrimaryAudioTrack;
    encoder << instance.wirelessPlaybackTargetName;
    encoder << instance.bufferedRanges;
    encoder << instance.networkState;
    encoder << instance.readyState;
    encoder << instance.movieLoadType;
    encoder << instance.wirelessPlaybackTargetType;
    encoder << instance.naturalSize;
    encoder << instance.maxFastForwardRate;
    encoder << instance.minFastReverseRate;
    encoder << instance.seekableTimeRangesLastModifiedTime;
    encoder << instance.liveUpdateInterval;
    encoder << instance.totalBytes;
    encoder << instance.videoMetrics;
    encoder << instance.documentIsCrossOrigin;
    encoder << instance.paused;
    encoder << instance.canSaveMediaData;
    encoder << instance.hasAudio;
    encoder << instance.hasVideo;
    encoder << instance.hasClosedCaptions;
    encoder << instance.hasAvailableVideoFrame;
    encoder << instance.wirelessVideoPlaybackDisabled;
    encoder << instance.didPassCORSAccessCheck;
}

std::optional<WebKit::RemoteMediaPlayerState> ArgumentCoder<WebKit::RemoteMediaPlayerState>::decode(Decoder& decoder)
{
    auto duration = decoder.decode<MediaTime>();
    if (!duration)
        return std::nullopt;

    auto minTimeSeekable = decoder.decode<MediaTime>();
    if (!minTimeSeekable)
        return std::nullopt;

    auto maxTimeSeekable = decoder.decode<MediaTime>();
    if (!maxTimeSeekable)
        return std::nullopt;

    auto startDate = decoder.decode<MediaTime>();
    if (!startDate)
        return std::nullopt;

    auto startTime = decoder.decode<MediaTime>();
    if (!startTime)
        return std::nullopt;

    auto languageOfPrimaryAudioTrack = decoder.decode<String>();
    if (!languageOfPrimaryAudioTrack)
        return std::nullopt;

    auto wirelessPlaybackTargetName = decoder.decode<String>();
    if (!wirelessPlaybackTargetName)
        return std::nullopt;

    auto bufferedRanges = decoder.decode<WebCore::PlatformTimeRanges>();
    if (!bufferedRanges)
        return std::nullopt;

    auto networkState = decoder.decode<WebCore::MediaPlayerEnums::NetworkState>();
    if (!networkState)
        return std::nullopt;

    auto readyState = decoder.decode<WebCore::MediaPlayerEnums::ReadyState>();
    if (!readyState)
        return std::nullopt;

    auto movieLoadType = decoder.decode<WebCore::MediaPlayerEnums::MovieLoadType>();
    if (!movieLoadType)
        return std::nullopt;

    auto wirelessPlaybackTargetType = decoder.decode<WebCore::MediaPlayerEnums::WirelessPlaybackTargetType>();
    if (!wirelessPlaybackTargetType)
        return std::nullopt;

    auto naturalSize = decoder.decode<WebCore::FloatSize>();
    if (!naturalSize)
        return std::nullopt;

    auto maxFastForwardRate = decoder.decode<double>();
    if (!maxFastForwardRate)
        return std::nullopt;

    auto minFastReverseRate = decoder.decode<double>();
    if (!minFastReverseRate)
        return std::nullopt;

    auto seekableTimeRangesLastModifiedTime = decoder.decode<double>();
    if (!seekableTimeRangesLastModifiedTime)
        return std::nullopt;

    auto liveUpdateInterval = decoder.decode<double>();
    if (!liveUpdateInterval)
        return std::nullopt;

    auto totalBytes = decoder.decode<uint64_t>();
    if (!totalBytes)
        return std::nullopt;

    auto videoMetrics = decoder.decode<std::optional<WebCore::VideoPlaybackQualityMetrics>>();
    if (!videoMetrics)
        return std::nullopt;

    auto documentIsCrossOrigin = decoder.decode<std::optional<bool>>();
    if (!documentIsCrossOrigin)
        return std::nullopt;

    auto paused = decoder.decode<bool>();
    if (!paused)
        return std::nullopt;

    auto canSaveMediaData = decoder.decode<bool>();
    if (!canSaveMediaData)
        return std::nullopt;

    auto hasAudio = decoder.decode<bool>();
    if (!hasAudio)
        return std::nullopt;

    auto hasVideo = decoder.decode<bool>();
    if (!hasVideo)
        return std::nullopt;

    auto hasClosedCaptions = decoder.decode<bool>();
    if (!hasClosedCaptions)
        return std::nullopt;

    auto hasAvailableVideoFrame = decoder.decode<bool>();
    if (!hasAvailableVideoFrame)
        return std::nullopt;

    auto wirelessVideoPlaybackDisabled = decoder.decode<bool>();
    if (!wirelessVideoPlaybackDisabled)
        return std::nullopt;

    auto didPassCORSAccessCheck = decoder.decode<bool>();
    if (!didPassCORSAccessCheck)
        return std::nullopt;

    return {
        WebKit::RemoteMediaPlayerState {
            WTFMove(*duration),
            WTFMove(*minTimeSeekable),
            WTFMove(*maxTimeSeekable),
            WTFMove(*startDate),
            WTFMove(*startTime),
            WTFMove(*languageOfPrimaryAudioTrack),
            WTFMove(*wirelessPlaybackTargetName),
            WTFMove(*bufferedRanges),
            WTFMove(*networkState),
            WTFMove(*readyState),
            WTFMove(*movieLoadType),
            WTFMove(*wirelessPlaybackTargetType),
            WTFMove(*naturalSize),
            WTFMove(*maxFastForwardRate),
            WTFMove(*minFastReverseRate),
            WTFMove(*seekableTimeRangesLastModifiedTime),
            WTFMove(*liveUpdateInterval),
            WTFMove(*totalBytes),
            WTFMove(*videoMetrics),
            WTFMove(*documentIsCrossOrigin),
            WTFMove(*paused),
            WTFMove(*canSaveMediaData),
            WTFMove(*hasAudio),
            WTFMove(*hasVideo),
            WTFMove(*hasClosedCaptions),
            WTFMove(*hasAvailableVideoFrame),
            WTFMove(*wirelessVideoPlaybackDisabled),
            WTFMove(*didPassCORSAccessCheck)
        }
    };
}

#endif

} // namespace IPC

namespace WTF {

template<> bool isValidEnum<IPC::WebCore_TimingFunction_Subclass, void>(uint8_t value)
{
    switch (static_cast<IPC::WebCore_TimingFunction_Subclass>(value)) {
    case IPC::WebCore_TimingFunction_Subclass::LinearTimingFunction:
    case IPC::WebCore_TimingFunction_Subclass::CubicBezierTimingFunction:
    case IPC::WebCore_TimingFunction_Subclass::StepsTimingFunction:
    case IPC::WebCore_TimingFunction_Subclass::SpringTimingFunction:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<IPC::WebCore_TransformOperation_Subclass, void>(uint8_t value)
{
    switch (static_cast<IPC::WebCore_TransformOperation_Subclass>(value)) {
    case IPC::WebCore_TransformOperation_Subclass::TranslateTransformOperation:
    case IPC::WebCore_TransformOperation_Subclass::ScaleTransformOperation:
    case IPC::WebCore_TransformOperation_Subclass::RotateTransformOperation:
    case IPC::WebCore_TransformOperation_Subclass::SkewTransformOperation:
    case IPC::WebCore_TransformOperation_Subclass::MatrixTransformOperation:
    case IPC::WebCore_TransformOperation_Subclass::Matrix3DTransformOperation:
    case IPC::WebCore_TransformOperation_Subclass::PerspectiveTransformOperation:
    case IPC::WebCore_TransformOperation_Subclass::IdentityTransformOperation:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<IPC::WebCore_BasicShape_Subclass, void>(uint8_t value)
{
    switch (static_cast<IPC::WebCore_BasicShape_Subclass>(value)) {
    case IPC::WebCore_BasicShape_Subclass::BasicShapeCircle:
    case IPC::WebCore_BasicShape_Subclass::BasicShapeEllipse:
    case IPC::WebCore_BasicShape_Subclass::BasicShapePolygon:
    case IPC::WebCore_BasicShape_Subclass::BasicShapePath:
    case IPC::WebCore_BasicShape_Subclass::BasicShapeInset:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<IPC::WebCore_PathOperation_Subclass, void>(uint8_t value)
{
    switch (static_cast<IPC::WebCore_PathOperation_Subclass>(value)) {
    case IPC::WebCore_PathOperation_Subclass::ReferencePathOperation:
    case IPC::WebCore_PathOperation_Subclass::ShapePathOperation:
    case IPC::WebCore_PathOperation_Subclass::BoxPathOperation:
    case IPC::WebCore_PathOperation_Subclass::RayPathOperation:
        return true;
    default:
        return false;
    }
}

#if ENABLE(INLINE_PATH_DATA)
template<> bool isValidEnum<WebCore::ArcData::Type, void>(uint8_t value)
{
    switch (static_cast<WebCore::ArcData::Type>(value)) {
    case WebCore::ArcData::Type::ArcOnly:
    case WebCore::ArcData::Type::LineAndArc:
    case WebCore::ArcData::Type::ClosedLineAndArc:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<PAL::WebGPU::TextureFormat, void>(uint8_t value)
{
    switch (static_cast<PAL::WebGPU::TextureFormat>(value)) {
    case PAL::WebGPU::TextureFormat::R8unorm:
    case PAL::WebGPU::TextureFormat::R8snorm:
    case PAL::WebGPU::TextureFormat::R8uint:
    case PAL::WebGPU::TextureFormat::R8sint:
    case PAL::WebGPU::TextureFormat::R16uint:
    case PAL::WebGPU::TextureFormat::R16sint:
    case PAL::WebGPU::TextureFormat::R16float:
    case PAL::WebGPU::TextureFormat::Rg8unorm:
    case PAL::WebGPU::TextureFormat::Rg8snorm:
    case PAL::WebGPU::TextureFormat::Rg8uint:
    case PAL::WebGPU::TextureFormat::Rg8sint:
    case PAL::WebGPU::TextureFormat::R32uint:
    case PAL::WebGPU::TextureFormat::R32sint:
    case PAL::WebGPU::TextureFormat::R32float:
    case PAL::WebGPU::TextureFormat::Rg16uint:
    case PAL::WebGPU::TextureFormat::Rg16sint:
    case PAL::WebGPU::TextureFormat::Rg16float:
    case PAL::WebGPU::TextureFormat::Rgba8unorm:
    case PAL::WebGPU::TextureFormat::Rgba8unormSRGB:
    case PAL::WebGPU::TextureFormat::Rgba8snorm:
    case PAL::WebGPU::TextureFormat::Rgba8uint:
    case PAL::WebGPU::TextureFormat::Rgba8sint:
    case PAL::WebGPU::TextureFormat::Bgra8unorm:
    case PAL::WebGPU::TextureFormat::Bgra8unormSRGB:
    case PAL::WebGPU::TextureFormat::Rgb9e5ufloat:
    case PAL::WebGPU::TextureFormat::Rgb10a2unorm:
    case PAL::WebGPU::TextureFormat::Rg11b10ufloat:
    case PAL::WebGPU::TextureFormat::Rg32uint:
    case PAL::WebGPU::TextureFormat::Rg32sint:
    case PAL::WebGPU::TextureFormat::Rg32float:
    case PAL::WebGPU::TextureFormat::Rgba16uint:
    case PAL::WebGPU::TextureFormat::Rgba16sint:
    case PAL::WebGPU::TextureFormat::Rgba16float:
    case PAL::WebGPU::TextureFormat::Rgba32uint:
    case PAL::WebGPU::TextureFormat::Rgba32sint:
    case PAL::WebGPU::TextureFormat::Rgba32float:
    case PAL::WebGPU::TextureFormat::Stencil8:
    case PAL::WebGPU::TextureFormat::Depth16unorm:
    case PAL::WebGPU::TextureFormat::Depth24plus:
    case PAL::WebGPU::TextureFormat::Depth24plusStencil8:
    case PAL::WebGPU::TextureFormat::Depth32float:
    case PAL::WebGPU::TextureFormat::Depth32floatStencil8:
    case PAL::WebGPU::TextureFormat::Bc1RgbaUnorm:
    case PAL::WebGPU::TextureFormat::Bc1RgbaUnormSRGB:
    case PAL::WebGPU::TextureFormat::Bc2RgbaUnorm:
    case PAL::WebGPU::TextureFormat::Bc2RgbaUnormSRGB:
    case PAL::WebGPU::TextureFormat::Bc3RgbaUnorm:
    case PAL::WebGPU::TextureFormat::Bc3RgbaUnormSRGB:
    case PAL::WebGPU::TextureFormat::Bc4RUnorm:
    case PAL::WebGPU::TextureFormat::Bc4RSnorm:
    case PAL::WebGPU::TextureFormat::Bc5RgUnorm:
    case PAL::WebGPU::TextureFormat::Bc5RgSnorm:
    case PAL::WebGPU::TextureFormat::Bc6hRgbUfloat:
    case PAL::WebGPU::TextureFormat::Bc6hRgbFloat:
    case PAL::WebGPU::TextureFormat::Bc7RgbaUnorm:
    case PAL::WebGPU::TextureFormat::Bc7RgbaUnormSRGB:
    case PAL::WebGPU::TextureFormat::Etc2Rgb8unorm:
    case PAL::WebGPU::TextureFormat::Etc2Rgb8unormSRGB:
    case PAL::WebGPU::TextureFormat::Etc2Rgb8a1unorm:
    case PAL::WebGPU::TextureFormat::Etc2Rgb8a1unormSRGB:
    case PAL::WebGPU::TextureFormat::Etc2Rgba8unorm:
    case PAL::WebGPU::TextureFormat::Etc2Rgba8unormSRGB:
    case PAL::WebGPU::TextureFormat::EacR11unorm:
    case PAL::WebGPU::TextureFormat::EacR11snorm:
    case PAL::WebGPU::TextureFormat::EacRg11unorm:
    case PAL::WebGPU::TextureFormat::EacRg11snorm:
    case PAL::WebGPU::TextureFormat::Astc4x4Unorm:
    case PAL::WebGPU::TextureFormat::Astc4x4UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc5x4Unorm:
    case PAL::WebGPU::TextureFormat::Astc5x4UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc5x5Unorm:
    case PAL::WebGPU::TextureFormat::Astc5x5UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc6x5Unorm:
    case PAL::WebGPU::TextureFormat::Astc6x5UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc6x6Unorm:
    case PAL::WebGPU::TextureFormat::Astc6x6UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc8x5Unorm:
    case PAL::WebGPU::TextureFormat::Astc8x5UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc8x6Unorm:
    case PAL::WebGPU::TextureFormat::Astc8x6UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc8x8Unorm:
    case PAL::WebGPU::TextureFormat::Astc8x8UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc10x5Unorm:
    case PAL::WebGPU::TextureFormat::Astc10x5UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc10x6Unorm:
    case PAL::WebGPU::TextureFormat::Astc10x6UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc10x8Unorm:
    case PAL::WebGPU::TextureFormat::Astc10x8UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc10x10Unorm:
    case PAL::WebGPU::TextureFormat::Astc10x10UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc12x10Unorm:
    case PAL::WebGPU::TextureFormat::Astc12x10UnormSRGB:
    case PAL::WebGPU::TextureFormat::Astc12x12Unorm:
    case PAL::WebGPU::TextureFormat::Astc12x12UnormSRGB:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<PAL::WebGPU::TextureAspect, void>(uint8_t value)
{
    switch (static_cast<PAL::WebGPU::TextureAspect>(value)) {
    case PAL::WebGPU::TextureAspect::All:
    case PAL::WebGPU::TextureAspect::StencilOnly:
    case PAL::WebGPU::TextureAspect::DepthOnly:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<PAL::WebGPU::PredefinedColorSpace, void>(uint8_t value)
{
    switch (static_cast<PAL::WebGPU::PredefinedColorSpace>(value)) {
    case PAL::WebGPU::PredefinedColorSpace::SRGB:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebKit::SameDocumentNavigationType, void>(uint8_t value)
{
    switch (static_cast<WebKit::SameDocumentNavigationType>(value)) {
    case WebKit::SameDocumentNavigationType::AnchorNavigation:
    case WebKit::SameDocumentNavigationType::SessionStatePush:
    case WebKit::SameDocumentNavigationType::SessionStateReplace:
    case WebKit::SameDocumentNavigationType::SessionStatePop:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontWidthVariant, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontWidthVariant>(value)) {
    case WebCore::FontWidthVariant::RegularWidth:
    case WebCore::FontWidthVariant::HalfWidth:
    case WebCore::FontWidthVariant::ThirdWidth:
    case WebCore::FontWidthVariant::QuarterWidth:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::Kerning, void>(uint8_t value)
{
    switch (static_cast<WebCore::Kerning>(value)) {
    case WebCore::Kerning::Auto:
    case WebCore::Kerning::Normal:
    case WebCore::Kerning::NoShift:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontOpticalSizing, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontOpticalSizing>(value)) {
    case WebCore::FontOpticalSizing::Enabled:
    case WebCore::FontOpticalSizing::Disabled:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontStyleAxis, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontStyleAxis>(value)) {
    case WebCore::FontStyleAxis::slnt:
    case WebCore::FontStyleAxis::ital:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::AllowUserInstalledFonts, void>(uint8_t value)
{
    switch (static_cast<WebCore::AllowUserInstalledFonts>(value)) {
    case WebCore::AllowUserInstalledFonts::No:
    case WebCore::AllowUserInstalledFonts::Yes:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontVariantEastAsianVariant, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontVariantEastAsianVariant>(value)) {
    case WebCore::FontVariantEastAsianVariant::Normal:
    case WebCore::FontVariantEastAsianVariant::Jis78:
    case WebCore::FontVariantEastAsianVariant::Jis83:
    case WebCore::FontVariantEastAsianVariant::Jis90:
    case WebCore::FontVariantEastAsianVariant::Jis04:
    case WebCore::FontVariantEastAsianVariant::Simplified:
    case WebCore::FontVariantEastAsianVariant::Traditional:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontVariantEastAsianWidth, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontVariantEastAsianWidth>(value)) {
    case WebCore::FontVariantEastAsianWidth::Normal:
    case WebCore::FontVariantEastAsianWidth::Full:
    case WebCore::FontVariantEastAsianWidth::Proportional:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontVariantEastAsianRuby, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontVariantEastAsianRuby>(value)) {
    case WebCore::FontVariantEastAsianRuby::Normal:
    case WebCore::FontVariantEastAsianRuby::Yes:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontVariantLigatures, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontVariantLigatures>(value)) {
    case WebCore::FontVariantLigatures::Normal:
    case WebCore::FontVariantLigatures::Yes:
    case WebCore::FontVariantLigatures::No:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontVariantPosition, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontVariantPosition>(value)) {
    case WebCore::FontVariantPosition::Normal:
    case WebCore::FontVariantPosition::Subscript:
    case WebCore::FontVariantPosition::Superscript:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontVariantCaps, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontVariantCaps>(value)) {
    case WebCore::FontVariantCaps::Normal:
    case WebCore::FontVariantCaps::Small:
    case WebCore::FontVariantCaps::AllSmall:
    case WebCore::FontVariantCaps::Petite:
    case WebCore::FontVariantCaps::AllPetite:
    case WebCore::FontVariantCaps::Unicase:
    case WebCore::FontVariantCaps::Titling:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontVariantNumericFigure, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontVariantNumericFigure>(value)) {
    case WebCore::FontVariantNumericFigure::Normal:
    case WebCore::FontVariantNumericFigure::LiningNumbers:
    case WebCore::FontVariantNumericFigure::OldStyleNumbers:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontVariantNumericSpacing, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontVariantNumericSpacing>(value)) {
    case WebCore::FontVariantNumericSpacing::Normal:
    case WebCore::FontVariantNumericSpacing::ProportionalNumbers:
    case WebCore::FontVariantNumericSpacing::TabularNumbers:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontVariantNumericFraction, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontVariantNumericFraction>(value)) {
    case WebCore::FontVariantNumericFraction::Normal:
    case WebCore::FontVariantNumericFraction::DiagonalFractions:
    case WebCore::FontVariantNumericFraction::StackedFractions:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::TextRenderingMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::TextRenderingMode>(value)) {
    case WebCore::TextRenderingMode::AutoTextRendering:
    case WebCore::TextRenderingMode::OptimizeSpeed:
    case WebCore::TextRenderingMode::OptimizeLegibility:
    case WebCore::TextRenderingMode::GeometricPrecision:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontSmoothingMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontSmoothingMode>(value)) {
    case WebCore::FontSmoothingMode::AutoSmoothing:
    case WebCore::FontSmoothingMode::NoSmoothing:
    case WebCore::FontSmoothingMode::Antialiased:
    case WebCore::FontSmoothingMode::SubpixelAntialiased:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontOrientation, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontOrientation>(value)) {
    case WebCore::FontOrientation::Horizontal:
    case WebCore::FontOrientation::Vertical:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::NonCJKGlyphOrientation, void>(uint8_t value)
{
    switch (static_cast<WebCore::NonCJKGlyphOrientation>(value)) {
    case WebCore::NonCJKGlyphOrientation::Mixed:
    case WebCore::NonCJKGlyphOrientation::Upright:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::IndexedDB::KeyType, void>(int8_t value)
{
    switch (static_cast<WebCore::IndexedDB::KeyType>(value)) {
    case WebCore::IndexedDB::KeyType::Max:
    case WebCore::IndexedDB::KeyType::Invalid:
    case WebCore::IndexedDB::KeyType::Array:
    case WebCore::IndexedDB::KeyType::Binary:
    case WebCore::IndexedDB::KeyType::String:
    case WebCore::IndexedDB::KeyType::Date:
    case WebCore::IndexedDB::KeyType::Number:
    case WebCore::IndexedDB::KeyType::Min:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::IndexedDB::CursorDirection, void>(uint8_t value)
{
    switch (static_cast<WebCore::IndexedDB::CursorDirection>(value)) {
    case WebCore::IndexedDB::CursorDirection::Next:
    case WebCore::IndexedDB::CursorDirection::Nextunique:
    case WebCore::IndexedDB::CursorDirection::Prev:
    case WebCore::IndexedDB::CursorDirection::Prevunique:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::IndexedDB::ObjectStoreOverwriteMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::IndexedDB::ObjectStoreOverwriteMode>(value)) {
    case WebCore::IndexedDB::ObjectStoreOverwriteMode::Overwrite:
    case WebCore::IndexedDB::ObjectStoreOverwriteMode::OverwriteForCursor:
    case WebCore::IndexedDB::ObjectStoreOverwriteMode::NoOverwrite:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::IndexedDB::RequestType, void>(uint8_t value)
{
    switch (static_cast<WebCore::IndexedDB::RequestType>(value)) {
    case WebCore::IndexedDB::RequestType::Open:
    case WebCore::IndexedDB::RequestType::Delete:
    case WebCore::IndexedDB::RequestType::Other:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::CubicBezierTimingFunction::TimingFunctionPreset, void>(uint8_t value)
{
    switch (static_cast<WebCore::CubicBezierTimingFunction::TimingFunctionPreset>(value)) {
    case WebCore::CubicBezierTimingFunction::TimingFunctionPreset::Ease:
    case WebCore::CubicBezierTimingFunction::TimingFunctionPreset::EaseIn:
    case WebCore::CubicBezierTimingFunction::TimingFunctionPreset::EaseOut:
    case WebCore::CubicBezierTimingFunction::TimingFunctionPreset::EaseInOut:
    case WebCore::CubicBezierTimingFunction::TimingFunctionPreset::Custom:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::StepsTimingFunction::StepPosition, void>(uint8_t value)
{
    switch (static_cast<WebCore::StepsTimingFunction::StepPosition>(value)) {
    case WebCore::StepsTimingFunction::StepPosition::JumpStart:
    case WebCore::StepsTimingFunction::StepPosition::JumpEnd:
    case WebCore::StepsTimingFunction::StepPosition::JumpNone:
    case WebCore::StepsTimingFunction::StepPosition::JumpBoth:
    case WebCore::StepsTimingFunction::StepPosition::Start:
    case WebCore::StepsTimingFunction::StepPosition::End:
        return true;
    default:
        return false;
    }
}

template<> bool isValidOptionSet<WebCore::NavigatorAPIsAccessed>(OptionSet<WebCore::NavigatorAPIsAccessed> value)
{
    constexpr uint64_t allValidBitsValue =
        static_cast<uint64_t>(WebCore::NavigatorAPIsAccessed::AppVersion)
        | static_cast<uint64_t>(WebCore::NavigatorAPIsAccessed::UserAgent)
        | static_cast<uint64_t>(WebCore::NavigatorAPIsAccessed::Plugins)
        | static_cast<uint64_t>(WebCore::NavigatorAPIsAccessed::MimeTypes)
        | static_cast<uint64_t>(WebCore::NavigatorAPIsAccessed::CookieEnabled);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

template<> bool isValidOptionSet<WebCore::ScreenAPIsAccessed>(OptionSet<WebCore::ScreenAPIsAccessed> value)
{
    constexpr uint64_t allValidBitsValue =
        static_cast<uint64_t>(WebCore::ScreenAPIsAccessed::Height)
        | static_cast<uint64_t>(WebCore::ScreenAPIsAccessed::Width)
        | static_cast<uint64_t>(WebCore::ScreenAPIsAccessed::ColorDepth)
        | static_cast<uint64_t>(WebCore::ScreenAPIsAccessed::PixelDepth)
        | static_cast<uint64_t>(WebCore::ScreenAPIsAccessed::AvailLeft)
        | static_cast<uint64_t>(WebCore::ScreenAPIsAccessed::AvailTop)
        | static_cast<uint64_t>(WebCore::ScreenAPIsAccessed::AvailHeight)
        | static_cast<uint64_t>(WebCore::ScreenAPIsAccessed::AvailWidth);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

template<> bool isValidEnum<WebCore::ViewportFit, void>(uint8_t value)
{
    switch (static_cast<WebCore::ViewportFit>(value)) {
    case WebCore::ViewportFit::Auto:
    case WebCore::ViewportFit::Contain:
    case WebCore::ViewportFit::Cover:
        return true;
    default:
        return false;
    }
}

#if ENABLE(APPLE_PAY)
template<> bool isValidEnum<WebCore::ApplePayErrorContactField, void>(uint8_t value)
{
    switch (static_cast<WebCore::ApplePayErrorContactField>(value)) {
    case WebCore::ApplePayErrorContactField::PhoneNumber:
    case WebCore::ApplePayErrorContactField::EmailAddress:
    case WebCore::ApplePayErrorContactField::Name:
    case WebCore::ApplePayErrorContactField::PhoneticName:
    case WebCore::ApplePayErrorContactField::PostalAddress:
    case WebCore::ApplePayErrorContactField::AddressLines:
    case WebCore::ApplePayErrorContactField::SubLocality:
    case WebCore::ApplePayErrorContactField::Locality:
    case WebCore::ApplePayErrorContactField::PostalCode:
    case WebCore::ApplePayErrorContactField::SubAdministrativeArea:
    case WebCore::ApplePayErrorContactField::AdministrativeArea:
    case WebCore::ApplePayErrorContactField::Country:
    case WebCore::ApplePayErrorContactField::CountryCode:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(APPLE_PAY)
template<> bool isValidEnum<WebCore::ApplePayErrorCode, void>(uint8_t value)
{
    switch (static_cast<WebCore::ApplePayErrorCode>(value)) {
    case WebCore::ApplePayErrorCode::Unknown:
    case WebCore::ApplePayErrorCode::ShippingContactInvalid:
    case WebCore::ApplePayErrorCode::BillingContactInvalid:
    case WebCore::ApplePayErrorCode::AddressUnserviceable:
#if ENABLE(APPLE_PAY_COUPON_CODE)
    case WebCore::ApplePayErrorCode::CouponCodeInvalid:
#endif
#if ENABLE(APPLE_PAY_COUPON_CODE)
    case WebCore::ApplePayErrorCode::CouponCodeExpired:
#endif
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(APPLICATION_MANIFEST)
template<> bool isValidEnum<WebCore::ApplicationManifest::Display, void>(uint8_t value)
{
    switch (static_cast<WebCore::ApplicationManifest::Display>(value)) {
    case WebCore::ApplicationManifest::Display::Browser:
    case WebCore::ApplicationManifest::Display::MinimalUI:
    case WebCore::ApplicationManifest::Display::Standalone:
    case WebCore::ApplicationManifest::Display::Fullscreen:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(APPLICATION_MANIFEST)
template<> bool isValidOptionSet<WebCore::ApplicationManifest::Icon::Purpose>(OptionSet<WebCore::ApplicationManifest::Icon::Purpose> value)
{
    constexpr uint8_t allValidBitsValue =
        static_cast<uint8_t>(WebCore::ApplicationManifest::Icon::Purpose::Any)
        | static_cast<uint8_t>(WebCore::ApplicationManifest::Icon::Purpose::Monochrome)
        | static_cast<uint8_t>(WebCore::ApplicationManifest::Icon::Purpose::Maskable);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}
#endif

template<> bool isValidEnum<WebCore::DOMCacheEngine::Error, void>(uint8_t value)
{
    switch (static_cast<WebCore::DOMCacheEngine::Error>(value)) {
    case WebCore::DOMCacheEngine::Error::NotImplemented:
    case WebCore::DOMCacheEngine::Error::ReadDisk:
    case WebCore::DOMCacheEngine::Error::WriteDisk:
    case WebCore::DOMCacheEngine::Error::QuotaExceeded:
    case WebCore::DOMCacheEngine::Error::Internal:
    case WebCore::DOMCacheEngine::Error::Stopped:
    case WebCore::DOMCacheEngine::Error::CORP:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::SpeechRecognitionErrorType, void>(uint8_t value)
{
    switch (static_cast<WebCore::SpeechRecognitionErrorType>(value)) {
    case WebCore::SpeechRecognitionErrorType::NoSpeech:
    case WebCore::SpeechRecognitionErrorType::Aborted:
    case WebCore::SpeechRecognitionErrorType::AudioCapture:
    case WebCore::SpeechRecognitionErrorType::Network:
    case WebCore::SpeechRecognitionErrorType::NotAllowed:
    case WebCore::SpeechRecognitionErrorType::ServiceNotAllowed:
    case WebCore::SpeechRecognitionErrorType::BadGrammar:
    case WebCore::SpeechRecognitionErrorType::LanguageNotSupported:
        return true;
    default:
        return false;
    }
}

#if ENABLE(WEB_AUTHN)
template<> bool isValidEnum<WebCore::AttestationConveyancePreference, void>(uint8_t value)
{
    switch (static_cast<WebCore::AttestationConveyancePreference>(value)) {
    case WebCore::AttestationConveyancePreference::None:
    case WebCore::AttestationConveyancePreference::Indirect:
    case WebCore::AttestationConveyancePreference::Direct:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::Cookie::SameSitePolicy, void>(uint8_t value)
{
    switch (static_cast<WebCore::Cookie::SameSitePolicy>(value)) {
    case WebCore::Cookie::SameSitePolicy::None:
    case WebCore::Cookie::SameSitePolicy::Lax:
    case WebCore::Cookie::SameSitePolicy::Strict:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::RenderingPurpose, void>(uint8_t value)
{
    switch (static_cast<WebCore::RenderingPurpose>(value)) {
    case WebCore::RenderingPurpose::Unspecified:
    case WebCore::RenderingPurpose::Canvas:
    case WebCore::RenderingPurpose::DOM:
    case WebCore::RenderingPurpose::LayerBacking:
    case WebCore::RenderingPurpose::Snapshot:
    case WebCore::RenderingPurpose::ShareableSnapshot:
    case WebCore::RenderingPurpose::MediaPainting:
        return true;
    default:
        return false;
    }
}

#if ENABLE(CONTENT_FILTERING_IN_NETWORKING_PROCESS)
template<> bool isValidEnum<WebCore::MockContentFilterSettings::DecisionPoint, void>(uint8_t value)
{
    switch (static_cast<WebCore::MockContentFilterSettings::DecisionPoint>(value)) {
    case WebCore::MockContentFilterSettings::DecisionPoint::AfterWillSendRequest:
    case WebCore::MockContentFilterSettings::DecisionPoint::AfterRedirect:
    case WebCore::MockContentFilterSettings::DecisionPoint::AfterResponse:
    case WebCore::MockContentFilterSettings::DecisionPoint::AfterAddData:
    case WebCore::MockContentFilterSettings::DecisionPoint::AfterFinishedAddingData:
    case WebCore::MockContentFilterSettings::DecisionPoint::Never:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::AutoplayEvent, void>(uint8_t value)
{
    switch (static_cast<WebCore::AutoplayEvent>(value)) {
    case WebCore::AutoplayEvent::DidPreventMediaFromPlaying:
    case WebCore::AutoplayEvent::DidPlayMediaWithUserGesture:
    case WebCore::AutoplayEvent::DidAutoplayMediaPastThresholdWithoutUserInterference:
    case WebCore::AutoplayEvent::UserDidInterfereWithPlayback:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::InputMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::InputMode>(value)) {
    case WebCore::InputMode::Unspecified:
    case WebCore::InputMode::None:
    case WebCore::InputMode::Text:
    case WebCore::InputMode::Telephone:
    case WebCore::InputMode::Url:
    case WebCore::InputMode::Email:
    case WebCore::InputMode::Numeric:
    case WebCore::InputMode::Decimal:
    case WebCore::InputMode::Search:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::NotificationDirection, void>(uint8_t value)
{
    switch (static_cast<WebCore::NotificationDirection>(value)) {
    case WebCore::NotificationDirection::Auto:
    case WebCore::NotificationDirection::Ltr:
    case WebCore::NotificationDirection::Rtl:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::StoredCredentialsPolicy, void>(uint8_t value)
{
    switch (static_cast<WebCore::StoredCredentialsPolicy>(value)) {
    case WebCore::StoredCredentialsPolicy::DoNotUse:
    case WebCore::StoredCredentialsPolicy::Use:
    case WebCore::StoredCredentialsPolicy::EphemeralStateless:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::PreflightPolicy, void>(uint8_t value)
{
    switch (static_cast<WebCore::PreflightPolicy>(value)) {
    case WebCore::PreflightPolicy::Consider:
    case WebCore::PreflightPolicy::Force:
    case WebCore::PreflightPolicy::Prevent:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WTFLogChannelState, void>(uint8_t value)
{
    switch (static_cast<WTFLogChannelState>(value)) {
    case WTFLogChannelState::Off:
    case WTFLogChannelState::On:
    case WTFLogChannelState::OnWithAccumulation:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ScrollSnapStrictness, void>(uint8_t value)
{
    switch (static_cast<WebCore::ScrollSnapStrictness>(value)) {
    case WebCore::ScrollSnapStrictness::None:
    case WebCore::ScrollSnapStrictness::Proximity:
    case WebCore::ScrollSnapStrictness::Mandatory:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::LengthType, void>(uint8_t value)
{
    switch (static_cast<WebCore::LengthType>(value)) {
    case WebCore::LengthType::Auto:
    case WebCore::LengthType::Relative:
    case WebCore::LengthType::Percent:
    case WebCore::LengthType::Fixed:
    case WebCore::LengthType::Intrinsic:
    case WebCore::LengthType::MinIntrinsic:
    case WebCore::LengthType::MinContent:
    case WebCore::LengthType::MaxContent:
    case WebCore::LengthType::FillAvailable:
    case WebCore::LengthType::FitContent:
    case WebCore::LengthType::Calculated:
    case WebCore::LengthType::Undefined:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::OverscrollBehavior, void>(uint8_t value)
{
    switch (static_cast<WebCore::OverscrollBehavior>(value)) {
    case WebCore::OverscrollBehavior::Auto:
    case WebCore::OverscrollBehavior::Contain:
    case WebCore::OverscrollBehavior::None:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ScrollPinningBehavior, void>(uint8_t value)
{
    switch (static_cast<WebCore::ScrollPinningBehavior>(value)) {
    case WebCore::ScrollPinningBehavior::DoNotPin:
    case WebCore::ScrollPinningBehavior::PinToTop:
    case WebCore::ScrollPinningBehavior::PinToBottom:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::DiagnosticLoggingDomain, void>(uint8_t value)
{
    switch (static_cast<WebCore::DiagnosticLoggingDomain>(value)) {
    case WebCore::DiagnosticLoggingDomain::Media:
        return true;
    default:
        return false;
    }
}

#if !USE(CG)
template<> bool isValidEnum<WebCore::PlatformColorSpace::Name, void>(uint8_t value)
{
    switch (static_cast<WebCore::PlatformColorSpace::Name>(value)) {
    case WebCore::PlatformColorSpace::Name::SRGB:
#if ENABLE(DESTINATION_COLOR_SPACE_LINEAR_SRGB)
    case WebCore::PlatformColorSpace::Name::LinearSRGB:
#endif
#if ENABLE(DESTINATION_COLOR_SPACE_DISPLAY_P3)
    case WebCore::PlatformColorSpace::Name::DisplayP3:
#endif
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::MediaCaptureType, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaCaptureType>(value)) {
    case WebCore::MediaCaptureType::MediaCaptureTypeNone:
    case WebCore::MediaCaptureType::MediaCaptureTypeUser:
    case WebCore::MediaCaptureType::MediaCaptureTypeEnvironment:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaStreamRequest::Type, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaStreamRequest::Type>(value)) {
    case WebCore::MediaStreamRequest::Type::UserMedia:
    case WebCore::MediaStreamRequest::Type::DisplayMedia:
    case WebCore::MediaStreamRequest::Type::DisplayMediaWithAudio:
        return true;
    default:
        return false;
    }
}

#if ENABLE(WEB_AUTHN)
template<> bool isValidEnum<WebCore::AuthenticatorTransport, void>(uint8_t value)
{
    switch (static_cast<WebCore::AuthenticatorTransport>(value)) {
    case WebCore::AuthenticatorTransport::Usb:
    case WebCore::AuthenticatorTransport::Nfc:
    case WebCore::AuthenticatorTransport::Ble:
    case WebCore::AuthenticatorTransport::Internal:
    case WebCore::AuthenticatorTransport::Cable:
    case WebCore::AuthenticatorTransport::Hybrid:
    case WebCore::AuthenticatorTransport::SmartCard:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(DATALIST_ELEMENT)
template<> bool isValidEnum<WebCore::DataListSuggestionActivationType, void>(uint8_t value)
{
    switch (static_cast<WebCore::DataListSuggestionActivationType>(value)) {
    case WebCore::DataListSuggestionActivationType::ControlClicked:
    case WebCore::DataListSuggestionActivationType::IndicatorClicked:
    case WebCore::DataListSuggestionActivationType::TextChanged:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::AlphaPremultiplication, void>(uint8_t value)
{
    switch (static_cast<WebCore::AlphaPremultiplication>(value)) {
    case WebCore::AlphaPremultiplication::Premultiplied:
    case WebCore::AlphaPremultiplication::Unpremultiplied:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::PixelFormat, void>(uint8_t value)
{
    switch (static_cast<WebCore::PixelFormat>(value)) {
    case WebCore::PixelFormat::RGBA8:
    case WebCore::PixelFormat::BGRX8:
    case WebCore::PixelFormat::BGRA8:
    case WebCore::PixelFormat::RGB10:
    case WebCore::PixelFormat::RGB10A8:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::EventTrackingRegions::EventType, void>(uint8_t value)
{
    switch (static_cast<WebCore::EventTrackingRegions::EventType>(value)) {
    case WebCore::EventTrackingRegions::EventType::Mousedown:
    case WebCore::EventTrackingRegions::EventType::Mousemove:
    case WebCore::EventTrackingRegions::EventType::Mouseup:
    case WebCore::EventTrackingRegions::EventType::Mousewheel:
    case WebCore::EventTrackingRegions::EventType::Pointerdown:
    case WebCore::EventTrackingRegions::EventType::Pointerenter:
    case WebCore::EventTrackingRegions::EventType::Pointerleave:
    case WebCore::EventTrackingRegions::EventType::Pointermove:
    case WebCore::EventTrackingRegions::EventType::Pointerout:
    case WebCore::EventTrackingRegions::EventType::Pointerover:
    case WebCore::EventTrackingRegions::EventType::Pointerup:
    case WebCore::EventTrackingRegions::EventType::Touchend:
    case WebCore::EventTrackingRegions::EventType::Touchforcechange:
    case WebCore::EventTrackingRegions::EventType::Touchmove:
    case WebCore::EventTrackingRegions::EventType::Touchstart:
    case WebCore::EventTrackingRegions::EventType::Wheel:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ScrollElasticity, void>(uint8_t value)
{
    switch (static_cast<WebCore::ScrollElasticity>(value)) {
    case WebCore::ScrollElasticity::Automatic:
    case WebCore::ScrollElasticity::None:
    case WebCore::ScrollElasticity::Allowed:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ScrollbarMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::ScrollbarMode>(value)) {
    case WebCore::ScrollbarMode::Auto:
    case WebCore::ScrollbarMode::AlwaysOff:
    case WebCore::ScrollbarMode::AlwaysOn:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::NativeScrollbarVisibility, void>(uint8_t value)
{
    switch (static_cast<WebCore::NativeScrollbarVisibility>(value)) {
    case WebCore::NativeScrollbarVisibility::Visible:
    case WebCore::NativeScrollbarVisibility::HiddenByStyle:
    case WebCore::NativeScrollbarVisibility::ReplacedByCustomScrollbar:
        return true;
    default:
        return false;
    }
}

#if ENABLE(GPU_PROCESS)
template<> bool isValidEnum<WebCore::GraphicsContextGLPowerPreference, void>(uint8_t value)
{
    switch (static_cast<WebCore::GraphicsContextGLPowerPreference>(value)) {
    case WebCore::GraphicsContextGLPowerPreference::Default:
    case WebCore::GraphicsContextGLPowerPreference::LowPower:
    case WebCore::GraphicsContextGLPowerPreference::HighPerformance:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(GPU_PROCESS)
template<> bool isValidEnum<WebCore::GraphicsContextGLWebGLVersion, void>(uint8_t value)
{
    switch (static_cast<WebCore::GraphicsContextGLWebGLVersion>(value)) {
    case WebCore::GraphicsContextGLWebGLVersion::WebGL1:
    case WebCore::GraphicsContextGLWebGLVersion::WebGL2:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::BasicShapeRadius::Type, void>(uint8_t value)
{
    switch (static_cast<WebCore::BasicShapeRadius::Type>(value)) {
    case WebCore::BasicShapeRadius::Type::Value:
    case WebCore::BasicShapeRadius::Type::ClosestSide:
    case WebCore::BasicShapeRadius::Type::FarthestSide:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::CSSBoxType, void>(uint8_t value)
{
    switch (static_cast<WebCore::CSSBoxType>(value)) {
    case WebCore::CSSBoxType::BoxMissing:
    case WebCore::CSSBoxType::MarginBox:
    case WebCore::CSSBoxType::BorderBox:
    case WebCore::CSSBoxType::PaddingBox:
    case WebCore::CSSBoxType::ContentBox:
    case WebCore::CSSBoxType::FillBox:
    case WebCore::CSSBoxType::StrokeBox:
    case WebCore::CSSBoxType::ViewBox:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::RayPathOperation::Size, void>(uint8_t value)
{
    switch (static_cast<WebCore::RayPathOperation::Size>(value)) {
    case WebCore::RayPathOperation::Size::ClosestSide:
    case WebCore::RayPathOperation::Size::ClosestCorner:
    case WebCore::RayPathOperation::Size::FarthestSide:
    case WebCore::RayPathOperation::Size::FarthestCorner:
    case WebCore::RayPathOperation::Size::Sides:
        return true;
    default:
        return false;
    }
}

#if ENABLE(WEB_AUTHN)
template<> bool isValidEnum<WebCore::UserVerificationRequirement, void>(uint8_t value)
{
    switch (static_cast<WebCore::UserVerificationRequirement>(value)) {
    case WebCore::UserVerificationRequirement::Required:
    case WebCore::UserVerificationRequirement::Preferred:
    case WebCore::UserVerificationRequirement::Discouraged:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(WEB_AUTHN)
template<> bool isValidEnum<WebCore::ResidentKeyRequirement, void>(uint8_t value)
{
    switch (static_cast<WebCore::ResidentKeyRequirement>(value)) {
    case WebCore::ResidentKeyRequirement::Required:
    case WebCore::ResidentKeyRequirement::Preferred:
    case WebCore::ResidentKeyRequirement::Discouraged:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(WEB_AUTHN)
template<> bool isValidEnum<WebCore::AuthenticatorAttachment, void>(uint8_t value)
{
    switch (static_cast<WebCore::AuthenticatorAttachment>(value)) {
    case WebCore::AuthenticatorAttachment::Platform:
    case WebCore::AuthenticatorAttachment::CrossPlatform:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::ResourceRequestCachePolicy, void>(uint8_t value)
{
    switch (static_cast<WebCore::ResourceRequestCachePolicy>(value)) {
    case WebCore::ResourceRequestCachePolicy::UseProtocolCachePolicy:
    case WebCore::ResourceRequestCachePolicy::ReloadIgnoringCacheData:
    case WebCore::ResourceRequestCachePolicy::ReturnCacheDataElseLoad:
    case WebCore::ResourceRequestCachePolicy::ReturnCacheDataDontLoad:
    case WebCore::ResourceRequestCachePolicy::DoNotUseAnyCache:
    case WebCore::ResourceRequestCachePolicy::RefreshAnyCacheData:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ResourceRequestBase::SameSiteDisposition, void>(uint8_t value)
{
    switch (static_cast<WebCore::ResourceRequestBase::SameSiteDisposition>(value)) {
    case WebCore::ResourceRequestBase::SameSiteDisposition::Unspecified:
    case WebCore::ResourceRequestBase::SameSiteDisposition::SameSite:
    case WebCore::ResourceRequestBase::SameSiteDisposition::CrossSite:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ResourceRequestRequester, void>(uint8_t value)
{
    switch (static_cast<WebCore::ResourceRequestRequester>(value)) {
    case WebCore::ResourceRequestRequester::Unspecified:
    case WebCore::ResourceRequestRequester::Main:
    case WebCore::ResourceRequestRequester::XHR:
    case WebCore::ResourceRequestRequester::Fetch:
    case WebCore::ResourceRequestRequester::Media:
    case WebCore::ResourceRequestRequester::Model:
    case WebCore::ResourceRequestRequester::ImportScripts:
    case WebCore::ResourceRequestRequester::Ping:
    case WebCore::ResourceRequestRequester::Beacon:
    case WebCore::ResourceRequestRequester::EventSource:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ResourceLoadPriority, void>(uint8_t value)
{
    switch (static_cast<WebCore::ResourceLoadPriority>(value)) {
    case WebCore::ResourceLoadPriority::VeryLow:
    case WebCore::ResourceLoadPriority::Low:
    case WebCore::ResourceLoadPriority::Medium:
    case WebCore::ResourceLoadPriority::High:
    case WebCore::ResourceLoadPriority::VeryHigh:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ResourceResponseBase::Type, void>(uint8_t value)
{
    switch (static_cast<WebCore::ResourceResponseBase::Type>(value)) {
    case WebCore::ResourceResponseBase::Type::Basic:
    case WebCore::ResourceResponseBase::Type::Cors:
    case WebCore::ResourceResponseBase::Type::Default:
    case WebCore::ResourceResponseBase::Type::Error:
    case WebCore::ResourceResponseBase::Type::Opaque:
    case WebCore::ResourceResponseBase::Type::Opaqueredirect:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ResourceResponseBase::Tainting, void>(uint8_t value)
{
    switch (static_cast<WebCore::ResourceResponseBase::Tainting>(value)) {
    case WebCore::ResourceResponseBase::Tainting::Basic:
    case WebCore::ResourceResponseBase::Tainting::Cors:
    case WebCore::ResourceResponseBase::Tainting::Opaque:
    case WebCore::ResourceResponseBase::Tainting::Opaqueredirect:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ResourceResponseBase::Source, void>(uint8_t value)
{
    switch (static_cast<WebCore::ResourceResponseBase::Source>(value)) {
    case WebCore::ResourceResponseBase::Source::Unknown:
    case WebCore::ResourceResponseBase::Source::Network:
    case WebCore::ResourceResponseBase::Source::DiskCache:
    case WebCore::ResourceResponseBase::Source::DiskCacheAfterValidation:
    case WebCore::ResourceResponseBase::Source::MemoryCache:
    case WebCore::ResourceResponseBase::Source::MemoryCacheAfterValidation:
    case WebCore::ResourceResponseBase::Source::ServiceWorker:
    case WebCore::ResourceResponseBase::Source::ApplicationCache:
    case WebCore::ResourceResponseBase::Source::DOMCache:
    case WebCore::ResourceResponseBase::Source::InspectorOverride:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ReferrerPolicy, void>(uint8_t value)
{
    switch (static_cast<WebCore::ReferrerPolicy>(value)) {
    case WebCore::ReferrerPolicy::EmptyString:
    case WebCore::ReferrerPolicy::NoReferrer:
    case WebCore::ReferrerPolicy::NoReferrerWhenDowngrade:
    case WebCore::ReferrerPolicy::SameOrigin:
    case WebCore::ReferrerPolicy::Origin:
    case WebCore::ReferrerPolicy::StrictOrigin:
    case WebCore::ReferrerPolicy::OriginWhenCrossOrigin:
    case WebCore::ReferrerPolicy::StrictOriginWhenCrossOrigin:
    case WebCore::ReferrerPolicy::UnsafeUrl:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FetchOptionsDestination, void>(uint8_t value)
{
    switch (static_cast<WebCore::FetchOptionsDestination>(value)) {
    case WebCore::FetchOptionsDestination::EmptyString:
    case WebCore::FetchOptionsDestination::Audio:
    case WebCore::FetchOptionsDestination::Audioworklet:
    case WebCore::FetchOptionsDestination::Document:
    case WebCore::FetchOptionsDestination::Embed:
    case WebCore::FetchOptionsDestination::Font:
    case WebCore::FetchOptionsDestination::Image:
    case WebCore::FetchOptionsDestination::Iframe:
    case WebCore::FetchOptionsDestination::Manifest:
    case WebCore::FetchOptionsDestination::Model:
    case WebCore::FetchOptionsDestination::Object:
    case WebCore::FetchOptionsDestination::Paintworklet:
    case WebCore::FetchOptionsDestination::Report:
    case WebCore::FetchOptionsDestination::Script:
    case WebCore::FetchOptionsDestination::Serviceworker:
    case WebCore::FetchOptionsDestination::Sharedworker:
    case WebCore::FetchOptionsDestination::Style:
    case WebCore::FetchOptionsDestination::Track:
    case WebCore::FetchOptionsDestination::Video:
    case WebCore::FetchOptionsDestination::Worker:
    case WebCore::FetchOptionsDestination::Xslt:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FetchOptionsMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::FetchOptionsMode>(value)) {
    case WebCore::FetchOptionsMode::Navigate:
    case WebCore::FetchOptionsMode::SameOrigin:
    case WebCore::FetchOptionsMode::NoCors:
    case WebCore::FetchOptionsMode::Cors:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FetchOptionsCredentials, void>(uint8_t value)
{
    switch (static_cast<WebCore::FetchOptionsCredentials>(value)) {
    case WebCore::FetchOptionsCredentials::Omit:
    case WebCore::FetchOptionsCredentials::SameOrigin:
    case WebCore::FetchOptionsCredentials::Include:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FetchOptionsCache, void>(uint8_t value)
{
    switch (static_cast<WebCore::FetchOptionsCache>(value)) {
    case WebCore::FetchOptionsCache::Default:
    case WebCore::FetchOptionsCache::NoStore:
    case WebCore::FetchOptionsCache::Reload:
    case WebCore::FetchOptionsCache::NoCache:
    case WebCore::FetchOptionsCache::ForceCache:
    case WebCore::FetchOptionsCache::OnlyIfCached:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FetchOptionsRedirect, void>(uint8_t value)
{
    switch (static_cast<WebCore::FetchOptionsRedirect>(value)) {
    case WebCore::FetchOptionsRedirect::Follow:
    case WebCore::FetchOptionsRedirect::Error:
    case WebCore::FetchOptionsRedirect::Manual:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FetchHeadersGuard, void>(uint8_t value)
{
    switch (static_cast<WebCore::FetchHeadersGuard>(value)) {
    case WebCore::FetchHeadersGuard::None:
    case WebCore::FetchHeadersGuard::Immutable:
    case WebCore::FetchHeadersGuard::Request:
    case WebCore::FetchHeadersGuard::RequestNoCors:
    case WebCore::FetchHeadersGuard::Response:
        return true;
    default:
        return false;
    }
}

template<> bool isValidOptionSet<WebCore::ControlStyle::State>(OptionSet<WebCore::ControlStyle::State> value)
{
    constexpr unsigned allValidBitsValue =
        static_cast<unsigned>(WebCore::ControlStyle::State::Hovered)
        | static_cast<unsigned>(WebCore::ControlStyle::State::Pressed)
        | static_cast<unsigned>(WebCore::ControlStyle::State::Focused)
        | static_cast<unsigned>(WebCore::ControlStyle::State::Enabled)
        | static_cast<unsigned>(WebCore::ControlStyle::State::Checked)
        | static_cast<unsigned>(WebCore::ControlStyle::State::Default)
        | static_cast<unsigned>(WebCore::ControlStyle::State::WindowActive)
        | static_cast<unsigned>(WebCore::ControlStyle::State::Indeterminate)
        | static_cast<unsigned>(WebCore::ControlStyle::State::SpinUp)
        | static_cast<unsigned>(WebCore::ControlStyle::State::Presenting)
        | static_cast<unsigned>(WebCore::ControlStyle::State::FormSemanticContext)
        | static_cast<unsigned>(WebCore::ControlStyle::State::DarkAppearance)
        | static_cast<unsigned>(WebCore::ControlStyle::State::RightToLeft)
        | static_cast<unsigned>(WebCore::ControlStyle::State::LargeControls)
        | static_cast<unsigned>(WebCore::ControlStyle::State::ReadOnly)
        | static_cast<unsigned>(WebCore::ControlStyle::State::ListButton)
        | static_cast<unsigned>(WebCore::ControlStyle::State::ListButtonPressed)
        | static_cast<unsigned>(WebCore::ControlStyle::State::VerticalWritingMode);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

template<> bool isValidEnum<WebCore::StyleAppearance, void>(uint8_t value)
{
    switch (static_cast<WebCore::StyleAppearance>(value)) {
    case WebCore::StyleAppearance::None:
    case WebCore::StyleAppearance::Auto:
    case WebCore::StyleAppearance::Checkbox:
    case WebCore::StyleAppearance::Radio:
    case WebCore::StyleAppearance::PushButton:
    case WebCore::StyleAppearance::SquareButton:
    case WebCore::StyleAppearance::Button:
    case WebCore::StyleAppearance::DefaultButton:
    case WebCore::StyleAppearance::Listbox:
    case WebCore::StyleAppearance::Menulist:
    case WebCore::StyleAppearance::MenulistButton:
    case WebCore::StyleAppearance::Meter:
    case WebCore::StyleAppearance::ProgressBar:
    case WebCore::StyleAppearance::SliderHorizontal:
    case WebCore::StyleAppearance::SliderVertical:
    case WebCore::StyleAppearance::SearchField:
#if ENABLE(APPLE_PAY)
    case WebCore::StyleAppearance::ApplePayButton:
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    case WebCore::StyleAppearance::Attachment:
#endif
#if ENABLE(ATTACHMENT_ELEMENT)
    case WebCore::StyleAppearance::BorderlessAttachment:
#endif
    case WebCore::StyleAppearance::TextArea:
    case WebCore::StyleAppearance::TextField:
    case WebCore::StyleAppearance::CapsLockIndicator:
#if ENABLE(INPUT_TYPE_COLOR)
    case WebCore::StyleAppearance::ColorWell:
#endif
#if ENABLE(SERVICE_CONTROLS)
    case WebCore::StyleAppearance::ImageControlsButton:
#endif
    case WebCore::StyleAppearance::InnerSpinButton:
#if ENABLE(DATALIST_ELEMENT)
    case WebCore::StyleAppearance::ListButton:
#endif
    case WebCore::StyleAppearance::SearchFieldDecoration:
    case WebCore::StyleAppearance::SearchFieldResultsDecoration:
    case WebCore::StyleAppearance::SearchFieldResultsButton:
    case WebCore::StyleAppearance::SearchFieldCancelButton:
    case WebCore::StyleAppearance::SliderThumbHorizontal:
    case WebCore::StyleAppearance::SliderThumbVertical:
        return true;
    default:
        return false;
    }
}

#if ENABLE(APPLE_PAY)
template<> bool isValidEnum<WebCore::ApplePayButtonType, void>(uint8_t value)
{
    switch (static_cast<WebCore::ApplePayButtonType>(value)) {
    case WebCore::ApplePayButtonType::Plain:
    case WebCore::ApplePayButtonType::Buy:
    case WebCore::ApplePayButtonType::SetUp:
    case WebCore::ApplePayButtonType::Donate:
    case WebCore::ApplePayButtonType::CheckOut:
    case WebCore::ApplePayButtonType::Book:
    case WebCore::ApplePayButtonType::Subscribe:
#if ENABLE(APPLE_PAY_NEW_BUTTON_TYPES)
    case WebCore::ApplePayButtonType::Reload:
#endif
#if ENABLE(APPLE_PAY_NEW_BUTTON_TYPES)
    case WebCore::ApplePayButtonType::AddMoney:
#endif
#if ENABLE(APPLE_PAY_NEW_BUTTON_TYPES)
    case WebCore::ApplePayButtonType::TopUp:
#endif
#if ENABLE(APPLE_PAY_NEW_BUTTON_TYPES)
    case WebCore::ApplePayButtonType::Order:
#endif
#if ENABLE(APPLE_PAY_NEW_BUTTON_TYPES)
    case WebCore::ApplePayButtonType::Rent:
#endif
#if ENABLE(APPLE_PAY_NEW_BUTTON_TYPES)
    case WebCore::ApplePayButtonType::Support:
#endif
#if ENABLE(APPLE_PAY_NEW_BUTTON_TYPES)
    case WebCore::ApplePayButtonType::Contribute:
#endif
#if ENABLE(APPLE_PAY_NEW_BUTTON_TYPES)
    case WebCore::ApplePayButtonType::Tip:
#endif
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(APPLE_PAY)
template<> bool isValidEnum<WebCore::ApplePayButtonStyle, void>(uint8_t value)
{
    switch (static_cast<WebCore::ApplePayButtonStyle>(value)) {
    case WebCore::ApplePayButtonStyle::White:
    case WebCore::ApplePayButtonStyle::WhiteOutline:
    case WebCore::ApplePayButtonStyle::Black:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::MeterPart::GaugeRegion, void>(uint8_t value)
{
    switch (static_cast<WebCore::MeterPart::GaugeRegion>(value)) {
    case WebCore::MeterPart::GaugeRegion::Optimum:
    case WebCore::MeterPart::GaugeRegion::Suboptimal:
    case WebCore::MeterPart::GaugeRegion::EvenLessGood:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ModalContainerDecision, void>(uint8_t value)
{
    switch (static_cast<WebCore::ModalContainerDecision>(value)) {
    case WebCore::ModalContainerDecision::Show:
    case WebCore::ModalContainerDecision::HideAndIgnore:
    case WebCore::ModalContainerDecision::HideAndAllow:
    case WebCore::ModalContainerDecision::HideAndDisallow:
        return true;
    default:
        return false;
    }
}

template<> bool isValidOptionSet<WebCore::AutoplayEventFlags>(OptionSet<WebCore::AutoplayEventFlags> value)
{
    constexpr uint8_t allValidBitsValue =
        static_cast<uint8_t>(WebCore::AutoplayEventFlags::HasAudio)
        | static_cast<uint8_t>(WebCore::AutoplayEventFlags::PlaybackWasPrevented)
        | static_cast<uint8_t>(WebCore::AutoplayEventFlags::MediaIsMainContent);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

template<> bool isValidEnum<WebCore::FocusDirection, void>(uint8_t value)
{
    switch (static_cast<WebCore::FocusDirection>(value)) {
    case WebCore::FocusDirection::None:
    case WebCore::FocusDirection::Forward:
    case WebCore::FocusDirection::Backward:
    case WebCore::FocusDirection::Up:
    case WebCore::FocusDirection::Down:
    case WebCore::FocusDirection::Left:
    case WebCore::FocusDirection::Right:
        return true;
    default:
        return false;
    }
}

#if ENABLE(GAMEPAD)
template<> bool isValidEnum<WebCore::GamepadHapticEffectType, void>(uint8_t value)
{
    switch (static_cast<WebCore::GamepadHapticEffectType>(value)) {
    case WebCore::GamepadHapticEffectType::DualRumble:
    case WebCore::GamepadHapticEffectType::TriggerRumble:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::DOMPasteAccessCategory, void>(uint8_t value)
{
    switch (static_cast<WebCore::DOMPasteAccessCategory>(value)) {
    case WebCore::DOMPasteAccessCategory::General:
    case WebCore::DOMPasteAccessCategory::Fonts:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::DOMPasteAccessPolicy, void>(uint8_t value)
{
    switch (static_cast<WebCore::DOMPasteAccessPolicy>(value)) {
    case WebCore::DOMPasteAccessPolicy::NotRequestedYet:
    case WebCore::DOMPasteAccessPolicy::Denied:
    case WebCore::DOMPasteAccessPolicy::Granted:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::DOMPasteAccessResponse, void>(uint8_t value)
{
    switch (static_cast<WebCore::DOMPasteAccessResponse>(value)) {
    case WebCore::DOMPasteAccessResponse::DeniedForGesture:
    case WebCore::DOMPasteAccessResponse::GrantedForCommand:
    case WebCore::DOMPasteAccessResponse::GrantedForGesture:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::DeviceOrientationOrMotionPermissionState, void>(uint8_t value)
{
    switch (static_cast<WebCore::DeviceOrientationOrMotionPermissionState>(value)) {
    case WebCore::DeviceOrientationOrMotionPermissionState::Granted:
    case WebCore::DeviceOrientationOrMotionPermissionState::Denied:
    case WebCore::DeviceOrientationOrMotionPermissionState::Prompt:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ExceptionDetails::Type, void>(uint8_t value)
{
    switch (static_cast<WebCore::ExceptionDetails::Type>(value)) {
    case WebCore::ExceptionDetails::Type::Script:
    case WebCore::ExceptionDetails::Type::InvalidTargetFrame:
    case WebCore::ExceptionDetails::Type::AppBoundDomain:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::VerticalAlignChange, void>(uint8_t value)
{
    switch (static_cast<WebCore::VerticalAlignChange>(value)) {
    case WebCore::VerticalAlignChange::Superscript:
    case WebCore::VerticalAlignChange::Baseline:
    case WebCore::VerticalAlignChange::Subscript:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::TextGranularity, void>(uint8_t value)
{
    switch (static_cast<WebCore::TextGranularity>(value)) {
    case WebCore::TextGranularity::CharacterGranularity:
    case WebCore::TextGranularity::WordGranularity:
    case WebCore::TextGranularity::SentenceGranularity:
    case WebCore::TextGranularity::LineGranularity:
    case WebCore::TextGranularity::ParagraphGranularity:
    case WebCore::TextGranularity::DocumentGranularity:
    case WebCore::TextGranularity::SentenceBoundary:
    case WebCore::TextGranularity::LineBoundary:
    case WebCore::TextGranularity::ParagraphBoundary:
    case WebCore::TextGranularity::DocumentBoundary:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontAttributes::SubscriptOrSuperscript, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontAttributes::SubscriptOrSuperscript>(value)) {
    case WebCore::FontAttributes::SubscriptOrSuperscript::None:
    case WebCore::FontAttributes::SubscriptOrSuperscript::Subscript:
    case WebCore::FontAttributes::SubscriptOrSuperscript::Superscript:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontAttributes::HorizontalAlignment, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontAttributes::HorizontalAlignment>(value)) {
    case WebCore::FontAttributes::HorizontalAlignment::Left:
    case WebCore::FontAttributes::HorizontalAlignment::Center:
    case WebCore::FontAttributes::HorizontalAlignment::Right:
    case WebCore::FontAttributes::HorizontalAlignment::Justify:
    case WebCore::FontAttributes::HorizontalAlignment::Natural:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::WritingDirection, void>(uint8_t value)
{
    switch (static_cast<WebCore::WritingDirection>(value)) {
    case WebCore::WritingDirection::Natural:
    case WebCore::WritingDirection::LeftToRight:
    case WebCore::WritingDirection::RightToLeft:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::SelectionDirection, void>(uint8_t value)
{
    switch (static_cast<WebCore::SelectionDirection>(value)) {
    case WebCore::SelectionDirection::Forward:
    case WebCore::SelectionDirection::Backward:
    case WebCore::SelectionDirection::Right:
    case WebCore::SelectionDirection::Left:
        return true;
    default:
        return false;
    }
}

#if ENABLE(DATA_DETECTION)
template<> bool isValidOptionSet<WebCore::DataDetectorType>(OptionSet<WebCore::DataDetectorType> value)
{
    constexpr uint8_t allValidBitsValue =
        static_cast<uint8_t>(WebCore::DataDetectorType::PhoneNumber)
        | static_cast<uint8_t>(WebCore::DataDetectorType::Link)
        | static_cast<uint8_t>(WebCore::DataDetectorType::Address)
        | static_cast<uint8_t>(WebCore::DataDetectorType::CalendarEvent)
        | static_cast<uint8_t>(WebCore::DataDetectorType::TrackingNumber)
        | static_cast<uint8_t>(WebCore::DataDetectorType::FlightNumber)
        | static_cast<uint8_t>(WebCore::DataDetectorType::LookupSuggestion);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}
#endif

template<> bool isValidEnum<WebCore::AutocapitalizeType, void>(uint8_t value)
{
    switch (static_cast<WebCore::AutocapitalizeType>(value)) {
    case WebCore::AutocapitalizeType::Default:
    case WebCore::AutocapitalizeType::None:
    case WebCore::AutocapitalizeType::Words:
    case WebCore::AutocapitalizeType::Sentences:
    case WebCore::AutocapitalizeType::AllCharacters:
        return true;
    default:
        return false;
    }
}

#if ENABLE(ASYNC_SCROLLING)
template<> bool isValidOptionSet<WebCore::ScrollingStateNodeProperty>(OptionSet<WebCore::ScrollingStateNodeProperty> value)
{
    constexpr uint64_t allValidBitsValue =
        static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::Layer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ChildNodes)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ScrollableAreaSize)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::TotalContentsSize)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ReachableContentsSize)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ScrollPosition)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ScrollOrigin)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ScrollableAreaParams)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ReasonsForSynchronousScrolling)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::RequestedScrollPosition)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::SnapOffsetsInfo)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::CurrentHorizontalSnapOffsetIndex)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::CurrentVerticalSnapOffsetIndex)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::IsMonitoringWheelEvents)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ScrollContainerLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ScrolledContentsLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::HorizontalScrollbarLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::VerticalScrollbarLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::PainterForScrollbar)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::FrameScaleFactor)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::EventTrackingRegion)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::RootContentsLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::CounterScrollingLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::InsetClipLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ContentShadowLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::HeaderHeight)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::FooterHeight)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::HeaderLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::FooterLayer)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::BehaviorForFixedElements)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::TopContentInset)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::FixedElementsLayoutRelativeToFrame)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::VisualViewportIsSmallerThanLayoutViewport)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::AsyncFrameOrOverflowScrollingEnabled)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::WheelEventGesturesBecomeNonBlocking)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ScrollingPerformanceTestingEnabled)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::LayoutViewport)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::MinLayoutViewportOrigin)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::MaxLayoutViewportOrigin)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::OverrideVisualViewportSize)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::RelatedOverflowScrollingNodes)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::LayoutConstraintData)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::ViewportConstraints)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::OverflowScrollingNode)
        | static_cast<uint64_t>(WebCore::ScrollingStateNodeProperty::KeyboardScrollData);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}
#endif

#if ENABLE(ENCRYPTED_MEDIA)
template<> bool isValidEnum<WebCore::CDMSessionType, void>(uint8_t value)
{
    switch (static_cast<WebCore::CDMSessionType>(value)) {
    case WebCore::CDMSessionType::Temporary:
    case WebCore::CDMSessionType::PersistentUsageRecord:
    case WebCore::CDMSessionType::PersistentLicense:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::MediaSelectionOption::MediaType, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaSelectionOption::MediaType>(value)) {
    case WebCore::MediaSelectionOption::MediaType::Unknown:
    case WebCore::MediaSelectionOption::MediaType::Audio:
    case WebCore::MediaSelectionOption::MediaType::Subtitles:
    case WebCore::MediaSelectionOption::MediaType::Captions:
    case WebCore::MediaSelectionOption::MediaType::Metadata:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaSelectionOption::LegibleType, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaSelectionOption::LegibleType>(value)) {
    case WebCore::MediaSelectionOption::LegibleType::Regular:
    case WebCore::MediaSelectionOption::LegibleType::LegibleOff:
    case WebCore::MediaSelectionOption::LegibleType::LegibleAuto:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaDecodingType, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaDecodingType>(value)) {
    case WebCore::MediaDecodingType::File:
    case WebCore::MediaDecodingType::MediaSource:
    case WebCore::MediaDecodingType::WebRTC:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::TextManipulationControllerExclusionRule::Type, void>(uint8_t value)
{
    switch (static_cast<WebCore::TextManipulationControllerExclusionRule::Type>(value)) {
    case WebCore::TextManipulationControllerExclusionRule::Type::Exclude:
    case WebCore::TextManipulationControllerExclusionRule::Type::Include:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::TextManipulationControllerManipulationFailure::Type, void>(uint8_t value)
{
    switch (static_cast<WebCore::TextManipulationControllerManipulationFailure::Type>(value)) {
    case WebCore::TextManipulationControllerManipulationFailure::Type::ContentChanged:
    case WebCore::TextManipulationControllerManipulationFailure::Type::InvalidItem:
    case WebCore::TextManipulationControllerManipulationFailure::Type::InvalidToken:
    case WebCore::TextManipulationControllerManipulationFailure::Type::ExclusionViolation:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerNetworkState, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerNetworkState>(value)) {
    case WebCore::MediaPlayerNetworkState::Empty:
    case WebCore::MediaPlayerNetworkState::Idle:
    case WebCore::MediaPlayerNetworkState::Loading:
    case WebCore::MediaPlayerNetworkState::Loaded:
    case WebCore::MediaPlayerNetworkState::FormatError:
    case WebCore::MediaPlayerNetworkState::NetworkError:
    case WebCore::MediaPlayerNetworkState::DecodeError:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerReadyState, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerReadyState>(value)) {
    case WebCore::MediaPlayerReadyState::HaveNothing:
    case WebCore::MediaPlayerReadyState::HaveMetadata:
    case WebCore::MediaPlayerReadyState::HaveCurrentData:
    case WebCore::MediaPlayerReadyState::HaveFutureData:
    case WebCore::MediaPlayerReadyState::HaveEnoughData:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerMovieLoadType, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerMovieLoadType>(value)) {
    case WebCore::MediaPlayerMovieLoadType::Unknown:
    case WebCore::MediaPlayerMovieLoadType::Download:
    case WebCore::MediaPlayerMovieLoadType::StoredStream:
    case WebCore::MediaPlayerMovieLoadType::LiveStream:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerPreload, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerPreload>(value)) {
    case WebCore::MediaPlayerPreload::None:
    case WebCore::MediaPlayerPreload::MetaData:
    case WebCore::MediaPlayerPreload::Auto:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerVideoGravity, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerVideoGravity>(value)) {
    case WebCore::MediaPlayerVideoGravity::Resize:
    case WebCore::MediaPlayerVideoGravity::ResizeAspect:
    case WebCore::MediaPlayerVideoGravity::ResizeAspectFill:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerSupportsType, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerSupportsType>(value)) {
    case WebCore::MediaPlayerSupportsType::IsNotSupported:
    case WebCore::MediaPlayerSupportsType::IsSupported:
    case WebCore::MediaPlayerSupportsType::MayBeSupported:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerBufferingPolicy, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerBufferingPolicy>(value)) {
    case WebCore::MediaPlayerBufferingPolicy::Default:
    case WebCore::MediaPlayerBufferingPolicy::LimitReadAhead:
    case WebCore::MediaPlayerBufferingPolicy::MakeResourcesPurgeable:
    case WebCore::MediaPlayerBufferingPolicy::PurgeResources:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerMediaEngineIdentifier, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerMediaEngineIdentifier>(value)) {
    case WebCore::MediaPlayerMediaEngineIdentifier::AVFoundation:
    case WebCore::MediaPlayerMediaEngineIdentifier::AVFoundationMSE:
    case WebCore::MediaPlayerMediaEngineIdentifier::AVFoundationMediaStream:
    case WebCore::MediaPlayerMediaEngineIdentifier::AVFoundationCF:
    case WebCore::MediaPlayerMediaEngineIdentifier::GStreamer:
    case WebCore::MediaPlayerMediaEngineIdentifier::GStreamerMSE:
    case WebCore::MediaPlayerMediaEngineIdentifier::HolePunch:
    case WebCore::MediaPlayerMediaEngineIdentifier::MediaFoundation:
    case WebCore::MediaPlayerMediaEngineIdentifier::MockMSE:
    case WebCore::MediaPlayerMediaEngineIdentifier::CocoaWebM:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerWirelessPlaybackTargetType, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerWirelessPlaybackTargetType>(value)) {
    case WebCore::MediaPlayerWirelessPlaybackTargetType::TargetTypeNone:
    case WebCore::MediaPlayerWirelessPlaybackTargetType::TargetTypeAirPlay:
    case WebCore::MediaPlayerWirelessPlaybackTargetType::TargetTypeTVOut:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::MediaPlayerPitchCorrectionAlgorithm, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaPlayerPitchCorrectionAlgorithm>(value)) {
    case WebCore::MediaPlayerPitchCorrectionAlgorithm::BestAllAround:
    case WebCore::MediaPlayerPitchCorrectionAlgorithm::BestForMusic:
    case WebCore::MediaPlayerPitchCorrectionAlgorithm::BestForSpeech:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::SpeechRecognitionUpdateType, void>(uint8_t value)
{
    switch (static_cast<WebCore::SpeechRecognitionUpdateType>(value)) {
    case WebCore::SpeechRecognitionUpdateType::Start:
    case WebCore::SpeechRecognitionUpdateType::AudioStart:
    case WebCore::SpeechRecognitionUpdateType::SoundStart:
    case WebCore::SpeechRecognitionUpdateType::SpeechStart:
    case WebCore::SpeechRecognitionUpdateType::SpeechEnd:
    case WebCore::SpeechRecognitionUpdateType::SoundEnd:
    case WebCore::SpeechRecognitionUpdateType::AudioEnd:
    case WebCore::SpeechRecognitionUpdateType::Result:
    case WebCore::SpeechRecognitionUpdateType::NoMatch:
    case WebCore::SpeechRecognitionUpdateType::Error:
    case WebCore::SpeechRecognitionUpdateType::End:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::CompositeOperator, void>(uint8_t value)
{
    switch (static_cast<WebCore::CompositeOperator>(value)) {
    case WebCore::CompositeOperator::Clear:
    case WebCore::CompositeOperator::Copy:
    case WebCore::CompositeOperator::SourceOver:
    case WebCore::CompositeOperator::SourceIn:
    case WebCore::CompositeOperator::SourceOut:
    case WebCore::CompositeOperator::SourceAtop:
    case WebCore::CompositeOperator::DestinationOver:
    case WebCore::CompositeOperator::DestinationIn:
    case WebCore::CompositeOperator::DestinationOut:
    case WebCore::CompositeOperator::DestinationAtop:
    case WebCore::CompositeOperator::XOR:
    case WebCore::CompositeOperator::PlusDarker:
    case WebCore::CompositeOperator::PlusLighter:
    case WebCore::CompositeOperator::Difference:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::BlendMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::BlendMode>(value)) {
    case WebCore::BlendMode::Normal:
    case WebCore::BlendMode::Multiply:
    case WebCore::BlendMode::Screen:
    case WebCore::BlendMode::Darken:
    case WebCore::BlendMode::Lighten:
    case WebCore::BlendMode::Overlay:
    case WebCore::BlendMode::ColorDodge:
    case WebCore::BlendMode::ColorBurn:
    case WebCore::BlendMode::HardLight:
    case WebCore::BlendMode::SoftLight:
    case WebCore::BlendMode::Difference:
    case WebCore::BlendMode::Exclusion:
    case WebCore::BlendMode::Hue:
    case WebCore::BlendMode::Saturation:
    case WebCore::BlendMode::Color:
    case WebCore::BlendMode::Luminosity:
    case WebCore::BlendMode::PlusDarker:
    case WebCore::BlendMode::PlusLighter:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::GradientSpreadMethod, void>(uint8_t value)
{
    switch (static_cast<WebCore::GradientSpreadMethod>(value)) {
    case WebCore::GradientSpreadMethod::Pad:
    case WebCore::GradientSpreadMethod::Reflect:
    case WebCore::GradientSpreadMethod::Repeat:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::InterpolationQuality, void>(uint8_t value)
{
    switch (static_cast<WebCore::InterpolationQuality>(value)) {
    case WebCore::InterpolationQuality::Default:
    case WebCore::InterpolationQuality::DoNotInterpolate:
    case WebCore::InterpolationQuality::Low:
    case WebCore::InterpolationQuality::Medium:
    case WebCore::InterpolationQuality::High:
        return true;
    default:
        return false;
    }
}

#if ENABLE(VIDEO)
template<> bool isValidEnum<WebCore::VideoFrameRotation, void>(uint16_t value)
{
    switch (static_cast<WebCore::VideoFrameRotation>(value)) {
    case WebCore::VideoFrameRotation::None:
    case WebCore::VideoFrameRotation::UpsideDown:
    case WebCore::VideoFrameRotation::Right:
    case WebCore::VideoFrameRotation::Left:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::PathElementType, void>(uint8_t value)
{
    switch (static_cast<WebCore::PathElementType>(value)) {
    case WebCore::PathElementType::MoveToPoint:
    case WebCore::PathElementType::AddLineToPoint:
    case WebCore::PathElementType::AddQuadCurveToPoint:
    case WebCore::PathElementType::AddCurveToPoint:
    case WebCore::PathElementType::CloseSubpath:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ColorInterpolationColorSpace, void>(uint8_t value)
{
    switch (static_cast<WebCore::ColorInterpolationColorSpace>(value)) {
    case WebCore::ColorInterpolationColorSpace::HSL:
    case WebCore::ColorInterpolationColorSpace::HWB:
    case WebCore::ColorInterpolationColorSpace::LCH:
    case WebCore::ColorInterpolationColorSpace::Lab:
    case WebCore::ColorInterpolationColorSpace::OKLCH:
    case WebCore::ColorInterpolationColorSpace::OKLab:
    case WebCore::ColorInterpolationColorSpace::SRGB:
    case WebCore::ColorInterpolationColorSpace::SRGBLinear:
    case WebCore::ColorInterpolationColorSpace::XYZD50:
    case WebCore::ColorInterpolationColorSpace::XYZD65:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::HueInterpolationMethod, void>(uint8_t value)
{
    switch (static_cast<WebCore::HueInterpolationMethod>(value)) {
    case WebCore::HueInterpolationMethod::Shorter:
    case WebCore::HueInterpolationMethod::Longer:
    case WebCore::HueInterpolationMethod::Increasing:
    case WebCore::HueInterpolationMethod::Decreasing:
        return true;
    default:
        return false;
    }
}

#if USE(AUDIO_SESSION)
template<> bool isValidEnum<WebCore::RouteSharingPolicy, void>(uint8_t value)
{
    switch (static_cast<WebCore::RouteSharingPolicy>(value)) {
    case WebCore::RouteSharingPolicy::Default:
    case WebCore::RouteSharingPolicy::LongFormAudio:
    case WebCore::RouteSharingPolicy::Independent:
    case WebCore::RouteSharingPolicy::LongFormVideo:
        return true;
    default:
        return false;
    }
}
#endif

#if USE(AUDIO_SESSION)
template<> bool isValidEnum<WebCore::AudioSessionCategory, void>(uint8_t value)
{
    switch (static_cast<WebCore::AudioSessionCategory>(value)) {
    case WebCore::AudioSessionCategory::None:
    case WebCore::AudioSessionCategory::AmbientSound:
    case WebCore::AudioSessionCategory::SoloAmbientSound:
    case WebCore::AudioSessionCategory::MediaPlayback:
    case WebCore::AudioSessionCategory::RecordAudio:
    case WebCore::AudioSessionCategory::PlayAndRecord:
    case WebCore::AudioSessionCategory::AudioProcessing:
        return true;
    default:
        return false;
    }
}
#endif

#if USE(AUDIO_SESSION)
template<> bool isValidEnum<WebCore::AudioSessionRoutingArbitrationError, void>(uint8_t value)
{
    switch (static_cast<WebCore::AudioSessionRoutingArbitrationError>(value)) {
    case WebCore::AudioSessionRoutingArbitrationError::None:
    case WebCore::AudioSessionRoutingArbitrationError::Failed:
    case WebCore::AudioSessionRoutingArbitrationError::Cancelled:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(ENCRYPTED_MEDIA)
template<> bool isValidEnum<WebCore::CDMKeyStatus, void>(uint8_t value)
{
    switch (static_cast<WebCore::CDMKeyStatus>(value)) {
    case WebCore::CDMKeyStatus::Usable:
    case WebCore::CDMKeyStatus::Expired:
    case WebCore::CDMKeyStatus::Released:
    case WebCore::CDMKeyStatus::OutputRestricted:
    case WebCore::CDMKeyStatus::OutputDownscaled:
    case WebCore::CDMKeyStatus::StatusPending:
    case WebCore::CDMKeyStatus::InternalError:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(ENCRYPTED_MEDIA)
template<> bool isValidEnum<WebCore::CDMMessageType, void>(uint8_t value)
{
    switch (static_cast<WebCore::CDMMessageType>(value)) {
    case WebCore::CDMMessageType::LicenseRequest:
    case WebCore::CDMMessageType::LicenseRenewal:
    case WebCore::CDMMessageType::LicenseRelease:
    case WebCore::CDMMessageType::IndividualizationRequest:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(ENCRYPTED_MEDIA)
template<> bool isValidEnum<WebCore::CDMRequirement, void>(uint8_t value)
{
    switch (static_cast<WebCore::CDMRequirement>(value)) {
    case WebCore::CDMRequirement::Required:
    case WebCore::CDMRequirement::Optional:
    case WebCore::CDMRequirement::NotAllowed:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(MEDIA_STREAM)
template<> bool isValidEnum<WebCore::MediaConstraintType, void>(uint8_t value)
{
    switch (static_cast<WebCore::MediaConstraintType>(value)) {
    case WebCore::MediaConstraintType::Unknown:
    case WebCore::MediaConstraintType::Width:
    case WebCore::MediaConstraintType::Height:
    case WebCore::MediaConstraintType::AspectRatio:
    case WebCore::MediaConstraintType::FrameRate:
    case WebCore::MediaConstraintType::FacingMode:
    case WebCore::MediaConstraintType::Volume:
    case WebCore::MediaConstraintType::SampleRate:
    case WebCore::MediaConstraintType::SampleSize:
    case WebCore::MediaConstraintType::EchoCancellation:
    case WebCore::MediaConstraintType::DeviceId:
    case WebCore::MediaConstraintType::GroupId:
    case WebCore::MediaConstraintType::DisplaySurface:
    case WebCore::MediaConstraintType::LogicalSurface:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(WEB_RTC)
template<> bool isValidEnum<WebCore::RTCDataChannelState, void>(uint8_t value)
{
    switch (static_cast<WebCore::RTCDataChannelState>(value)) {
    case WebCore::RTCDataChannelState::Connecting:
    case WebCore::RTCDataChannelState::Open:
    case WebCore::RTCDataChannelState::Closing:
    case WebCore::RTCDataChannelState::Closed:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(WEB_RTC)
template<> bool isValidEnum<WebCore::RTCPriorityType, void>(uint8_t value)
{
    switch (static_cast<WebCore::RTCPriorityType>(value)) {
    case WebCore::RTCPriorityType::VeryLow:
    case WebCore::RTCPriorityType::Low:
    case WebCore::RTCPriorityType::Medium:
    case WebCore::RTCPriorityType::High:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::LineCap, void>(uint8_t value)
{
    switch (static_cast<WebCore::LineCap>(value)) {
    case WebCore::LineCap::Butt:
    case WebCore::LineCap::Round:
    case WebCore::LineCap::Square:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::LineJoin, void>(uint8_t value)
{
    switch (static_cast<WebCore::LineJoin>(value)) {
    case WebCore::LineJoin::Miter:
    case WebCore::LineJoin::Round:
    case WebCore::LineJoin::Bevel:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::StrokeStyle, void>(uint8_t value)
{
    switch (static_cast<WebCore::StrokeStyle>(value)) {
    case WebCore::StrokeStyle::NoStroke:
    case WebCore::StrokeStyle::SolidStroke:
    case WebCore::StrokeStyle::DottedStroke:
    case WebCore::StrokeStyle::DashedStroke:
    case WebCore::StrokeStyle::DoubleStroke:
    case WebCore::StrokeStyle::WavyStroke:
        return true;
    default:
        return false;
    }
}

template<> bool isValidOptionSet<WebCore::TextDrawingMode>(OptionSet<WebCore::TextDrawingMode> value)
{
    constexpr uint8_t allValidBitsValue =
        static_cast<uint8_t>(WebCore::TextDrawingMode::Fill)
        | static_cast<uint8_t>(WebCore::TextDrawingMode::Stroke);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

template<> bool isValidEnum<WebCore::DecodingMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::DecodingMode>(value)) {
    case WebCore::DecodingMode::Auto:
    case WebCore::DecodingMode::SynchronousThumbnail:
    case WebCore::DecodingMode::Synchronous:
    case WebCore::DecodingMode::Asynchronous:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::DocumentMarkerLineStyleMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::DocumentMarkerLineStyleMode>(value)) {
    case WebCore::DocumentMarkerLineStyleMode::TextCheckingDictationPhraseWithAlternatives:
    case WebCore::DocumentMarkerLineStyleMode::Spelling:
    case WebCore::DocumentMarkerLineStyleMode::Grammar:
    case WebCore::DocumentMarkerLineStyleMode::AutocorrectionReplacement:
    case WebCore::DocumentMarkerLineStyleMode::DictationAlternatives:
        return true;
    default:
        return false;
    }
}

#if ENABLE(VIDEO)
template<> bool isValidEnum<WebCore::GenericCueData::Alignment, void>(uint8_t value)
{
    switch (static_cast<WebCore::GenericCueData::Alignment>(value)) {
    case WebCore::GenericCueData::Alignment::None:
    case WebCore::GenericCueData::Alignment::Start:
    case WebCore::GenericCueData::Alignment::Middle:
    case WebCore::GenericCueData::Alignment::End:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(VIDEO)
template<> bool isValidEnum<WebCore::GenericCueData::Status, void>(uint8_t value)
{
    switch (static_cast<WebCore::GenericCueData::Status>(value)) {
    case WebCore::GenericCueData::Status::Uninitialized:
    case WebCore::GenericCueData::Status::Partial:
    case WebCore::GenericCueData::Status::Complete:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidEnum<WebCore::ImageOrientation::Orientation, void>(int value)
{
    switch (static_cast<WebCore::ImageOrientation::Orientation>(value)) {
    case WebCore::ImageOrientation::Orientation::FromImage:
    case WebCore::ImageOrientation::Orientation::OriginTopLeft:
    case WebCore::ImageOrientation::Orientation::OriginTopRight:
    case WebCore::ImageOrientation::Orientation::OriginBottomRight:
    case WebCore::ImageOrientation::Orientation::OriginBottomLeft:
    case WebCore::ImageOrientation::Orientation::OriginLeftTop:
    case WebCore::ImageOrientation::Orientation::OriginRightTop:
    case WebCore::ImageOrientation::Orientation::OriginRightBottom:
    case WebCore::ImageOrientation::Orientation::OriginLeftBottom:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::CrossOriginOpenerPolicyValue, void>(uint8_t value)
{
    switch (static_cast<WebCore::CrossOriginOpenerPolicyValue>(value)) {
    case WebCore::CrossOriginOpenerPolicyValue::UnsafeNone:
    case WebCore::CrossOriginOpenerPolicyValue::SameOrigin:
    case WebCore::CrossOriginOpenerPolicyValue::SameOriginPlusCOEP:
    case WebCore::CrossOriginOpenerPolicyValue::SameOriginAllowPopups:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::HTTPCookieAcceptPolicy, void>(uint8_t value)
{
    switch (static_cast<WebCore::HTTPCookieAcceptPolicy>(value)) {
    case WebCore::HTTPCookieAcceptPolicy::AlwaysAccept:
    case WebCore::HTTPCookieAcceptPolicy::Never:
    case WebCore::HTTPCookieAcceptPolicy::OnlyFromMainDocumentDomain:
    case WebCore::HTTPCookieAcceptPolicy::ExclusivelyFromMainDocumentDomain:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::NetworkLoadPriority, void>(uint8_t value)
{
    switch (static_cast<WebCore::NetworkLoadPriority>(value)) {
    case WebCore::NetworkLoadPriority::Low:
    case WebCore::NetworkLoadPriority::Medium:
    case WebCore::NetworkLoadPriority::High:
    case WebCore::NetworkLoadPriority::Unknown:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::PrivacyStance, void>(uint8_t value)
{
    switch (static_cast<WebCore::PrivacyStance>(value)) {
    case WebCore::PrivacyStance::Unknown:
    case WebCore::PrivacyStance::NotEligible:
    case WebCore::PrivacyStance::Proxied:
    case WebCore::PrivacyStance::Failed:
    case WebCore::PrivacyStance::Direct:
    case WebCore::PrivacyStance::FailedUnreachable:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::ThirdPartyCookieBlockingMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::ThirdPartyCookieBlockingMode>(value)) {
    case WebCore::ThirdPartyCookieBlockingMode::All:
    case WebCore::ThirdPartyCookieBlockingMode::AllExceptBetweenAppBoundDomains:
    case WebCore::ThirdPartyCookieBlockingMode::AllExceptManagedDomains:
    case WebCore::ThirdPartyCookieBlockingMode::AllOnSitesWithoutUserInteraction:
    case WebCore::ThirdPartyCookieBlockingMode::OnlyAccordingToPerDomainPolicy:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FirstPartyWebsiteDataRemovalMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::FirstPartyWebsiteDataRemovalMode>(value)) {
    case WebCore::FirstPartyWebsiteDataRemovalMode::AllButCookies:
    case WebCore::FirstPartyWebsiteDataRemovalMode::None:
    case WebCore::FirstPartyWebsiteDataRemovalMode::AllButCookiesLiveOnTestingTimeout:
    case WebCore::FirstPartyWebsiteDataRemovalMode::AllButCookiesReproTestingTimeout:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebCore::FontRenderingMode, void>(uint8_t value)
{
    switch (static_cast<WebCore::FontRenderingMode>(value)) {
    case WebCore::FontRenderingMode::Normal:
    case WebCore::FontRenderingMode::Alternate:
        return true;
    default:
        return false;
    }
}

template<> bool isValidOptionSet<WebCore::DragApplicationFlags>(OptionSet<WebCore::DragApplicationFlags> value)
{
    constexpr uint8_t allValidBitsValue =
        static_cast<uint8_t>(WebCore::DragApplicationFlags::IsModal)
        | static_cast<uint8_t>(WebCore::DragApplicationFlags::IsSource)
        | static_cast<uint8_t>(WebCore::DragApplicationFlags::HasAttachedSheet)
        | static_cast<uint8_t>(WebCore::DragApplicationFlags::IsCopyKeyDown);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

template<> bool isValidOptionSet<WebCore::TextCheckingType>(OptionSet<WebCore::TextCheckingType> value)
{
    constexpr uint8_t allValidBitsValue =
        static_cast<uint8_t>(WebCore::TextCheckingType::None)
        | static_cast<uint8_t>(WebCore::TextCheckingType::Spelling)
        | static_cast<uint8_t>(WebCore::TextCheckingType::Grammar)
        | static_cast<uint8_t>(WebCore::TextCheckingType::Link)
        | static_cast<uint8_t>(WebCore::TextCheckingType::Quote)
        | static_cast<uint8_t>(WebCore::TextCheckingType::Dash)
        | static_cast<uint8_t>(WebCore::TextCheckingType::Replacement)
        | static_cast<uint8_t>(WebCore::TextCheckingType::Correction)
        | static_cast<uint8_t>(WebCore::TextCheckingType::ShowCorrectionPanel);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

#if ENABLE(SERVICE_WORKER)
template<> bool isValidEnum<WebCore::ServiceWorkerClientType, void>(uint8_t value)
{
    switch (static_cast<WebCore::ServiceWorkerClientType>(value)) {
    case WebCore::ServiceWorkerClientType::Window:
    case WebCore::ServiceWorkerClientType::Worker:
    case WebCore::ServiceWorkerClientType::Sharedworker:
    case WebCore::ServiceWorkerClientType::All:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(SERVICE_WORKER)
template<> bool isValidEnum<WebCore::ServiceWorkerJobType, void>(uint8_t value)
{
    switch (static_cast<WebCore::ServiceWorkerJobType>(value)) {
    case WebCore::ServiceWorkerJobType::Register:
    case WebCore::ServiceWorkerJobType::Unregister:
    case WebCore::ServiceWorkerJobType::Update:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(SERVICE_WORKER)
template<> bool isValidEnum<WebCore::ServiceWorkerRegistrationState, void>(uint8_t value)
{
    switch (static_cast<WebCore::ServiceWorkerRegistrationState>(value)) {
    case WebCore::ServiceWorkerRegistrationState::Installing:
    case WebCore::ServiceWorkerRegistrationState::Waiting:
    case WebCore::ServiceWorkerRegistrationState::Active:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(SERVICE_WORKER)
template<> bool isValidEnum<WebCore::ServiceWorkerState, void>(uint8_t value)
{
    switch (static_cast<WebCore::ServiceWorkerState>(value)) {
    case WebCore::ServiceWorkerState::Parsed:
    case WebCore::ServiceWorkerState::Installing:
    case WebCore::ServiceWorkerState::Installed:
    case WebCore::ServiceWorkerState::Activating:
    case WebCore::ServiceWorkerState::Activated:
    case WebCore::ServiceWorkerState::Redundant:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(SERVICE_WORKER)
template<> bool isValidEnum<WebCore::ServiceWorkerClientFrameType, void>(uint8_t value)
{
    switch (static_cast<WebCore::ServiceWorkerClientFrameType>(value)) {
    case WebCore::ServiceWorkerClientFrameType::Auxiliary:
    case WebCore::ServiceWorkerClientFrameType::TopLevel:
    case WebCore::ServiceWorkerClientFrameType::Nested:
    case WebCore::ServiceWorkerClientFrameType::None:
        return true;
    default:
        return false;
    }
}
#endif

#if ENABLE(SERVICE_WORKER)
template<> bool isValidEnum<WebCore::ServiceWorkerUpdateViaCache, void>(uint8_t value)
{
    switch (static_cast<WebCore::ServiceWorkerUpdateViaCache>(value)) {
    case WebCore::ServiceWorkerUpdateViaCache::Imports:
    case WebCore::ServiceWorkerUpdateViaCache::All:
    case WebCore::ServiceWorkerUpdateViaCache::None:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidOptionSet<WebKit::WebEventModifier>(OptionSet<WebKit::WebEventModifier> value)
{
    constexpr uint8_t allValidBitsValue =
        static_cast<uint8_t>(WebKit::WebEventModifier::ShiftKey)
        | static_cast<uint8_t>(WebKit::WebEventModifier::ControlKey)
        | static_cast<uint8_t>(WebKit::WebEventModifier::AltKey)
        | static_cast<uint8_t>(WebKit::WebEventModifier::MetaKey)
        | static_cast<uint8_t>(WebKit::WebEventModifier::CapsLockKey);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

template<> bool isValidEnum<WebKit::WebEventType, void>(int8_t value)
{
    switch (static_cast<WebKit::WebEventType>(value)) {
    case WebKit::WebEventType::NoType:
    case WebKit::WebEventType::MouseDown:
    case WebKit::WebEventType::MouseUp:
    case WebKit::WebEventType::MouseMove:
    case WebKit::WebEventType::MouseForceChanged:
    case WebKit::WebEventType::MouseForceDown:
    case WebKit::WebEventType::MouseForceUp:
    case WebKit::WebEventType::Wheel:
    case WebKit::WebEventType::KeyDown:
    case WebKit::WebEventType::KeyUp:
    case WebKit::WebEventType::RawKeyDown:
    case WebKit::WebEventType::Char:
#if ENABLE(TOUCH_EVENTS)
    case WebKit::WebEventType::TouchStart:
#endif
#if ENABLE(TOUCH_EVENTS)
    case WebKit::WebEventType::TouchMove:
#endif
#if ENABLE(TOUCH_EVENTS)
    case WebKit::WebEventType::TouchEnd:
#endif
#if ENABLE(TOUCH_EVENTS)
    case WebKit::WebEventType::TouchCancel:
#endif
#if ENABLE(MAC_GESTURE_EVENTS)
    case WebKit::WebEventType::GestureStart:
#endif
#if ENABLE(MAC_GESTURE_EVENTS)
    case WebKit::WebEventType::GestureChange:
#endif
#if ENABLE(MAC_GESTURE_EVENTS)
    case WebKit::WebEventType::GestureEnd:
#endif
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebKit::WebMouseEventButton, void>(int32_t value)
{
    switch (static_cast<WebKit::WebMouseEventButton>(value)) {
    case WebKit::WebMouseEventButton::LeftButton:
    case WebKit::WebMouseEventButton::MiddleButton:
    case WebKit::WebMouseEventButton::RightButton:
    case WebKit::WebMouseEventButton::NoButton:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebKit::WebMouseEventSyntheticClickType, void>(uint32_t value)
{
    switch (static_cast<WebKit::WebMouseEventSyntheticClickType>(value)) {
    case WebKit::WebMouseEventSyntheticClickType::NoTap:
    case WebKit::WebMouseEventSyntheticClickType::OneFingerTap:
    case WebKit::WebMouseEventSyntheticClickType::TwoFingerTap:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebKit::WebWheelEvent::Granularity, void>(uint8_t value)
{
    switch (static_cast<WebKit::WebWheelEvent::Granularity>(value)) {
    case WebKit::WebWheelEvent::Granularity::ScrollByPageWheelEvent:
    case WebKit::WebWheelEvent::Granularity::ScrollByPixelWheelEvent:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebKit::WebWheelEvent::Phase, void>(uint32_t value)
{
    switch (static_cast<WebKit::WebWheelEvent::Phase>(value)) {
    case WebKit::WebWheelEvent::Phase::PhaseNone:
    case WebKit::WebWheelEvent::Phase::PhaseBegan:
    case WebKit::WebWheelEvent::Phase::PhaseStationary:
    case WebKit::WebWheelEvent::Phase::PhaseChanged:
    case WebKit::WebWheelEvent::Phase::PhaseEnded:
    case WebKit::WebWheelEvent::Phase::PhaseCancelled:
    case WebKit::WebWheelEvent::Phase::PhaseMayBegin:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebKit::WebWheelEvent::MomentumEndType, void>(uint8_t value)
{
    switch (static_cast<WebKit::WebWheelEvent::MomentumEndType>(value)) {
    case WebKit::WebWheelEvent::MomentumEndType::Unknown:
    case WebKit::WebWheelEvent::MomentumEndType::Interrupted:
    case WebKit::WebWheelEvent::MomentumEndType::Natural:
        return true;
    default:
        return false;
    }
}

template<> bool isValidEnum<WebKit::WebHitTestResultData::IsScrollbar, void>(uint8_t value)
{
    switch (static_cast<WebKit::WebHitTestResultData::IsScrollbar>(value)) {
    case WebKit::WebHitTestResultData::IsScrollbar::No:
    case WebKit::WebHitTestResultData::IsScrollbar::Vertical:
    case WebKit::WebHitTestResultData::IsScrollbar::Horizontal:
        return true;
    default:
        return false;
    }
}

#if ENABLE(WK_WEB_EXTENSIONS)
template<> bool isValidEnum<WebKit::WebExtensionEventListenerType, void>(uint8_t value)
{
    switch (static_cast<WebKit::WebExtensionEventListenerType>(value)) {
    case WebKit::WebExtensionEventListenerType::Unknown:
    case WebKit::WebExtensionEventListenerType::ActionOnClicked:
    case WebKit::WebExtensionEventListenerType::AlarmsOnAlarm:
    case WebKit::WebExtensionEventListenerType::CommandsOnCommand:
    case WebKit::WebExtensionEventListenerType::ContextMenusOnClicked:
    case WebKit::WebExtensionEventListenerType::CookiesOnChanged:
    case WebKit::WebExtensionEventListenerType::DevToolsElementsPanelOnSelectionChanged:
    case WebKit::WebExtensionEventListenerType::DevToolsExtensionPanelOnShown:
    case WebKit::WebExtensionEventListenerType::DevToolsExtensionPanelOnHidden:
    case WebKit::WebExtensionEventListenerType::DevToolsExtensionSidebarPaneOnShown:
    case WebKit::WebExtensionEventListenerType::DevToolsExtensionSidebarPaneOnHidden:
    case WebKit::WebExtensionEventListenerType::DevToolsExtensionPanelOnSearch:
    case WebKit::WebExtensionEventListenerType::DevToolsNetworkOnNavigated:
    case WebKit::WebExtensionEventListenerType::DevToolsNetworkOnRequestFinished:
    case WebKit::WebExtensionEventListenerType::DevToolsPanelsOnThemeChanged:
    case WebKit::WebExtensionEventListenerType::NotificationsOnButtonClicked:
    case WebKit::WebExtensionEventListenerType::NotificationsOnClicked:
    case WebKit::WebExtensionEventListenerType::PermissionsOnAdded:
    case WebKit::WebExtensionEventListenerType::PermissionsOnRemoved:
    case WebKit::WebExtensionEventListenerType::PortOnDisconnect:
    case WebKit::WebExtensionEventListenerType::PortOnMessage:
    case WebKit::WebExtensionEventListenerType::RuntimeOnConnect:
    case WebKit::WebExtensionEventListenerType::RuntimeOnConnectExternal:
    case WebKit::WebExtensionEventListenerType::RuntimeOnInstalled:
    case WebKit::WebExtensionEventListenerType::RuntimeOnMessage:
    case WebKit::WebExtensionEventListenerType::RuntimeOnMessageExternal:
    case WebKit::WebExtensionEventListenerType::RuntimeOnStartup:
    case WebKit::WebExtensionEventListenerType::StorageOnChanged:
    case WebKit::WebExtensionEventListenerType::TabsOnActivated:
    case WebKit::WebExtensionEventListenerType::TabsOnAttached:
    case WebKit::WebExtensionEventListenerType::TabsOnCreated:
    case WebKit::WebExtensionEventListenerType::TabsOnDetached:
    case WebKit::WebExtensionEventListenerType::TabsOnHighlighted:
    case WebKit::WebExtensionEventListenerType::TabsOnMoved:
    case WebKit::WebExtensionEventListenerType::TabsOnRemoved:
    case WebKit::WebExtensionEventListenerType::TabsOnReplaced:
    case WebKit::WebExtensionEventListenerType::TabsOnUpdated:
    case WebKit::WebExtensionEventListenerType::WebNavigationOnBeforeNavigate:
    case WebKit::WebExtensionEventListenerType::WebNavigationOnCommitted:
    case WebKit::WebExtensionEventListenerType::WebNavigationOnCompleted:
    case WebKit::WebExtensionEventListenerType::WebNavigationOnDOMContentLoaded:
    case WebKit::WebExtensionEventListenerType::WebNavigationOnErrorOccurred:
    case WebKit::WebExtensionEventListenerType::WebRequestOnAuthRequired:
    case WebKit::WebExtensionEventListenerType::WebRequestOnBeforeRedirect:
    case WebKit::WebExtensionEventListenerType::WebRequestOnBeforeRequest:
    case WebKit::WebExtensionEventListenerType::WebRequestOnBeforeSendHeaders:
    case WebKit::WebExtensionEventListenerType::WebRequestOnCompleted:
    case WebKit::WebExtensionEventListenerType::WebRequestOnErrorOccurred:
    case WebKit::WebExtensionEventListenerType::WebRequestOnHeadersReceived:
    case WebKit::WebExtensionEventListenerType::WebRequestOnResponseStarted:
    case WebKit::WebExtensionEventListenerType::WebRequestOnSendHeaders:
    case WebKit::WebExtensionEventListenerType::WindowsOnCreated:
    case WebKit::WebExtensionEventListenerType::WindowsOnFocusChanged:
    case WebKit::WebExtensionEventListenerType::WindowsOnRemoved:
    case WebKit::WebExtensionEventListenerType::DevToolsInspectedWindowOnResourceAdded:
    case WebKit::WebExtensionEventListenerType::DownloadsOnCreated:
    case WebKit::WebExtensionEventListenerType::DownloadsOnChanged:
        return true;
    default:
        return false;
    }
}
#endif

#if PLATFORM(COCOA)
template<> bool isValidOptionSet<WebKit::LayerChange>(OptionSet<WebKit::LayerChange> value)
{
    constexpr uint64_t allValidBitsValue =
        static_cast<uint64_t>(WebKit::LayerChange::NameChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::ChildrenChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::PositionChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::BoundsChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::BackgroundColorChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::AnchorPointChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::BorderWidthChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::BorderColorChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::OpacityChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::TransformChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::SublayerTransformChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::HiddenChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::GeometryFlippedChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::DoubleSidedChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::MasksToBoundsChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::OpaqueChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::ContentsHiddenChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::MaskLayerChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::ClonedContentsChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::ContentsRectChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::ContentsScaleChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::CornerRadiusChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::ShapeRoundedRectChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::ShapePathChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::MinificationFilterChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::MagnificationFilterChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::BlendModeChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::WindRuleChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::SpeedChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::TimeOffsetChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::BackingStoreChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::BackingStoreAttachmentChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::FiltersChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::AnimationsChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::AntialiasesEdgesChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::CustomAppearanceChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::UserInteractionEnabledChanged)
        | static_cast<uint64_t>(WebKit::LayerChange::EventRegionChanged)
#if HAVE(CORE_ANIMATION_SEPARATED_LAYERS)
        | static_cast<uint64_t>(WebKit::LayerChange::SeparatedChanged)
#endif
#if HAVE(CORE_ANIMATION_SEPARATED_LAYERS) && HAVE(CORE_ANIMATION_SEPARATED_PORTALS)
        | static_cast<uint64_t>(WebKit::LayerChange::SeparatedPortalChanged)
#endif
#if HAVE(CORE_ANIMATION_SEPARATED_LAYERS) && HAVE(CORE_ANIMATION_SEPARATED_PORTALS)
        | static_cast<uint64_t>(WebKit::LayerChange::DescendentOfSeparatedPortalChanged)
#endif
        | static_cast<uint64_t>(WebKit::LayerChange::ScrollingNodeIDChanged);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}
#endif

template<> bool isValidEnum<WebKit::SwapBuffersDisplayRequirement, void>(uint8_t value)
{
    switch (static_cast<WebKit::SwapBuffersDisplayRequirement>(value)) {
    case WebKit::SwapBuffersDisplayRequirement::NeedsFullDisplay:
    case WebKit::SwapBuffersDisplayRequirement::NeedsNormalDisplay:
    case WebKit::SwapBuffersDisplayRequirement::NeedsNoDisplay:
        return true;
    default:
        return false;
    }
}

template<> bool isValidOptionSet<WebKit::RemoteScrollingUIStateChanges>(OptionSet<WebKit::RemoteScrollingUIStateChanges> value)
{
    constexpr uint8_t allValidBitsValue =
        static_cast<uint8_t>(WebKit::RemoteScrollingUIStateChanges::ScrollSnapNodes)
        | static_cast<uint8_t>(WebKit::RemoteScrollingUIStateChanges::UserScrollNodes);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

#if ENABLE(GPU_PROCESS)
template<> bool isValidEnum<PAL::WebGPU::FeatureName, void>(uint8_t value)
{
    switch (static_cast<PAL::WebGPU::FeatureName>(value)) {
    case PAL::WebGPU::FeatureName::DepthClipControl:
    case PAL::WebGPU::FeatureName::Depth32floatStencil8:
    case PAL::WebGPU::FeatureName::TextureCompressionBc:
    case PAL::WebGPU::FeatureName::TextureCompressionEtc2:
    case PAL::WebGPU::FeatureName::TextureCompressionAstc:
    case PAL::WebGPU::FeatureName::TimestampQuery:
    case PAL::WebGPU::FeatureName::IndirectFirstInstance:
        return true;
    default:
        return false;
    }
}
#endif

template<> bool isValidOptionSet<WebKit::WebsiteDataFetchOption>(OptionSet<WebKit::WebsiteDataFetchOption> value)
{
    constexpr uint8_t allValidBitsValue =
        static_cast<uint8_t>(WebKit::WebsiteDataFetchOption::ComputeSizes)
        | static_cast<uint8_t>(WebKit::WebsiteDataFetchOption::DoNotCreateProcesses);
    return (value.toRaw() | allValidBitsValue) == allValidBitsValue;
}

#if ENABLE(WEBXR)
template<> bool isValidEnum<PlatformXR::SessionFeature, void>(uint8_t value)
{
    switch (static_cast<PlatformXR::SessionFeature>(value)) {
    case PlatformXR::SessionFeature::ReferenceSpaceTypeViewer:
    case PlatformXR::SessionFeature::ReferenceSpaceTypeLocal:
    case PlatformXR::SessionFeature::ReferenceSpaceTypeLocalFloor:
    case PlatformXR::SessionFeature::ReferenceSpaceTypeBoundedFloor:
    case PlatformXR::SessionFeature::ReferenceSpaceTypeUnbounded:
#if ENABLE(WEBXR_HANDS)
    case PlatformXR::SessionFeature::HandTracking:
#endif
        return true;
    default:
        return false;
    }
}
#endif

} // namespace WTF

#if COMPILER(GCC)
IGNORE_WARNINGS_END
#endif
